package ConfigurationConversion;
# $Header: /usr/local/CVS/SoundPointIP/IPPhone/Utilities/WolverineConfigFileConversion/ConfigurationConversion.pm,v 1.2 2010/07/22 20:53:05 brad_marusiak Exp $
##
##
## Copyright (c) 2010 Polycom Inc.
##
##
use strict;
use warnings;
use XML::Simple;

my $VERSION = '$Revision: 1.2 $';
my $currFilePath;
my $removedReportPath;
my $nonDefaultReportPath;
my $deprecatedReportPath;
my $warningsReportPath;
my $baseline = loadBaselines();
my $currentConf;
my %wolverineParams;
my $outputFilePath;
my $flatOutput = 0;
my %codecs;
my @customLangs;


## Warning flags, each of these warnings we only want to log once
my $warn_codecPreferenceChanges = 0;
my $warn_audioSettingChanges = 0;
my $warn_fileSystemChanges = 0;
my $warn_readonly = 0;

## features, ringtones, chords, ringers, etc... All things who used to be indexed via integer and are now named
my @baselineFeaturendex = qw(presence messaging directory calllist ring-download calllist-received calllist-placed
                            calllist-missed url-dialing call-park group-call-pickup directed-call-pickup last-call-return
                            acd-login-logout acd-agent-availability nway-conference call-recording enhanced-feature-keys
                            corporate-directory picture-frame);
my @langs = qw(Chinese_China Danish_Denmark Dutch_Netherlands English_Canada English_United_Kingdom English_United_States French_France
          German_Germany Italian_Italy Japanese_Japan Korean_Korea Norwegian_Norway Polish_Poland Portuguese_Portugal Russian_Russia
          Slovenian_Slovenia Spanish_Spain Swedish_Sweden);
my @ringers = qw(ringer1 ringer2 ringer3 ringer4 ringer5 ringer6 ringer7 ringer8 ringer9 ringer10
                ringer11 ringer12 ringer15 ringer16 ringer17 ringer18 ringer19 ringer20 ringer21
                ringer22 ringer23 ringer24 ringer13 ringer14); ## the last 2 are intentionally out of order (they were added in wolverine)
my @ringtones = qw(default visual autoAnswer ringAutoAnswer internal external emergency custom1 custom2 custom3 custom4
                  custom5 custom6 custom7 custom8 custom9 custom10 custom11 custom12 custom13 custom14 custom15 custom16 custom17 precedence);
my @callProg = qw(dialTone busyTone ringback reorder stutter callWaiting callWaitingLong confirmation howler recWarning msgWaiting
                 alerting intercom bargeIn secondaryDialTone);
my @miscPattern = qw(messageWaiting instantMessage remoteHoldNotification localHoldNotification positiveConfirm
                   negativeConfirm welcome);
my @ringerChords = qw(F2 Gb2 G2 Ab2 A3 Bb3 B3 C3 Db3 D3 Eb3 E3 F3 Gb3 G3 Ab3 A4 Bb4 B4 C4
                     Db4 D4 Eb4 E4 F4 spare1 spare2 spare3 spare4 spare5 A3Major Bb3Major B3Major C3Major Db3Major D3Major
                   Eb3Major E3Major F3Major Gb3Major G3Major Ab3Major A4Major spare6 spare7 ringback
                   spare8 spare9 spare10 spare11 originalLow originalHigh spare12 spare13 spare14 spare15 spare16
                   spare17 spare18 spare19);
my @callProgChords = qw(dialTone busyTone ringback reorder stutter_3 callWaiting howler recWarning stutterLong intercom);
my @miscChord = qw(cs1 cs2 cs3 cs4 cs5 cs6 cs7 cs8 cs9 cs10 cs11);
my @indicatorPatterns = qw(off on wink flash flutter brokenFlutter active offering flashSlow lockedOut scaHeld
                       held remoteBusyOffering powerSaving);


## This hash lists all parameters that existed in pre 3.3.0 releases which have
## been removed or have undergone name changes.
##
## Format is    old_param_name => 3.3.0_param_name
##
## Some old parameters can map to multiple new parameters
## Just input those as an array
##
## Format is    old_param_name => [3.3.0_param1_name, 3.3.0_param2_name, ...]
my %DEPRECATED = (
    ## all the feature.x.name params are omitted, they must be special cased
    ## because of the integer in their names which is technically variable.
    'feature.x.name'                => undef,
    'feature.x.enabled'             => undef,

    'log.level.change.sspsc'        => undef,
    'log.level.change.httpauth'     => 'log.level.change.httpa',
    'voIpProt.local.port'           => 'voIpProt.SIP.local.port',

    'usb.VVX_1500.recordBufSize.1'  => 'usb.recordBufSize.1',
    'usb.VVX_1500.recordBufSize.2'  => 'usb.recordBufSize.2',
    'usb.VVX_1500.recordBufSize.3'  => 'usb.recordBufSize.3',
    'usb.IP_650.recordBufSize.1'    => ['usb.recordBufSize.1.IP650', 'usb.recordBufSize.1.IP670'],
    'usb.IP_650.recordBufSize.2'    => ['usb.recordBufSize.2.IP650', 'usb.recordBufSize.3.IP670'],
    'usb.IP_650.recordBufSize.3'    => ['usb.recordBufSize.2.IP650', 'usb.recordBufSize.3.IP670'],

    'se.rt.4.mod'                   => undef,

    ## resources and memory usage parameters
    'dir.local.volatile.maxSize.2meg'=> undef,
    'dir.local.volatile.maxSize.8meg'=> 'dir.local.volatile.maxSize',
    'dir.local.volatile.maxSize.4meg'=>['dir.local.volatile.maxSize.SPIP320', 'dir.local.volatile.maxSize.SPIP330'],
    'dir.local.nonvolatile.maxSize.2meg'=> undef,
    'dir.local.nonvolatile.maxSize.8meg'=> 'dir.local.nonVolatile.maxSize',
    'dir.local.nonVolatile.maxSize.4meg' =>['dir.local.nonVolatile.maxSize.SPIP320', 'dir.local.nonVolatile.maxSize.SPIP330'],
    'dir.global.volatile.maxSize.2meg'=> undef,
    'dir.global.volatile.maxSize.8meg'=> 'dir.global.volatile.maxSize',
    'dir.global.volatile.maxSize.4meg'=>   ['dir.global.volatile.maxSize.SPIP320', 'dir.global.volatile.maxSize.SPIP330'],
    'dir.global.nonvolatile.maxSize.2meg'=> undef,
    'dir.global.nonvolatile.maxSize.8meg'=> 'dir.global.nonVolatile.maxSize',
    'dir.global.nonVolatile.maxSize.4meg'=>['dir.global.nonVolatile.maxSize.SPIP320', 'dir.global.nonVolatile.maxSize.SPIP320'],
    'prov.fileSystem.rfs0.minFreeSpace' => undef,
    'prov.fileSystem.ffs0.2meg.minFreeSpace' => undef,
    'prov.fileSystem.ffs0.4meg.minFreeSpace' => ['prov.fileSystem.ffs0.minFreeSpace.SPIP320', 'prov.fileSystem.ffs0.minFreeSpace.SPIP330'],
    'prov.fileSystem.ffs0.8meg.minFreeSpace' => undef,
    'prov.fileSystem.ffs0.minFreeSpace' => undef,
    'res.quotas.1.name'             => undef,
    'res.quotas.2.name'             => undef,
    'res.quotas.3.name'             => undef,
    'res.quotas.4.name'             => undef,
    'res.quotas.5.name'             => undef,
    'res.quotas.6.name'             => undef,

    'ramdisk.bytesPerBlock'         => undef,
    'ramdisk.blocksPerTrack'        => undef,
    'ramdisk.nBlocks'               => undef,
    'ramdisk.nBlocks.IP_650'        => undef,

    'ind.idleDisplay.mode'          => undef,

    ## Launchpad settings
    'mb.launchpad.enabled'          => undef,
    'mb.main.1.icon'                => undef,
    'mb.main.1.text'                => undef,
    'mb.main.1.url'                 => undef,
    'mb.main.2.icon'                => undef,
    'mb.main.2.text'                => undef,
    'mb.main.2.url'                 => undef,
    'mb.main.3.icon'                => undef,
    'mb.main.3.text'                => undef,
    'mb.main.3.url'                 => undef,
    'mb.main.4.icon'                => undef,
    'mb.main.4.text'                => undef,
    'mb.main.4.url'                 => undef,
    'mb.main.5.icon'                => undef,
    'mb.main.5.text'                => undef,
    'mb.main.5.url'                 => undef,
    'mb.main.6.icon'                => undef,
    'mb.main.6.text'                => undef,
    'mb.main.6.url'                 => undef,
    'mb.limits.nodes'               => undef,


    ## Audio Parameters - generic configs are removed
    'voice.audioProfile.Lin16.payloadSize'          => ["voice.audioProfile.Lin16.16ksps.payloadSize",
                                                        "voice.audioProfile.Lin16.32ksps.payloadSize",
                                                        "voice.audioProfile.Lin16.44_1ksps.payloadSize",
                                                        "voice.audioProfile.Lin16.48ksps.payloadSize",
                                                        "voice.audioProfile.Lin16.8ksps.payloadSize"],
    'voice.audioProfile.Lin16.jitterBufferMin'      => ["voice.audioProfile.Lin16.16ksps.jitterBufferMin",
                                                        "voice.audioProfile.Lin16.32ksps.jitterBufferMin",
                                                        "voice.audioProfile.Lin16.44_1ksps.jitterBufferMin",
                                                        "voice.audioProfile.Lin16.48ksps.jitterBufferMin",
                                                        "voice.audioProfile.Lin16.8ksps.jitterBufferMin"],
    'voice.audioProfile.Lin16.jitterBufferMax'      => ["voice.audioProfile.Lin16.16ksps.jitterBufferMax",
                                                        "voice.audioProfile.Lin16.32ksps.jitterBufferMax",
                                                        "voice.audioProfile.Lin16.44_1ksps.jitterBufferMax",
                                                        "voice.audioProfile.Lin16.48ksps.jitterBufferMax",
                                                        "voice.audioProfile.Lin16.8ksps.jitterBufferMax"],
    'voice.audioProfile.Lin16.jitterBufferShrink'   => ["voice.audioProfile.Lin16.16ksps.jitterBufferShrink",
                                                        "voice.audioProfile.Lin16.32ksps.jitterBufferShrink",
                                                        "voice.audioProfile.Lin16.44_1ksps.jitterBufferShrink",
                                                        "voice.audioProfile.Lin16.48ksps.jitterBufferShrink",
                                                        "voice.audioProfile.Lin16.8ksps.jitterBufferShrink"],
    'voice.audioProfile.G7221.payloadSize'          => ['voice.audioProfile.G7221.16kbps.payloadSize',
                                                        'voice.audioProfile.G7221.24kbps.payloadSize',
                                                        'voice.audioProfile.G7221.32kbps.payloadSize'],
    'voice.audioProfile.G7221.jitterBufferMin'      => ['voice.audioProfile.G7221.16kbps.jitterBufferMin',
                                                        'voice.audioProfile.G7221.24kbps.jitterBufferMin',
                                                        'voice.audioProfile.G7221.32kbps.jitterBufferMin'],
    'voice.audioProfile.G7221.jitterBufferMax'      => ['voice.audioProfile.G7221.16kbps.jitterBufferMax',
                                                        'voice.audioProfile.G7221.24kbps.jitterBufferMax',
                                                        'voice.audioProfile.G7221.32kbps.jitterBufferMax'],
    'voice.audioProfile.G7221.jitterBufferShrink'   => ['voice.audioProfile.G7221.16kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G7221.24kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G7221.32kbps.jitterBufferShrink'],
    'voice.audioProfile.G7221C.payloadSize'         => ['voice.audioProfile.G7221C.24kbps.payloadSize',
                                                        'voice.audioProfile.G7221C.32kbps.payloadSize',
                                                        'voice.audioProfile.G7221C.48kbps.payloadSize'],
    'voice.audioProfile.G7221C.jitterBufferMin'     => ['voice.audioProfile.G7221C.24kbps.jitterBufferMin',
                                                        'voice.audioProfile.G7221C.32kbps.jitterBufferMin',
                                                        'voice.audioProfile.G7221C.48kbps.jitterBufferMin'],
    'voice.audioProfile.G7221C.jitterBufferMax'     => ['voice.audioProfile.G7221C.24kbps.jitterBufferMax',
                                                        'voice.audioProfile.G7221C.32kbps.jitterBufferMax',
                                                        'voice.audioProfile.G7221C.48kbps.jitterBufferMax'],
    'voice.audioProfile.G7221C.jitterBufferShrink'  => ['voice.audioProfile.G7221C.24kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G7221C.32kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G7221C.48kbps.jitterBufferShrink'],
    'voice.audioProfile.Siren14.payloadSize'        => ['voice.audioProfile.Siren14.24kbps.payloadSize',
                                                        'voice.audioProfile.Siren14.32kbps.payloadSize',
                                                        'voice.audioProfile.Siren14.48kbps.payloadSize'],
    'voice.audioProfile.Siren14.jitterBufferMin'    => ['voice.audioProfile.Siren14.24kbps.jitterBufferMin',
                                                        'voice.audioProfile.Siren14.32kbps.jitterBufferMin',
                                                        'voice.audioProfile.Siren14.48kbps.jitterBufferMin'],
    'voice.audioProfile.Siren14.jitterBufferMax'    => ['voice.audioProfile.Siren14.24kbps.jitterBufferMax',
                                                        'voice.audioProfile.Siren14.32kbps.jitterBufferMax',
                                                        'voice.audioProfile.Siren14.48kbps.jitterBufferMax'],
    'voice.audioProfile.Siren14.jitterBufferShrink' => ['voice.audioProfile.Siren14.24kbps.jitterBufferShrink',
                                                        'voice.audioProfile.Siren14.32kbps.jitterBufferShrink',
                                                        'voice.audioProfile.Siren14.48kbps.jitterBufferShrink'],
    'voice.audioProfile.Siren22.payloadSize'        => ['voice.audioProfile.Siren22.32kbps.payloadSize',
                                                        'voice.audioProfile.Siren22.48kbps.payloadSize',
                                                        'voice.audioProfile.Siren22.64kbps.payloadSize'],
    'voice.audioProfile.Siren22.jitterBufferMin'    => ['voice.audioProfile.Siren22.32kbps.jitterBufferMin',
                                                        'voice.audioProfile.Siren22.48kbps.jitterBufferMin',
                                                        'voice.audioProfile.Siren22.64kbps.jitterBufferMin'],
    'voice.audioProfile.Siren22.jitterBufferMax'    => ['voice.audioProfile.Siren22.32kbps.jitterBufferMax',
                                                        'voice.audioProfile.Siren22.48kbps.jitterBufferMax',
                                                        'voice.audioProfile.Siren22.64kbps.jitterBufferMax'],
    'voice.audioProfile.Siren22.jitterBufferShrink' => ['voice.audioProfile.Siren22.32kbps.jitterBufferShrink',
                                                        'voice.audioProfile.Siren22.48kbps.jitterBufferShrink',
                                                        'voice.audioProfile.Siren22.64kbps.jitterBufferShrink'],
    'voice.audioProfile.iLBC.payloadSize'           => ["voice.audioProfile.iLBC.13_33kbps.payloadSize",
                                                        "voice.audioProfile.iLBC.15_2kbps.payloadSize"],
    'voice.audioProfile.iLBC.jitterBufferMin'       => ["voice.audioProfile.iLBC.13_33kbps.jitterBufferMin",
                                                        "voice.audioProfile.iLBC.15_2kbps.jitterBufferMin"],
    'voice.audioProfile.iLBC.jitterBufferMax'       => ["voice.audioProfile.iLBC.13_33kbps.jitterBufferMax",
                                                        "voice.audioProfile.iLBC.15_2kbps.jitterBufferMax"],
    'voice.audioProfile.iLBC.jitterBufferShrink'    => ["voice.audioProfile.iLBC.13_33kbps.jitterBufferShrink",
                                                        "voice.audioProfile.iLBC.15_2kbps.jitterBufferShrink"],
    'voice.audioProfile.G719.payloadSize'           => ['voice.audioProfile.G719.32kbps.payloadSize',
                                                        'voice.audioProfile.G719.48kbps.payloadSize',
                                                        'voice.audioProfile.G719.64kbps.payloadSize'],
    'voice.audioProfile.G719.jitterBufferMin'       => ['voice.audioProfile.G719.32kbps.jitterBufferMin',
                                                        'voice.audioProfile.G719.48kbps.jitterBufferMin',
                                                        'voice.audioProfile.G719.64kbps.jitterBufferMin'],
    'voice.audioProfile.G719.jitterBufferMax'       => ['voice.audioProfile.G719.32kbps.jitterBufferMax',
                                                        'voice.audioProfile.G719.48kbps.jitterBufferMax',
                                                        'voice.audioProfile.G719.64kbps.jitterBufferMax'],
    'voice.audioProfile.G719.jitterBufferShrink'    => ['voice.audioProfile.G719.32kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G719.48kbps.jitterBufferShrink',
                                                        'voice.audioProfile.G719.64kbps.jitterBufferShrink'],


    ## These key parameters and their functions are special cased in the main conversion file
    #'key.XXXX.YYYY.function.prim'   =>'',
    #'key.XXXX.YYYY.subPoint.prim '  =>'',

    ## localization
    'lcl.ml.lang.IP_500.list'       => ['lcl.ml.lang.list.SPIP320',
                                        'lcl.ml.lang.list.SPIP330',
                                        'lcl.ml.lang.list.SPIP321',
                                        'lcl.ml.lang.list.SPIP331',
                                        'lcl.ml.lang.list.SPIP335'],
    'lcl.ml.lang.IP_600.list'       =>  'lcl.ml.lang.list',
    'lcl.ml.lang.IP_4000.list'       => undef,

    'voice.codecPref.G711Mu'            => undef,
    'voice.codecPref.G711A'             => undef,
    'voice.codecPref.G729AB'            => undef,
    'voice.codecPref.iLBC.13_33kbps'    => undef,
    'voice.codecPref.iLBC.15_2kbps'     => undef,
    'voice.codecPref.IP_300.G711Mu'     => undef,
    'voice.codecPref.IP_300.G711A'      => undef,
    'voice.codecPref.IP_300.G729AB'     => undef,
    'voice.codecPref.IP_4000.G711Mu'    => undef,
    'voice.codecPref.IP_4000.G711A'     => undef,
    'voice.codecPref.IP_4000.G729AB'    => undef,
    'voice.codecPref.IP_7000.G711Mu'    => undef,
    'voice.codecPref.IP_7000.G711A'     => undef,
    'voice.codecPref.IP_7000.G729AB'    => undef,
    'voice.codecPref.IP_7000.G722'      => undef,
    'voice.codecPref.IP_7000.G7221.16kbps' => undef,
    'voice.codecPref.IP_7000.G7221.24kbps' => undef,
    'voice.codecPref.IP_7000.G7221.32kbps' => undef,
    'voice.codecPref.IP_7000.G7221C.24kbps' => undef,
    'voice.codecPref.IP_7000.G7221C.32kbps' => undef,
    'voice.codecPref.IP_7000.G7221C.48kbps' => undef,
    'voice.codecPref.IP_7000.Siren14.24kbps' => undef,
    'voice.codecPref.IP_7000.Siren14.32kbps' => undef,
    'voice.codecPref.IP_7000.Siren14.48kbps' => undef,
    'voice.codecPref.IP_7000.Siren22.32kbps' => undef,
    'voice.codecPref.IP_7000.Siren22.48kbps' => undef,
    'voice.codecPref.IP_7000.Siren22.64kbps' => undef,
    'voice.codecPref.IP_7000.iLBC.13_33kbps' => undef,
    'voice.codecPref.IP_7000.iLBC.15_2kbps' => undef,
    'voice.codecPref.IP_7000.Lin16.16ksps'  => undef,
    'voice.codecPref.IP_7000.Lin16.32ksps'  => undef,
    'voice.codecPref.IP_7000.Lin16.48ksps'  => undef,
    'voice.codecPref.IP_650.G711Mu'         => undef,
    'voice.codecPref.IP_650.G711A'          => undef,
    'voice.codecPref.IP_650.G729AB'         => undef,
    'voice.codecPref.IP_650.G722'           => undef,
    'voice.codecPref.IP_650.iLBC.13_33kbps' => undef,
    'voice.codecPref.IP_650.iLBC.15_2kbps'  => undef,
    'voice.codecPref.IP_6000.G711Mu'        => undef,
    'voice.codecPref.IP_6000.G711A'         => undef,
    'voice.codecPref.IP_6000.G729AB'        => undef,
    'voice.codecPref.IP_6000.G722'          => undef,
    'voice.codecPref.IP_6000.G7221.16kbps'  => undef,
    'voice.codecPref.IP_6000.G7221.24kbps'  => undef,
    'voice.codecPref.IP_6000.G7221.32kbps'  => undef,
    'voice.codecPref.IP_6000.G7221C.24kbps' => undef,
    'voice.codecPref.IP_6000.G7221C.32kbps' => undef,
    'voice.codecPref.IP_6000.G7221C.48kbps' => undef,
    'voice.codecPref.IP_6000.Siren14.24kbps' => undef,
    'voice.codecPref.IP_6000.Siren14.32kbps' => undef,
    'voice.codecPref.IP_6000.Siren14.48kbps' => undef,
    'voice.codecPref.IP_6000.iLBC.13_33kbps' => undef,
    'voice.codecPref.IP_6000.iLBC.15_2kbps' => undef,
    'voice.codecPref.VVX_1500.G711Mu'       => undef,
    'voice.codecPref.VVX_1500.G711A'        => undef,
    'voice.codecPref.VVX_1500.G729AB'       => undef,
    'voice.codecPref.VVX_1500.G722'         => undef,
    'voice.codecPref.VVX_1500.G7221.16kbps' => undef,
    'voice.codecPref.VVX_1500.G7221.24kbps' => undef,
    'voice.codecPref.VVX_1500.G7221.32kbps' => undef,
    'voice.codecPref.VVX_1500.G7221C.24kbps' => undef,
    'voice.codecPref.VVX_1500.G7221C.32kbps' => undef,
    'voice.codecPref.VVX_1500.G7221C.48kbps' => undef,
    'voice.codecPref.VVX_1500.Siren14.24kbps' => undef,
    'voice.codecPref.VVX_1500.Siren14.32kbps' => undef,
    'voice.codecPref.VVX_1500.Siren14.48kbps' => undef,
    'voice.codecPref.VVX_1500.iLBC.13_33kbps' => undef,
    'voice.codecPref.VVX_1500.iLBC.15_2kbps' => undef,
    'voice.codecPref.VVX_1500.G719.32kbps' => undef,
    'voice.codecPref.VVX_1500.G719.48kbps' => undef,
    'voice.codecPref.VVX_1500.G719.64kbps' => undef,
    'voice.codecPref.VVX_1500.Lin16.8ksps' => undef,
    'voice.codecPref.VVX_1500.Lin16.16ksps' => undef,
    'voice.codecPref.VVX_1500.Lin16.32ksps' => undef,
    'voice.codecPref.VVX_1500.Lin16.44_1ksps' => undef,
    'voice.codecPref.VVX_1500.Lin16.48ksps' => undef
);








################################################################################
# setOptions - Configure the various options
#
# Parameters:
#
#   Report_Removed:
#       Values: <Filename>
#
#       Print to <Filename> all the parameters in your config file that have
#       not changed from the defaults. These are parameters that are not required
#       to be in a file when running UC 3.3.0
#       This setting will create A LOT of output.
#
#   Report_NonDefaults:
#       argument: <Filename>
#
#       Print to <Filename> all the parameters in your config file that have
#       been changed from the default values but whose parameter name remains
#       the same as past releases. These are parameters that must remain in
#       your config file when running UC 3.3.0 in order to take effect.
#
#   Report_Deprecated:
#       argument: <Filename>
#
#       Print to <Filename> all the parameters in your config file that have
#       been removed or changed in UC 3.3.0. These parameters will be included
#       in your config file only if their value has been modified from default.
#
#   Report_Warnings:
#       argument: <Filename>    (defaults to ./IMPORTANT_UC330_WARNINGS.txt if omitted)
#
#       This file will contain any important warnings or messages regarding issues
#       found while performing the configuration file conversion.
#
#   Output_File:
#       The completed config file after conversion.
#       Omit this parameter if you only wish to generate reports.
#
#   Flat_Output:
#       Output file will be a single level xml structure with all parameters as
#       atrtributes of the top level element.
#
################################################################################
sub setOptions
{
    my %args = @_;
    my $err = 0;

    if (exists($args{Report_Removed}))
    {
        $removedReportPath = $args{Report_Removed};
    }
    else
    {
        $removedReportPath = undef;
    }

    if (exists($args{Report_NonDefaults}))
    {
        $nonDefaultReportPath = $args{Report_NonDefaults};
    }
    else
    {
        $nonDefaultReportPath = undef;
    }

    if (exists($args{Report_Deprecated}))
    {
        $deprecatedReportPath = $args{Report_Deprecated};
    }
    else
    {
        $deprecatedReportPath = undef;
    }

    if (exists($args{Report_Warnings}))
    {
        $warningsReportPath = $args{Report_Warnings};
    }
    else
    {
        $warningsReportPath = './IMPORTANT_UC330_WARNINGS.txt';
    }

    if (exists($args{Output_File}))
    { $outputFilePath = $args{Output_File}; }

    if (exists($args{Flat_Output}))
    { $flatOutput = 1 if ($args{Flat_Output} == 1); }

    exit if $err;
}

sub getVersion
{
    if ($VERSION =~ /Revision: ([\d\.]*) \$/)
    {
        return $1;
    }
    else
    {
        return $VERSION;
    }
}





sub convertConfig
{
    $currFilePath = shift;

    ## This structure is a hash of all the params. This copy we will be modifying.
    $currentConf = loadConfigAsHash(XML=>$currFilePath);
    $warn_readonly = 1 if (! -w $currFilePath);

    ## These arrays of hashes record the state of the baseline configs vs the users configs
    my @removedParams = ();
        ## Key: PARAM => the parameter name. ex) call.donotdisturb.perReg
        ## Key: VALUE => the default value
    my @nonDefaultParams = ();
        ## Key: PARAM       => the parameter name. ex) call.donotdisturb.perReg
        ## Key: DEFAULT_VAL => the default value
        ## KEY: CURRENT_VAL => the value in use by the customer config
    my @newWolverineParams = ();
        ## Key: OLD_PARAM   => the parameter name in pre 3.3.0 releases
        ## Key: NEW_PARAM   => the parameter name as it should appear in 3.3.0. May be null.
        ## Key: DEFAULT_VAL => the default value
        ## Key: CURRENT_VAL => the value in use by the customer config
    undef(%codecs);
    undef(@customLangs);
    undef(%wolverineParams);

    ## Build a new hash of valid wolverine parameters
    foreach my $param (keys %$currentConf)
    {
        my %newParams;
        my $val = $currentConf->{$param};
        my $valChange = 0;

        if (isDeprecated(OLD_PARAM=>$param, OLD_VAL => $val, NEW_PARAM=>\%newParams, VAL_CHANGE_ONLY=>\$valChange))
        {
            if (scalar(keys %newParams) == 0)
            {
                ## Parameter has been removed with no replacement
                removeParameter($param, 'Obsolete', \@removedParams);
            }
            else
            {
                foreach my $p (keys %newParams)
                {
                    my $v = $newParams{$p};
                    my $defaultValue = getWolverineDefault($p);
                    $wolverineParams{$p} = $v;
                    push(@newWolverineParams, {OLD_PARAM=>$param, DEFAULT_VAL=>$defaultValue, NEW_PARAM=>$p, CURRENT_VAL=>$v, VAL_CHANGE_ONLY=>$valChange});
                }
            }
        }
        else
        {
            $wolverineParams{$param} = $val;
        }
    }

    resolveCodecChanges(\%wolverineParams);
    resolveLanguageChanges(\%wolverineParams);


    foreach my $param (keys %wolverineParams)
    {
        if (defined($baseline->{$param}))
        {
            if (isDefault($param))
            {
                removeParameter($param, 'Default', \@removedParams);
            }
            else
            {
                push(@nonDefaultParams, {PARAM=>$param, DEFAULT_VAL=>getWolverineDefault($param), CURRENT_VAL=>$wolverineParams{$param}});
            }
        }
        else
        {
            ## it may be a true parameter with a platform override
            my $genericParam = $param;
            $genericParam =~ s/\.(SPIP|SSIP|VVX)(320|321|330|331|335|450|550|560|650|670|5000|6000|7000|1500)$//i;
            if (defined($baseline->{$genericParam}))
            {
                if (isDefault($genericParam))
                {
                    ## leave it
                }
                else
                {
                    push(@nonDefaultParams, {PARAM=>$param, DEFAULT_VAL=>getWolverineDefault($genericParam), CURRENT_VAL=>$wolverineParams{$param}});
                }
            }
            else
            {
                ## truly an unknown param
                removeParameter($param, 'Obsolete', \@removedParams);
            }
        }
    }


    ####################################
    ## Create reports
    ##
    ##
    reportDeprecated(@newWolverineParams);
    reportChangesToDefault(@nonDefaultParams);
    reportRemoved(@removedParams);
    reportWarnings();

    ## Output the updated file
    writeConvertedConfig(\%wolverineParams);
    clearWarnings();

}




################################################################################
#
# The following subroutines are private and not intended to be explicitly called
# by anyone other than subroutines from this file
#
#################################################################################

sub getWolverineDefault
{
    my $param = shift;
    return $baseline->{$param}->[0];
}


sub isDefault
{
    my $p = shift;
    my $v = $wolverineParams{$p};
    $v = (defined($v) ? $v : '');

    ## clear any unique platform identifier from the parameter added during deprecation checking
    my $pGeneric = $p;
    my $defaultArray = $baseline->{$pGeneric};
    my $type = '';

    ## If the default type of a 3.3.0 value is numeric, we can assume that the same
    ## parameter configured in a pre-3.3.0 with a value of '' (null) can be removed as default.
    ## This doesn't hold true for strings so any null string we treat as non-default.
    ## All codec prefs orderings hold the special type SIntNull and can be left null.
    if ($p !~ /voice\.codecPref/)
    {
        my $testVal = $defaultArray->[0];
        $testVal = (defined($testVal) ? $testVal : '');
        if ($testVal =~ /^\d+$/)
        {
            $type = 'NUM';
        }
        if (!defined($v) || (defined($v) && $v eq ''))
        {
            if ($type eq 'NUM')
            {
                ## nulled value in a numeric field, treat as default.
                return 1;
            }
        }
    }

    # Compare against defaults
    foreach my $wolverineDefaults (@$defaultArray)
    {
        if ($v eq $wolverineDefaults)
        {
            return 1;
        }
    }

    ## there may be a .SPIPXXX tag after the param name, remove it and try again
    $pGeneric =~ s/\.(SPIP|SSIP|VVX)(320|330|321|331|231|335|450|550|560|650|670|4000|5000|6000|7000|1500)$//;
    $defaultArray = $baseline->{$pGeneric};
    foreach my $wolverineDefaults (@$defaultArray)
    {
        if ($v eq $wolverineDefaults)
        {
            return 1;
        }
    }

    checkWarnings($p);
    return 0;

}



sub removeParameter
{
    my $parameter = shift;
    my $reason = shift;
    my $list = shift;
    delete $wolverineParams{$parameter};
    push(@$list, "$reason: $parameter")
}

sub resolveLanguageChanges
{
    my $wolverineParams = shift;
    my $maxLangs = 24;
    my $customLangBase = 19;
    my $customLangIndex = $customLangBase;

    foreach my $custLang (@customLangs)
    {
        $wolverineParams->{"lcl.ml.lang.menu.$customLangIndex"} = $custLang->{NAME};
        $wolverineParams->{"lcl.ml.lang.menu.$customLangIndex.label"} = $custLang->{LABEL};
        $wolverineParams->{"lcl.ml.lang.clock.$customLangIndex.24HourClock"} = $custLang->{HOURS};
        $wolverineParams->{"lcl.ml.lang.clock.$customLangIndex.format"} = $custLang->{FORMAT};
        $wolverineParams->{"lcl.ml.lang.clock.$customLangIndex.longFormat"} = $custLang->{FORMATLONG};
        $wolverineParams->{"lcl.ml.lang.clock.$customLangIndex.dateTop"} = $custLang->{DATETOP};
        $wolverineParams->{"lcl.ml.lang.tags.$customLangIndex"} = $custLang->{TAGS};

        my $langListAddon = '';
        for ($customLangBase..$customLangIndex)
        {
            $langListAddon .= ",$_";
        }
        $wolverineParams->{'lcl.ml.lang.list'} = 'All';
        $wolverineParams->{'lcl.ml.lang.list.SPIP320'} = '2,3,4,5,6,7,8,9,12,13,14,15,16,17,18' . $langListAddon;
        $wolverineParams->{'lcl.ml.lang.list.SPIP330'} = '2,3,4,5,6,7,8,9,12,13,14,15,16,17,18' . $langListAddon;
        $wolverineParams->{'lcl.ml.lang.list.SPIP321'} = '2,3,4,5,6,7,8,9,12,13,14,15,16,17,18' . $langListAddon;
        $wolverineParams->{'lcl.ml.lang.list.SPIP331'} = '2,3,4,5,6,7,8,9,12,13,14,15,16,17,18' . $langListAddon;
        $wolverineParams->{'lcl.ml.lang.list.SPIP335'} = '2,3,4,5,6,7,8,9,12,13,14,15,16,17,18' . $langListAddon;
        $customLangIndex++;
    }

    ## ensure all non customs are default
    for (1..18)
    {
        ## return the values to default for languages < index == 18
        $wolverineParams{"lcl.ml.lang.menu.$_"}             = $baseline->{"lcl.ml.lang.menu.$_"}->[0] if (exists($wolverineParams{"lcl.ml.lang.menu.$_"}));
        $wolverineParams{"lcl.ml.lang.menu.$_.label"}       = $baseline->{"lcl.ml.lang.menu.$_.label"}->[0] if (exists($wolverineParams{"lcl.ml.lang.menu.$_.label"}));
        $wolverineParams{"lcl.ml.lang.clock.$_.24HourClock"}= $baseline->{"lcl.ml.lang.clock.$_.24HourClock"}->[0] if (exists($wolverineParams{"lcl.ml.lang.clock.$_.24HourClock"}));
        $wolverineParams{"lcl.ml.lang.clock.$_.format"}     = $baseline->{"lcl.ml.lang.clock.$_.format"}->[0] if (exists($wolverineParams{"lcl.ml.lang.clock.$_.format"}));
        $wolverineParams{"lcl.ml.lang.clock.$_.longFormat"} = $baseline->{"lcl.ml.lang.clock.$_.longFormat"}->[0] if (exists($wolverineParams{"lcl.ml.lang.clock.$_.longFormat"}));
        $wolverineParams{"lcl.ml.lang.clock.$_.dateTop"}    = $baseline->{"lcl.ml.lang.clock.$_.dateTop"}->[0]if (exists($wolverineParams{"lcl.ml.lang.clock.$_.dateTop"}));
        $wolverineParams{"lcl.ml.lang.tags.$_"}             = $baseline->{"lcl.ml.lang.tags.$_"}->[0] if (exists($wolverineParams{"lcl.ml.lang.tags.$_"}));
    }
}


## The codec selection mechanism ni Wolverine is quite different than the previous method.
## Attempting to map the old method to wolverine can be done in a simple 1-many procedure however
## that would create a vast number of parameters many of which are redundant. The goal is to keep
## with the spirit of a small, readable config set. As such, rather than guaranteeing the difficult
## task of a perfect mapping, we are solving the needs of the majority by using a few simple heuristics.
## Map the IP650 (ie: desktop HD phones) settings to all phones. These are the most commonly set
## and used codec preferences. Of the remiaing phones, the non-HD 320,330,321,331
## platforms also retain their own unique ordering should it be different. VVX and the conference
## phones will be set as the 650 like platforms.
sub resolveCodecChanges
{
    my $wolverineParams = shift;
    my @platforms = qw(IP320 IP650 IP7000);
    my @completeCodecList = qw(Siren22.64kbps Siren22.48kbps Siren22.32kbps G7221C.48kbps G7221C.32kbps G7221C.24kbps Siren14.48kbps
                                Siren14.32kbps Siren14.24kbps G7221.32kbps G7221.24kbps G7221.16kbps G719.64kbps G719.48kbps G719.32kbps
                                G722 iLBC.13_33kbps iLBC.15_2kbps G711_Mu G711_A G729_AB Lin16.48ksps Lin16.44_1ksps Lin16.32ksps Lin16.16ksps
                                Lin16.8ksps);
    my @codecOrder;
    my @zeroedCodecs;

    ## remove obsolete codec parameter names
    foreach my $obsolete (['voice.codecPrefs.G711A', 'voice.codecPrefs.G711Mu', 'voice.codecPrefs.G729AB'])
    {
        delete $wolverineParams->{$obsolete};
    }

    ## fill in a contrived value for any codec that never had one
    foreach my $platform (@platforms)
    {
        foreach my $c (@completeCodecList)
        {
            if (!defined($codecs{$platform}->{$c}) || $codecs{$platform}->{$c} eq '')
            {
                delete $codecs{$platform}->{$c};
            }
            elsif ($codecs{$platform}->{$c} =~ /^\d+$/)
            {
                if ($codecs{$platform}->{$c} == 0)
                {
                    delete $codecs{$platform}->{$c};
                    if ($platform eq 'IP650')
                    {
                        $wolverineParams->{"voice.codecPref.$c"} = 0;
                    }
                    elsif ($platform eq 'IP320')
                    {
                        unless (defined($codecs{IP650}->{$c}) && $codecs{IP650}->{$c} =~ /^\d+$/ && $codecs{IP650}->{$c} == 0)
                        {
                            $wolverineParams->{"voice.codecPref.$c.SPIP320"} = 0;
                            $wolverineParams->{"voice.codecPref.$c.SPIP330"} = 0;
                            $wolverineParams->{"voice.codecPref.$c.SPIP321"} = 0;
                            $wolverineParams->{"voice.codecPref.$c.SPIP331"} = 0;
                        }
                    }
                }
            }
            else
            {
                delete $codecs{$platform}->{$c};
            }
        }
    }


    my @a650 = sort { $codecs{IP650}->{$a} <=> $codecs{IP650}->{$b}; } (keys %{$codecs{IP650}});
    my @a320 = sort { $codecs{IP320}->{$a} <=> $codecs{IP320}->{$b}; } (keys %{$codecs{IP320}});

    my $indHD = 0;
    my $indNonHD = 0;
    my $counter = 1;
    while (1)
    {

        my $valHD = $a650[$indHD];
        my $valNonHD = $a320[$indNonHD];

        if (!defined($valHD) && !defined($valNonHD))
        {
            last;
        }
        elsif (defined($valHD) && !defined($valNonHD))
        {
            $wolverineParams->{"voice.codecPref.$valHD"} = $counter;
            $indHD++;
            $counter++;
            next;
        }
        elsif (!defined($valHD) && defined($valNonHD))
        {
            $wolverineParams->{"voice.codecPref.$valNonHD.SPIP320"} = $counter;
            $wolverineParams->{"voice.codecPref.$valNonHD.SPIP321"} = $counter;
            $wolverineParams->{"voice.codecPref.$valNonHD.SPIP330"} = $counter;
            $wolverineParams->{"voice.codecPref.$valNonHD.SPIP331"} = $counter;
            $indNonHD++;
            $counter++;
            next;
        }
        else
        {
            if ($valHD eq 'G722')
            {
                $wolverineParams->{"voice.codecPref.G722"} = $counter;
                $indHD++;
                $counter++;
                next;
            }

            if ($valHD eq $valNonHD)
            {
                $wolverineParams->{"voice.codecPref.$valHD"} = $counter;
                $indHD++;
                $indNonHD++;
                $counter++;
            }
            else
            {
                $wolverineParams->{"voice.codecPref.$valNonHD.SPIP320"} = $counter;
                $wolverineParams->{"voice.codecPref.$valNonHD.SPIP321"} = $counter;
                $wolverineParams->{"voice.codecPref.$valNonHD.SPIP330"} = $counter;
                $wolverineParams->{"voice.codecPref.$valNonHD.SPIP331"} = $counter;
                $wolverineParams->{"voice.codecPref.$valHD"} = $counter;
                $indHD++;
                $indNonHD++;
                $counter++;
                next;
            }
        }
    }
}

sub writeConvertedConfig
{
    my $outputConf = shift;
    my @comments;

    return if ($warn_readonly);

    if (defined($outputFilePath))
    {
        ## Since the XML::simple module doesn't output comments, add them now
        {
            local @ARGV = ($currFilePath);
            while(<>)
            {
                my $line = $_;
                if ($line =~ /(<!--.*?-->)/m)
                {
                    my $comment = $1;
                    push (@comments, $comment) unless ($comment =~ /PlcmConversionCreatedFile/);
                }
            }
        }

        my $fh;
        open($fh, ">:utf8", $outputFilePath) or die "Error writing config. Target File: $outputFilePath\nError: $!";

        ## apply the 3.3.0 schema file
        $outputConf->{'xmlns:xsi'} = 'http://www.w3.org/2001/XMLSchema-instance';
        $outputConf->{'xsi:noNamespaceSchemaLocation'} = 'polycomConfig.xsd';

        if ($flatOutput)
        {
            my $xml = new XML::Simple();
            $xml->XMLout(\%wolverineParams, SuppressEmpty => 1, RootName => 'polycomConfig', KeyAttr => [], OutputFile => $fh);
            close $fh;
        }
        else
        {
            my %outputXml;
            foreach my $k (keys %wolverineParams)
            {
                my $v = $outputConf->{$k};
                prettyXml($k, $v, \%outputXml);
            }

            my $xml = new XML::Simple();
            $xml->XMLout(\%outputXml, SuppressEmpty => 1, RootName => 'polycomConfig', KeyAttr => [], OutputFile => $fh);
            close $fh;
        }

        ## add all comments back in
        {
            local ($^I, @ARGV) = ('.bak', $outputFilePath);
            while(<>)
            {
                if ($. == 1)
                {
                    ## add a marker indicating this file was converted
                    my $version = getVersion();
                    print '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>' . "$/";
                    print "<!-- PlcmConversionCreatedFile version=$version converted=" . scalar(localtime()) . " -->$/";
                    print "$_$/" foreach (@comments);
                    print;
                }
                else
                {
                    print;
                }
            }
            unlink $outputFilePath . ".bak";
        }
    }
}

sub prettyXml
{
    my $param = shift;
    my $val = shift;
    my $h = shift;

    my @levels = split(/\./, $param);

    my $temp = '';
    my $ref = $h;
    for (0..($#levels - 1))
    {
        my $level = $levels[$_];
        if ($level =~ /^\d+$/)
        {
            $temp .= '.' . $level;
            next ;
        }
        elsif ($level =~ /^codecPref$/)
        {
            if (!exists($ref->{codecPref}))
            {
                $ref->{codecPref} = {};
            }
            $ref->{codecPref}->{$param} = $val;
            return;
        }

        if ($temp eq '')
        {
            $temp = $level;
        }
        else
        {
            $temp .= '.' . $level;
        }

        if (!exists($ref->{$temp}))
        {
            $ref->{$temp} = {};
        }
        if (ref($ref->{$temp}) eq 'HASH')
        {
            $ref = $ref->{$temp};
        }
    }
    $ref->{$param} = $val;
}



sub reportDeprecated
{
    my @newWolverineParams = @_;

    if (defined($deprecatedReportPath))
    {
        if( !open(FH, ">>:utf8", $deprecatedReportPath))
        {
            warn "Cannot open filepath: " . $deprecatedReportPath . " for writing.\nErr: $!\n";
        }
        else
        {
            if (!@newWolverineParams)
            {
                close FH;
                return;
            }
            print FH "===============================================================\n";
            print FH "Report for file: $currFilePath\n";
            print FH "The following parameter names have been altered:\n";
            print FH "===============================================================\n";

            foreach my $ref (sort {uc($a->{OLD_PARAM}) cmp uc($b->{OLD_PARAM})} @newWolverineParams)
            {
                my $param = $ref->{OLD_PARAM};
                my $wolverineParam = $ref->{NEW_PARAM};
                my $val = $ref->{CURRENT_VAL};
                $val = undef if (defined($val) && $val eq '');
                my $defaultValue = $ref->{DEFAULT_VAL};
                $defaultValue = undef if (defined($defaultValue) && $defaultValue eq '');

                if (defined($wolverineParam))
                {
                    if ((defined($defaultValue) && !defined($val)) || (!defined($defaultValue) && defined($val)) ||
                        (defined($defaultValue) && defined($val) && $defaultValue !~ /$val/i))
                    {
                        if (ref($wolverineParam) eq 'ARRAY')
                        {
                            for (0..(@$wolverineParam - 1))
                            {
                                if (ref($wolverineParam->[$_]) eq 'ARRAY')
                                {
                                    print FH " -- New: $wolverineParam->[$_]->[0] = '$wolverineParam->[$_]->[1]'\n";
                                }
                                else
                                {
                                    print FH " -- New: $wolverineParam->[$_] = '" . (defined($val) ? "$val'" : "'") . "\n";
                                }
                            }
                            print FH " -- Default: '" . (defined($defaultValue) ? $defaultValue . "'" : "'") . "\n\n";
                        }
                        else
                        {
                            print FH sprintf("%-40s  ->  %-40s\n", $ref->{OLD_PARAM}, $ref->{NEW_PARAM});
                        }
                    }
                }
                else
                {
                    print FH "Removed: $param\n";
                }
            }
            print FH "\n\n";
            close FH;
        }
    }
}


sub reportChangesToDefault
{
    my @nonDefaultParams = @_;

    if (defined($nonDefaultReportPath))
    {
        if( !open(FH2, ">>:utf8" , $nonDefaultReportPath))
        {
            warn "Cannot open filepath: " . $nonDefaultReportPath . " for writing.\nErr: $!\n";
        }
        else
        {
            if (!@nonDefaultParams)
            {
                close FH2;
                return;
            }
            print FH2 "================================================================================================\n";
            print FH2 "Report for file: $currFilePath\n";
            print FH2 "The following parameters have been altered from their defaults.\n";
            print FH2 "Parameter                                          Default                           Configured\n";
            print FH2 "================================================================================================\n";
            foreach my $ref (sort {uc($a->{PARAM}) cmp uc($b->{PARAM})} @nonDefaultParams)
            {
                my $def = defined($ref->{DEFAULT_VAL}) ? "'" . $ref->{DEFAULT_VAL} . "'" : "''";
                my $inUse = defined($ref->{CURRENT_VAL}) ? "'" . $ref->{CURRENT_VAL} . "'" : "''";
                print FH2 sprintf("%-50s  %-34s  %-34s\n",$ref->{PARAM}, $def, $inUse);
            }
            print FH2 "\n\n";
            close FH2;
        }
    }
}



sub reportRemoved
{
    my @removedParams = @_;

    if (defined($removedReportPath))
    {
        if( !open(FH3, ">>:utf8" , $removedReportPath))
        {
            warn "Cannot open filepath: " . $removedReportPath . " for writing. Err: $!\n";
        }
        else
        {
            if (!@removedParams)
            {
                close FH3;
                return;
            }
            print FH3 "===================================================================\n";
            print FH3 "Report for file: $currFilePath\n";
            print FH3 "The following parameters are either unknown, do not exist (DNE)\n" .
                      "in UCS 3.3.0, or have values matching the defaults. As such, they\n" .
                      "have been removed from your config files.\n";
            print FH3 "==================================================================\n";
            foreach my $param (sort @removedParams)
            {
                print FH3 "$param\n";
            }
            print FH3 "\n";
            close FH3;
        }
    }
}

sub clearWarnings
{
    $warn_codecPreferenceChanges = 0;
    $warn_audioSettingChanges = 0;
    $warn_fileSystemChanges = 0;
    $warn_readonly = 0;

}
sub checkWarnings
{
    my $param = shift;
    $warn_codecPreferenceChanges = 1 if ($param =~ /voice\.codecPref/i);
    $warn_audioSettingChanges = 1 if ($param =~ /voice\.(gain|aec|aes|ns|agc|rxEq|txEq|handset|headset)/i);
    $warn_fileSystemChanges = 1 if ($param =~ /prov\.fileSystem/i);
}

sub reportWarnings
{
    my $codecWarning = 0;
    my $fileSystemWarning = 0;
    my $audioSettingsWarning = 0;
    my $readonlyWarning = 0;
    my @lines;

    if (-e $warningsReportPath)
    {
        open(FH, "<$warningsReportPath") or warn "Error reading $warningsReportPath\n Err: $!\n";
        @lines = <FH>;
        close FH;

        ## Determine what we have warned for already
        foreach my $line (@lines)
        {
            $codecWarning = 1 if ($line =~ /---Codec Preferences Warning---/);
            $fileSystemWarning = 1 if ($line =~ /---File System Warning---/);
            $audioSettingsWarning = 1 if ($line =~ /---Audio Settings Warning---/);
            $readonlyWarning = 1 if ($line =~ /---Read Only Files---/);
        }
    }


    if ($warn_readonly)
    {
        if (!$readonlyWarning)
        {
            @lines =   ("---Read Only Files---\n" .
                        "The following files cannot be converted because they are read-only.\n\n" .
                        "---Read Only File List---\n" .
                        "$currFilePath\n\n\n\n",
                        @lines);
        }
        else
        {
            for (0..$#lines)
            {
                my $line = $lines[$_];
                if ($line =~ /---Read Only File List---/)
                {
                    $lines[$_] .=  "$currFilePath\n";
                }
            }
        }
    }

    if ($warn_codecPreferenceChanges)
    {
        if (!$codecWarning)
        {
            @lines =   ("---Codec Preferences Warning---\n" .
                        "Changes to the default voice codec selection preferences were found.\n" .
                        "The selection method has changed substantially and while this utility will try to\n" .
                        "maintain your preferences, Polycom strongly suggests you refer to Tech Bulletin 60519\n" .
                        "and verify that your configuration continues to match your expectation.\n" .
                        "http://www.polycom.com/support/voice/soundpoint_ip/VoIP_Technical_Bulletins_pub.html\n\n" .
                        "The following files have changes to 'voice.codecPref.*' parameters\n" .
                        "---Codec Changes File List---\n" .
                        "$currFilePath\n\n\n\n",
                        @lines);
        }
        else
        {
            for (0..$#lines)
            {
                my $line = $lines[$_];
                if ($line =~ /---Codec Changes File List---/)
                {
                    $lines[$_] .=  "$currFilePath\n";
                }
            }
        }
    }

    if ($warn_audioSettingChanges)
    {
        if (!$audioSettingsWarning)
        {
            @lines =   ("---Audio Settings Warning---\n" .
                        "Changes to the default audio settings were found.\n" .
                        "Polycom *strongly* recommends that you DO NOT change your audio settings as the pre-set values exhibit\n" .
                        "what we feel to be the optimal configuration for most circumstances.\n" .
                        "If you are sure that you need these settings to be altered, please ensure that you\n" .
                        "are altering them under guidance from qualified Polycom Support.\n\n" .
                        "The following files have one or more to important 'voice.*' parameters (Gain, AEC, AES, Volume, etc) parameters\n" .
                        "---Audio Settings File List---\n" .
                        "$currFilePath\n\n\n\n",
                        @lines);
        }
        else
        {
            for (0..$#lines)
            {
                my $line = $lines[$_];
                if ($line =~ /---Audio Settings File List---/)
                {
                    $lines[$_] .=  "$currFilePath\n";
                }
            }
        }
    }

    if ($warn_fileSystemChanges)
    {
        if (!$fileSystemWarning)
        {
            @lines =   ("---File System Warning---\n" .
                        "Changes to the default file system memory and disk configuration were found.\n" .
                        "Polycom *strongly* recommends that you do not change these settings.\n" .
                        "Please ensure that you are changing these values only under direct advisement from \n" .
                        "qualified Polycom Support.\n\n" .
                        "The following files have changes to important 'prov.fileSystem.*' parameters\n" .
                        "---File System Settings File List---\n" .
                        "$currFilePath\n\n\n\n",
                        @lines);
        }
        else
        {
            for (0..$#lines)
            {
                my $line = $lines[$_];
                if ($line =~ /---File System Settings File List---/)
                {
                    $lines[$_] .=  "$currFilePath\n";
                }
            }
        }
    }

    open(FH, ">$warningsReportPath") or warn "Error writing warnings file $warningsReportPath\nErr: $!\n";
    print FH @lines;
    close FH;
}

##
## Takes an xml file or string and returns a hash consisting of a key=>value pair
## for every config parameter in the file.
## If there are duplicate values, the first one encountered is the one whose
## value is retained
sub loadConfigAsHash
{
    my %args = @_;
    my $xml = $args{XML};

    my %hash;
    open(FH, "<", $xml);
    while(my $line = <FH>)
    {
        $line =~ s/<\?xml.*?>//g;
        $line =~ s/<!--.*?-->//g;
        my @matches = $line =~ /([\w_\.\d]+\=".*?")/g;

        foreach my $match (@matches)
        {
            my ($param, $val) = $match =~ /(.*)="(.*)"/gi;
            if (!exists($hash{$param}))
            {
                $hash{$param} = $val;
            }
        }
    }
    close FH;
    return \%hash;
}


sub isDeprecated
{
    my %args = @_;
    my $key = $args{OLD_PARAM};
    my $val = $args{OLD_VAL};
    my $newParam = $args{NEW_PARAM}; #hash ref
    my $valChange = $args{VAL_CHANGE_ONLY};

    ## Feature flags could have altered numbers or ordering... grr
    if ($key =~ /feature\.(\d+)\.(name|enabled)/)
    {
        if ($2 eq 'name')
        {
            $newParam = undef;
            return 1;
        }
        else # ($2 eq 'enabled')
        {
            my $tmp = $currentConf->{"feature.$1.name"};
            $tmp = $baselineFeaturendex[$1-1] unless (defined($tmp));
            my $userVal = $currentConf->{"feature.$1.enabled"};

            ## forced to avoid switch statements since the dev kit doesn't support them :(
            if    ($tmp eq 'presence')
            {
                $newParam->{'feature.presence.enabled'} = $userVal;
            }
            elsif ($tmp eq 'messaging')
            {
                $newParam->{'feature.messaging.enabled'} = $userVal;
                }
            elsif ($tmp eq 'directory')
            {
                $newParam->{'feature.directory.enabled'} = $userVal;
            }
            elsif ($tmp eq 'calllist')
            {
                $newParam->{'feature.callList.enabled'} = $userVal;
            }
            elsif ($tmp eq 'ring-download')
            {
                $newParam->{'feature.ringDownload.enabled'} = $userVal;
            }
            elsif ($tmp eq 'calllist-received')
            {
                $newParam->{'feature.callListReceived.enabled'} = $userVal;
            }
            elsif ($tmp eq 'calllist-placed')
            {
                $newParam->{'feature.callListPlaced.enabled'} = $userVal;
            }
            elsif ($tmp eq 'calllist-missed')
            {
                $newParam->{'feature.callListMissed.enabled'} = $userVal;
            }
            elsif ($tmp eq 'url-dialing')
            {
                $newParam->{'feature.urlDialing.enabled'} = $userVal;
            }
            elsif ($tmp eq 'call-park')
            {
                $newParam->{'feature.callPark.enabled'} = $userVal;
            }
            elsif ($tmp eq 'group-call-pickup')
            {
                $newParam->{'feature.groupCallPickup.enabled'} = $userVal;
            }
            elsif ($tmp eq 'directed-call-pickup')
            {
                $newParam->{'feature.directedCallPickup.enabled'} = $userVal;
            }
            elsif ($tmp eq 'last-call-return')
            {
                $newParam->{'feature.lastCallReturn.enabled'} = $userVal;
            }
            elsif ($tmp eq 'acd-login-logout')
            {
                $newParam->{'feature.acdLoginLogout.enabled'} = $userVal;
            }
            elsif ($tmp eq 'acd-agent-availability')
            {
                $newParam->{'feature.acdAgentAvailability.enabled'} = $userVal;
                }
            elsif ($tmp eq 'nway-conference')
            {
                $newParam->{'feature.nWayConference.enabled'} = $userVal;
            }
            elsif ($tmp eq 'call-recording')
            {
                $newParam->{'feature.callRecording.enabled'} = $userVal;
            }
            elsif ($tmp eq 'enhanced-feature-keys')
            {
                $newParam->{'feature.enhancedFeatureKeys.enabled'} = $userVal;
            }
            elsif ($tmp eq 'corporate-directory')
            {
                $newParam->{'feature.corporateDirectory.enabled'} = $userVal;
            }
            elsif ($tmp eq 'picture-frame')
            {
                $newParam->{'feature.pictureFrame.enabled'} = $userVal;
            }
            return 1;
        }
    }
    elsif ($key =~ /lcl\.ml\.lang\.menu\.(\d+)\.?(label)?/i)
    {
        my $index = $1;
        my $label = $2;

        my $newParam = undef;

        ## remove all languages if they match a default. Any language we find
        ## that appears to be custom, save it and add it to the list after the
        ## file is completely parsed.
        if (!defined($label))
        {
            my $langName = $currentConf->{$key};
            my $found = 0;
            foreach my $l (@langs)
            {
                if ($l eq $langName)
                {
                    $found = 1;
                    last;
                }
            }
            if (!$found && $langName ne '')
            {
                ## the lang looks custom, store its values
                my $customLabel     = $currentConf->{"lcl.ml.lang.menu.$index.label"};
                my $custom24        = $currentConf->{"lcl.ml.lang.clock.$index.24HourClock"};
                my $customFormat    = $currentConf->{"lcl.ml.lang.clock.$index.format"};
                my $customLong      = $currentConf->{"lcl.ml.lang.clock.$index.longFormat"};
                my $customDateTop   = $currentConf->{"lcl.ml.lang.clock.$index.dateTop"};
                my $customTags      = $currentConf->{"lcl.ml.lang.tags.$index"};
                push(@customLangs, {NAME => $langName, LABEL => $customLabel, FORMAT => $customFormat,
                                    HOURS => $custom24, TAGS => $customTags, FORMATLONG => $customLong,
                                    DATETOP => $customDateTop});
                return 0;
            }
            else
            {
                return 0;
            }
        }

    }
    elsif ($key =~ /call\.autoAnswer\.ringClass/i)
    {
        my $newValue;
        ## the parameter itself is the same but we can no longer reference the target ringtone by an index.
        if (defined($currentConf->{$key}) && $currentConf->{$key} ne '')
        {
            my $r = $currentConf->{$key};
            if ($r !~ /^\d+$/)
            {
               $r = 4;
            }
            $newParam->{$key} =  $ringtones[$r - 1];
        }
        else
        {
            ## the value is null, they may have added a new alertinfo parameter but it maps to no ringer
            return 0;
        }
        $$valChange = 1;
        return 1;
    }
    elsif ($key =~ /ind\.pattern\.powerSaving\.step\.\d+\.state/i)
    {
        if (defined($currentConf->{$key}) && $currentConf->{$key} ne '')
        {
            my $state = $currentConf->{$key};
            $state =~ s/Off/0/i;
            $state =~ s/On/1/i;
            $newParam->{$key} = $state;
            $$valChange = 1;
            return 1;
        }
        return 0;
    }
    elsif ($key =~ /ind\.pattern\.(\d+)\.(.*)/i)
    {
        my $index = $1;
        my $rest = $2;
        $rest =~ s/colour/color/;
        if (defined($index) && $index =~ /\d+/)
        {
            if ($index >= 15)
            {
                $newParam = undef;
            }
            else
            {
                if (($index == 14 || $index == 13) && $rest =~ /step\.\d+\.state/)
                {
                    $val =~ s/Off/0/i;
                    $val =~ s/On/1/i;
                }
                $newParam->{'ind.pattern.' . $indicatorPatterns[$index - 1] . ".$rest"} = $val;
            }
            return 1;
        }
        else
        {
            return 0;
        }
    }
    elsif ($key =~ /key\.(IP_\d+)\.(\w+)\.(function|subPoint).prim/i)
    {
        my $function = $2;
        my $funcOrSub = $3;
        if ($1 eq 'IP_330')
        {
            $newParam->{"key.$function.$funcOrSub.SPIP320"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP330"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP321"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP331"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP335"} = $val;
        }
        elsif ($1 eq 'IP_430')
        {
            $newParam = undef;
        }
        elsif ($1 eq 'IP_450')
        {
            $newParam->{"key.$function.$funcOrSub.SPIP450"} = $val;
        }
        elsif ($1 eq 'IP_550')
        {
            $newParam->{"key.$function.$funcOrSub.SPIP550"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP560"} = $val;
        }
        elsif ($1 eq 'IP_650')
        {
            $newParam->{"key.$function.$funcOrSub.SPIP550"} = $val;
            $newParam->{"key.$function.$funcOrSub.SPIP560"} = $val;
        }
        elsif ($1 eq 'IP_6000')
        {
            $newParam->{"key.$function.$funcOrSub.SSIP5000"} = $val;
            $newParam->{"key.$function.$funcOrSub.SSIP6000"} = $val;
        }
        elsif ($1 eq 'IP_7000')
        {
            $newParam->{"key.$function.$funcOrSub.SSIP7000"} = $val;
        }
        elsif ($1 eq 'VVX_1500')
        {
            $newParam->{"key.$function.$funcOrSub.VVX1500"} = $val;
        }
        return 1;
    }
    elsif ($key =~ /se\.rt\.(\d+)\.(.*)/i)
    {
        my $index = $1;
        my $subParam = $2;
        my $value = $currentConf->{$key};
        my $newValue;

        ## VOIP-60825, remove the se.rt.x.mod parameter
        if ($key =~ /se\.rt\.4\.mod/i)
        {
            $newParam = undef;
            return 0;
        }

        if ($subParam eq 'ringer')
        {
            if (defined($value) && $value ne '')
            {
                $newValue = $ringers[$value - 1];
            }
            else
            {
                $newValue = '';
            }
        }
        elsif ($2 eq 'callWait')
        {
            if (defined($value) && $value ne '')
            {
                $newValue = $callProg[$value - 1];
            }
            else
            {
                $newValue = '';
            }
        }
        else
        {
            $newValue = $currentConf->{$key};
        }
        $newParam->{'se.rt.' . $ringtones[$index - 1] . ".$2"} = $newValue;
        return 1;
    }
    elsif ($key =~ /se\.pat\.(callProg|ringer|misc)\.(\d+)\.(name|inst\.(\d+)\.(value|type|atten|param))/i)
    {
        my $type = $1;
        my $ind = $2;
        my $rest = $3;
        my $ind2 = $4;
        my $subParam = $5;
        my $newValue = $currentConf->{$key};

        if ($type eq 'callProg')
        {
            if (defined($subParam))
            {
                if ($subParam eq 'value')
                {
                    ## check the type for this instance, do not translate values of sampled audio files
                    my $temp = $currentConf->{"se.pat.callProg.$ind.inst.$4.type"};
                    if ($temp ne 'sampled')
                    {
                        if (defined($newValue) && $newValue ne '')
                        {
                            $newValue = $callProgChords[$newValue - 1] unless ($newValue <= 0);
                        }
                        else
                        {
                            $newValue = '';
                        }
                    }
                    ## else, the value remains the same. Should be an integer.
                }
            }
            $newParam->{"se.pat.callProg." . $callProg[$ind - 1] . ".$rest"} = $newValue;
        }
        elsif ($type eq 'ringer')
        {
            if (defined($subParam))
            {
                if ($subParam eq 'value')
                {
                    ## check the type for this instance, do not translate values of sampled audio files
                    my $temp = $currentConf->{"se.pat.ringer.$ind.inst.$4.type"};
                    if (defined($temp) && $temp eq 'chord')
                    {
                        if (defined($newValue) && $newValue ne '')
                        {
                            $newValue = $ringerChords[$newValue - 1] unless ($newValue <= 0);
                        }
                        else
                        {
                            $newValue = '';
                        }
                    }
                    ## else, the value remains the same. Should be an integer.
                }
            }
            $newParam->{"se.pat.ringer." . $ringers[$ind - 1] . ".$rest"} = $newValue;
        }
        elsif ($type eq 'misc')
        {
            if (defined($subParam))
            {
                if ($subParam eq 'value')
                {
                    ## check the type for this instance, do not translate values of sampled audio files
                    my $temp = $currentConf->{"se.pat.misc.$ind.inst.$4.type"};
                    if ($temp ne 'sampled')
                    {
                        if (defined($newValue) && $newValue ne '')
                        {
                            $newValue = $miscChord[$newValue - 1] unless ($newValue <= 0);
                        }
                        else
                        {
                            $newValue = '';
                        }
                    }
                    ## else, the value remains the same. Should be an integer.
                }
            }
            $newParam->{"se.pat.misc." . $miscPattern[$ind - 1] . ".$rest"} = $newValue;
        }
        return 1;
    }
    elsif ($key =~ /tone\.chord\.(callProg|ringer|misc)\.(\d+)(.*)/i)
    {
        my $type = $1;
        my $index = $2;
        my $rest = $3;
        if ($type eq 'callProg')
        {
            $newParam->{"tone.chord.callProg." . $callProgChords[$index - 1] . "$rest"} = $val;
        }
        elsif ($type eq 'ringer')
        {
            $newParam->{"tone.chord.ringer." . $ringerChords[$index - 1] . "$rest"} = $val;
        }
        elsif ($type eq 'misc')
        {
            $newParam->{"tone.chord.misc." . $miscChord[$index - 1] . "$rest"} = $val;
        }
        return 1;
    }
    elsif ($key =~ /voice\.(gain|aec|aes|ns|agc|rxEq|txEq|handset|headset)/i)
    {
        $newParam = undef;
        if (!isDefault($key))
        {
            $warn_audioSettingChanges = 1;
        }
        return 1;
    }
    elsif ($key =~ /voice\.codecPref\.(G711Mu|G711A|G729AB|iLBC.13_33kbps|iLBC.15_2kbps)/i)
    {
        my $c = $1;
        my $val = $currentConf->{$key};
        $val = '' if (!defined($val));

        if ($c eq 'G711Mu')
        {
            $codecs{IP320}->{'G711_Mu'} = $val;
            $newParam->{'voice.codecPref.G711_Mu'} = $val;
            return 1;
        }
        elsif ($c eq 'G711A')
        {
            $codecs{IP320}->{'G711_A'} = $val;
            $newParam->{'voice.codecPref.G711_A'} = $val;
            return 1;
        }
        elsif ($c eq 'G729AB')
        {
            $codecs{IP320}->{'G729_AB'} = $val;
            $newParam->{'voice.codecPref.G729_AB'} = $val;
            return 1;
        }
        else
        {
            $codecs{IP320}->{$c} = $val;
            return 0;
        }
    }
    elsif ($key =~ /voice\.codecPref\.(IP_650|IP_[567]000|VVX1500)\.(.*)/i)
    {
        my $platform = $1;
        my $c = $2;
        my $val = $currentConf->{$key};
        $val = '' if (!defined($val));

        if ($platform eq 'IP_650')
        {
            if ($c eq 'G711Mu')
            {
                $codecs{IP650}->{'G711_Mu'} = $val;
                #$newParam->{'voice.codecPref.G711_Mu'} = $val;
            }
            elsif ($c eq 'G711A')
            {
                $codecs{IP650}->{'G711_A'} = $val;
                #$newParam->{'voice.codecPref.G711_A'} = $val;
            }
            elsif ($c eq 'G729AB')
            {
                $codecs{IP650}->{'G729_AB'} = $val;
                #$newParam->{'voice.codecPref.G729_AB'} = $val;
            }
            else
            {
                $codecs{IP650}->{$c} = $val;
            }
        }
        return 1;
    }
    elsif ($key =~ /ind\.anim/i)
    {
        ## all idle animation parameters are deprecated and removed
        $newParam = undef;
        return 1;
    }
    elsif ($key =~ /bitmap\.(IP_\d+)\.(\d+)\.name/i)
    {
        my $platforms = $1;
        my $index = $2;
        if ($index == 61 && $platforms eq 'IP_330')
        {
            $newParam->{"bitmap.idleDisplay.name.SPIP320"} = $currentConf->{"bitmap.IP_330.61.name"};
            $newParam->{"bitmap.idleDisplay.name.SPIP330"} = $currentConf->{"bitmap.IP_330.61.name"};
            $newParam->{"bitmap.idleDisplay.name.SPIP321"} = $currentConf->{"bitmap.IP_330.61.name"};
            $newParam->{"bitmap.idleDisplay.name.SPIP331"} = $currentConf->{"bitmap.IP_330.61.name"};
            $newParam->{"bitmap.idleDisplay.name.SPIP335"} = $currentConf->{"bitmap.IP_330.61.name"};
        }
        elsif ($index == 65)
        {
            if ($platforms eq 'IP_450')
            {
                $newParam->{"bitmap.idleDisplay.name.SPIP450"} = $currentConf->{"bitmap.IP_450.65.name"};
            }
            elsif ($platforms eq 'IP_600')
            {
                $newParam->{"bitmap.idleDisplay.name.SPIP550"} = $currentConf->{"bitmap.IP_600.65.name"};
                $newParam->{"bitmap.idleDisplay.name.SPIP560"} = $currentConf->{"bitmap.IP_600.65.name"};
                $newParam->{"bitmap.idleDisplay.name.SPIP650"} = $currentConf->{"bitmap.IP_600.65.name"};
                $newParam->{"bitmap.idleDisplay.name.SPIP670"} = $currentConf->{"bitmap.IP_600.65.name"};
                $newParam->{"bitmap.idleDisplay.name.SPIP5000"} = $currentConf->{"bitmap.IP_600.65.name"};
                $newParam->{"bitmap.idleDisplay.name.SPIP6000"} = $currentConf->{"bitmap.IP_600.65.name"};
            }
            elsif ($platforms eq 'IP_7000')
            {
                $newParam->{"bitmap.idleDisplay.name.SSIP7000"} = $currentConf->{"bitmap.IP_7000.65.name"};
            }
            else
            {
                $newParam = undef;
            }
        }
        else
        {
            $newParam = undef;
        }
        return 1;
    }
    elsif ($key =~ /voIpProt\.SIP\.alertInfo\.(\d+).class/i)
    {
        my $newValue;
        ## the parameter itself is the same but we can no longer reference the target ringtone by an index.
        if (defined($currentConf->{$key}) && $currentConf->{$key} ne '')
        {
            my $r = $currentConf->{$key};
            if ($r !~ /^\d+$/)
            {
               $r = 1;
            }
            $newParam->{$key} =  $ringtones[$r - 1];
        }
        else
        {
            ## the value is null, they may have added a new alertinfo parameter but it maps to no ringer
            return 0;
        }
        $$valChange = 1;
        return 1;
    }
    elsif ($key =~ /attendant\.ringType/i)
    {
        my $r = $currentConf->{$key};
        if ($r !~ /^\d+$/)
        {
            $r = 1;
        }
        $newParam->{$key} =  $ringers[$r - 1];
        $$valChange = 1;
        return 1;
    }
    elsif ($key =~ /reg\.\d+\.ringType/i)
    {
        my $r = $currentConf->{$key};
        if ($r !~ /^\d+$/)
        {
            $r = 2;
        }
        $newParam->{$key} =  $ringers[$r - 1];
        $$valChange = 1;
        return 1;
    }
    elsif ($key =~ /ind\.gi/i)
    {
        ## all graphic indicators are no longer configurable
        $newParam = undef;
    }
    else
    {
        if (exists($DEPRECATED{$key}))
        {
            my $tmp = $DEPRECATED{$key};
            if (!defined($tmp))
            {
                $newParam = undef;
                return 1;
            }
            elsif (ref($tmp) eq 'ARRAY')
            {
                $newParam->{$_} = $val foreach (@$tmp);
            }
            return 1;
        }
        else
        {
            return 0;
        }
    }
}

## Do not touch this data structure.
## It is forced to be included here by the dev kits compiler failings rather than externally.
## Auto generated default values list based on cfgparamdefs. ref generateDefaultValues.pl
sub loadBaselines
{
    return {
	'ACS_URL' => ['0'],
	'ACS_URL_Password' => ['0'],
	'ACS_URL_Username' => ['0'],
	'BootServer_Prot' => ['0'],
	'BootServer_URL' => ['0'],
	'CPE_Password' => ['0'],
	'CPE_username' => ['0'],
	'Inform_Enable' => ['0'],
	'Inform_Interval' => ['35'],
	'Inform_Time' => ['0'],
	'Local_Timezone' => ['0'],
	'NTP_Server1' => ['0'],
	'NTP_server2' => ['0'],
	'Tr69CommandKey' => ['0'],
	'Tr69Event' => ['0'],
	'Upgrade_Enabled' => ['0'],
	'acd.1.unavailreason.active' => ['0'],
	'acd.1.unavailreason.codeName' => [''],
	'acd.1.unavailreason.codeValue' => [''],
	'acd.10.unavailreason.active' => ['0'],
	'acd.10.unavailreason.codeName' => [''],
	'acd.10.unavailreason.codeValue' => [''],
	'acd.100.unavailreason.active' => ['0'],
	'acd.100.unavailreason.codeName' => [''],
	'acd.100.unavailreason.codeValue' => [''],
	'acd.11.unavailreason.active' => ['0'],
	'acd.11.unavailreason.codeName' => [''],
	'acd.11.unavailreason.codeValue' => [''],
	'acd.12.unavailreason.active' => ['0'],
	'acd.12.unavailreason.codeName' => [''],
	'acd.12.unavailreason.codeValue' => [''],
	'acd.13.unavailreason.active' => ['0'],
	'acd.13.unavailreason.codeName' => [''],
	'acd.13.unavailreason.codeValue' => [''],
	'acd.14.unavailreason.active' => ['0'],
	'acd.14.unavailreason.codeName' => [''],
	'acd.14.unavailreason.codeValue' => [''],
	'acd.15.unavailreason.active' => ['0'],
	'acd.15.unavailreason.codeName' => [''],
	'acd.15.unavailreason.codeValue' => [''],
	'acd.16.unavailreason.active' => ['0'],
	'acd.16.unavailreason.codeName' => [''],
	'acd.16.unavailreason.codeValue' => [''],
	'acd.17.unavailreason.active' => ['0'],
	'acd.17.unavailreason.codeName' => [''],
	'acd.17.unavailreason.codeValue' => [''],
	'acd.18.unavailreason.active' => ['0'],
	'acd.18.unavailreason.codeName' => [''],
	'acd.18.unavailreason.codeValue' => [''],
	'acd.19.unavailreason.active' => ['0'],
	'acd.19.unavailreason.codeName' => [''],
	'acd.19.unavailreason.codeValue' => [''],
	'acd.2.unavailreason.active' => ['0'],
	'acd.2.unavailreason.codeName' => [''],
	'acd.2.unavailreason.codeValue' => [''],
	'acd.20.unavailreason.active' => ['0'],
	'acd.20.unavailreason.codeName' => [''],
	'acd.20.unavailreason.codeValue' => [''],
	'acd.21.unavailreason.active' => ['0'],
	'acd.21.unavailreason.codeName' => [''],
	'acd.21.unavailreason.codeValue' => [''],
	'acd.22.unavailreason.active' => ['0'],
	'acd.22.unavailreason.codeName' => [''],
	'acd.22.unavailreason.codeValue' => [''],
	'acd.23.unavailreason.active' => ['0'],
	'acd.23.unavailreason.codeName' => [''],
	'acd.23.unavailreason.codeValue' => [''],
	'acd.24.unavailreason.active' => ['0'],
	'acd.24.unavailreason.codeName' => [''],
	'acd.24.unavailreason.codeValue' => [''],
	'acd.25.unavailreason.active' => ['0'],
	'acd.25.unavailreason.codeName' => [''],
	'acd.25.unavailreason.codeValue' => [''],
	'acd.26.unavailreason.active' => ['0'],
	'acd.26.unavailreason.codeName' => [''],
	'acd.26.unavailreason.codeValue' => [''],
	'acd.27.unavailreason.active' => ['0'],
	'acd.27.unavailreason.codeName' => [''],
	'acd.27.unavailreason.codeValue' => [''],
	'acd.28.unavailreason.active' => ['0'],
	'acd.28.unavailreason.codeName' => [''],
	'acd.28.unavailreason.codeValue' => [''],
	'acd.29.unavailreason.active' => ['0'],
	'acd.29.unavailreason.codeName' => [''],
	'acd.29.unavailreason.codeValue' => [''],
	'acd.3.unavailreason.active' => ['0'],
	'acd.3.unavailreason.codeName' => [''],
	'acd.3.unavailreason.codeValue' => [''],
	'acd.30.unavailreason.active' => ['0'],
	'acd.30.unavailreason.codeName' => [''],
	'acd.30.unavailreason.codeValue' => [''],
	'acd.31.unavailreason.active' => ['0'],
	'acd.31.unavailreason.codeName' => [''],
	'acd.31.unavailreason.codeValue' => [''],
	'acd.32.unavailreason.active' => ['0'],
	'acd.32.unavailreason.codeName' => [''],
	'acd.32.unavailreason.codeValue' => [''],
	'acd.33.unavailreason.active' => ['0'],
	'acd.33.unavailreason.codeName' => [''],
	'acd.33.unavailreason.codeValue' => [''],
	'acd.34.unavailreason.active' => ['0'],
	'acd.34.unavailreason.codeName' => [''],
	'acd.34.unavailreason.codeValue' => [''],
	'acd.35.unavailreason.active' => ['0'],
	'acd.35.unavailreason.codeName' => [''],
	'acd.35.unavailreason.codeValue' => [''],
	'acd.36.unavailreason.active' => ['0'],
	'acd.36.unavailreason.codeName' => [''],
	'acd.36.unavailreason.codeValue' => [''],
	'acd.37.unavailreason.active' => ['0'],
	'acd.37.unavailreason.codeName' => [''],
	'acd.37.unavailreason.codeValue' => [''],
	'acd.38.unavailreason.active' => ['0'],
	'acd.38.unavailreason.codeName' => [''],
	'acd.38.unavailreason.codeValue' => [''],
	'acd.39.unavailreason.active' => ['0'],
	'acd.39.unavailreason.codeName' => [''],
	'acd.39.unavailreason.codeValue' => [''],
	'acd.4.unavailreason.active' => ['0'],
	'acd.4.unavailreason.codeName' => [''],
	'acd.4.unavailreason.codeValue' => [''],
	'acd.40.unavailreason.active' => ['0'],
	'acd.40.unavailreason.codeName' => [''],
	'acd.40.unavailreason.codeValue' => [''],
	'acd.41.unavailreason.active' => ['0'],
	'acd.41.unavailreason.codeName' => [''],
	'acd.41.unavailreason.codeValue' => [''],
	'acd.42.unavailreason.active' => ['0'],
	'acd.42.unavailreason.codeName' => [''],
	'acd.42.unavailreason.codeValue' => [''],
	'acd.43.unavailreason.active' => ['0'],
	'acd.43.unavailreason.codeName' => [''],
	'acd.43.unavailreason.codeValue' => [''],
	'acd.44.unavailreason.active' => ['0'],
	'acd.44.unavailreason.codeName' => [''],
	'acd.44.unavailreason.codeValue' => [''],
	'acd.45.unavailreason.active' => ['0'],
	'acd.45.unavailreason.codeName' => [''],
	'acd.45.unavailreason.codeValue' => [''],
	'acd.46.unavailreason.active' => ['0'],
	'acd.46.unavailreason.codeName' => [''],
	'acd.46.unavailreason.codeValue' => [''],
	'acd.47.unavailreason.active' => ['0'],
	'acd.47.unavailreason.codeName' => [''],
	'acd.47.unavailreason.codeValue' => [''],
	'acd.48.unavailreason.active' => ['0'],
	'acd.48.unavailreason.codeName' => [''],
	'acd.48.unavailreason.codeValue' => [''],
	'acd.49.unavailreason.active' => ['0'],
	'acd.49.unavailreason.codeName' => [''],
	'acd.49.unavailreason.codeValue' => [''],
	'acd.5.unavailreason.active' => ['0'],
	'acd.5.unavailreason.codeName' => [''],
	'acd.5.unavailreason.codeValue' => [''],
	'acd.50.unavailreason.active' => ['0'],
	'acd.50.unavailreason.codeName' => [''],
	'acd.50.unavailreason.codeValue' => [''],
	'acd.51.unavailreason.active' => ['0'],
	'acd.51.unavailreason.codeName' => [''],
	'acd.51.unavailreason.codeValue' => [''],
	'acd.52.unavailreason.active' => ['0'],
	'acd.52.unavailreason.codeName' => [''],
	'acd.52.unavailreason.codeValue' => [''],
	'acd.53.unavailreason.active' => ['0'],
	'acd.53.unavailreason.codeName' => [''],
	'acd.53.unavailreason.codeValue' => [''],
	'acd.54.unavailreason.active' => ['0'],
	'acd.54.unavailreason.codeName' => [''],
	'acd.54.unavailreason.codeValue' => [''],
	'acd.55.unavailreason.active' => ['0'],
	'acd.55.unavailreason.codeName' => [''],
	'acd.55.unavailreason.codeValue' => [''],
	'acd.56.unavailreason.active' => ['0'],
	'acd.56.unavailreason.codeName' => [''],
	'acd.56.unavailreason.codeValue' => [''],
	'acd.57.unavailreason.active' => ['0'],
	'acd.57.unavailreason.codeName' => [''],
	'acd.57.unavailreason.codeValue' => [''],
	'acd.58.unavailreason.active' => ['0'],
	'acd.58.unavailreason.codeName' => [''],
	'acd.58.unavailreason.codeValue' => [''],
	'acd.59.unavailreason.active' => ['0'],
	'acd.59.unavailreason.codeName' => [''],
	'acd.59.unavailreason.codeValue' => [''],
	'acd.6.unavailreason.active' => ['0'],
	'acd.6.unavailreason.codeName' => [''],
	'acd.6.unavailreason.codeValue' => [''],
	'acd.60.unavailreason.active' => ['0'],
	'acd.60.unavailreason.codeName' => [''],
	'acd.60.unavailreason.codeValue' => [''],
	'acd.61.unavailreason.active' => ['0'],
	'acd.61.unavailreason.codeName' => [''],
	'acd.61.unavailreason.codeValue' => [''],
	'acd.62.unavailreason.active' => ['0'],
	'acd.62.unavailreason.codeName' => [''],
	'acd.62.unavailreason.codeValue' => [''],
	'acd.63.unavailreason.active' => ['0'],
	'acd.63.unavailreason.codeName' => [''],
	'acd.63.unavailreason.codeValue' => [''],
	'acd.64.unavailreason.active' => ['0'],
	'acd.64.unavailreason.codeName' => [''],
	'acd.64.unavailreason.codeValue' => [''],
	'acd.65.unavailreason.active' => ['0'],
	'acd.65.unavailreason.codeName' => [''],
	'acd.65.unavailreason.codeValue' => [''],
	'acd.66.unavailreason.active' => ['0'],
	'acd.66.unavailreason.codeName' => [''],
	'acd.66.unavailreason.codeValue' => [''],
	'acd.67.unavailreason.active' => ['0'],
	'acd.67.unavailreason.codeName' => [''],
	'acd.67.unavailreason.codeValue' => [''],
	'acd.68.unavailreason.active' => ['0'],
	'acd.68.unavailreason.codeName' => [''],
	'acd.68.unavailreason.codeValue' => [''],
	'acd.69.unavailreason.active' => ['0'],
	'acd.69.unavailreason.codeName' => [''],
	'acd.69.unavailreason.codeValue' => [''],
	'acd.7.unavailreason.active' => ['0'],
	'acd.7.unavailreason.codeName' => [''],
	'acd.7.unavailreason.codeValue' => [''],
	'acd.70.unavailreason.active' => ['0'],
	'acd.70.unavailreason.codeName' => [''],
	'acd.70.unavailreason.codeValue' => [''],
	'acd.71.unavailreason.active' => ['0'],
	'acd.71.unavailreason.codeName' => [''],
	'acd.71.unavailreason.codeValue' => [''],
	'acd.72.unavailreason.active' => ['0'],
	'acd.72.unavailreason.codeName' => [''],
	'acd.72.unavailreason.codeValue' => [''],
	'acd.73.unavailreason.active' => ['0'],
	'acd.73.unavailreason.codeName' => [''],
	'acd.73.unavailreason.codeValue' => [''],
	'acd.74.unavailreason.active' => ['0'],
	'acd.74.unavailreason.codeName' => [''],
	'acd.74.unavailreason.codeValue' => [''],
	'acd.75.unavailreason.active' => ['0'],
	'acd.75.unavailreason.codeName' => [''],
	'acd.75.unavailreason.codeValue' => [''],
	'acd.76.unavailreason.active' => ['0'],
	'acd.76.unavailreason.codeName' => [''],
	'acd.76.unavailreason.codeValue' => [''],
	'acd.77.unavailreason.active' => ['0'],
	'acd.77.unavailreason.codeName' => [''],
	'acd.77.unavailreason.codeValue' => [''],
	'acd.78.unavailreason.active' => ['0'],
	'acd.78.unavailreason.codeName' => [''],
	'acd.78.unavailreason.codeValue' => [''],
	'acd.79.unavailreason.active' => ['0'],
	'acd.79.unavailreason.codeName' => [''],
	'acd.79.unavailreason.codeValue' => [''],
	'acd.8.unavailreason.active' => ['0'],
	'acd.8.unavailreason.codeName' => [''],
	'acd.8.unavailreason.codeValue' => [''],
	'acd.80.unavailreason.active' => ['0'],
	'acd.80.unavailreason.codeName' => [''],
	'acd.80.unavailreason.codeValue' => [''],
	'acd.81.unavailreason.active' => ['0'],
	'acd.81.unavailreason.codeName' => [''],
	'acd.81.unavailreason.codeValue' => [''],
	'acd.82.unavailreason.active' => ['0'],
	'acd.82.unavailreason.codeName' => [''],
	'acd.82.unavailreason.codeValue' => [''],
	'acd.83.unavailreason.active' => ['0'],
	'acd.83.unavailreason.codeName' => [''],
	'acd.83.unavailreason.codeValue' => [''],
	'acd.84.unavailreason.active' => ['0'],
	'acd.84.unavailreason.codeName' => [''],
	'acd.84.unavailreason.codeValue' => [''],
	'acd.85.unavailreason.active' => ['0'],
	'acd.85.unavailreason.codeName' => [''],
	'acd.85.unavailreason.codeValue' => [''],
	'acd.86.unavailreason.active' => ['0'],
	'acd.86.unavailreason.codeName' => [''],
	'acd.86.unavailreason.codeValue' => [''],
	'acd.87.unavailreason.active' => ['0'],
	'acd.87.unavailreason.codeName' => [''],
	'acd.87.unavailreason.codeValue' => [''],
	'acd.88.unavailreason.active' => ['0'],
	'acd.88.unavailreason.codeName' => [''],
	'acd.88.unavailreason.codeValue' => [''],
	'acd.89.unavailreason.active' => ['0'],
	'acd.89.unavailreason.codeName' => [''],
	'acd.89.unavailreason.codeValue' => [''],
	'acd.9.unavailreason.active' => ['0'],
	'acd.9.unavailreason.codeName' => [''],
	'acd.9.unavailreason.codeValue' => [''],
	'acd.90.unavailreason.active' => ['0'],
	'acd.90.unavailreason.codeName' => [''],
	'acd.90.unavailreason.codeValue' => [''],
	'acd.91.unavailreason.active' => ['0'],
	'acd.91.unavailreason.codeName' => [''],
	'acd.91.unavailreason.codeValue' => [''],
	'acd.92.unavailreason.active' => ['0'],
	'acd.92.unavailreason.codeName' => [''],
	'acd.92.unavailreason.codeValue' => [''],
	'acd.93.unavailreason.active' => ['0'],
	'acd.93.unavailreason.codeName' => [''],
	'acd.93.unavailreason.codeValue' => [''],
	'acd.94.unavailreason.active' => ['0'],
	'acd.94.unavailreason.codeName' => [''],
	'acd.94.unavailreason.codeValue' => [''],
	'acd.95.unavailreason.active' => ['0'],
	'acd.95.unavailreason.codeName' => [''],
	'acd.95.unavailreason.codeValue' => [''],
	'acd.96.unavailreason.active' => ['0'],
	'acd.96.unavailreason.codeName' => [''],
	'acd.96.unavailreason.codeValue' => [''],
	'acd.97.unavailreason.active' => ['0'],
	'acd.97.unavailreason.codeName' => [''],
	'acd.97.unavailreason.codeValue' => [''],
	'acd.98.unavailreason.active' => ['0'],
	'acd.98.unavailreason.codeName' => [''],
	'acd.98.unavailreason.codeValue' => [''],
	'acd.99.unavailreason.active' => ['0'],
	'acd.99.unavailreason.codeName' => [''],
	'acd.99.unavailreason.codeValue' => [''],
	'acd.reg' => ['1'],
	'acd.stateAtSignIn' => ['1'],
	'apps.1.Label' => [''],
	'apps.1.Url' => [''],
	'apps.10.Label' => [''],
	'apps.10.Url' => [''],
	'apps.2.Label' => [''],
	'apps.2.Url' => [''],
	'apps.3.Label' => [''],
	'apps.3.Url' => [''],
	'apps.4.Label' => [''],
	'apps.4.Url' => [''],
	'apps.5.Label' => [''],
	'apps.5.Url' => [''],
	'apps.6.Label' => [''],
	'apps.6.Url' => [''],
	'apps.7.Label' => [''],
	'apps.7.Url' => [''],
	'apps.8.Label' => [''],
	'apps.8.Url' => [''],
	'apps.9.Label' => [''],
	'apps.9.Url' => [''],
	'apps.push.alertSound' => ['0'],
	'apps.push.messageType' => ['0'],
	'apps.push.password' => [''],
	'apps.push.serverRootURL' => [''],
	'apps.push.username' => [''],
	'apps.statePolling.URL' => [''],
	'apps.statePolling.password' => [''],
	'apps.statePolling.username' => [''],
	'apps.telNotification.1.URL' => [''],
	'apps.telNotification.2.URL' => [''],
	'apps.telNotification.3.URL' => [''],
	'apps.telNotification.4.URL' => [''],
	'apps.telNotification.5.URL' => [''],
	'apps.telNotification.6.URL' => [''],
	'apps.telNotification.7.URL' => [''],
	'apps.telNotification.8.URL' => [''],
	'apps.telNotification.9.URL' => [''],
	'apps.telNotification.URL' => [''],
	'apps.telNotification.incomingEvent' => ['0'],
	'apps.telNotification.lineRegistrationEvent' => ['0'],
	'apps.telNotification.offhookEvent' => ['0'],
	'apps.telNotification.onhookEvent' => ['0'],
	'apps.telNotification.outgoingEvent' => ['0'],
	'apps.ucdesktop.IP' => ['127.0.0.1'],
	'apps.ucdesktop.enabled' => ['0'],
	'apps.ucdesktop.name' => ['phone'],
	'apps.ucdesktop.port' => ['24800'],
	'attendant.behaviors.display.remoteCallerID.automata' => ['1'],
	'attendant.behaviors.display.remoteCallerID.normal' => ['1'],
	'attendant.behaviors.display.spontaneousCallAppearances.automata' => ['0'],
	'attendant.behaviors.display.spontaneousCallAppearances.normal' => ['1'],
	'attendant.reg' => ['1'],
	'attendant.resourceList.1.address' => [''],
	'attendant.resourceList.1.label' => [''],
	'attendant.resourceList.1.type' => [''],
	'attendant.resourceList.10.address' => [''],
	'attendant.resourceList.10.label' => [''],
	'attendant.resourceList.10.type' => [''],
	'attendant.resourceList.11.address' => [''],
	'attendant.resourceList.11.label' => [''],
	'attendant.resourceList.11.type' => [''],
	'attendant.resourceList.12.address' => [''],
	'attendant.resourceList.12.label' => [''],
	'attendant.resourceList.12.type' => [''],
	'attendant.resourceList.13.address' => [''],
	'attendant.resourceList.13.label' => [''],
	'attendant.resourceList.13.type' => [''],
	'attendant.resourceList.14.address' => [''],
	'attendant.resourceList.14.label' => [''],
	'attendant.resourceList.14.type' => [''],
	'attendant.resourceList.15.address' => [''],
	'attendant.resourceList.15.label' => [''],
	'attendant.resourceList.15.type' => [''],
	'attendant.resourceList.16.address' => [''],
	'attendant.resourceList.16.label' => [''],
	'attendant.resourceList.16.type' => [''],
	'attendant.resourceList.17.address' => [''],
	'attendant.resourceList.17.label' => [''],
	'attendant.resourceList.17.type' => [''],
	'attendant.resourceList.18.address' => [''],
	'attendant.resourceList.18.label' => [''],
	'attendant.resourceList.18.type' => [''],
	'attendant.resourceList.19.address' => [''],
	'attendant.resourceList.19.label' => [''],
	'attendant.resourceList.19.type' => [''],
	'attendant.resourceList.2.address' => [''],
	'attendant.resourceList.2.label' => [''],
	'attendant.resourceList.2.type' => [''],
	'attendant.resourceList.20.address' => [''],
	'attendant.resourceList.20.label' => [''],
	'attendant.resourceList.20.type' => [''],
	'attendant.resourceList.21.address' => [''],
	'attendant.resourceList.21.label' => [''],
	'attendant.resourceList.21.type' => [''],
	'attendant.resourceList.22.address' => [''],
	'attendant.resourceList.22.label' => [''],
	'attendant.resourceList.22.type' => [''],
	'attendant.resourceList.23.address' => [''],
	'attendant.resourceList.23.label' => [''],
	'attendant.resourceList.23.type' => [''],
	'attendant.resourceList.24.address' => [''],
	'attendant.resourceList.24.label' => [''],
	'attendant.resourceList.24.type' => [''],
	'attendant.resourceList.25.address' => [''],
	'attendant.resourceList.25.label' => [''],
	'attendant.resourceList.25.type' => [''],
	'attendant.resourceList.26.address' => [''],
	'attendant.resourceList.26.label' => [''],
	'attendant.resourceList.26.type' => [''],
	'attendant.resourceList.27.address' => [''],
	'attendant.resourceList.27.label' => [''],
	'attendant.resourceList.27.type' => [''],
	'attendant.resourceList.28.address' => [''],
	'attendant.resourceList.28.label' => [''],
	'attendant.resourceList.28.type' => [''],
	'attendant.resourceList.29.address' => [''],
	'attendant.resourceList.29.label' => [''],
	'attendant.resourceList.29.type' => [''],
	'attendant.resourceList.3.address' => [''],
	'attendant.resourceList.3.label' => [''],
	'attendant.resourceList.3.type' => [''],
	'attendant.resourceList.30.address' => [''],
	'attendant.resourceList.30.label' => [''],
	'attendant.resourceList.30.type' => [''],
	'attendant.resourceList.31.address' => [''],
	'attendant.resourceList.31.label' => [''],
	'attendant.resourceList.31.type' => [''],
	'attendant.resourceList.32.address' => [''],
	'attendant.resourceList.32.label' => [''],
	'attendant.resourceList.32.type' => [''],
	'attendant.resourceList.33.address' => [''],
	'attendant.resourceList.33.label' => [''],
	'attendant.resourceList.33.type' => [''],
	'attendant.resourceList.34.address' => [''],
	'attendant.resourceList.34.label' => [''],
	'attendant.resourceList.34.type' => [''],
	'attendant.resourceList.35.address' => [''],
	'attendant.resourceList.35.label' => [''],
	'attendant.resourceList.35.type' => [''],
	'attendant.resourceList.36.address' => [''],
	'attendant.resourceList.36.label' => [''],
	'attendant.resourceList.36.type' => [''],
	'attendant.resourceList.37.address' => [''],
	'attendant.resourceList.37.label' => [''],
	'attendant.resourceList.37.type' => [''],
	'attendant.resourceList.38.address' => [''],
	'attendant.resourceList.38.label' => [''],
	'attendant.resourceList.38.type' => [''],
	'attendant.resourceList.39.address' => [''],
	'attendant.resourceList.39.label' => [''],
	'attendant.resourceList.39.type' => [''],
	'attendant.resourceList.4.address' => [''],
	'attendant.resourceList.4.label' => [''],
	'attendant.resourceList.4.type' => [''],
	'attendant.resourceList.40.address' => [''],
	'attendant.resourceList.40.label' => [''],
	'attendant.resourceList.40.type' => [''],
	'attendant.resourceList.41.address' => [''],
	'attendant.resourceList.41.label' => [''],
	'attendant.resourceList.41.type' => [''],
	'attendant.resourceList.42.address' => [''],
	'attendant.resourceList.42.label' => [''],
	'attendant.resourceList.42.type' => [''],
	'attendant.resourceList.43.address' => [''],
	'attendant.resourceList.43.label' => [''],
	'attendant.resourceList.43.type' => [''],
	'attendant.resourceList.44.address' => [''],
	'attendant.resourceList.44.label' => [''],
	'attendant.resourceList.44.type' => [''],
	'attendant.resourceList.45.address' => [''],
	'attendant.resourceList.45.label' => [''],
	'attendant.resourceList.45.type' => [''],
	'attendant.resourceList.46.address' => [''],
	'attendant.resourceList.46.label' => [''],
	'attendant.resourceList.46.type' => [''],
	'attendant.resourceList.47.address' => [''],
	'attendant.resourceList.47.label' => [''],
	'attendant.resourceList.47.type' => [''],
	'attendant.resourceList.48.address' => [''],
	'attendant.resourceList.48.label' => [''],
	'attendant.resourceList.48.type' => [''],
	'attendant.resourceList.5.address' => [''],
	'attendant.resourceList.5.label' => [''],
	'attendant.resourceList.5.type' => [''],
	'attendant.resourceList.6.address' => [''],
	'attendant.resourceList.6.label' => [''],
	'attendant.resourceList.6.type' => [''],
	'attendant.resourceList.7.address' => [''],
	'attendant.resourceList.7.label' => [''],
	'attendant.resourceList.7.type' => [''],
	'attendant.resourceList.8.address' => [''],
	'attendant.resourceList.8.label' => [''],
	'attendant.resourceList.8.type' => [''],
	'attendant.resourceList.9.address' => [''],
	'attendant.resourceList.9.label' => [''],
	'attendant.resourceList.9.type' => [''],
	'attendant.ringType' => ['ringer1'],
	'attendant.uri' => [''],
	'bg.VVX_1500.color.bm.1.name' => [''],
	'bg.VVX_1500.color.bm.2.name' => [''],
	'bg.VVX_1500.color.bm.3.name' => [''],
	'bg.VVX_1500.color.bm.4.name' => [''],
	'bg.VVX_1500.color.bm.5.name' => [''],
	'bg.VVX_1500.color.bm.6.name' => [''],
	'bg.VVX_1500.color.selection' => ['1,1'],
	'bg.hiRes.color.bm.1.em.name' => ['LeafEM.jpg'],
	'bg.hiRes.color.bm.1.name' => ['Leaf.jpg'],
	'bg.hiRes.color.bm.10.em.name' => [''],
	'bg.hiRes.color.bm.10.name' => [''],
	'bg.hiRes.color.bm.11.em.name' => [''],
	'bg.hiRes.color.bm.11.name' => [''],
	'bg.hiRes.color.bm.12.em.name' => [''],
	'bg.hiRes.color.bm.12.name' => [''],
	'bg.hiRes.color.bm.13.em.name' => [''],
	'bg.hiRes.color.bm.13.name' => [''],
	'bg.hiRes.color.bm.14.em.name' => [''],
	'bg.hiRes.color.bm.14.name' => [''],
	'bg.hiRes.color.bm.15.em.name' => [''],
	'bg.hiRes.color.bm.15.name' => [''],
	'bg.hiRes.color.bm.16.em.name' => [''],
	'bg.hiRes.color.bm.16.name' => [''],
	'bg.hiRes.color.bm.17.em.name' => [''],
	'bg.hiRes.color.bm.17.name' => [''],
	'bg.hiRes.color.bm.18.em.name' => [''],
	'bg.hiRes.color.bm.18.name' => [''],
	'bg.hiRes.color.bm.19.em.name' => [''],
	'bg.hiRes.color.bm.19.name' => [''],
	'bg.hiRes.color.bm.2.em.name' => ['SailboatEM.jpg'],
	'bg.hiRes.color.bm.2.name' => ['Sailboat.jpg'],
	'bg.hiRes.color.bm.20.em.name' => [''],
	'bg.hiRes.color.bm.20.name' => [''],
	'bg.hiRes.color.bm.3.em.name' => ['BeachEM.jpg'],
	'bg.hiRes.color.bm.3.name' => ['Beach.jpg', ''],
	'bg.hiRes.color.bm.4.em.name' => ['PalmEM.jpg'],
	'bg.hiRes.color.bm.4.name' => ['Palm.jpg', ''],
	'bg.hiRes.color.bm.5.em.name' => ['JellyfishEM.jpg'],
	'bg.hiRes.color.bm.5.name' => ['Jellyfish.jpg'],
	'bg.hiRes.color.bm.6.em.name' => ['MountainEM.jpg'],
	'bg.hiRes.color.bm.6.name' => ['Mountain.jpg'],
	'bg.hiRes.color.bm.7.em.name' => [''],
	'bg.hiRes.color.bm.7.name' => [''],
	'bg.hiRes.color.bm.8.em.name' => [''],
	'bg.hiRes.color.bm.8.name' => [''],
	'bg.hiRes.color.bm.9.em.name' => [''],
	'bg.hiRes.color.bm.9.name' => [''],
	'bg.hiRes.color.pat.solid.1.blue' => ['249',255],
	'bg.hiRes.color.pat.solid.1.green' => ['207',255],
	'bg.hiRes.color.pat.solid.1.name' => ['Light Blue','White'],
	'bg.hiRes.color.pat.solid.1.red' => ['151',255],
	'bg.hiRes.color.pat.solid.10.blue' => ['0'],
	'bg.hiRes.color.pat.solid.10.green' => ['0'],
	'bg.hiRes.color.pat.solid.10.name' => [''],
	'bg.hiRes.color.pat.solid.10.red' => ['0'],
	'bg.hiRes.color.pat.solid.11.blue' => ['0'],
	'bg.hiRes.color.pat.solid.11.green' => ['0'],
	'bg.hiRes.color.pat.solid.11.name' => [''],
	'bg.hiRes.color.pat.solid.11.red' => ['0'],
	'bg.hiRes.color.pat.solid.12.blue' => ['0'],
	'bg.hiRes.color.pat.solid.12.green' => ['0'],
	'bg.hiRes.color.pat.solid.12.name' => [''],
	'bg.hiRes.color.pat.solid.12.red' => ['0'],
	'bg.hiRes.color.pat.solid.13.blue' => ['0'],
	'bg.hiRes.color.pat.solid.13.green' => ['0'],
	'bg.hiRes.color.pat.solid.13.name' => [''],
	'bg.hiRes.color.pat.solid.13.red' => ['0'],
	'bg.hiRes.color.pat.solid.14.blue' => ['0'],
	'bg.hiRes.color.pat.solid.14.green' => ['0'],
	'bg.hiRes.color.pat.solid.14.name' => [''],
	'bg.hiRes.color.pat.solid.14.red' => ['0'],
	'bg.hiRes.color.pat.solid.15.blue' => ['0'],
	'bg.hiRes.color.pat.solid.15.green' => ['0'],
	'bg.hiRes.color.pat.solid.15.name' => [''],
	'bg.hiRes.color.pat.solid.15.red' => ['0'],
	'bg.hiRes.color.pat.solid.16.blue' => ['0'],
	'bg.hiRes.color.pat.solid.16.green' => ['0'],
	'bg.hiRes.color.pat.solid.16.name' => [''],
	'bg.hiRes.color.pat.solid.16.red' => ['0'],
	'bg.hiRes.color.pat.solid.17.blue' => ['0'],
	'bg.hiRes.color.pat.solid.17.green' => ['0'],
	'bg.hiRes.color.pat.solid.17.name' => [''],
	'bg.hiRes.color.pat.solid.17.red' => ['0'],
	'bg.hiRes.color.pat.solid.18.blue' => ['0'],
	'bg.hiRes.color.pat.solid.18.green' => ['0'],
	'bg.hiRes.color.pat.solid.18.name' => [''],
	'bg.hiRes.color.pat.solid.18.red' => ['0'],
	'bg.hiRes.color.pat.solid.19.blue' => ['0'],
	'bg.hiRes.color.pat.solid.19.green' => ['0'],
	'bg.hiRes.color.pat.solid.19.name' => [''],
	'bg.hiRes.color.pat.solid.19.red' => ['0'],
	'bg.hiRes.color.pat.solid.2.blue' => ['148',160],
	'bg.hiRes.color.pat.solid.2.green' => ['148',160],
	'bg.hiRes.color.pat.solid.2.name' => ['Teal', 'Light Gray'],
	'bg.hiRes.color.pat.solid.2.red' => ['73', 160],
	'bg.hiRes.color.pat.solid.20.blue' => ['0'],
	'bg.hiRes.color.pat.solid.20.green' => ['0'],
	'bg.hiRes.color.pat.solid.20.name' => [''],
	'bg.hiRes.color.pat.solid.20.red' => ['0'],
	'bg.hiRes.color.pat.solid.3.blue' => ['69',231],
	'bg.hiRes.color.pat.solid.3.green' => ['157',249],
	'bg.hiRes.color.pat.solid.3.name' => ['Tan', 'Aqua Marine'],
	'bg.hiRes.color.pat.solid.3.red' => ['245', 57],
	'bg.hiRes.color.pat.solid.4.blue' => ['0', 0],
	'bg.hiRes.color.pat.solid.4.green' => ['0', 112],
	'bg.hiRes.color.pat.solid.4.name' => ['', 'Tan'],
	'bg.hiRes.color.pat.solid.4.red' => ['0', 186],
	'bg.hiRes.color.pat.solid.5.blue' => ['0'],
	'bg.hiRes.color.pat.solid.5.green' => ['0'],
	'bg.hiRes.color.pat.solid.5.name' => [''],
	'bg.hiRes.color.pat.solid.5.red' => ['0'],
	'bg.hiRes.color.pat.solid.6.blue' => ['0'],
	'bg.hiRes.color.pat.solid.6.green' => ['0'],
	'bg.hiRes.color.pat.solid.6.name' => [''],
	'bg.hiRes.color.pat.solid.6.red' => ['0'],
	'bg.hiRes.color.pat.solid.7.blue' => ['0'],
	'bg.hiRes.color.pat.solid.7.green' => ['0'],
	'bg.hiRes.color.pat.solid.7.name' => [''],
	'bg.hiRes.color.pat.solid.7.red' => ['0'],
	'bg.hiRes.color.pat.solid.8.blue' => ['0'],
	'bg.hiRes.color.pat.solid.8.green' => ['0'],
	'bg.hiRes.color.pat.solid.8.name' => [''],
	'bg.hiRes.color.pat.solid.8.red' => ['0'],
	'bg.hiRes.color.pat.solid.9.blue' => ['0'],
	'bg.hiRes.color.pat.solid.9.green' => ['0'],
	'bg.hiRes.color.pat.solid.9.name' => [''],
	'bg.hiRes.color.pat.solid.9.red' => ['0'],
	'bg.hiRes.color.selection' => ['1,1'],
	'bg.hiRes.gray.bm.1.adj' => ['0'],
	'bg.hiRes.gray.bm.1.em.name' => ['LeafEM.jpg'],
	'bg.hiRes.gray.bm.1.name' => ['Leaf.jpg'],
	'bg.hiRes.gray.bm.10.em.name' => [''],
	'bg.hiRes.gray.bm.10.name' => [''],
	'bg.hiRes.gray.bm.11.em.name' => [''],
	'bg.hiRes.gray.bm.11.name' => [''],
	'bg.hiRes.gray.bm.12.em.name' => [''],
	'bg.hiRes.gray.bm.12.name' => [''],
	'bg.hiRes.gray.bm.13.em.name' => [''],
	'bg.hiRes.gray.bm.13.name' => [''],
	'bg.hiRes.gray.bm.14.em.name' => [''],
	'bg.hiRes.gray.bm.14.name' => [''],
	'bg.hiRes.gray.bm.15.em.name' => [''],
	'bg.hiRes.gray.bm.15.name' => [''],
	'bg.hiRes.gray.bm.16.em.name' => [''],
	'bg.hiRes.gray.bm.16.name' => [''],
	'bg.hiRes.gray.bm.17.em.name' => [''],
	'bg.hiRes.gray.bm.17.name' => [''],
	'bg.hiRes.gray.bm.18.em.name' => [''],
	'bg.hiRes.gray.bm.18.name' => [''],
	'bg.hiRes.gray.bm.19.em.name' => [''],
	'bg.hiRes.gray.bm.19.name' => [''],
	'bg.hiRes.gray.bm.2.adj' => ['-3'],
	'bg.hiRes.gray.bm.2.em.name' => ['SailboatEM.jpg'],
	'bg.hiRes.gray.bm.2.name' => ['Sailboat.jpg'],
	'bg.hiRes.gray.bm.20.em.name' => [''],
	'bg.hiRes.gray.bm.20.name' => [''],
	'bg.hiRes.gray.bm.3.adj' => ['0'],
	'bg.hiRes.gray.bm.3.em.name' => ['BeachEM.jpg'],
	'bg.hiRes.gray.bm.3.name' => ['Beach.jpg'],
	'bg.hiRes.gray.bm.4.adj' => ['-3'],
	'bg.hiRes.gray.bm.4.em.name' => ['PalmEM.jpg'],
	'bg.hiRes.gray.bm.4.name' => ['Palm.jpg', ''],
	'bg.hiRes.gray.bm.5.adj' => ['-2'],
	'bg.hiRes.gray.bm.5.em.name' => ['JellyfishEM.jpg'],
	'bg.hiRes.gray.bm.5.name' => ['Jellyfish.jpg'],
	'bg.hiRes.gray.bm.6.adj' => ['0'],
	'bg.hiRes.gray.bm.6.em.name' => ['MountainEM.jpg'],
	'bg.hiRes.gray.bm.6.name' => ['Mountain.jpg'],
	'bg.hiRes.gray.bm.7.em.name' => [''],
	'bg.hiRes.gray.bm.7.name' => [''],
	'bg.hiRes.gray.bm.8.em.name' => [''],
	'bg.hiRes.gray.bm.8.name' => [''],
	'bg.hiRes.gray.bm.9.em.name' => [''],
	'bg.hiRes.gray.bm.9.name' => [''],
	'bg.hiRes.gray.pat.solid.1.blue' => ['255'],
	'bg.hiRes.gray.pat.solid.1.green' => ['255'],
	'bg.hiRes.gray.pat.solid.1.name' => ['White'],
	'bg.hiRes.gray.pat.solid.1.red' => ['255'],
	'bg.hiRes.gray.pat.solid.10.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.10.green' => ['0'],
	'bg.hiRes.gray.pat.solid.10.name' => [''],
	'bg.hiRes.gray.pat.solid.10.red' => ['0'],
	'bg.hiRes.gray.pat.solid.11.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.11.green' => ['0'],
	'bg.hiRes.gray.pat.solid.11.name' => [''],
	'bg.hiRes.gray.pat.solid.11.red' => ['0'],
	'bg.hiRes.gray.pat.solid.12.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.12.green' => ['0'],
	'bg.hiRes.gray.pat.solid.12.name' => [''],
	'bg.hiRes.gray.pat.solid.12.red' => ['0'],
	'bg.hiRes.gray.pat.solid.13.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.13.green' => ['0'],
	'bg.hiRes.gray.pat.solid.13.name' => [''],
	'bg.hiRes.gray.pat.solid.13.red' => ['0'],
	'bg.hiRes.gray.pat.solid.14.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.14.green' => ['0'],
	'bg.hiRes.gray.pat.solid.14.name' => [''],
	'bg.hiRes.gray.pat.solid.14.red' => ['0'],
	'bg.hiRes.gray.pat.solid.15.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.15.green' => ['0'],
	'bg.hiRes.gray.pat.solid.15.name' => [''],
	'bg.hiRes.gray.pat.solid.15.red' => ['0'],
	'bg.hiRes.gray.pat.solid.16.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.16.green' => ['0'],
	'bg.hiRes.gray.pat.solid.16.name' => [''],
	'bg.hiRes.gray.pat.solid.16.red' => ['0'],
	'bg.hiRes.gray.pat.solid.17.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.17.green' => ['0'],
	'bg.hiRes.gray.pat.solid.17.name' => [''],
	'bg.hiRes.gray.pat.solid.17.red' => ['0'],
	'bg.hiRes.gray.pat.solid.18.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.18.green' => ['0'],
	'bg.hiRes.gray.pat.solid.18.name' => [''],
	'bg.hiRes.gray.pat.solid.18.red' => ['0'],
	'bg.hiRes.gray.pat.solid.19.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.19.green' => ['0'],
	'bg.hiRes.gray.pat.solid.19.name' => [''],
	'bg.hiRes.gray.pat.solid.19.red' => ['0'],
	'bg.hiRes.gray.pat.solid.2.blue' => ['160'],
	'bg.hiRes.gray.pat.solid.2.green' => ['160'],
	'bg.hiRes.gray.pat.solid.2.name' => ['Light Gray'],
	'bg.hiRes.gray.pat.solid.2.red' => ['160'],
	'bg.hiRes.gray.pat.solid.20.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.20.green' => ['0'],
	'bg.hiRes.gray.pat.solid.20.name' => [''],
	'bg.hiRes.gray.pat.solid.20.red' => ['0'],
	'bg.hiRes.gray.pat.solid.3.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.3.green' => ['0'],
	'bg.hiRes.gray.pat.solid.3.name' => [''],
	'bg.hiRes.gray.pat.solid.3.red' => ['0'],
	'bg.hiRes.gray.pat.solid.4.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.4.green' => ['0'],
	'bg.hiRes.gray.pat.solid.4.name' => [''],
	'bg.hiRes.gray.pat.solid.4.red' => ['0'],
	'bg.hiRes.gray.pat.solid.5.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.5.green' => ['0'],
	'bg.hiRes.gray.pat.solid.5.name' => [''],
	'bg.hiRes.gray.pat.solid.5.red' => ['0'],
	'bg.hiRes.gray.pat.solid.6.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.6.green' => ['0'],
	'bg.hiRes.gray.pat.solid.6.name' => [''],
	'bg.hiRes.gray.pat.solid.6.red' => ['0'],
	'bg.hiRes.gray.pat.solid.7.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.7.green' => ['0'],
	'bg.hiRes.gray.pat.solid.7.name' => [''],
	'bg.hiRes.gray.pat.solid.7.red' => ['0'],
	'bg.hiRes.gray.pat.solid.8.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.8.green' => ['0'],
	'bg.hiRes.gray.pat.solid.8.name' => [''],
	'bg.hiRes.gray.pat.solid.8.red' => ['0'],
	'bg.hiRes.gray.pat.solid.9.blue' => ['0'],
	'bg.hiRes.gray.pat.solid.9.green' => ['0'],
	'bg.hiRes.gray.pat.solid.9.name' => [''],
	'bg.hiRes.gray.pat.solid.9.red' => ['0'],
	'bg.hiRes.gray.pr.1.adj' => ['-3'],
	'bg.hiRes.gray.pr.2.adj' => ['0'],
	'bg.hiRes.gray.pr.3.adj' => ['0'],
	'bg.hiRes.gray.pr.4.adj' => ['0'],
	'bg.hiRes.gray.pr.5.adj' => ['0'],
	'bg.hiRes.gray.pr.6.adj' => ['0'],
	'bg.hiRes.gray.selection' => ['2,1'],
	'bg.medRes.gray.bm.1.adj' => ['0'],
	'bg.medRes.gray.bm.1.name' => ['Leaf256x116.jpg'],
	'bg.medRes.gray.bm.10.name' => [''],
	'bg.medRes.gray.bm.11.name' => [''],
	'bg.medRes.gray.bm.12.name' => [''],
	'bg.medRes.gray.bm.13.name' => [''],
	'bg.medRes.gray.bm.14.name' => [''],
	'bg.medRes.gray.bm.15.name' => [''],
	'bg.medRes.gray.bm.16.name' => [''],
	'bg.medRes.gray.bm.17.name' => [''],
	'bg.medRes.gray.bm.18.name' => [''],
	'bg.medRes.gray.bm.19.name' => [''],
	'bg.medRes.gray.bm.2.adj' => ['-3'],
	'bg.medRes.gray.bm.2.name' => ['Sailboat256x116.jpg'],
	'bg.medRes.gray.bm.20.name' => [''],
	'bg.medRes.gray.bm.3.adj' => ['0'],
	'bg.medRes.gray.bm.3.name' => ['Beach256x116.jpg'],
	'bg.medRes.gray.bm.4.adj' => ['-3'],
	'bg.medRes.gray.bm.4.name' => ['Palm256x116.jpg'],
	'bg.medRes.gray.bm.5.adj' => ['-2'],
	'bg.medRes.gray.bm.5.name' => ['Jellyfish256x116.jpg'],
	'bg.medRes.gray.bm.6.adj' => ['0'],
	'bg.medRes.gray.bm.6.name' => ['Mountain256x116.jpg'],
	'bg.medRes.gray.bm.7.name' => [''],
	'bg.medRes.gray.bm.8.name' => [''],
	'bg.medRes.gray.bm.9.name' => [''],
	'bg.medRes.gray.pat.solid.1.blue' => ['255'],
	'bg.medRes.gray.pat.solid.1.green' => ['255'],
	'bg.medRes.gray.pat.solid.1.name' => ['White'],
	'bg.medRes.gray.pat.solid.1.red' => ['255'],
	'bg.medRes.gray.pat.solid.10.blue' => ['0'],
	'bg.medRes.gray.pat.solid.10.green' => ['0'],
	'bg.medRes.gray.pat.solid.10.name' => [''],
	'bg.medRes.gray.pat.solid.10.red' => ['0'],
	'bg.medRes.gray.pat.solid.11.blue' => ['0'],
	'bg.medRes.gray.pat.solid.11.green' => ['0'],
	'bg.medRes.gray.pat.solid.11.name' => [''],
	'bg.medRes.gray.pat.solid.11.red' => ['0'],
	'bg.medRes.gray.pat.solid.12.blue' => ['0'],
	'bg.medRes.gray.pat.solid.12.green' => ['0'],
	'bg.medRes.gray.pat.solid.12.name' => [''],
	'bg.medRes.gray.pat.solid.12.red' => ['0'],
	'bg.medRes.gray.pat.solid.13.blue' => ['0'],
	'bg.medRes.gray.pat.solid.13.green' => ['0'],
	'bg.medRes.gray.pat.solid.13.name' => [''],
	'bg.medRes.gray.pat.solid.13.red' => ['0'],
	'bg.medRes.gray.pat.solid.14.blue' => ['0'],
	'bg.medRes.gray.pat.solid.14.green' => ['0'],
	'bg.medRes.gray.pat.solid.14.name' => [''],
	'bg.medRes.gray.pat.solid.14.red' => ['0'],
	'bg.medRes.gray.pat.solid.15.blue' => ['0'],
	'bg.medRes.gray.pat.solid.15.green' => ['0'],
	'bg.medRes.gray.pat.solid.15.name' => [''],
	'bg.medRes.gray.pat.solid.15.red' => ['0'],
	'bg.medRes.gray.pat.solid.16.blue' => ['0'],
	'bg.medRes.gray.pat.solid.16.green' => ['0'],
	'bg.medRes.gray.pat.solid.16.name' => [''],
	'bg.medRes.gray.pat.solid.16.red' => ['0'],
	'bg.medRes.gray.pat.solid.17.blue' => ['0'],
	'bg.medRes.gray.pat.solid.17.green' => ['0'],
	'bg.medRes.gray.pat.solid.17.name' => [''],
	'bg.medRes.gray.pat.solid.17.red' => ['0'],
	'bg.medRes.gray.pat.solid.18.blue' => ['0'],
	'bg.medRes.gray.pat.solid.18.green' => ['0'],
	'bg.medRes.gray.pat.solid.18.name' => [''],
	'bg.medRes.gray.pat.solid.18.red' => ['0'],
	'bg.medRes.gray.pat.solid.19.blue' => ['0'],
	'bg.medRes.gray.pat.solid.19.green' => ['0'],
	'bg.medRes.gray.pat.solid.19.name' => [''],
	'bg.medRes.gray.pat.solid.19.red' => ['0'],
	'bg.medRes.gray.pat.solid.2.blue' => ['160'],
	'bg.medRes.gray.pat.solid.2.green' => ['160'],
	'bg.medRes.gray.pat.solid.2.name' => ['Light Gray'],
	'bg.medRes.gray.pat.solid.2.red' => ['160'],
	'bg.medRes.gray.pat.solid.20.blue' => ['0'],
	'bg.medRes.gray.pat.solid.20.green' => ['0'],
	'bg.medRes.gray.pat.solid.20.name' => [''],
	'bg.medRes.gray.pat.solid.20.red' => ['0'],
	'bg.medRes.gray.pat.solid.3.blue' => ['0'],
	'bg.medRes.gray.pat.solid.3.green' => ['0'],
	'bg.medRes.gray.pat.solid.3.name' => [''],
	'bg.medRes.gray.pat.solid.3.red' => ['0'],
	'bg.medRes.gray.pat.solid.4.blue' => ['0'],
	'bg.medRes.gray.pat.solid.4.green' => ['0'],
	'bg.medRes.gray.pat.solid.4.name' => [''],
	'bg.medRes.gray.pat.solid.4.red' => ['0'],
	'bg.medRes.gray.pat.solid.5.blue' => ['0'],
	'bg.medRes.gray.pat.solid.5.green' => ['0'],
	'bg.medRes.gray.pat.solid.5.name' => [''],
	'bg.medRes.gray.pat.solid.5.red' => ['0'],
	'bg.medRes.gray.pat.solid.6.blue' => ['0'],
	'bg.medRes.gray.pat.solid.6.green' => ['0'],
	'bg.medRes.gray.pat.solid.6.name' => [''],
	'bg.medRes.gray.pat.solid.6.red' => ['0'],
	'bg.medRes.gray.pat.solid.7.blue' => ['0'],
	'bg.medRes.gray.pat.solid.7.green' => ['0'],
	'bg.medRes.gray.pat.solid.7.name' => [''],
	'bg.medRes.gray.pat.solid.7.red' => ['0'],
	'bg.medRes.gray.pat.solid.8.blue' => ['0'],
	'bg.medRes.gray.pat.solid.8.green' => ['0'],
	'bg.medRes.gray.pat.solid.8.name' => [''],
	'bg.medRes.gray.pat.solid.8.red' => ['0'],
	'bg.medRes.gray.pat.solid.9.blue' => ['0'],
	'bg.medRes.gray.pat.solid.9.green' => ['0'],
	'bg.medRes.gray.pat.solid.9.name' => [''],
	'bg.medRes.gray.pat.solid.9.red' => ['0'],
	'bg.medRes.gray.pr.1.adj' => ['-3'],
	'bg.medRes.gray.pr.2.adj' => ['0'],
	'bg.medRes.gray.pr.3.adj' => ['0'],
	'bg.medRes.gray.pr.4.adj' => ['0'],
	'bg.medRes.gray.pr.5.adj' => ['0'],
	'bg.medRes.gray.pr.6.adj' => ['0'],
	'bg.medRes.gray.selection' => ['2,1'],
	'bitmap.idleDisplay.name' => [''],
	'button.color.selection.1.1.modify' => ['rgbHiLo,68,255,0,85,68,255'],
	'button.color.selection.1.2.modify' => ['', 'none' ],
	'button.color.selection.1.3.modify' => ['', 'none' ],
	'button.color.selection.1.4.modify' => ['', 'none' ],
	'button.color.selection.1.5.modify' => ['', 'none' ],
	'button.color.selection.1.6.modify' => ['', 'none' ],
	'button.color.selection.2.1.modify' => ['rgbHiLo,0,255,0,255,102,255'],
	'button.color.selection.2.2.modify' => ['rgbHiLo,0,255,51,255,51,255'],
	'button.color.selection.2.3.modify' => ['rgbHiLo,153,255,51,255,0,255'],
	'button.color.selection.2.4.modify' => ['', 'none' ],
	'button.color.selection.2.5.modify' => ['', 'none' ],
	'button.color.selection.2.6.modify' => ['', 'none' ],
	'button.color.selection.3.1.modify' => ['rgbHiLo,51,255,68,255,0,119'],
	'button.color.selection.3.2.modify' => ['rgbHiLo,34,255,0,255,170,255'],
	'button.color.selection.3.3.modify' => ['rgbHiLo,136,221,51,51,187,255'],
	'button.color.selection.3.4.modify' => ['rgbHiLo,34,255,119,255,0,255'],
	'button.color.selection.3.5.modify' => ['rgbHiLo,170,255,68,255,0,255'],
	'button.color.selection.3.6.modify' => ['rgbHiLo,0,255,102,255,153,255'],
	'button.color.selection.4.1.modify' => ['', 'none' ],
	'button.color.selection.4.2.modify' => ['', 'none' ],
	'button.color.selection.4.3.modify' => ['', 'none' ],
	'button.color.selection.4.4.modify' => ['', 'none' ],
	'button.color.selection.4.5.modify' => ['', 'none' ],
	'button.color.selection.4.6.modify' => ['', 'none' ],
	'button.color.selection.5.1.modify' => ['', 'none' ],
	'button.color.selection.5.2.modify' => ['', 'none' ],
	'button.color.selection.5.3.modify' => ['', 'none' ],
	'button.color.selection.5.4.modify' => ['', 'none' ],
	'button.color.selection.5.5.modify' => ['', 'none' ],
	'button.color.selection.5.6.modify' => ['', 'none' ],
	'button.color.selection.6.1.modify' => ['', 'none' ],
	'button.color.selection.6.2.modify' => ['', 'none' ],
	'button.color.selection.6.3.modify' => ['', 'none' ],
	'button.color.selection.6.4.modify' => ['', 'none' ],
	'button.color.selection.6.5.modify' => ['', 'none' ],
	'button.color.selection.6.6.modify' => ['', 'none' ],
	'button.gray.selection.1.1.modify' => ['', 'none' ],
	'button.gray.selection.1.2.modify' => ['', 'none' ],
	'button.gray.selection.1.3.modify' => ['', 'none' ],
	'button.gray.selection.1.4.modify' => ['', 'none' ],
	'button.gray.selection.1.5.modify' => ['', 'none' ],
	'button.gray.selection.1.6.modify' => ['', 'none' ],
	'button.gray.selection.2.1.modify' => ['', 'none' ],
	'button.gray.selection.2.2.modify' => ['', 'none' ],
	'button.gray.selection.2.3.modify' => ['', 'none' ],
	'button.gray.selection.2.4.modify' => ['', 'none' ],
	'button.gray.selection.2.5.modify' => ['', 'none' ],
	'button.gray.selection.2.6.modify' => ['', 'none' ],
	'button.gray.selection.3.1.modify' => ['', 'none' ],
	'button.gray.selection.3.2.modify' => ['', 'none' ],
	'button.gray.selection.3.3.modify' => ['', 'none' ],
	'button.gray.selection.3.4.modify' => ['', 'none' ],
	'button.gray.selection.3.5.modify' => ['', 'none' ],
	'button.gray.selection.3.6.modify' => ['', 'none' ],
	'button.gray.selection.4.1.modify' => ['', 'none' ],
	'button.gray.selection.4.2.modify' => ['', 'none' ],
	'button.gray.selection.4.3.modify' => ['', 'none' ],
	'button.gray.selection.4.4.modify' => ['', 'none' ],
	'button.gray.selection.4.5.modify' => ['', 'none' ],
	'button.gray.selection.4.6.modify' => ['', 'none' ],
	'button.gray.selection.5.1.modify' => ['', 'none' ],
	'button.gray.selection.5.2.modify' => ['', 'none' ],
	'button.gray.selection.5.3.modify' => ['', 'none' ],
	'button.gray.selection.5.4.modify' => ['', 'none' ],
	'button.gray.selection.5.5.modify' => ['', 'none' ],
	'button.gray.selection.5.6.modify' => ['', 'none' ],
	'button.gray.selection.6.1.modify' => ['', 'none' ],
	'button.gray.selection.6.2.modify' => ['', 'none' ],
	'button.gray.selection.6.3.modify' => ['', 'none' ],
	'button.gray.selection.6.4.modify' => ['', 'none' ],
	'button.gray.selection.6.5.modify' => ['', 'none' ],
	'button.gray.selection.6.6.modify' => ['', 'none' ],
	'call.autoAnswer.H323' => ['0'],
	'call.autoAnswer.SIP' => ['0'],
	'call.autoAnswer.micMute' => ['1'],
	'call.autoAnswer.ringClass' => ['ringAutoAnswer'],
	'call.autoAnswer.videoMute' => ['0'],
	'call.autoOffHook.1.contact' => [''],
	'call.autoOffHook.1.enabled' => ['0'],
	'call.autoOffHook.1.protocol' => [''],
	'call.autoOffHook.10.contact' => [''],
	'call.autoOffHook.10.enabled' => ['0'],
	'call.autoOffHook.10.protocol' => [''],
	'call.autoOffHook.11.contact' => [''],
	'call.autoOffHook.11.enabled' => ['0'],
	'call.autoOffHook.11.protocol' => [''],
	'call.autoOffHook.12.contact' => [''],
	'call.autoOffHook.12.enabled' => ['0'],
	'call.autoOffHook.12.protocol' => [''],
	'call.autoOffHook.13.contact' => [''],
	'call.autoOffHook.13.enabled' => ['0'],
	'call.autoOffHook.13.protocol' => [''],
	'call.autoOffHook.14.contact' => [''],
	'call.autoOffHook.14.enabled' => ['0'],
	'call.autoOffHook.14.protocol' => [''],
	'call.autoOffHook.15.contact' => [''],
	'call.autoOffHook.15.enabled' => ['0'],
	'call.autoOffHook.15.protocol' => [''],
	'call.autoOffHook.16.contact' => [''],
	'call.autoOffHook.16.enabled' => ['0'],
	'call.autoOffHook.16.protocol' => [''],
	'call.autoOffHook.17.contact' => [''],
	'call.autoOffHook.17.enabled' => ['0'],
	'call.autoOffHook.17.protocol' => [''],
	'call.autoOffHook.18.contact' => [''],
	'call.autoOffHook.18.enabled' => ['0'],
	'call.autoOffHook.18.protocol' => [''],
	'call.autoOffHook.19.contact' => [''],
	'call.autoOffHook.19.enabled' => ['0'],
	'call.autoOffHook.19.protocol' => [''],
	'call.autoOffHook.2.contact' => [''],
	'call.autoOffHook.2.enabled' => ['0'],
	'call.autoOffHook.2.protocol' => [''],
	'call.autoOffHook.20.contact' => [''],
	'call.autoOffHook.20.enabled' => ['0'],
	'call.autoOffHook.20.protocol' => [''],
	'call.autoOffHook.21.contact' => [''],
	'call.autoOffHook.21.enabled' => ['0'],
	'call.autoOffHook.21.protocol' => [''],
	'call.autoOffHook.22.contact' => [''],
	'call.autoOffHook.22.enabled' => ['0'],
	'call.autoOffHook.22.protocol' => [''],
	'call.autoOffHook.23.contact' => [''],
	'call.autoOffHook.23.enabled' => ['0'],
	'call.autoOffHook.23.protocol' => [''],
	'call.autoOffHook.24.contact' => [''],
	'call.autoOffHook.24.enabled' => ['0'],
	'call.autoOffHook.24.protocol' => [''],
	'call.autoOffHook.25.contact' => [''],
	'call.autoOffHook.25.enabled' => ['0'],
	'call.autoOffHook.25.protocol' => [''],
	'call.autoOffHook.26.contact' => [''],
	'call.autoOffHook.26.enabled' => ['0'],
	'call.autoOffHook.26.protocol' => [''],
	'call.autoOffHook.27.contact' => [''],
	'call.autoOffHook.27.enabled' => ['0'],
	'call.autoOffHook.27.protocol' => [''],
	'call.autoOffHook.28.contact' => [''],
	'call.autoOffHook.28.enabled' => ['0'],
	'call.autoOffHook.28.protocol' => [''],
	'call.autoOffHook.29.contact' => [''],
	'call.autoOffHook.29.enabled' => ['0'],
	'call.autoOffHook.29.protocol' => [''],
	'call.autoOffHook.3.contact' => [''],
	'call.autoOffHook.3.enabled' => ['0'],
	'call.autoOffHook.3.protocol' => [''],
	'call.autoOffHook.30.contact' => [''],
	'call.autoOffHook.30.enabled' => ['0'],
	'call.autoOffHook.30.protocol' => [''],
	'call.autoOffHook.31.contact' => [''],
	'call.autoOffHook.31.enabled' => ['0'],
	'call.autoOffHook.31.protocol' => [''],
	'call.autoOffHook.32.contact' => [''],
	'call.autoOffHook.32.enabled' => ['0'],
	'call.autoOffHook.32.protocol' => [''],
	'call.autoOffHook.33.contact' => [''],
	'call.autoOffHook.33.enabled' => ['0'],
	'call.autoOffHook.33.protocol' => [''],
	'call.autoOffHook.34.contact' => [''],
	'call.autoOffHook.34.enabled' => ['0'],
	'call.autoOffHook.34.protocol' => [''],
	'call.autoOffHook.4.contact' => [''],
	'call.autoOffHook.4.enabled' => ['0'],
	'call.autoOffHook.4.protocol' => [''],
	'call.autoOffHook.5.contact' => [''],
	'call.autoOffHook.5.enabled' => ['0'],
	'call.autoOffHook.5.protocol' => [''],
	'call.autoOffHook.6.contact' => [''],
	'call.autoOffHook.6.enabled' => ['0'],
	'call.autoOffHook.6.protocol' => [''],
	'call.autoOffHook.7.contact' => [''],
	'call.autoOffHook.7.enabled' => ['0'],
	'call.autoOffHook.7.protocol' => [''],
	'call.autoOffHook.8.contact' => [''],
	'call.autoOffHook.8.enabled' => ['0'],
	'call.autoOffHook.8.protocol' => [''],
	'call.autoOffHook.9.contact' => [''],
	'call.autoOffHook.9.enabled' => ['0'],
	'call.autoOffHook.9.protocol' => [''],
	'call.autoRouting.preference' => ['line'],
	'call.autoRouting.preferredProtocol' => ['SIP'],
	'call.callWaiting.ring' => ['beep'],
	'call.callsPerLineKey' => ['24'],
	'call.dialtoneTimeOut' => ['60'],
	'call.directedCallPickupMethod' => [''],
	'call.directedCallPickupString' => ['*97'],
	'call.disableMobileCalls' => ['0'],
	'call.donotdisturb.perReg' => ['0'],
	'call.enableOnNotRegistered' => ['1'],
	'call.hold.localReminder.enabled' => ['0'],
	'call.hold.localReminder.period' => ['60'],
	'call.hold.localReminder.startDelay' => ['90'],
	'call.hold.remoteNotification.enabled' => ['0'],
	'call.hold.remoteNotification.period' => ['60'],
	'call.hold.remoteNotification.startDelay' => ['60'],
	'call.lastCallReturnString' => ['*69'],
	'call.localConferenceCallHold' => ['0'],
	'call.missedCallTracking.1.enabled' => ['1'],
	'call.missedCallTracking.10.enabled' => ['1'],
	'call.missedCallTracking.11.enabled' => ['1'],
	'call.missedCallTracking.12.enabled' => ['1'],
	'call.missedCallTracking.13.enabled' => ['1'],
	'call.missedCallTracking.14.enabled' => ['1'],
	'call.missedCallTracking.15.enabled' => ['1'],
	'call.missedCallTracking.16.enabled' => ['1'],
	'call.missedCallTracking.17.enabled' => ['1'],
	'call.missedCallTracking.18.enabled' => ['1'],
	'call.missedCallTracking.19.enabled' => ['1'],
	'call.missedCallTracking.2.enabled' => ['1'],
	'call.missedCallTracking.20.enabled' => ['1'],
	'call.missedCallTracking.21.enabled' => ['1'],
	'call.missedCallTracking.22.enabled' => ['1'],
	'call.missedCallTracking.23.enabled' => ['1'],
	'call.missedCallTracking.24.enabled' => ['1'],
	'call.missedCallTracking.25.enabled' => ['1'],
	'call.missedCallTracking.26.enabled' => ['1'],
	'call.missedCallTracking.27.enabled' => ['1'],
	'call.missedCallTracking.28.enabled' => ['1'],
	'call.missedCallTracking.29.enabled' => ['1'],
	'call.missedCallTracking.3.enabled' => ['1'],
	'call.missedCallTracking.30.enabled' => ['1'],
	'call.missedCallTracking.31.enabled' => ['1'],
	'call.missedCallTracking.32.enabled' => ['1'],
	'call.missedCallTracking.33.enabled' => ['1'],
	'call.missedCallTracking.34.enabled' => ['1'],
	'call.missedCallTracking.4.enabled' => ['1'],
	'call.missedCallTracking.5.enabled' => ['1'],
	'call.missedCallTracking.6.enabled' => ['1'],
	'call.missedCallTracking.7.enabled' => ['1'],
	'call.missedCallTracking.8.enabled' => ['1'],
	'call.missedCallTracking.9.enabled' => ['1'],
	'call.offeringTimeOut' => ['60'],
	'call.parkedCallRetrieveMethod' => [''],
	'call.parkedCallRetrieveString' => [''],
	'call.rejectBusyOnDnd' => ['1'],
	'call.ringBackTimeOut' => ['60'],
	'call.serverMissedCall.1.enabled' => ['0'],
	'call.serverMissedCall.10.enabled' => ['0'],
	'call.serverMissedCall.11.enabled' => ['0'],
	'call.serverMissedCall.12.enabled' => ['0'],
	'call.serverMissedCall.13.enabled' => ['0'],
	'call.serverMissedCall.14.enabled' => ['0'],
	'call.serverMissedCall.15.enabled' => ['0'],
	'call.serverMissedCall.16.enabled' => ['0'],
	'call.serverMissedCall.17.enabled' => ['0'],
	'call.serverMissedCall.18.enabled' => ['0'],
	'call.serverMissedCall.19.enabled' => ['0'],
	'call.serverMissedCall.2.enabled' => ['0'],
	'call.serverMissedCall.20.enabled' => ['0'],
	'call.serverMissedCall.21.enabled' => ['0'],
	'call.serverMissedCall.22.enabled' => ['0'],
	'call.serverMissedCall.23.enabled' => ['0'],
	'call.serverMissedCall.24.enabled' => ['0'],
	'call.serverMissedCall.25.enabled' => ['0'],
	'call.serverMissedCall.26.enabled' => ['0'],
	'call.serverMissedCall.27.enabled' => ['0'],
	'call.serverMissedCall.28.enabled' => ['0'],
	'call.serverMissedCall.29.enabled' => ['0'],
	'call.serverMissedCall.3.enabled' => ['0'],
	'call.serverMissedCall.30.enabled' => ['0'],
	'call.serverMissedCall.31.enabled' => ['0'],
	'call.serverMissedCall.32.enabled' => ['0'],
	'call.serverMissedCall.33.enabled' => ['0'],
	'call.serverMissedCall.34.enabled' => ['0'],
	'call.serverMissedCall.4.enabled' => ['0'],
	'call.serverMissedCall.5.enabled' => ['0'],
	'call.serverMissedCall.6.enabled' => ['0'],
	'call.serverMissedCall.7.enabled' => ['0'],
	'call.serverMissedCall.8.enabled' => ['0'],
	'call.serverMissedCall.9.enabled' => ['0'],
	'call.shared.disableDivert' => ['1'],
	'call.shared.exposeAutoHolds' => ['0'],
	'call.shared.oneTouchResume' => ['0'],
	'call.shared.seizeFailReorder' => ['1'],
	'call.singleKeyPressConference' => ['0'],
	'call.stickyAutoLineSeize' => ['0'],
	'call.stickyAutoLineSeize.onHookDialing' => ['0'],
	'call.transfer.blindPreferred' => ['0'],
	'call.transferOnConferenceEnd' => ['1'],
	'call.urlModeDialing' => ['0'],
	'debug.disableWatchdog' => ['0'],
	'device.auth.localAdminPassword' => [''],
	'device.auth.localAdminPassword.set' => ['0'],
	'device.auth.localUserPassword' => [''],
	'device.auth.localUserPassword.set' => ['0'],
	'device.auth.regPassword1' => [''],
	'device.auth.regPassword1.set' => ['0'],
	'device.auth.regPassword10' => [''],
	'device.auth.regPassword10.set' => ['0'],
	'device.auth.regPassword11' => [''],
	'device.auth.regPassword11.set' => ['0'],
	'device.auth.regPassword12' => [''],
	'device.auth.regPassword12.set' => ['0'],
	'device.auth.regPassword13' => [''],
	'device.auth.regPassword13.set' => ['0'],
	'device.auth.regPassword14' => [''],
	'device.auth.regPassword14.set' => ['0'],
	'device.auth.regPassword15' => [''],
	'device.auth.regPassword15.set' => ['0'],
	'device.auth.regPassword16' => [''],
	'device.auth.regPassword16.set' => ['0'],
	'device.auth.regPassword17' => [''],
	'device.auth.regPassword17.set' => ['0'],
	'device.auth.regPassword18' => [''],
	'device.auth.regPassword18.set' => ['0'],
	'device.auth.regPassword19' => [''],
	'device.auth.regPassword19.set' => ['0'],
	'device.auth.regPassword2' => [''],
	'device.auth.regPassword2.set' => ['0'],
	'device.auth.regPassword20' => [''],
	'device.auth.regPassword20.set' => ['0'],
	'device.auth.regPassword21' => [''],
	'device.auth.regPassword21.set' => ['0'],
	'device.auth.regPassword22' => [''],
	'device.auth.regPassword22.set' => ['0'],
	'device.auth.regPassword23' => [''],
	'device.auth.regPassword23.set' => ['0'],
	'device.auth.regPassword24' => [''],
	'device.auth.regPassword24.set' => ['0'],
	'device.auth.regPassword25' => [''],
	'device.auth.regPassword25.set' => ['0'],
	'device.auth.regPassword26' => [''],
	'device.auth.regPassword26.set' => ['0'],
	'device.auth.regPassword27' => [''],
	'device.auth.regPassword27.set' => ['0'],
	'device.auth.regPassword28' => [''],
	'device.auth.regPassword28.set' => ['0'],
	'device.auth.regPassword29' => [''],
	'device.auth.regPassword29.set' => ['0'],
	'device.auth.regPassword3' => [''],
	'device.auth.regPassword3.set' => ['0'],
	'device.auth.regPassword30' => [''],
	'device.auth.regPassword30.set' => ['0'],
	'device.auth.regPassword31' => [''],
	'device.auth.regPassword31.set' => ['0'],
	'device.auth.regPassword32' => [''],
	'device.auth.regPassword32.set' => ['0'],
	'device.auth.regPassword33' => [''],
	'device.auth.regPassword33.set' => ['0'],
	'device.auth.regPassword34' => [''],
	'device.auth.regPassword34.set' => ['0'],
	'device.auth.regPassword35' => [''],
	'device.auth.regPassword35.set' => ['0'],
	'device.auth.regPassword36' => [''],
	'device.auth.regPassword36.set' => ['0'],
	'device.auth.regPassword37' => [''],
	'device.auth.regPassword37.set' => ['0'],
	'device.auth.regPassword38' => [''],
	'device.auth.regPassword38.set' => ['0'],
	'device.auth.regPassword39' => [''],
	'device.auth.regPassword39.set' => ['0'],
	'device.auth.regPassword4' => [''],
	'device.auth.regPassword4.set' => ['0'],
	'device.auth.regPassword40' => [''],
	'device.auth.regPassword40.set' => ['0'],
	'device.auth.regPassword41' => [''],
	'device.auth.regPassword41.set' => ['0'],
	'device.auth.regPassword42' => [''],
	'device.auth.regPassword42.set' => ['0'],
	'device.auth.regPassword43' => [''],
	'device.auth.regPassword43.set' => ['0'],
	'device.auth.regPassword44' => [''],
	'device.auth.regPassword44.set' => ['0'],
	'device.auth.regPassword45' => [''],
	'device.auth.regPassword45.set' => ['0'],
	'device.auth.regPassword46' => [''],
	'device.auth.regPassword46.set' => ['0'],
	'device.auth.regPassword47' => [''],
	'device.auth.regPassword47.set' => ['0'],
	'device.auth.regPassword48' => [''],
	'device.auth.regPassword48.set' => ['0'],
	'device.auth.regPassword5' => [''],
	'device.auth.regPassword5.set' => ['0'],
	'device.auth.regPassword6' => [''],
	'device.auth.regPassword6.set' => ['0'],
	'device.auth.regPassword7' => [''],
	'device.auth.regPassword7.set' => ['0'],
	'device.auth.regPassword8' => [''],
	'device.auth.regPassword8.set' => ['0'],
	'device.auth.regPassword9' => [''],
	'device.auth.regPassword9.set' => ['0'],
	'device.auth.regUser1' => [''],
	'device.auth.regUser1.set' => ['0'],
	'device.auth.regUser10' => [''],
	'device.auth.regUser10.set' => ['0'],
	'device.auth.regUser11' => [''],
	'device.auth.regUser11.set' => ['0'],
	'device.auth.regUser12' => [''],
	'device.auth.regUser12.set' => ['0'],
	'device.auth.regUser13' => [''],
	'device.auth.regUser13.set' => ['0'],
	'device.auth.regUser14' => [''],
	'device.auth.regUser14.set' => ['0'],
	'device.auth.regUser15' => [''],
	'device.auth.regUser15.set' => ['0'],
	'device.auth.regUser16' => [''],
	'device.auth.regUser16.set' => ['0'],
	'device.auth.regUser17' => [''],
	'device.auth.regUser17.set' => ['0'],
	'device.auth.regUser18' => [''],
	'device.auth.regUser18.set' => ['0'],
	'device.auth.regUser19' => [''],
	'device.auth.regUser19.set' => ['0'],
	'device.auth.regUser2' => [''],
	'device.auth.regUser2.set' => ['0'],
	'device.auth.regUser20' => [''],
	'device.auth.regUser20.set' => ['0'],
	'device.auth.regUser21' => [''],
	'device.auth.regUser21.set' => ['0'],
	'device.auth.regUser22' => [''],
	'device.auth.regUser22.set' => ['0'],
	'device.auth.regUser23' => [''],
	'device.auth.regUser23.set' => ['0'],
	'device.auth.regUser24' => [''],
	'device.auth.regUser24.set' => ['0'],
	'device.auth.regUser25' => [''],
	'device.auth.regUser25.set' => ['0'],
	'device.auth.regUser26' => [''],
	'device.auth.regUser26.set' => ['0'],
	'device.auth.regUser27' => [''],
	'device.auth.regUser27.set' => ['0'],
	'device.auth.regUser28' => [''],
	'device.auth.regUser28.set' => ['0'],
	'device.auth.regUser29' => [''],
	'device.auth.regUser29.set' => ['0'],
	'device.auth.regUser3' => [''],
	'device.auth.regUser3.set' => ['0'],
	'device.auth.regUser30' => [''],
	'device.auth.regUser30.set' => ['0'],
	'device.auth.regUser31' => [''],
	'device.auth.regUser31.set' => ['0'],
	'device.auth.regUser32' => [''],
	'device.auth.regUser32.set' => ['0'],
	'device.auth.regUser33' => [''],
	'device.auth.regUser33.set' => ['0'],
	'device.auth.regUser34' => [''],
	'device.auth.regUser34.set' => ['0'],
	'device.auth.regUser35' => [''],
	'device.auth.regUser35.set' => ['0'],
	'device.auth.regUser36' => [''],
	'device.auth.regUser36.set' => ['0'],
	'device.auth.regUser37' => [''],
	'device.auth.regUser37.set' => ['0'],
	'device.auth.regUser38' => [''],
	'device.auth.regUser38.set' => ['0'],
	'device.auth.regUser39' => [''],
	'device.auth.regUser39.set' => ['0'],
	'device.auth.regUser4' => [''],
	'device.auth.regUser4.set' => ['0'],
	'device.auth.regUser40' => [''],
	'device.auth.regUser40.set' => ['0'],
	'device.auth.regUser41' => [''],
	'device.auth.regUser41.set' => ['0'],
	'device.auth.regUser42' => [''],
	'device.auth.regUser42.set' => ['0'],
	'device.auth.regUser43' => [''],
	'device.auth.regUser43.set' => ['0'],
	'device.auth.regUser44' => [''],
	'device.auth.regUser44.set' => ['0'],
	'device.auth.regUser45' => [''],
	'device.auth.regUser45.set' => ['0'],
	'device.auth.regUser46' => [''],
	'device.auth.regUser46.set' => ['0'],
	'device.auth.regUser47' => [''],
	'device.auth.regUser47.set' => ['0'],
	'device.auth.regUser48' => [''],
	'device.auth.regUser48.set' => ['0'],
	'device.auth.regUser5' => [''],
	'device.auth.regUser5.set' => ['0'],
	'device.auth.regUser6' => [''],
	'device.auth.regUser6.set' => ['0'],
	'device.auth.regUser7' => [''],
	'device.auth.regUser7.set' => ['0'],
	'device.auth.regUser8' => [''],
	'device.auth.regUser8.set' => ['0'],
	'device.auth.regUser9' => [''],
	'device.auth.regUser9.set' => ['0'],
	'device.auth.telnetPassword' => [''],
	'device.auth.telnetPassword.set' => ['0'],
	'device.auth.telnetUser' => [''],
	'device.auth.telnetUser.set' => ['0'],
	'device.cma.mode' => [''],
	'device.cma.mode.set' => ['0'],
	'device.cma.serverName' => [''],
	'device.cma.serverName.set' => ['0'],
	'device.dhcp.bootSrvOpt' => [''],
	'device.dhcp.bootSrvOpt.set' => ['0'],
	'device.dhcp.bootSrvOptType' => [''],
	'device.dhcp.bootSrvOptType.set' => ['0'],
	'device.dhcp.bootSrvUseOpt' => [''],
	'device.dhcp.bootSrvUseOpt.set' => ['0'],
	'device.dhcp.dhcpVlanDiscOpt' => [''],
	'device.dhcp.dhcpVlanDiscOpt.set' => ['0'],
	'device.dhcp.dhcpVlanDiscUseOpt' => [''],
	'device.dhcp.dhcpVlanDiscUseOpt.set' => ['0'],
	'device.dhcp.enabled' => [''],
	'device.dhcp.enabled.set' => ['0'],
	'device.dhcp.offerTimeout' => [''],
	'device.dhcp.offerTimeout.set' => ['0'],
	'device.dhcp.option60Type' => ['0'],
	'device.dhcp.option60Type.set' => ['0'],
	'device.dns.altSrvAddress' => [''],
	'device.dns.altSrvAddress.set' => ['0'],
	'device.dns.domain' => [''],
	'device.dns.domain.set' => ['0'],
	'device.dns.serverAddress' => [''],
	'device.dns.serverAddress.set' => ['0'],
	'device.em.power' => [''],
	'device.em.power.set' => ['0'],
	'device.line.mwiLine1' => [''],
	'device.line.mwiLine1.set' => ['0'],
	'device.line.mwiLine10' => [''],
	'device.line.mwiLine10.set' => ['0'],
	'device.line.mwiLine11' => [''],
	'device.line.mwiLine11.set' => ['0'],
	'device.line.mwiLine12' => [''],
	'device.line.mwiLine12.set' => ['0'],
	'device.line.mwiLine13' => [''],
	'device.line.mwiLine13.set' => ['0'],
	'device.line.mwiLine14' => [''],
	'device.line.mwiLine14.set' => ['0'],
	'device.line.mwiLine15' => [''],
	'device.line.mwiLine15.set' => ['0'],
	'device.line.mwiLine16' => [''],
	'device.line.mwiLine16.set' => ['0'],
	'device.line.mwiLine17' => [''],
	'device.line.mwiLine17.set' => ['0'],
	'device.line.mwiLine18' => [''],
	'device.line.mwiLine18.set' => ['0'],
	'device.line.mwiLine19' => [''],
	'device.line.mwiLine19.set' => ['0'],
	'device.line.mwiLine2' => [''],
	'device.line.mwiLine2.set' => ['0'],
	'device.line.mwiLine20' => [''],
	'device.line.mwiLine20.set' => ['0'],
	'device.line.mwiLine21' => [''],
	'device.line.mwiLine21.set' => ['0'],
	'device.line.mwiLine22' => [''],
	'device.line.mwiLine22.set' => ['0'],
	'device.line.mwiLine23' => [''],
	'device.line.mwiLine23.set' => ['0'],
	'device.line.mwiLine24' => [''],
	'device.line.mwiLine24.set' => ['0'],
	'device.line.mwiLine25' => [''],
	'device.line.mwiLine25.set' => ['0'],
	'device.line.mwiLine26' => [''],
	'device.line.mwiLine26.set' => ['0'],
	'device.line.mwiLine27' => [''],
	'device.line.mwiLine27.set' => ['0'],
	'device.line.mwiLine28' => [''],
	'device.line.mwiLine28.set' => ['0'],
	'device.line.mwiLine29' => [''],
	'device.line.mwiLine29.set' => ['0'],
	'device.line.mwiLine3' => [''],
	'device.line.mwiLine3.set' => ['0'],
	'device.line.mwiLine30' => [''],
	'device.line.mwiLine30.set' => ['0'],
	'device.line.mwiLine31' => [''],
	'device.line.mwiLine31.set' => ['0'],
	'device.line.mwiLine32' => [''],
	'device.line.mwiLine32.set' => ['0'],
	'device.line.mwiLine33' => [''],
	'device.line.mwiLine33.set' => ['0'],
	'device.line.mwiLine34' => [''],
	'device.line.mwiLine34.set' => ['0'],
	'device.line.mwiLine35' => [''],
	'device.line.mwiLine35.set' => ['0'],
	'device.line.mwiLine36' => [''],
	'device.line.mwiLine36.set' => ['0'],
	'device.line.mwiLine37' => [''],
	'device.line.mwiLine37.set' => ['0'],
	'device.line.mwiLine38' => [''],
	'device.line.mwiLine38.set' => ['0'],
	'device.line.mwiLine39' => [''],
	'device.line.mwiLine39.set' => ['0'],
	'device.line.mwiLine4' => [''],
	'device.line.mwiLine4.set' => ['0'],
	'device.line.mwiLine40' => [''],
	'device.line.mwiLine40.set' => ['0'],
	'device.line.mwiLine41' => [''],
	'device.line.mwiLine41.set' => ['0'],
	'device.line.mwiLine42' => [''],
	'device.line.mwiLine42.set' => ['0'],
	'device.line.mwiLine43' => [''],
	'device.line.mwiLine43.set' => ['0'],
	'device.line.mwiLine44' => [''],
	'device.line.mwiLine44.set' => ['0'],
	'device.line.mwiLine45' => [''],
	'device.line.mwiLine45.set' => ['0'],
	'device.line.mwiLine46' => [''],
	'device.line.mwiLine46.set' => ['0'],
	'device.line.mwiLine47' => [''],
	'device.line.mwiLine47.set' => ['0'],
	'device.line.mwiLine48' => [''],
	'device.line.mwiLine48.set' => ['0'],
	'device.line.mwiLine5' => [''],
	'device.line.mwiLine5.set' => ['0'],
	'device.line.mwiLine6' => [''],
	'device.line.mwiLine6.set' => ['0'],
	'device.line.mwiLine7' => [''],
	'device.line.mwiLine7.set' => ['0'],
	'device.line.mwiLine8' => [''],
	'device.line.mwiLine8.set' => ['0'],
	'device.line.mwiLine9' => [''],
	'device.line.mwiLine9.set' => ['0'],
	'device.logincred.domain' => [''],
	'device.logincred.domain.set' => ['0'],
	'device.logincred.password' => [''],
	'device.logincred.password.set' => ['0'],
	'device.logincred.user' => [''],
	'device.logincred.user.set' => ['0'],
	'device.masterConfigFile.LogFileDirectory' => [''],
	'device.net.IPgateway' => [''],
	'device.net.IPgateway.set' => ['0'],
	'device.net.cdpEnabled' => [''],
	'device.net.cdpEnabled.set' => ['0'],
	'device.net.ether1000BTClockLAN' => [''],
	'device.net.ether1000BTClockLAN.set' => ['0'],
	'device.net.ether1000BTClockPC' => [''],
	'device.net.ether1000BTClockPC.set' => ['0'],
	'device.net.etherModeLAN' => [''],
	'device.net.etherModeLAN.set' => ['0'],
	'device.net.etherModePC' => [''],
	'device.net.etherModePC.set' => ['0'],
	'device.net.etherStormFilter' => [''],
	'device.net.etherStormFilter.set' => ['0'],
	'device.net.etherVlanFilter' => [''],
	'device.net.etherVlanFilter.set' => ['0'],
	'device.net.ipAddress' => [''],
	'device.net.ipAddress.set' => ['0'],
	'device.net.lldpEnabled' => [''],
	'device.net.lldpEnabled.set' => ['0'],
	'device.net.subnetMask' => [''],
	'device.net.subnetMask.set' => ['0'],
	'device.net.vlanId' => [''],
	'device.net.vlanId.set' => ['0'],
	'device.ntlm.versionMode' => ['0'],
	'device.ntlm.versionMode.set' => ['0'],
	'device.prov.appProvString' => [''],
	'device.prov.appProvString.set' => ['0'],
	'device.prov.appProvType' => [''],
	'device.prov.appProvType.set' => ['0'],
	'device.prov.clinkEnabled' => [''],
	'device.prov.clinkEnabled.set' => ['0'],
	'device.prov.maxRedunServers' => [''],
	'device.prov.maxRedunServers.set' => ['0'],
	'device.prov.networkEnvironment' => [''],
	'device.prov.networkEnvironment.set' => ['0'],
	'device.prov.password' => [''],
	'device.prov.password.set' => ['0'],
	'device.prov.redunAttemptLimit' => [''],
	'device.prov.redunAttemptLimit.set' => ['0'],
	'device.prov.redunInterAttemptDelay' => [''],
	'device.prov.redunInterAttemptDelay.set' => ['0'],
	'device.prov.serverName' => [''],
	'device.prov.serverName.set' => ['0'],
	'device.prov.serverType' => [''],
	'device.prov.serverType.set' => ['0'],
	'device.prov.tagSerialNo' => [''],
	'device.prov.tagSerialNo.set' => ['0'],
	'device.prov.user' => [''],
	'device.prov.user.set' => ['0'],
	'device.sec.SSL.certList' => [''],
	'device.sec.SSL.certList.set' => ['0'],
	'device.sec.SSL.customCert' => [''],
	'device.sec.SSL.customCert.set' => ['0'],
	'device.sec.SSL.customDeviceCert.privateKey' => [''],
	'device.sec.SSL.customDeviceCert.publicCert' => [''],
	'device.sec.SSL.customDeviceCert.set' => ['0'],
	'device.sec.configEncryption.key' => [''],
	'device.sec.configEncryption.key.set' => ['0'],
	'device.sec.deviceCertEnabled' => [''],
	'device.sec.deviceCertEnabled.set' => ['0'],
	'device.serial.enable' => ['0'],
	'device.serial.enable.set' => ['0'],
	'device.set' => ['0'],
	'device.sntp.gmtOffset' => [''],
	'device.sntp.gmtOffset.set' => ['0'],
	'device.sntp.serverName' => [''],
	'device.sntp.serverName.set' => ['0'],
	'device.syslog.facility' => [''],
	'device.syslog.facility.set' => ['0'],
	'device.syslog.prependMac' => [''],
	'device.syslog.prependMac.set' => ['0'],
	'device.syslog.renderLevel' => [''],
	'device.syslog.renderLevel.set' => ['0'],
	'device.syslog.serverName' => [''],
	'device.syslog.serverName.set' => ['0'],
	'device.syslog.transport' => [''],
	'device.syslog.transport.set' => ['0'],
	'diagnostics.audioRecordMaxTime' => ['10'],
	'diags.sshc.enabled' => ['0'],
	'diags.sshc.gateway.fingerprint' => ['829ce55c75dbda93742fcc9939c962ae'],
	'diags.sshc.gateway.password' => [''],
	'diags.sshc.gateway.port' => ['22'],
	'diags.sshc.gateway.server' => ['voip-diagnostics.polycom.com'],
	'diags.sshc.gateway.user' => ['PolycomIPPhone'],
	'diags.telnetd.enabled' => ['0'],
	'dialplan.1.applyToCallListDial' => ['1'],
	'dialplan.1.applyToDirectoryDial' => ['0'],
	'dialplan.1.applyToTelUriDial' => ['1'],
	'dialplan.1.applyToUserDial' => ['1'],
	'dialplan.1.applyToUserSend' => ['1'],
	'dialplan.1.digitmap' => [''],
	'dialplan.1.digitmap.timeOut' => [''],
	'dialplan.1.impossibleMatchHandling' => ['0'],
	'dialplan.1.removeEndOfDial' => ['1'],
	'dialplan.1.routing.emergency.1.server.1' => ['0'],
	'dialplan.1.routing.emergency.1.server.2' => ['0'],
	'dialplan.1.routing.emergency.1.server.3' => ['0'],
	'dialplan.1.routing.emergency.1.value' => [''],
	'dialplan.1.routing.emergency.2.server.1' => ['0'],
	'dialplan.1.routing.emergency.2.server.2' => ['0'],
	'dialplan.1.routing.emergency.2.server.3' => ['0'],
	'dialplan.1.routing.emergency.2.value' => [''],
	'dialplan.1.routing.emergency.3.server.1' => ['0'],
	'dialplan.1.routing.emergency.3.server.2' => ['0'],
	'dialplan.1.routing.emergency.3.server.3' => ['0'],
	'dialplan.1.routing.emergency.3.value' => [''],
	'dialplan.1.routing.emergency.4.server.1' => ['0'],
	'dialplan.1.routing.emergency.4.server.2' => ['0'],
	'dialplan.1.routing.emergency.4.server.3' => ['0'],
	'dialplan.1.routing.emergency.4.value' => [''],
	'dialplan.1.routing.server.1.address' => [''],
	'dialplan.1.routing.server.1.port' => ['5060'],
	'dialplan.1.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.1.routing.server.2.address' => [''],
	'dialplan.1.routing.server.2.port' => ['5060'],
	'dialplan.1.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.1.routing.server.3.address' => [''],
	'dialplan.1.routing.server.3.port' => ['5060'],
	'dialplan.1.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.1.routing.server.4.address' => [''],
	'dialplan.1.routing.server.4.port' => ['5060'],
	'dialplan.1.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.10.applyToCallListDial' => ['1'],
	'dialplan.10.applyToDirectoryDial' => ['0'],
	'dialplan.10.applyToTelUriDial' => ['1'],
	'dialplan.10.applyToUserDial' => ['1'],
	'dialplan.10.applyToUserSend' => ['1'],
	'dialplan.10.digitmap' => [''],
	'dialplan.10.digitmap.timeOut' => [''],
	'dialplan.10.impossibleMatchHandling' => ['0'],
	'dialplan.10.removeEndOfDial' => ['1'],
	'dialplan.10.routing.emergency.1.server.1' => ['0'],
	'dialplan.10.routing.emergency.1.server.2' => ['0'],
	'dialplan.10.routing.emergency.1.server.3' => ['0'],
	'dialplan.10.routing.emergency.1.value' => [''],
	'dialplan.10.routing.emergency.2.server.1' => ['0'],
	'dialplan.10.routing.emergency.2.server.2' => ['0'],
	'dialplan.10.routing.emergency.2.server.3' => ['0'],
	'dialplan.10.routing.emergency.2.value' => [''],
	'dialplan.10.routing.emergency.3.server.1' => ['0'],
	'dialplan.10.routing.emergency.3.server.2' => ['0'],
	'dialplan.10.routing.emergency.3.server.3' => ['0'],
	'dialplan.10.routing.emergency.3.value' => [''],
	'dialplan.10.routing.emergency.4.server.1' => ['0'],
	'dialplan.10.routing.emergency.4.server.2' => ['0'],
	'dialplan.10.routing.emergency.4.server.3' => ['0'],
	'dialplan.10.routing.emergency.4.value' => [''],
	'dialplan.10.routing.server.1.address' => [''],
	'dialplan.10.routing.server.1.port' => ['5060'],
	'dialplan.10.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.10.routing.server.2.address' => [''],
	'dialplan.10.routing.server.2.port' => ['5060'],
	'dialplan.10.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.10.routing.server.3.address' => [''],
	'dialplan.10.routing.server.3.port' => ['5060'],
	'dialplan.10.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.10.routing.server.4.address' => [''],
	'dialplan.10.routing.server.4.port' => ['5060'],
	'dialplan.10.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.11.applyToCallListDial' => ['1'],
	'dialplan.11.applyToDirectoryDial' => ['0'],
	'dialplan.11.applyToTelUriDial' => ['1'],
	'dialplan.11.applyToUserDial' => ['1'],
	'dialplan.11.applyToUserSend' => ['1'],
	'dialplan.11.digitmap' => [''],
	'dialplan.11.digitmap.timeOut' => [''],
	'dialplan.11.impossibleMatchHandling' => ['0'],
	'dialplan.11.removeEndOfDial' => ['1'],
	'dialplan.11.routing.emergency.1.server.1' => ['0'],
	'dialplan.11.routing.emergency.1.server.2' => ['0'],
	'dialplan.11.routing.emergency.1.server.3' => ['0'],
	'dialplan.11.routing.emergency.1.value' => [''],
	'dialplan.11.routing.emergency.2.server.1' => ['0'],
	'dialplan.11.routing.emergency.2.server.2' => ['0'],
	'dialplan.11.routing.emergency.2.server.3' => ['0'],
	'dialplan.11.routing.emergency.2.value' => [''],
	'dialplan.11.routing.emergency.3.server.1' => ['0'],
	'dialplan.11.routing.emergency.3.server.2' => ['0'],
	'dialplan.11.routing.emergency.3.server.3' => ['0'],
	'dialplan.11.routing.emergency.3.value' => [''],
	'dialplan.11.routing.emergency.4.server.1' => ['0'],
	'dialplan.11.routing.emergency.4.server.2' => ['0'],
	'dialplan.11.routing.emergency.4.server.3' => ['0'],
	'dialplan.11.routing.emergency.4.value' => [''],
	'dialplan.11.routing.server.1.address' => [''],
	'dialplan.11.routing.server.1.port' => ['5060'],
	'dialplan.11.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.11.routing.server.2.address' => [''],
	'dialplan.11.routing.server.2.port' => ['5060'],
	'dialplan.11.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.11.routing.server.3.address' => [''],
	'dialplan.11.routing.server.3.port' => ['5060'],
	'dialplan.11.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.11.routing.server.4.address' => [''],
	'dialplan.11.routing.server.4.port' => ['5060'],
	'dialplan.11.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.12.applyToCallListDial' => ['1'],
	'dialplan.12.applyToDirectoryDial' => ['0'],
	'dialplan.12.applyToTelUriDial' => ['1'],
	'dialplan.12.applyToUserDial' => ['1'],
	'dialplan.12.applyToUserSend' => ['1'],
	'dialplan.12.digitmap' => [''],
	'dialplan.12.digitmap.timeOut' => [''],
	'dialplan.12.impossibleMatchHandling' => ['0'],
	'dialplan.12.removeEndOfDial' => ['1'],
	'dialplan.12.routing.emergency.1.server.1' => ['0'],
	'dialplan.12.routing.emergency.1.server.2' => ['0'],
	'dialplan.12.routing.emergency.1.server.3' => ['0'],
	'dialplan.12.routing.emergency.1.value' => [''],
	'dialplan.12.routing.emergency.2.server.1' => ['0'],
	'dialplan.12.routing.emergency.2.server.2' => ['0'],
	'dialplan.12.routing.emergency.2.server.3' => ['0'],
	'dialplan.12.routing.emergency.2.value' => [''],
	'dialplan.12.routing.emergency.3.server.1' => ['0'],
	'dialplan.12.routing.emergency.3.server.2' => ['0'],
	'dialplan.12.routing.emergency.3.server.3' => ['0'],
	'dialplan.12.routing.emergency.3.value' => [''],
	'dialplan.12.routing.emergency.4.server.1' => ['0'],
	'dialplan.12.routing.emergency.4.server.2' => ['0'],
	'dialplan.12.routing.emergency.4.server.3' => ['0'],
	'dialplan.12.routing.emergency.4.value' => [''],
	'dialplan.12.routing.server.1.address' => [''],
	'dialplan.12.routing.server.1.port' => ['5060'],
	'dialplan.12.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.12.routing.server.2.address' => [''],
	'dialplan.12.routing.server.2.port' => ['5060'],
	'dialplan.12.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.12.routing.server.3.address' => [''],
	'dialplan.12.routing.server.3.port' => ['5060'],
	'dialplan.12.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.12.routing.server.4.address' => [''],
	'dialplan.12.routing.server.4.port' => ['5060'],
	'dialplan.12.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.13.applyToCallListDial' => ['1'],
	'dialplan.13.applyToDirectoryDial' => ['0'],
	'dialplan.13.applyToTelUriDial' => ['1'],
	'dialplan.13.applyToUserDial' => ['1'],
	'dialplan.13.applyToUserSend' => ['1'],
	'dialplan.13.digitmap' => [''],
	'dialplan.13.digitmap.timeOut' => [''],
	'dialplan.13.impossibleMatchHandling' => ['0'],
	'dialplan.13.removeEndOfDial' => ['1'],
	'dialplan.13.routing.emergency.1.server.1' => ['0'],
	'dialplan.13.routing.emergency.1.server.2' => ['0'],
	'dialplan.13.routing.emergency.1.server.3' => ['0'],
	'dialplan.13.routing.emergency.1.value' => [''],
	'dialplan.13.routing.emergency.2.server.1' => ['0'],
	'dialplan.13.routing.emergency.2.server.2' => ['0'],
	'dialplan.13.routing.emergency.2.server.3' => ['0'],
	'dialplan.13.routing.emergency.2.value' => [''],
	'dialplan.13.routing.emergency.3.server.1' => ['0'],
	'dialplan.13.routing.emergency.3.server.2' => ['0'],
	'dialplan.13.routing.emergency.3.server.3' => ['0'],
	'dialplan.13.routing.emergency.3.value' => [''],
	'dialplan.13.routing.emergency.4.server.1' => ['0'],
	'dialplan.13.routing.emergency.4.server.2' => ['0'],
	'dialplan.13.routing.emergency.4.server.3' => ['0'],
	'dialplan.13.routing.emergency.4.value' => [''],
	'dialplan.13.routing.server.1.address' => [''],
	'dialplan.13.routing.server.1.port' => ['5060'],
	'dialplan.13.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.13.routing.server.2.address' => [''],
	'dialplan.13.routing.server.2.port' => ['5060'],
	'dialplan.13.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.13.routing.server.3.address' => [''],
	'dialplan.13.routing.server.3.port' => ['5060'],
	'dialplan.13.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.13.routing.server.4.address' => [''],
	'dialplan.13.routing.server.4.port' => ['5060'],
	'dialplan.13.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.14.applyToCallListDial' => ['1'],
	'dialplan.14.applyToDirectoryDial' => ['0'],
	'dialplan.14.applyToTelUriDial' => ['1'],
	'dialplan.14.applyToUserDial' => ['1'],
	'dialplan.14.applyToUserSend' => ['1'],
	'dialplan.14.digitmap' => [''],
	'dialplan.14.digitmap.timeOut' => [''],
	'dialplan.14.impossibleMatchHandling' => ['0'],
	'dialplan.14.removeEndOfDial' => ['1'],
	'dialplan.14.routing.emergency.1.server.1' => ['0'],
	'dialplan.14.routing.emergency.1.server.2' => ['0'],
	'dialplan.14.routing.emergency.1.server.3' => ['0'],
	'dialplan.14.routing.emergency.1.value' => [''],
	'dialplan.14.routing.emergency.2.server.1' => ['0'],
	'dialplan.14.routing.emergency.2.server.2' => ['0'],
	'dialplan.14.routing.emergency.2.server.3' => ['0'],
	'dialplan.14.routing.emergency.2.value' => [''],
	'dialplan.14.routing.emergency.3.server.1' => ['0'],
	'dialplan.14.routing.emergency.3.server.2' => ['0'],
	'dialplan.14.routing.emergency.3.server.3' => ['0'],
	'dialplan.14.routing.emergency.3.value' => [''],
	'dialplan.14.routing.emergency.4.server.1' => ['0'],
	'dialplan.14.routing.emergency.4.server.2' => ['0'],
	'dialplan.14.routing.emergency.4.server.3' => ['0'],
	'dialplan.14.routing.emergency.4.value' => [''],
	'dialplan.14.routing.server.1.address' => [''],
	'dialplan.14.routing.server.1.port' => ['5060'],
	'dialplan.14.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.14.routing.server.2.address' => [''],
	'dialplan.14.routing.server.2.port' => ['5060'],
	'dialplan.14.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.14.routing.server.3.address' => [''],
	'dialplan.14.routing.server.3.port' => ['5060'],
	'dialplan.14.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.14.routing.server.4.address' => [''],
	'dialplan.14.routing.server.4.port' => ['5060'],
	'dialplan.14.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.15.applyToCallListDial' => ['1'],
	'dialplan.15.applyToDirectoryDial' => ['0'],
	'dialplan.15.applyToTelUriDial' => ['1'],
	'dialplan.15.applyToUserDial' => ['1'],
	'dialplan.15.applyToUserSend' => ['1'],
	'dialplan.15.digitmap' => [''],
	'dialplan.15.digitmap.timeOut' => [''],
	'dialplan.15.impossibleMatchHandling' => ['0'],
	'dialplan.15.removeEndOfDial' => ['1'],
	'dialplan.15.routing.emergency.1.server.1' => ['0'],
	'dialplan.15.routing.emergency.1.server.2' => ['0'],
	'dialplan.15.routing.emergency.1.server.3' => ['0'],
	'dialplan.15.routing.emergency.1.value' => [''],
	'dialplan.15.routing.emergency.2.server.1' => ['0'],
	'dialplan.15.routing.emergency.2.server.2' => ['0'],
	'dialplan.15.routing.emergency.2.server.3' => ['0'],
	'dialplan.15.routing.emergency.2.value' => [''],
	'dialplan.15.routing.emergency.3.server.1' => ['0'],
	'dialplan.15.routing.emergency.3.server.2' => ['0'],
	'dialplan.15.routing.emergency.3.server.3' => ['0'],
	'dialplan.15.routing.emergency.3.value' => [''],
	'dialplan.15.routing.emergency.4.server.1' => ['0'],
	'dialplan.15.routing.emergency.4.server.2' => ['0'],
	'dialplan.15.routing.emergency.4.server.3' => ['0'],
	'dialplan.15.routing.emergency.4.value' => [''],
	'dialplan.15.routing.server.1.address' => [''],
	'dialplan.15.routing.server.1.port' => ['5060'],
	'dialplan.15.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.15.routing.server.2.address' => [''],
	'dialplan.15.routing.server.2.port' => ['5060'],
	'dialplan.15.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.15.routing.server.3.address' => [''],
	'dialplan.15.routing.server.3.port' => ['5060'],
	'dialplan.15.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.15.routing.server.4.address' => [''],
	'dialplan.15.routing.server.4.port' => ['5060'],
	'dialplan.15.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.16.applyToCallListDial' => ['1'],
	'dialplan.16.applyToDirectoryDial' => ['0'],
	'dialplan.16.applyToTelUriDial' => ['1'],
	'dialplan.16.applyToUserDial' => ['1'],
	'dialplan.16.applyToUserSend' => ['1'],
	'dialplan.16.digitmap' => [''],
	'dialplan.16.digitmap.timeOut' => [''],
	'dialplan.16.impossibleMatchHandling' => ['0'],
	'dialplan.16.removeEndOfDial' => ['1'],
	'dialplan.16.routing.emergency.1.server.1' => ['0'],
	'dialplan.16.routing.emergency.1.server.2' => ['0'],
	'dialplan.16.routing.emergency.1.server.3' => ['0'],
	'dialplan.16.routing.emergency.1.value' => [''],
	'dialplan.16.routing.emergency.2.server.1' => ['0'],
	'dialplan.16.routing.emergency.2.server.2' => ['0'],
	'dialplan.16.routing.emergency.2.server.3' => ['0'],
	'dialplan.16.routing.emergency.2.value' => [''],
	'dialplan.16.routing.emergency.3.server.1' => ['0'],
	'dialplan.16.routing.emergency.3.server.2' => ['0'],
	'dialplan.16.routing.emergency.3.server.3' => ['0'],
	'dialplan.16.routing.emergency.3.value' => [''],
	'dialplan.16.routing.emergency.4.server.1' => ['0'],
	'dialplan.16.routing.emergency.4.server.2' => ['0'],
	'dialplan.16.routing.emergency.4.server.3' => ['0'],
	'dialplan.16.routing.emergency.4.value' => [''],
	'dialplan.16.routing.server.1.address' => [''],
	'dialplan.16.routing.server.1.port' => ['5060'],
	'dialplan.16.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.16.routing.server.2.address' => [''],
	'dialplan.16.routing.server.2.port' => ['5060'],
	'dialplan.16.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.16.routing.server.3.address' => [''],
	'dialplan.16.routing.server.3.port' => ['5060'],
	'dialplan.16.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.16.routing.server.4.address' => [''],
	'dialplan.16.routing.server.4.port' => ['5060'],
	'dialplan.16.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.17.applyToCallListDial' => ['1'],
	'dialplan.17.applyToDirectoryDial' => ['0'],
	'dialplan.17.applyToTelUriDial' => ['1'],
	'dialplan.17.applyToUserDial' => ['1'],
	'dialplan.17.applyToUserSend' => ['1'],
	'dialplan.17.digitmap' => [''],
	'dialplan.17.digitmap.timeOut' => [''],
	'dialplan.17.impossibleMatchHandling' => ['0'],
	'dialplan.17.removeEndOfDial' => ['1'],
	'dialplan.17.routing.emergency.1.server.1' => ['0'],
	'dialplan.17.routing.emergency.1.server.2' => ['0'],
	'dialplan.17.routing.emergency.1.server.3' => ['0'],
	'dialplan.17.routing.emergency.1.value' => [''],
	'dialplan.17.routing.emergency.2.server.1' => ['0'],
	'dialplan.17.routing.emergency.2.server.2' => ['0'],
	'dialplan.17.routing.emergency.2.server.3' => ['0'],
	'dialplan.17.routing.emergency.2.value' => [''],
	'dialplan.17.routing.emergency.3.server.1' => ['0'],
	'dialplan.17.routing.emergency.3.server.2' => ['0'],
	'dialplan.17.routing.emergency.3.server.3' => ['0'],
	'dialplan.17.routing.emergency.3.value' => [''],
	'dialplan.17.routing.emergency.4.server.1' => ['0'],
	'dialplan.17.routing.emergency.4.server.2' => ['0'],
	'dialplan.17.routing.emergency.4.server.3' => ['0'],
	'dialplan.17.routing.emergency.4.value' => [''],
	'dialplan.17.routing.server.1.address' => [''],
	'dialplan.17.routing.server.1.port' => ['5060'],
	'dialplan.17.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.17.routing.server.2.address' => [''],
	'dialplan.17.routing.server.2.port' => ['5060'],
	'dialplan.17.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.17.routing.server.3.address' => [''],
	'dialplan.17.routing.server.3.port' => ['5060'],
	'dialplan.17.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.17.routing.server.4.address' => [''],
	'dialplan.17.routing.server.4.port' => ['5060'],
	'dialplan.17.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.18.applyToCallListDial' => ['1'],
	'dialplan.18.applyToDirectoryDial' => ['0'],
	'dialplan.18.applyToTelUriDial' => ['1'],
	'dialplan.18.applyToUserDial' => ['1'],
	'dialplan.18.applyToUserSend' => ['1'],
	'dialplan.18.digitmap' => [''],
	'dialplan.18.digitmap.timeOut' => [''],
	'dialplan.18.impossibleMatchHandling' => ['0'],
	'dialplan.18.removeEndOfDial' => ['1'],
	'dialplan.18.routing.emergency.1.server.1' => ['0'],
	'dialplan.18.routing.emergency.1.server.2' => ['0'],
	'dialplan.18.routing.emergency.1.server.3' => ['0'],
	'dialplan.18.routing.emergency.1.value' => [''],
	'dialplan.18.routing.emergency.2.server.1' => ['0'],
	'dialplan.18.routing.emergency.2.server.2' => ['0'],
	'dialplan.18.routing.emergency.2.server.3' => ['0'],
	'dialplan.18.routing.emergency.2.value' => [''],
	'dialplan.18.routing.emergency.3.server.1' => ['0'],
	'dialplan.18.routing.emergency.3.server.2' => ['0'],
	'dialplan.18.routing.emergency.3.server.3' => ['0'],
	'dialplan.18.routing.emergency.3.value' => [''],
	'dialplan.18.routing.emergency.4.server.1' => ['0'],
	'dialplan.18.routing.emergency.4.server.2' => ['0'],
	'dialplan.18.routing.emergency.4.server.3' => ['0'],
	'dialplan.18.routing.emergency.4.value' => [''],
	'dialplan.18.routing.server.1.address' => [''],
	'dialplan.18.routing.server.1.port' => ['5060'],
	'dialplan.18.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.18.routing.server.2.address' => [''],
	'dialplan.18.routing.server.2.port' => ['5060'],
	'dialplan.18.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.18.routing.server.3.address' => [''],
	'dialplan.18.routing.server.3.port' => ['5060'],
	'dialplan.18.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.18.routing.server.4.address' => [''],
	'dialplan.18.routing.server.4.port' => ['5060'],
	'dialplan.18.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.19.applyToCallListDial' => ['1'],
	'dialplan.19.applyToDirectoryDial' => ['0'],
	'dialplan.19.applyToTelUriDial' => ['1'],
	'dialplan.19.applyToUserDial' => ['1'],
	'dialplan.19.applyToUserSend' => ['1'],
	'dialplan.19.digitmap' => [''],
	'dialplan.19.digitmap.timeOut' => [''],
	'dialplan.19.impossibleMatchHandling' => ['0'],
	'dialplan.19.removeEndOfDial' => ['1'],
	'dialplan.19.routing.emergency.1.server.1' => ['0'],
	'dialplan.19.routing.emergency.1.server.2' => ['0'],
	'dialplan.19.routing.emergency.1.server.3' => ['0'],
	'dialplan.19.routing.emergency.1.value' => [''],
	'dialplan.19.routing.emergency.2.server.1' => ['0'],
	'dialplan.19.routing.emergency.2.server.2' => ['0'],
	'dialplan.19.routing.emergency.2.server.3' => ['0'],
	'dialplan.19.routing.emergency.2.value' => [''],
	'dialplan.19.routing.emergency.3.server.1' => ['0'],
	'dialplan.19.routing.emergency.3.server.2' => ['0'],
	'dialplan.19.routing.emergency.3.server.3' => ['0'],
	'dialplan.19.routing.emergency.3.value' => [''],
	'dialplan.19.routing.emergency.4.server.1' => ['0'],
	'dialplan.19.routing.emergency.4.server.2' => ['0'],
	'dialplan.19.routing.emergency.4.server.3' => ['0'],
	'dialplan.19.routing.emergency.4.value' => [''],
	'dialplan.19.routing.server.1.address' => [''],
	'dialplan.19.routing.server.1.port' => ['5060'],
	'dialplan.19.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.19.routing.server.2.address' => [''],
	'dialplan.19.routing.server.2.port' => ['5060'],
	'dialplan.19.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.19.routing.server.3.address' => [''],
	'dialplan.19.routing.server.3.port' => ['5060'],
	'dialplan.19.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.19.routing.server.4.address' => [''],
	'dialplan.19.routing.server.4.port' => ['5060'],
	'dialplan.19.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.2.applyToCallListDial' => ['1'],
	'dialplan.2.applyToDirectoryDial' => ['0'],
	'dialplan.2.applyToTelUriDial' => ['1'],
	'dialplan.2.applyToUserDial' => ['1'],
	'dialplan.2.applyToUserSend' => ['1'],
	'dialplan.2.digitmap' => [''],
	'dialplan.2.digitmap.timeOut' => [''],
	'dialplan.2.impossibleMatchHandling' => ['0'],
	'dialplan.2.removeEndOfDial' => ['1'],
	'dialplan.2.routing.emergency.1.server.1' => ['0'],
	'dialplan.2.routing.emergency.1.server.2' => ['0'],
	'dialplan.2.routing.emergency.1.server.3' => ['0'],
	'dialplan.2.routing.emergency.1.value' => [''],
	'dialplan.2.routing.emergency.2.server.1' => ['0'],
	'dialplan.2.routing.emergency.2.server.2' => ['0'],
	'dialplan.2.routing.emergency.2.server.3' => ['0'],
	'dialplan.2.routing.emergency.2.value' => [''],
	'dialplan.2.routing.emergency.3.server.1' => ['0'],
	'dialplan.2.routing.emergency.3.server.2' => ['0'],
	'dialplan.2.routing.emergency.3.server.3' => ['0'],
	'dialplan.2.routing.emergency.3.value' => [''],
	'dialplan.2.routing.emergency.4.server.1' => ['0'],
	'dialplan.2.routing.emergency.4.server.2' => ['0'],
	'dialplan.2.routing.emergency.4.server.3' => ['0'],
	'dialplan.2.routing.emergency.4.value' => [''],
	'dialplan.2.routing.server.1.address' => [''],
	'dialplan.2.routing.server.1.port' => ['5060'],
	'dialplan.2.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.2.routing.server.2.address' => [''],
	'dialplan.2.routing.server.2.port' => ['5060'],
	'dialplan.2.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.2.routing.server.3.address' => [''],
	'dialplan.2.routing.server.3.port' => ['5060'],
	'dialplan.2.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.2.routing.server.4.address' => [''],
	'dialplan.2.routing.server.4.port' => ['5060'],
	'dialplan.2.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.20.applyToCallListDial' => ['1'],
	'dialplan.20.applyToDirectoryDial' => ['0'],
	'dialplan.20.applyToTelUriDial' => ['1'],
	'dialplan.20.applyToUserDial' => ['1'],
	'dialplan.20.applyToUserSend' => ['1'],
	'dialplan.20.digitmap' => [''],
	'dialplan.20.digitmap.timeOut' => [''],
	'dialplan.20.impossibleMatchHandling' => ['0'],
	'dialplan.20.removeEndOfDial' => ['1'],
	'dialplan.20.routing.emergency.1.server.1' => ['0'],
	'dialplan.20.routing.emergency.1.server.2' => ['0'],
	'dialplan.20.routing.emergency.1.server.3' => ['0'],
	'dialplan.20.routing.emergency.1.value' => [''],
	'dialplan.20.routing.emergency.2.server.1' => ['0'],
	'dialplan.20.routing.emergency.2.server.2' => ['0'],
	'dialplan.20.routing.emergency.2.server.3' => ['0'],
	'dialplan.20.routing.emergency.2.value' => [''],
	'dialplan.20.routing.emergency.3.server.1' => ['0'],
	'dialplan.20.routing.emergency.3.server.2' => ['0'],
	'dialplan.20.routing.emergency.3.server.3' => ['0'],
	'dialplan.20.routing.emergency.3.value' => [''],
	'dialplan.20.routing.emergency.4.server.1' => ['0'],
	'dialplan.20.routing.emergency.4.server.2' => ['0'],
	'dialplan.20.routing.emergency.4.server.3' => ['0'],
	'dialplan.20.routing.emergency.4.value' => [''],
	'dialplan.20.routing.server.1.address' => [''],
	'dialplan.20.routing.server.1.port' => ['5060'],
	'dialplan.20.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.20.routing.server.2.address' => [''],
	'dialplan.20.routing.server.2.port' => ['5060'],
	'dialplan.20.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.20.routing.server.3.address' => [''],
	'dialplan.20.routing.server.3.port' => ['5060'],
	'dialplan.20.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.20.routing.server.4.address' => [''],
	'dialplan.20.routing.server.4.port' => ['5060'],
	'dialplan.20.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.21.applyToCallListDial' => ['1'],
	'dialplan.21.applyToDirectoryDial' => ['0'],
	'dialplan.21.applyToTelUriDial' => ['1'],
	'dialplan.21.applyToUserDial' => ['1'],
	'dialplan.21.applyToUserSend' => ['1'],
	'dialplan.21.digitmap' => [''],
	'dialplan.21.digitmap.timeOut' => [''],
	'dialplan.21.impossibleMatchHandling' => ['0'],
	'dialplan.21.removeEndOfDial' => ['1'],
	'dialplan.21.routing.emergency.1.server.1' => ['0'],
	'dialplan.21.routing.emergency.1.server.2' => ['0'],
	'dialplan.21.routing.emergency.1.server.3' => ['0'],
	'dialplan.21.routing.emergency.1.value' => [''],
	'dialplan.21.routing.emergency.2.server.1' => ['0'],
	'dialplan.21.routing.emergency.2.server.2' => ['0'],
	'dialplan.21.routing.emergency.2.server.3' => ['0'],
	'dialplan.21.routing.emergency.2.value' => [''],
	'dialplan.21.routing.emergency.3.server.1' => ['0'],
	'dialplan.21.routing.emergency.3.server.2' => ['0'],
	'dialplan.21.routing.emergency.3.server.3' => ['0'],
	'dialplan.21.routing.emergency.3.value' => [''],
	'dialplan.21.routing.emergency.4.server.1' => ['0'],
	'dialplan.21.routing.emergency.4.server.2' => ['0'],
	'dialplan.21.routing.emergency.4.server.3' => ['0'],
	'dialplan.21.routing.emergency.4.value' => [''],
	'dialplan.21.routing.server.1.address' => [''],
	'dialplan.21.routing.server.1.port' => ['5060'],
	'dialplan.21.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.21.routing.server.2.address' => [''],
	'dialplan.21.routing.server.2.port' => ['5060'],
	'dialplan.21.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.21.routing.server.3.address' => [''],
	'dialplan.21.routing.server.3.port' => ['5060'],
	'dialplan.21.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.21.routing.server.4.address' => [''],
	'dialplan.21.routing.server.4.port' => ['5060'],
	'dialplan.21.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.22.applyToCallListDial' => ['1'],
	'dialplan.22.applyToDirectoryDial' => ['0'],
	'dialplan.22.applyToTelUriDial' => ['1'],
	'dialplan.22.applyToUserDial' => ['1'],
	'dialplan.22.applyToUserSend' => ['1'],
	'dialplan.22.digitmap' => [''],
	'dialplan.22.digitmap.timeOut' => [''],
	'dialplan.22.impossibleMatchHandling' => ['0'],
	'dialplan.22.removeEndOfDial' => ['1'],
	'dialplan.22.routing.emergency.1.server.1' => ['0'],
	'dialplan.22.routing.emergency.1.server.2' => ['0'],
	'dialplan.22.routing.emergency.1.server.3' => ['0'],
	'dialplan.22.routing.emergency.1.value' => [''],
	'dialplan.22.routing.emergency.2.server.1' => ['0'],
	'dialplan.22.routing.emergency.2.server.2' => ['0'],
	'dialplan.22.routing.emergency.2.server.3' => ['0'],
	'dialplan.22.routing.emergency.2.value' => [''],
	'dialplan.22.routing.emergency.3.server.1' => ['0'],
	'dialplan.22.routing.emergency.3.server.2' => ['0'],
	'dialplan.22.routing.emergency.3.server.3' => ['0'],
	'dialplan.22.routing.emergency.3.value' => [''],
	'dialplan.22.routing.emergency.4.server.1' => ['0'],
	'dialplan.22.routing.emergency.4.server.2' => ['0'],
	'dialplan.22.routing.emergency.4.server.3' => ['0'],
	'dialplan.22.routing.emergency.4.value' => [''],
	'dialplan.22.routing.server.1.address' => [''],
	'dialplan.22.routing.server.1.port' => ['5060'],
	'dialplan.22.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.22.routing.server.2.address' => [''],
	'dialplan.22.routing.server.2.port' => ['5060'],
	'dialplan.22.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.22.routing.server.3.address' => [''],
	'dialplan.22.routing.server.3.port' => ['5060'],
	'dialplan.22.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.22.routing.server.4.address' => [''],
	'dialplan.22.routing.server.4.port' => ['5060'],
	'dialplan.22.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.23.applyToCallListDial' => ['1'],
	'dialplan.23.applyToDirectoryDial' => ['0'],
	'dialplan.23.applyToTelUriDial' => ['1'],
	'dialplan.23.applyToUserDial' => ['1'],
	'dialplan.23.applyToUserSend' => ['1'],
	'dialplan.23.digitmap' => [''],
	'dialplan.23.digitmap.timeOut' => [''],
	'dialplan.23.impossibleMatchHandling' => ['0'],
	'dialplan.23.removeEndOfDial' => ['1'],
	'dialplan.23.routing.emergency.1.server.1' => ['0'],
	'dialplan.23.routing.emergency.1.server.2' => ['0'],
	'dialplan.23.routing.emergency.1.server.3' => ['0'],
	'dialplan.23.routing.emergency.1.value' => [''],
	'dialplan.23.routing.emergency.2.server.1' => ['0'],
	'dialplan.23.routing.emergency.2.server.2' => ['0'],
	'dialplan.23.routing.emergency.2.server.3' => ['0'],
	'dialplan.23.routing.emergency.2.value' => [''],
	'dialplan.23.routing.emergency.3.server.1' => ['0'],
	'dialplan.23.routing.emergency.3.server.2' => ['0'],
	'dialplan.23.routing.emergency.3.server.3' => ['0'],
	'dialplan.23.routing.emergency.3.value' => [''],
	'dialplan.23.routing.emergency.4.server.1' => ['0'],
	'dialplan.23.routing.emergency.4.server.2' => ['0'],
	'dialplan.23.routing.emergency.4.server.3' => ['0'],
	'dialplan.23.routing.emergency.4.value' => [''],
	'dialplan.23.routing.server.1.address' => [''],
	'dialplan.23.routing.server.1.port' => ['5060'],
	'dialplan.23.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.23.routing.server.2.address' => [''],
	'dialplan.23.routing.server.2.port' => ['5060'],
	'dialplan.23.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.23.routing.server.3.address' => [''],
	'dialplan.23.routing.server.3.port' => ['5060'],
	'dialplan.23.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.23.routing.server.4.address' => [''],
	'dialplan.23.routing.server.4.port' => ['5060'],
	'dialplan.23.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.24.applyToCallListDial' => ['1'],
	'dialplan.24.applyToDirectoryDial' => ['0'],
	'dialplan.24.applyToTelUriDial' => ['1'],
	'dialplan.24.applyToUserDial' => ['1'],
	'dialplan.24.applyToUserSend' => ['1'],
	'dialplan.24.digitmap' => [''],
	'dialplan.24.digitmap.timeOut' => [''],
	'dialplan.24.impossibleMatchHandling' => ['0'],
	'dialplan.24.removeEndOfDial' => ['1'],
	'dialplan.24.routing.emergency.1.server.1' => ['0'],
	'dialplan.24.routing.emergency.1.server.2' => ['0'],
	'dialplan.24.routing.emergency.1.server.3' => ['0'],
	'dialplan.24.routing.emergency.1.value' => [''],
	'dialplan.24.routing.emergency.2.server.1' => ['0'],
	'dialplan.24.routing.emergency.2.server.2' => ['0'],
	'dialplan.24.routing.emergency.2.server.3' => ['0'],
	'dialplan.24.routing.emergency.2.value' => [''],
	'dialplan.24.routing.emergency.3.server.1' => ['0'],
	'dialplan.24.routing.emergency.3.server.2' => ['0'],
	'dialplan.24.routing.emergency.3.server.3' => ['0'],
	'dialplan.24.routing.emergency.3.value' => [''],
	'dialplan.24.routing.emergency.4.server.1' => ['0'],
	'dialplan.24.routing.emergency.4.server.2' => ['0'],
	'dialplan.24.routing.emergency.4.server.3' => ['0'],
	'dialplan.24.routing.emergency.4.value' => [''],
	'dialplan.24.routing.server.1.address' => [''],
	'dialplan.24.routing.server.1.port' => ['5060'],
	'dialplan.24.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.24.routing.server.2.address' => [''],
	'dialplan.24.routing.server.2.port' => ['5060'],
	'dialplan.24.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.24.routing.server.3.address' => [''],
	'dialplan.24.routing.server.3.port' => ['5060'],
	'dialplan.24.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.24.routing.server.4.address' => [''],
	'dialplan.24.routing.server.4.port' => ['5060'],
	'dialplan.24.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.25.applyToCallListDial' => ['1'],
	'dialplan.25.applyToDirectoryDial' => ['0'],
	'dialplan.25.applyToTelUriDial' => ['1'],
	'dialplan.25.applyToUserDial' => ['1'],
	'dialplan.25.applyToUserSend' => ['1'],
	'dialplan.25.digitmap' => [''],
	'dialplan.25.digitmap.timeOut' => [''],
	'dialplan.25.impossibleMatchHandling' => ['0'],
	'dialplan.25.removeEndOfDial' => ['1'],
	'dialplan.25.routing.emergency.1.server.1' => ['0'],
	'dialplan.25.routing.emergency.1.server.2' => ['0'],
	'dialplan.25.routing.emergency.1.server.3' => ['0'],
	'dialplan.25.routing.emergency.1.value' => [''],
	'dialplan.25.routing.emergency.2.server.1' => ['0'],
	'dialplan.25.routing.emergency.2.server.2' => ['0'],
	'dialplan.25.routing.emergency.2.server.3' => ['0'],
	'dialplan.25.routing.emergency.2.value' => [''],
	'dialplan.25.routing.emergency.3.server.1' => ['0'],
	'dialplan.25.routing.emergency.3.server.2' => ['0'],
	'dialplan.25.routing.emergency.3.server.3' => ['0'],
	'dialplan.25.routing.emergency.3.value' => [''],
	'dialplan.25.routing.emergency.4.server.1' => ['0'],
	'dialplan.25.routing.emergency.4.server.2' => ['0'],
	'dialplan.25.routing.emergency.4.server.3' => ['0'],
	'dialplan.25.routing.emergency.4.value' => [''],
	'dialplan.25.routing.server.1.address' => [''],
	'dialplan.25.routing.server.1.port' => ['5060'],
	'dialplan.25.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.25.routing.server.2.address' => [''],
	'dialplan.25.routing.server.2.port' => ['5060'],
	'dialplan.25.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.25.routing.server.3.address' => [''],
	'dialplan.25.routing.server.3.port' => ['5060'],
	'dialplan.25.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.25.routing.server.4.address' => [''],
	'dialplan.25.routing.server.4.port' => ['5060'],
	'dialplan.25.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.26.applyToCallListDial' => ['1'],
	'dialplan.26.applyToDirectoryDial' => ['0'],
	'dialplan.26.applyToTelUriDial' => ['1'],
	'dialplan.26.applyToUserDial' => ['1'],
	'dialplan.26.applyToUserSend' => ['1'],
	'dialplan.26.digitmap' => [''],
	'dialplan.26.digitmap.timeOut' => [''],
	'dialplan.26.impossibleMatchHandling' => ['0'],
	'dialplan.26.removeEndOfDial' => ['1'],
	'dialplan.26.routing.emergency.1.server.1' => ['0'],
	'dialplan.26.routing.emergency.1.server.2' => ['0'],
	'dialplan.26.routing.emergency.1.server.3' => ['0'],
	'dialplan.26.routing.emergency.1.value' => [''],
	'dialplan.26.routing.emergency.2.server.1' => ['0'],
	'dialplan.26.routing.emergency.2.server.2' => ['0'],
	'dialplan.26.routing.emergency.2.server.3' => ['0'],
	'dialplan.26.routing.emergency.2.value' => [''],
	'dialplan.26.routing.emergency.3.server.1' => ['0'],
	'dialplan.26.routing.emergency.3.server.2' => ['0'],
	'dialplan.26.routing.emergency.3.server.3' => ['0'],
	'dialplan.26.routing.emergency.3.value' => [''],
	'dialplan.26.routing.emergency.4.server.1' => ['0'],
	'dialplan.26.routing.emergency.4.server.2' => ['0'],
	'dialplan.26.routing.emergency.4.server.3' => ['0'],
	'dialplan.26.routing.emergency.4.value' => [''],
	'dialplan.26.routing.server.1.address' => [''],
	'dialplan.26.routing.server.1.port' => ['5060'],
	'dialplan.26.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.26.routing.server.2.address' => [''],
	'dialplan.26.routing.server.2.port' => ['5060'],
	'dialplan.26.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.26.routing.server.3.address' => [''],
	'dialplan.26.routing.server.3.port' => ['5060'],
	'dialplan.26.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.26.routing.server.4.address' => [''],
	'dialplan.26.routing.server.4.port' => ['5060'],
	'dialplan.26.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.27.applyToCallListDial' => ['1'],
	'dialplan.27.applyToDirectoryDial' => ['0'],
	'dialplan.27.applyToTelUriDial' => ['1'],
	'dialplan.27.applyToUserDial' => ['1'],
	'dialplan.27.applyToUserSend' => ['1'],
	'dialplan.27.digitmap' => [''],
	'dialplan.27.digitmap.timeOut' => [''],
	'dialplan.27.impossibleMatchHandling' => ['0'],
	'dialplan.27.removeEndOfDial' => ['1'],
	'dialplan.27.routing.emergency.1.server.1' => ['0'],
	'dialplan.27.routing.emergency.1.server.2' => ['0'],
	'dialplan.27.routing.emergency.1.server.3' => ['0'],
	'dialplan.27.routing.emergency.1.value' => [''],
	'dialplan.27.routing.emergency.2.server.1' => ['0'],
	'dialplan.27.routing.emergency.2.server.2' => ['0'],
	'dialplan.27.routing.emergency.2.server.3' => ['0'],
	'dialplan.27.routing.emergency.2.value' => [''],
	'dialplan.27.routing.emergency.3.server.1' => ['0'],
	'dialplan.27.routing.emergency.3.server.2' => ['0'],
	'dialplan.27.routing.emergency.3.server.3' => ['0'],
	'dialplan.27.routing.emergency.3.value' => [''],
	'dialplan.27.routing.emergency.4.server.1' => ['0'],
	'dialplan.27.routing.emergency.4.server.2' => ['0'],
	'dialplan.27.routing.emergency.4.server.3' => ['0'],
	'dialplan.27.routing.emergency.4.value' => [''],
	'dialplan.27.routing.server.1.address' => [''],
	'dialplan.27.routing.server.1.port' => ['5060'],
	'dialplan.27.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.27.routing.server.2.address' => [''],
	'dialplan.27.routing.server.2.port' => ['5060'],
	'dialplan.27.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.27.routing.server.3.address' => [''],
	'dialplan.27.routing.server.3.port' => ['5060'],
	'dialplan.27.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.27.routing.server.4.address' => [''],
	'dialplan.27.routing.server.4.port' => ['5060'],
	'dialplan.27.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.28.applyToCallListDial' => ['1'],
	'dialplan.28.applyToDirectoryDial' => ['0'],
	'dialplan.28.applyToTelUriDial' => ['1'],
	'dialplan.28.applyToUserDial' => ['1'],
	'dialplan.28.applyToUserSend' => ['1'],
	'dialplan.28.digitmap' => [''],
	'dialplan.28.digitmap.timeOut' => [''],
	'dialplan.28.impossibleMatchHandling' => ['0'],
	'dialplan.28.removeEndOfDial' => ['1'],
	'dialplan.28.routing.emergency.1.server.1' => ['0'],
	'dialplan.28.routing.emergency.1.server.2' => ['0'],
	'dialplan.28.routing.emergency.1.server.3' => ['0'],
	'dialplan.28.routing.emergency.1.value' => [''],
	'dialplan.28.routing.emergency.2.server.1' => ['0'],
	'dialplan.28.routing.emergency.2.server.2' => ['0'],
	'dialplan.28.routing.emergency.2.server.3' => ['0'],
	'dialplan.28.routing.emergency.2.value' => [''],
	'dialplan.28.routing.emergency.3.server.1' => ['0'],
	'dialplan.28.routing.emergency.3.server.2' => ['0'],
	'dialplan.28.routing.emergency.3.server.3' => ['0'],
	'dialplan.28.routing.emergency.3.value' => [''],
	'dialplan.28.routing.emergency.4.server.1' => ['0'],
	'dialplan.28.routing.emergency.4.server.2' => ['0'],
	'dialplan.28.routing.emergency.4.server.3' => ['0'],
	'dialplan.28.routing.emergency.4.value' => [''],
	'dialplan.28.routing.server.1.address' => [''],
	'dialplan.28.routing.server.1.port' => ['5060'],
	'dialplan.28.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.28.routing.server.2.address' => [''],
	'dialplan.28.routing.server.2.port' => ['5060'],
	'dialplan.28.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.28.routing.server.3.address' => [''],
	'dialplan.28.routing.server.3.port' => ['5060'],
	'dialplan.28.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.28.routing.server.4.address' => [''],
	'dialplan.28.routing.server.4.port' => ['5060'],
	'dialplan.28.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.29.applyToCallListDial' => ['1'],
	'dialplan.29.applyToDirectoryDial' => ['0'],
	'dialplan.29.applyToTelUriDial' => ['1'],
	'dialplan.29.applyToUserDial' => ['1'],
	'dialplan.29.applyToUserSend' => ['1'],
	'dialplan.29.digitmap' => [''],
	'dialplan.29.digitmap.timeOut' => [''],
	'dialplan.29.impossibleMatchHandling' => ['0'],
	'dialplan.29.removeEndOfDial' => ['1'],
	'dialplan.29.routing.emergency.1.server.1' => ['0'],
	'dialplan.29.routing.emergency.1.server.2' => ['0'],
	'dialplan.29.routing.emergency.1.server.3' => ['0'],
	'dialplan.29.routing.emergency.1.value' => [''],
	'dialplan.29.routing.emergency.2.server.1' => ['0'],
	'dialplan.29.routing.emergency.2.server.2' => ['0'],
	'dialplan.29.routing.emergency.2.server.3' => ['0'],
	'dialplan.29.routing.emergency.2.value' => [''],
	'dialplan.29.routing.emergency.3.server.1' => ['0'],
	'dialplan.29.routing.emergency.3.server.2' => ['0'],
	'dialplan.29.routing.emergency.3.server.3' => ['0'],
	'dialplan.29.routing.emergency.3.value' => [''],
	'dialplan.29.routing.emergency.4.server.1' => ['0'],
	'dialplan.29.routing.emergency.4.server.2' => ['0'],
	'dialplan.29.routing.emergency.4.server.3' => ['0'],
	'dialplan.29.routing.emergency.4.value' => [''],
	'dialplan.29.routing.server.1.address' => [''],
	'dialplan.29.routing.server.1.port' => ['5060'],
	'dialplan.29.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.29.routing.server.2.address' => [''],
	'dialplan.29.routing.server.2.port' => ['5060'],
	'dialplan.29.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.29.routing.server.3.address' => [''],
	'dialplan.29.routing.server.3.port' => ['5060'],
	'dialplan.29.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.29.routing.server.4.address' => [''],
	'dialplan.29.routing.server.4.port' => ['5060'],
	'dialplan.29.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.3.applyToCallListDial' => ['1'],
	'dialplan.3.applyToDirectoryDial' => ['0'],
	'dialplan.3.applyToTelUriDial' => ['1'],
	'dialplan.3.applyToUserDial' => ['1'],
	'dialplan.3.applyToUserSend' => ['1'],
	'dialplan.3.digitmap' => [''],
	'dialplan.3.digitmap.timeOut' => [''],
	'dialplan.3.impossibleMatchHandling' => ['0'],
	'dialplan.3.removeEndOfDial' => ['1'],
	'dialplan.3.routing.emergency.1.server.1' => ['0'],
	'dialplan.3.routing.emergency.1.server.2' => ['0'],
	'dialplan.3.routing.emergency.1.server.3' => ['0'],
	'dialplan.3.routing.emergency.1.value' => [''],
	'dialplan.3.routing.emergency.2.server.1' => ['0'],
	'dialplan.3.routing.emergency.2.server.2' => ['0'],
	'dialplan.3.routing.emergency.2.server.3' => ['0'],
	'dialplan.3.routing.emergency.2.value' => [''],
	'dialplan.3.routing.emergency.3.server.1' => ['0'],
	'dialplan.3.routing.emergency.3.server.2' => ['0'],
	'dialplan.3.routing.emergency.3.server.3' => ['0'],
	'dialplan.3.routing.emergency.3.value' => [''],
	'dialplan.3.routing.emergency.4.server.1' => ['0'],
	'dialplan.3.routing.emergency.4.server.2' => ['0'],
	'dialplan.3.routing.emergency.4.server.3' => ['0'],
	'dialplan.3.routing.emergency.4.value' => [''],
	'dialplan.3.routing.server.1.address' => [''],
	'dialplan.3.routing.server.1.port' => ['5060'],
	'dialplan.3.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.3.routing.server.2.address' => [''],
	'dialplan.3.routing.server.2.port' => ['5060'],
	'dialplan.3.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.3.routing.server.3.address' => [''],
	'dialplan.3.routing.server.3.port' => ['5060'],
	'dialplan.3.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.3.routing.server.4.address' => [''],
	'dialplan.3.routing.server.4.port' => ['5060'],
	'dialplan.3.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.30.applyToCallListDial' => ['1'],
	'dialplan.30.applyToDirectoryDial' => ['0'],
	'dialplan.30.applyToTelUriDial' => ['1'],
	'dialplan.30.applyToUserDial' => ['1'],
	'dialplan.30.applyToUserSend' => ['1'],
	'dialplan.30.digitmap' => [''],
	'dialplan.30.digitmap.timeOut' => [''],
	'dialplan.30.impossibleMatchHandling' => ['0'],
	'dialplan.30.removeEndOfDial' => ['1'],
	'dialplan.30.routing.emergency.1.server.1' => ['0'],
	'dialplan.30.routing.emergency.1.server.2' => ['0'],
	'dialplan.30.routing.emergency.1.server.3' => ['0'],
	'dialplan.30.routing.emergency.1.value' => [''],
	'dialplan.30.routing.emergency.2.server.1' => ['0'],
	'dialplan.30.routing.emergency.2.server.2' => ['0'],
	'dialplan.30.routing.emergency.2.server.3' => ['0'],
	'dialplan.30.routing.emergency.2.value' => [''],
	'dialplan.30.routing.emergency.3.server.1' => ['0'],
	'dialplan.30.routing.emergency.3.server.2' => ['0'],
	'dialplan.30.routing.emergency.3.server.3' => ['0'],
	'dialplan.30.routing.emergency.3.value' => [''],
	'dialplan.30.routing.emergency.4.server.1' => ['0'],
	'dialplan.30.routing.emergency.4.server.2' => ['0'],
	'dialplan.30.routing.emergency.4.server.3' => ['0'],
	'dialplan.30.routing.emergency.4.value' => [''],
	'dialplan.30.routing.server.1.address' => [''],
	'dialplan.30.routing.server.1.port' => ['5060'],
	'dialplan.30.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.30.routing.server.2.address' => [''],
	'dialplan.30.routing.server.2.port' => ['5060'],
	'dialplan.30.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.30.routing.server.3.address' => [''],
	'dialplan.30.routing.server.3.port' => ['5060'],
	'dialplan.30.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.30.routing.server.4.address' => [''],
	'dialplan.30.routing.server.4.port' => ['5060'],
	'dialplan.30.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.31.applyToCallListDial' => ['1'],
	'dialplan.31.applyToDirectoryDial' => ['0'],
	'dialplan.31.applyToTelUriDial' => ['1'],
	'dialplan.31.applyToUserDial' => ['1'],
	'dialplan.31.applyToUserSend' => ['1'],
	'dialplan.31.digitmap' => [''],
	'dialplan.31.digitmap.timeOut' => [''],
	'dialplan.31.impossibleMatchHandling' => ['0'],
	'dialplan.31.removeEndOfDial' => ['1'],
	'dialplan.31.routing.emergency.1.server.1' => ['0'],
	'dialplan.31.routing.emergency.1.server.2' => ['0'],
	'dialplan.31.routing.emergency.1.server.3' => ['0'],
	'dialplan.31.routing.emergency.1.value' => [''],
	'dialplan.31.routing.emergency.2.server.1' => ['0'],
	'dialplan.31.routing.emergency.2.server.2' => ['0'],
	'dialplan.31.routing.emergency.2.server.3' => ['0'],
	'dialplan.31.routing.emergency.2.value' => [''],
	'dialplan.31.routing.emergency.3.server.1' => ['0'],
	'dialplan.31.routing.emergency.3.server.2' => ['0'],
	'dialplan.31.routing.emergency.3.server.3' => ['0'],
	'dialplan.31.routing.emergency.3.value' => [''],
	'dialplan.31.routing.emergency.4.server.1' => ['0'],
	'dialplan.31.routing.emergency.4.server.2' => ['0'],
	'dialplan.31.routing.emergency.4.server.3' => ['0'],
	'dialplan.31.routing.emergency.4.value' => [''],
	'dialplan.31.routing.server.1.address' => [''],
	'dialplan.31.routing.server.1.port' => ['5060'],
	'dialplan.31.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.31.routing.server.2.address' => [''],
	'dialplan.31.routing.server.2.port' => ['5060'],
	'dialplan.31.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.31.routing.server.3.address' => [''],
	'dialplan.31.routing.server.3.port' => ['5060'],
	'dialplan.31.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.31.routing.server.4.address' => [''],
	'dialplan.31.routing.server.4.port' => ['5060'],
	'dialplan.31.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.32.applyToCallListDial' => ['1'],
	'dialplan.32.applyToDirectoryDial' => ['0'],
	'dialplan.32.applyToTelUriDial' => ['1'],
	'dialplan.32.applyToUserDial' => ['1'],
	'dialplan.32.applyToUserSend' => ['1'],
	'dialplan.32.digitmap' => [''],
	'dialplan.32.digitmap.timeOut' => [''],
	'dialplan.32.impossibleMatchHandling' => ['0'],
	'dialplan.32.removeEndOfDial' => ['1'],
	'dialplan.32.routing.emergency.1.server.1' => ['0'],
	'dialplan.32.routing.emergency.1.server.2' => ['0'],
	'dialplan.32.routing.emergency.1.server.3' => ['0'],
	'dialplan.32.routing.emergency.1.value' => [''],
	'dialplan.32.routing.emergency.2.server.1' => ['0'],
	'dialplan.32.routing.emergency.2.server.2' => ['0'],
	'dialplan.32.routing.emergency.2.server.3' => ['0'],
	'dialplan.32.routing.emergency.2.value' => [''],
	'dialplan.32.routing.emergency.3.server.1' => ['0'],
	'dialplan.32.routing.emergency.3.server.2' => ['0'],
	'dialplan.32.routing.emergency.3.server.3' => ['0'],
	'dialplan.32.routing.emergency.3.value' => [''],
	'dialplan.32.routing.emergency.4.server.1' => ['0'],
	'dialplan.32.routing.emergency.4.server.2' => ['0'],
	'dialplan.32.routing.emergency.4.server.3' => ['0'],
	'dialplan.32.routing.emergency.4.value' => [''],
	'dialplan.32.routing.server.1.address' => [''],
	'dialplan.32.routing.server.1.port' => ['5060'],
	'dialplan.32.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.32.routing.server.2.address' => [''],
	'dialplan.32.routing.server.2.port' => ['5060'],
	'dialplan.32.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.32.routing.server.3.address' => [''],
	'dialplan.32.routing.server.3.port' => ['5060'],
	'dialplan.32.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.32.routing.server.4.address' => [''],
	'dialplan.32.routing.server.4.port' => ['5060'],
	'dialplan.32.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.33.applyToCallListDial' => ['1'],
	'dialplan.33.applyToDirectoryDial' => ['0'],
	'dialplan.33.applyToTelUriDial' => ['1'],
	'dialplan.33.applyToUserDial' => ['1'],
	'dialplan.33.applyToUserSend' => ['1'],
	'dialplan.33.digitmap' => [''],
	'dialplan.33.digitmap.timeOut' => [''],
	'dialplan.33.impossibleMatchHandling' => ['0'],
	'dialplan.33.removeEndOfDial' => ['1'],
	'dialplan.33.routing.emergency.1.server.1' => ['0'],
	'dialplan.33.routing.emergency.1.server.2' => ['0'],
	'dialplan.33.routing.emergency.1.server.3' => ['0'],
	'dialplan.33.routing.emergency.1.value' => [''],
	'dialplan.33.routing.emergency.2.server.1' => ['0'],
	'dialplan.33.routing.emergency.2.server.2' => ['0'],
	'dialplan.33.routing.emergency.2.server.3' => ['0'],
	'dialplan.33.routing.emergency.2.value' => [''],
	'dialplan.33.routing.emergency.3.server.1' => ['0'],
	'dialplan.33.routing.emergency.3.server.2' => ['0'],
	'dialplan.33.routing.emergency.3.server.3' => ['0'],
	'dialplan.33.routing.emergency.3.value' => [''],
	'dialplan.33.routing.emergency.4.server.1' => ['0'],
	'dialplan.33.routing.emergency.4.server.2' => ['0'],
	'dialplan.33.routing.emergency.4.server.3' => ['0'],
	'dialplan.33.routing.emergency.4.value' => [''],
	'dialplan.33.routing.server.1.address' => [''],
	'dialplan.33.routing.server.1.port' => ['5060'],
	'dialplan.33.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.33.routing.server.2.address' => [''],
	'dialplan.33.routing.server.2.port' => ['5060'],
	'dialplan.33.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.33.routing.server.3.address' => [''],
	'dialplan.33.routing.server.3.port' => ['5060'],
	'dialplan.33.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.33.routing.server.4.address' => [''],
	'dialplan.33.routing.server.4.port' => ['5060'],
	'dialplan.33.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.34.applyToCallListDial' => ['1'],
	'dialplan.34.applyToDirectoryDial' => ['0'],
	'dialplan.34.applyToTelUriDial' => ['1'],
	'dialplan.34.applyToUserDial' => ['1'],
	'dialplan.34.applyToUserSend' => ['1'],
	'dialplan.34.digitmap' => [''],
	'dialplan.34.digitmap.timeOut' => [''],
	'dialplan.34.impossibleMatchHandling' => ['0'],
	'dialplan.34.removeEndOfDial' => ['1'],
	'dialplan.34.routing.emergency.1.server.1' => ['0'],
	'dialplan.34.routing.emergency.1.server.2' => ['0'],
	'dialplan.34.routing.emergency.1.server.3' => ['0'],
	'dialplan.34.routing.emergency.1.value' => [''],
	'dialplan.34.routing.emergency.2.server.1' => ['0'],
	'dialplan.34.routing.emergency.2.server.2' => ['0'],
	'dialplan.34.routing.emergency.2.server.3' => ['0'],
	'dialplan.34.routing.emergency.2.value' => [''],
	'dialplan.34.routing.emergency.3.server.1' => ['0'],
	'dialplan.34.routing.emergency.3.server.2' => ['0'],
	'dialplan.34.routing.emergency.3.server.3' => ['0'],
	'dialplan.34.routing.emergency.3.value' => [''],
	'dialplan.34.routing.emergency.4.server.1' => ['0'],
	'dialplan.34.routing.emergency.4.server.2' => ['0'],
	'dialplan.34.routing.emergency.4.server.3' => ['0'],
	'dialplan.34.routing.emergency.4.value' => [''],
	'dialplan.34.routing.server.1.address' => [''],
	'dialplan.34.routing.server.1.port' => ['5060'],
	'dialplan.34.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.34.routing.server.2.address' => [''],
	'dialplan.34.routing.server.2.port' => ['5060'],
	'dialplan.34.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.34.routing.server.3.address' => [''],
	'dialplan.34.routing.server.3.port' => ['5060'],
	'dialplan.34.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.34.routing.server.4.address' => [''],
	'dialplan.34.routing.server.4.port' => ['5060'],
	'dialplan.34.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.4.applyToCallListDial' => ['1'],
	'dialplan.4.applyToDirectoryDial' => ['0'],
	'dialplan.4.applyToTelUriDial' => ['1'],
	'dialplan.4.applyToUserDial' => ['1'],
	'dialplan.4.applyToUserSend' => ['1'],
	'dialplan.4.digitmap' => [''],
	'dialplan.4.digitmap.timeOut' => [''],
	'dialplan.4.impossibleMatchHandling' => ['0'],
	'dialplan.4.removeEndOfDial' => ['1'],
	'dialplan.4.routing.emergency.1.server.1' => ['0'],
	'dialplan.4.routing.emergency.1.server.2' => ['0'],
	'dialplan.4.routing.emergency.1.server.3' => ['0'],
	'dialplan.4.routing.emergency.1.value' => [''],
	'dialplan.4.routing.emergency.2.server.1' => ['0'],
	'dialplan.4.routing.emergency.2.server.2' => ['0'],
	'dialplan.4.routing.emergency.2.server.3' => ['0'],
	'dialplan.4.routing.emergency.2.value' => [''],
	'dialplan.4.routing.emergency.3.server.1' => ['0'],
	'dialplan.4.routing.emergency.3.server.2' => ['0'],
	'dialplan.4.routing.emergency.3.server.3' => ['0'],
	'dialplan.4.routing.emergency.3.value' => [''],
	'dialplan.4.routing.emergency.4.server.1' => ['0'],
	'dialplan.4.routing.emergency.4.server.2' => ['0'],
	'dialplan.4.routing.emergency.4.server.3' => ['0'],
	'dialplan.4.routing.emergency.4.value' => [''],
	'dialplan.4.routing.server.1.address' => [''],
	'dialplan.4.routing.server.1.port' => ['5060'],
	'dialplan.4.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.4.routing.server.2.address' => [''],
	'dialplan.4.routing.server.2.port' => ['5060'],
	'dialplan.4.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.4.routing.server.3.address' => [''],
	'dialplan.4.routing.server.3.port' => ['5060'],
	'dialplan.4.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.4.routing.server.4.address' => [''],
	'dialplan.4.routing.server.4.port' => ['5060'],
	'dialplan.4.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.5.applyToCallListDial' => ['1'],
	'dialplan.5.applyToDirectoryDial' => ['0'],
	'dialplan.5.applyToTelUriDial' => ['1'],
	'dialplan.5.applyToUserDial' => ['1'],
	'dialplan.5.applyToUserSend' => ['1'],
	'dialplan.5.digitmap' => [''],
	'dialplan.5.digitmap.timeOut' => [''],
	'dialplan.5.impossibleMatchHandling' => ['0'],
	'dialplan.5.removeEndOfDial' => ['1'],
	'dialplan.5.routing.emergency.1.server.1' => ['0'],
	'dialplan.5.routing.emergency.1.server.2' => ['0'],
	'dialplan.5.routing.emergency.1.server.3' => ['0'],
	'dialplan.5.routing.emergency.1.value' => [''],
	'dialplan.5.routing.emergency.2.server.1' => ['0'],
	'dialplan.5.routing.emergency.2.server.2' => ['0'],
	'dialplan.5.routing.emergency.2.server.3' => ['0'],
	'dialplan.5.routing.emergency.2.value' => [''],
	'dialplan.5.routing.emergency.3.server.1' => ['0'],
	'dialplan.5.routing.emergency.3.server.2' => ['0'],
	'dialplan.5.routing.emergency.3.server.3' => ['0'],
	'dialplan.5.routing.emergency.3.value' => [''],
	'dialplan.5.routing.emergency.4.server.1' => ['0'],
	'dialplan.5.routing.emergency.4.server.2' => ['0'],
	'dialplan.5.routing.emergency.4.server.3' => ['0'],
	'dialplan.5.routing.emergency.4.value' => [''],
	'dialplan.5.routing.server.1.address' => [''],
	'dialplan.5.routing.server.1.port' => ['5060'],
	'dialplan.5.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.5.routing.server.2.address' => [''],
	'dialplan.5.routing.server.2.port' => ['5060'],
	'dialplan.5.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.5.routing.server.3.address' => [''],
	'dialplan.5.routing.server.3.port' => ['5060'],
	'dialplan.5.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.5.routing.server.4.address' => [''],
	'dialplan.5.routing.server.4.port' => ['5060'],
	'dialplan.5.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.6.applyToCallListDial' => ['1'],
	'dialplan.6.applyToDirectoryDial' => ['0'],
	'dialplan.6.applyToTelUriDial' => ['1'],
	'dialplan.6.applyToUserDial' => ['1'],
	'dialplan.6.applyToUserSend' => ['1'],
	'dialplan.6.digitmap' => [''],
	'dialplan.6.digitmap.timeOut' => [''],
	'dialplan.6.impossibleMatchHandling' => ['0'],
	'dialplan.6.removeEndOfDial' => ['1'],
	'dialplan.6.routing.emergency.1.server.1' => ['0'],
	'dialplan.6.routing.emergency.1.server.2' => ['0'],
	'dialplan.6.routing.emergency.1.server.3' => ['0'],
	'dialplan.6.routing.emergency.1.value' => [''],
	'dialplan.6.routing.emergency.2.server.1' => ['0'],
	'dialplan.6.routing.emergency.2.server.2' => ['0'],
	'dialplan.6.routing.emergency.2.server.3' => ['0'],
	'dialplan.6.routing.emergency.2.value' => [''],
	'dialplan.6.routing.emergency.3.server.1' => ['0'],
	'dialplan.6.routing.emergency.3.server.2' => ['0'],
	'dialplan.6.routing.emergency.3.server.3' => ['0'],
	'dialplan.6.routing.emergency.3.value' => [''],
	'dialplan.6.routing.emergency.4.server.1' => ['0'],
	'dialplan.6.routing.emergency.4.server.2' => ['0'],
	'dialplan.6.routing.emergency.4.server.3' => ['0'],
	'dialplan.6.routing.emergency.4.value' => [''],
	'dialplan.6.routing.server.1.address' => [''],
	'dialplan.6.routing.server.1.port' => ['5060'],
	'dialplan.6.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.6.routing.server.2.address' => [''],
	'dialplan.6.routing.server.2.port' => ['5060'],
	'dialplan.6.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.6.routing.server.3.address' => [''],
	'dialplan.6.routing.server.3.port' => ['5060'],
	'dialplan.6.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.6.routing.server.4.address' => [''],
	'dialplan.6.routing.server.4.port' => ['5060'],
	'dialplan.6.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.7.applyToCallListDial' => ['1'],
	'dialplan.7.applyToDirectoryDial' => ['0'],
	'dialplan.7.applyToTelUriDial' => ['1'],
	'dialplan.7.applyToUserDial' => ['1'],
	'dialplan.7.applyToUserSend' => ['1'],
	'dialplan.7.digitmap' => [''],
	'dialplan.7.digitmap.timeOut' => [''],
	'dialplan.7.impossibleMatchHandling' => ['0'],
	'dialplan.7.removeEndOfDial' => ['1'],
	'dialplan.7.routing.emergency.1.server.1' => ['0'],
	'dialplan.7.routing.emergency.1.server.2' => ['0'],
	'dialplan.7.routing.emergency.1.server.3' => ['0'],
	'dialplan.7.routing.emergency.1.value' => [''],
	'dialplan.7.routing.emergency.2.server.1' => ['0'],
	'dialplan.7.routing.emergency.2.server.2' => ['0'],
	'dialplan.7.routing.emergency.2.server.3' => ['0'],
	'dialplan.7.routing.emergency.2.value' => [''],
	'dialplan.7.routing.emergency.3.server.1' => ['0'],
	'dialplan.7.routing.emergency.3.server.2' => ['0'],
	'dialplan.7.routing.emergency.3.server.3' => ['0'],
	'dialplan.7.routing.emergency.3.value' => [''],
	'dialplan.7.routing.emergency.4.server.1' => ['0'],
	'dialplan.7.routing.emergency.4.server.2' => ['0'],
	'dialplan.7.routing.emergency.4.server.3' => ['0'],
	'dialplan.7.routing.emergency.4.value' => [''],
	'dialplan.7.routing.server.1.address' => [''],
	'dialplan.7.routing.server.1.port' => ['5060'],
	'dialplan.7.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.7.routing.server.2.address' => [''],
	'dialplan.7.routing.server.2.port' => ['5060'],
	'dialplan.7.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.7.routing.server.3.address' => [''],
	'dialplan.7.routing.server.3.port' => ['5060'],
	'dialplan.7.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.7.routing.server.4.address' => [''],
	'dialplan.7.routing.server.4.port' => ['5060'],
	'dialplan.7.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.8.applyToCallListDial' => ['1'],
	'dialplan.8.applyToDirectoryDial' => ['0'],
	'dialplan.8.applyToTelUriDial' => ['1'],
	'dialplan.8.applyToUserDial' => ['1'],
	'dialplan.8.applyToUserSend' => ['1'],
	'dialplan.8.digitmap' => [''],
	'dialplan.8.digitmap.timeOut' => [''],
	'dialplan.8.impossibleMatchHandling' => ['0'],
	'dialplan.8.removeEndOfDial' => ['1'],
	'dialplan.8.routing.emergency.1.server.1' => ['0'],
	'dialplan.8.routing.emergency.1.server.2' => ['0'],
	'dialplan.8.routing.emergency.1.server.3' => ['0'],
	'dialplan.8.routing.emergency.1.value' => [''],
	'dialplan.8.routing.emergency.2.server.1' => ['0'],
	'dialplan.8.routing.emergency.2.server.2' => ['0'],
	'dialplan.8.routing.emergency.2.server.3' => ['0'],
	'dialplan.8.routing.emergency.2.value' => [''],
	'dialplan.8.routing.emergency.3.server.1' => ['0'],
	'dialplan.8.routing.emergency.3.server.2' => ['0'],
	'dialplan.8.routing.emergency.3.server.3' => ['0'],
	'dialplan.8.routing.emergency.3.value' => [''],
	'dialplan.8.routing.emergency.4.server.1' => ['0'],
	'dialplan.8.routing.emergency.4.server.2' => ['0'],
	'dialplan.8.routing.emergency.4.server.3' => ['0'],
	'dialplan.8.routing.emergency.4.value' => [''],
	'dialplan.8.routing.server.1.address' => [''],
	'dialplan.8.routing.server.1.port' => ['5060'],
	'dialplan.8.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.8.routing.server.2.address' => [''],
	'dialplan.8.routing.server.2.port' => ['5060'],
	'dialplan.8.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.8.routing.server.3.address' => [''],
	'dialplan.8.routing.server.3.port' => ['5060'],
	'dialplan.8.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.8.routing.server.4.address' => [''],
	'dialplan.8.routing.server.4.port' => ['5060'],
	'dialplan.8.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.9.applyToCallListDial' => ['1'],
	'dialplan.9.applyToDirectoryDial' => ['0'],
	'dialplan.9.applyToTelUriDial' => ['1'],
	'dialplan.9.applyToUserDial' => ['1'],
	'dialplan.9.applyToUserSend' => ['1'],
	'dialplan.9.digitmap' => [''],
	'dialplan.9.digitmap.timeOut' => [''],
	'dialplan.9.impossibleMatchHandling' => ['0'],
	'dialplan.9.removeEndOfDial' => ['1'],
	'dialplan.9.routing.emergency.1.server.1' => ['0'],
	'dialplan.9.routing.emergency.1.server.2' => ['0'],
	'dialplan.9.routing.emergency.1.server.3' => ['0'],
	'dialplan.9.routing.emergency.1.value' => [''],
	'dialplan.9.routing.emergency.2.server.1' => ['0'],
	'dialplan.9.routing.emergency.2.server.2' => ['0'],
	'dialplan.9.routing.emergency.2.server.3' => ['0'],
	'dialplan.9.routing.emergency.2.value' => [''],
	'dialplan.9.routing.emergency.3.server.1' => ['0'],
	'dialplan.9.routing.emergency.3.server.2' => ['0'],
	'dialplan.9.routing.emergency.3.server.3' => ['0'],
	'dialplan.9.routing.emergency.3.value' => [''],
	'dialplan.9.routing.emergency.4.server.1' => ['0'],
	'dialplan.9.routing.emergency.4.server.2' => ['0'],
	'dialplan.9.routing.emergency.4.server.3' => ['0'],
	'dialplan.9.routing.emergency.4.value' => [''],
	'dialplan.9.routing.server.1.address' => [''],
	'dialplan.9.routing.server.1.port' => ['5060'],
	'dialplan.9.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.9.routing.server.2.address' => [''],
	'dialplan.9.routing.server.2.port' => ['5060'],
	'dialplan.9.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.9.routing.server.3.address' => [''],
	'dialplan.9.routing.server.3.port' => ['5060'],
	'dialplan.9.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.9.routing.server.4.address' => [''],
	'dialplan.9.routing.server.4.port' => ['5060'],
	'dialplan.9.routing.server.4.transport' => ['DNSnaptr'],
	'dialplan.applyToCallListDial' => ['1'],
	'dialplan.applyToDirectoryDial' => ['0'],
	'dialplan.applyToRemoteDialing' => ['0'],
	'dialplan.applyToTelUriDial' => ['1'],
	'dialplan.applyToUserDial' => ['1'],
	'dialplan.applyToUserSend' => ['1'],
	'dialplan.digitmap' => ['[2-9]11|0T|011xxx.T|[0-1][2-9]xxxxxxxxx|[2-9]xxxxxxxxx|[2-9]xxxT'],
	'dialplan.digitmap.timeOut' => ['3|3|3|3|3|3'],
	'dialplan.filterNonDigitUriUsers' => ['0'],
	'dialplan.impossibleMatchHandling' => ['0'],
	'dialplan.removeEndOfDial' => ['1'],
	'dialplan.routing.emergency.1.description' => ['Emergency'],
	'dialplan.routing.emergency.1.server.1' => ['1'],
	'dialplan.routing.emergency.1.server.2' => ['1'],
	'dialplan.routing.emergency.1.server.3' => ['1'],
	'dialplan.routing.emergency.1.server.4' => ['1'],
	'dialplan.routing.emergency.1.value' => ['911'],
	'dialplan.routing.emergency.2.description' => [''],
	'dialplan.routing.emergency.2.server.1' => ['1'],
	'dialplan.routing.emergency.2.server.2' => ['1'],
	'dialplan.routing.emergency.2.server.3' => ['1'],
	'dialplan.routing.emergency.2.server.4' => ['1'],
	'dialplan.routing.emergency.2.value' => [''],
	'dialplan.routing.emergency.3.description' => [''],
	'dialplan.routing.emergency.3.server.1' => ['1'],
	'dialplan.routing.emergency.3.server.2' => ['1'],
	'dialplan.routing.emergency.3.server.3' => ['1'],
	'dialplan.routing.emergency.3.server.4' => ['1'],
	'dialplan.routing.emergency.3.value' => [''],
	'dialplan.routing.emergency.4.description' => [''],
	'dialplan.routing.emergency.4.server.1' => ['1'],
	'dialplan.routing.emergency.4.server.2' => ['1'],
	'dialplan.routing.emergency.4.server.3' => ['1'],
	'dialplan.routing.emergency.4.server.4' => ['1'],
	'dialplan.routing.emergency.4.value' => [''],
	'dialplan.routing.server.1.address' => [''],
	'dialplan.routing.server.1.port' => ['5060'],
	'dialplan.routing.server.1.transport' => ['DNSnaptr'],
	'dialplan.routing.server.2.address' => [''],
	'dialplan.routing.server.2.port' => ['5060'],
	'dialplan.routing.server.2.transport' => ['DNSnaptr'],
	'dialplan.routing.server.3.address' => [''],
	'dialplan.routing.server.3.port' => ['5060'],
	'dialplan.routing.server.3.transport' => ['DNSnaptr'],
	'dialplan.routing.server.4.address' => [''],
	'dialplan.routing.server.4.port' => ['5060'],
	'dialplan.routing.server.4.transport' => ['DNSnaptr'],
	'dir.H350.dev.address' => [''],
	'dir.H350.dev.attribute.1.filter' => [''],
	'dir.H350.dev.attribute.1.label' => [''],
	'dir.H350.dev.attribute.1.name' => [''],
	'dir.H350.dev.attribute.1.searchable' => ['0'],
	'dir.H350.dev.attribute.1.sticky' => ['0'],
	'dir.H350.dev.attribute.1.type' => [''],
	'dir.H350.dev.attribute.2.filter' => [''],
	'dir.H350.dev.attribute.2.label' => [''],
	'dir.H350.dev.attribute.2.name' => [''],
	'dir.H350.dev.attribute.2.searchable' => ['0'],
	'dir.H350.dev.attribute.2.sticky' => ['0'],
	'dir.H350.dev.attribute.2.type' => [''],
	'dir.H350.dev.attribute.3.filter' => [''],
	'dir.H350.dev.attribute.3.label' => [''],
	'dir.H350.dev.attribute.3.name' => [''],
	'dir.H350.dev.attribute.3.searchable' => ['0'],
	'dir.H350.dev.attribute.3.sticky' => ['0'],
	'dir.H350.dev.attribute.3.type' => [''],
	'dir.H350.dev.attribute.4.filter' => [''],
	'dir.H350.dev.attribute.4.label' => [''],
	'dir.H350.dev.attribute.4.name' => [''],
	'dir.H350.dev.attribute.4.searchable' => ['0'],
	'dir.H350.dev.attribute.4.sticky' => ['0'],
	'dir.H350.dev.attribute.4.type' => [''],
	'dir.H350.dev.attribute.5.filter' => [''],
	'dir.H350.dev.attribute.5.label' => [''],
	'dir.H350.dev.attribute.5.name' => [''],
	'dir.H350.dev.attribute.5.searchable' => ['0'],
	'dir.H350.dev.attribute.5.sticky' => ['0'],
	'dir.H350.dev.attribute.5.type' => [''],
	'dir.H350.dev.attribute.6.filter' => [''],
	'dir.H350.dev.attribute.6.label' => [''],
	'dir.H350.dev.attribute.6.name' => [''],
	'dir.H350.dev.attribute.6.searchable' => ['0'],
	'dir.H350.dev.attribute.6.sticky' => ['0'],
	'dir.H350.dev.attribute.6.type' => [''],
	'dir.H350.dev.attribute.7.filter' => [''],
	'dir.H350.dev.attribute.7.label' => [''],
	'dir.H350.dev.attribute.7.name' => [''],
	'dir.H350.dev.attribute.7.searchable' => ['0'],
	'dir.H350.dev.attribute.7.sticky' => ['0'],
	'dir.H350.dev.attribute.7.type' => [''],
	'dir.H350.dev.attribute.8.filter' => [''],
	'dir.H350.dev.attribute.8.label' => [''],
	'dir.H350.dev.attribute.8.name' => [''],
	'dir.H350.dev.attribute.8.searchable' => ['0'],
	'dir.H350.dev.attribute.8.sticky' => ['0'],
	'dir.H350.dev.attribute.8.type' => [''],
	'dir.H350.dev.auth.useLoginCredentials' => ['0'],
	'dir.H350.dev.autoQuerySubmitTimeout' => ['0'],
	'dir.H350.dev.backGroundSync' => ['0'],
	'dir.H350.dev.backGroundSync.period' => ['86400'],
	'dir.H350.dev.baseDN' => [''],
	'dir.H350.dev.cacheSize' => ['128'],
	'dir.H350.dev.domain' => [''],
	'dir.H350.dev.filterPrefix' => [''],
	'dir.H350.dev.pageSize' => ['32'],
	'dir.H350.dev.password' => [''],
	'dir.H350.dev.port' => ['0'],
	'dir.H350.dev.scope' => ['sub'],
	'dir.H350.dev.secCacheSize' => ['32'],
	'dir.H350.dev.sortControl' => ['0'],
	'dir.H350.dev.transport' => [''],
	'dir.H350.dev.user' => [''],
	'dir.H350.dev.utfSubset.1.start' => [''],
	'dir.H350.dev.utfSubset.1.stop' => [''],
	'dir.H350.dev.utfSubset.10.start' => [''],
	'dir.H350.dev.utfSubset.10.stop' => [''],
	'dir.H350.dev.utfSubset.11.start' => [''],
	'dir.H350.dev.utfSubset.11.stop' => [''],
	'dir.H350.dev.utfSubset.12.start' => [''],
	'dir.H350.dev.utfSubset.12.stop' => [''],
	'dir.H350.dev.utfSubset.13.start' => [''],
	'dir.H350.dev.utfSubset.13.stop' => [''],
	'dir.H350.dev.utfSubset.14.start' => [''],
	'dir.H350.dev.utfSubset.14.stop' => [''],
	'dir.H350.dev.utfSubset.15.start' => [''],
	'dir.H350.dev.utfSubset.15.stop' => [''],
	'dir.H350.dev.utfSubset.16.start' => [''],
	'dir.H350.dev.utfSubset.16.stop' => [''],
	'dir.H350.dev.utfSubset.17.start' => [''],
	'dir.H350.dev.utfSubset.17.stop' => [''],
	'dir.H350.dev.utfSubset.18.start' => [''],
	'dir.H350.dev.utfSubset.18.stop' => [''],
	'dir.H350.dev.utfSubset.19.start' => [''],
	'dir.H350.dev.utfSubset.19.stop' => [''],
	'dir.H350.dev.utfSubset.2.start' => [''],
	'dir.H350.dev.utfSubset.2.stop' => [''],
	'dir.H350.dev.utfSubset.20.start' => [''],
	'dir.H350.dev.utfSubset.20.stop' => [''],
	'dir.H350.dev.utfSubset.21.start' => [''],
	'dir.H350.dev.utfSubset.21.stop' => [''],
	'dir.H350.dev.utfSubset.22.start' => [''],
	'dir.H350.dev.utfSubset.22.stop' => [''],
	'dir.H350.dev.utfSubset.23.start' => [''],
	'dir.H350.dev.utfSubset.23.stop' => [''],
	'dir.H350.dev.utfSubset.24.start' => [''],
	'dir.H350.dev.utfSubset.24.stop' => [''],
	'dir.H350.dev.utfSubset.25.start' => [''],
	'dir.H350.dev.utfSubset.25.stop' => [''],
	'dir.H350.dev.utfSubset.26.start' => [''],
	'dir.H350.dev.utfSubset.26.stop' => [''],
	'dir.H350.dev.utfSubset.27.start' => [''],
	'dir.H350.dev.utfSubset.27.stop' => [''],
	'dir.H350.dev.utfSubset.28.start' => [''],
	'dir.H350.dev.utfSubset.28.stop' => [''],
	'dir.H350.dev.utfSubset.29.start' => [''],
	'dir.H350.dev.utfSubset.29.stop' => [''],
	'dir.H350.dev.utfSubset.3.start' => [''],
	'dir.H350.dev.utfSubset.3.stop' => [''],
	'dir.H350.dev.utfSubset.30.start' => [''],
	'dir.H350.dev.utfSubset.30.stop' => [''],
	'dir.H350.dev.utfSubset.31.start' => [''],
	'dir.H350.dev.utfSubset.31.stop' => [''],
	'dir.H350.dev.utfSubset.32.start' => [''],
	'dir.H350.dev.utfSubset.32.stop' => [''],
	'dir.H350.dev.utfSubset.4.start' => [''],
	'dir.H350.dev.utfSubset.4.stop' => [''],
	'dir.H350.dev.utfSubset.5.start' => [''],
	'dir.H350.dev.utfSubset.5.stop' => [''],
	'dir.H350.dev.utfSubset.6.start' => [''],
	'dir.H350.dev.utfSubset.6.stop' => [''],
	'dir.H350.dev.utfSubset.7.start' => [''],
	'dir.H350.dev.utfSubset.7.stop' => [''],
	'dir.H350.dev.utfSubset.8.start' => [''],
	'dir.H350.dev.utfSubset.8.stop' => [''],
	'dir.H350.dev.utfSubset.9.start' => [''],
	'dir.H350.dev.utfSubset.9.stop' => [''],
	'dir.H350.dev.verifyCert' => ['1'],
	'dir.H350.dev.viewPersistence' => ['0'],
	'dir.H350.dev.vlv.allow' => ['0'],
	'dir.H350.dev.vlv.sortOrder' => [''],
	'dir.H350.group.address' => [''],
	'dir.H350.group.attribute.1.filter' => [''],
	'dir.H350.group.attribute.1.label' => [''],
	'dir.H350.group.attribute.1.name' => [''],
	'dir.H350.group.attribute.1.searchable' => ['0'],
	'dir.H350.group.attribute.1.sticky' => ['0'],
	'dir.H350.group.attribute.1.type' => [''],
	'dir.H350.group.attribute.2.filter' => [''],
	'dir.H350.group.attribute.2.label' => [''],
	'dir.H350.group.attribute.2.name' => [''],
	'dir.H350.group.attribute.2.searchable' => ['0'],
	'dir.H350.group.attribute.2.sticky' => ['0'],
	'dir.H350.group.attribute.2.type' => [''],
	'dir.H350.group.attribute.3.filter' => [''],
	'dir.H350.group.attribute.3.label' => [''],
	'dir.H350.group.attribute.3.name' => [''],
	'dir.H350.group.attribute.3.searchable' => ['0'],
	'dir.H350.group.attribute.3.sticky' => ['0'],
	'dir.H350.group.attribute.3.type' => [''],
	'dir.H350.group.attribute.4.filter' => [''],
	'dir.H350.group.attribute.4.label' => [''],
	'dir.H350.group.attribute.4.name' => [''],
	'dir.H350.group.attribute.4.searchable' => ['0'],
	'dir.H350.group.attribute.4.sticky' => ['0'],
	'dir.H350.group.attribute.4.type' => [''],
	'dir.H350.group.attribute.5.filter' => [''],
	'dir.H350.group.attribute.5.label' => [''],
	'dir.H350.group.attribute.5.name' => [''],
	'dir.H350.group.attribute.5.searchable' => ['0'],
	'dir.H350.group.attribute.5.sticky' => ['0'],
	'dir.H350.group.attribute.5.type' => [''],
	'dir.H350.group.attribute.6.filter' => [''],
	'dir.H350.group.attribute.6.label' => [''],
	'dir.H350.group.attribute.6.name' => [''],
	'dir.H350.group.attribute.6.searchable' => ['0'],
	'dir.H350.group.attribute.6.sticky' => ['0'],
	'dir.H350.group.attribute.6.type' => [''],
	'dir.H350.group.attribute.7.filter' => [''],
	'dir.H350.group.attribute.7.label' => [''],
	'dir.H350.group.attribute.7.name' => [''],
	'dir.H350.group.attribute.7.searchable' => ['0'],
	'dir.H350.group.attribute.7.sticky' => ['0'],
	'dir.H350.group.attribute.7.type' => [''],
	'dir.H350.group.attribute.8.filter' => [''],
	'dir.H350.group.attribute.8.label' => [''],
	'dir.H350.group.attribute.8.name' => [''],
	'dir.H350.group.attribute.8.searchable' => ['0'],
	'dir.H350.group.attribute.8.sticky' => ['0'],
	'dir.H350.group.attribute.8.type' => [''],
	'dir.H350.group.auth.useLoginCredentials' => ['0'],
	'dir.H350.group.autoQuerySubmitTimeout' => ['0'],
	'dir.H350.group.backGroundSync' => ['0'],
	'dir.H350.group.backGroundSync.period' => ['86400'],
	'dir.H350.group.baseDN' => [''],
	'dir.H350.group.cacheSize' => ['128'],
	'dir.H350.group.domain' => [''],
	'dir.H350.group.filterPrefix' => [''],
	'dir.H350.group.pageSize' => ['32'],
	'dir.H350.group.password' => [''],
	'dir.H350.group.port' => ['0'],
	'dir.H350.group.query.AllMembers' => [''],
	'dir.H350.group.query.listAll' => [''],
	'dir.H350.group.query.memberSearch' => [''],
	'dir.H350.group.scope' => ['sub'],
	'dir.H350.group.secCacheSize' => ['32'],
	'dir.H350.group.sortControl' => ['0'],
	'dir.H350.group.transport' => [''],
	'dir.H350.group.user' => [''],
	'dir.H350.group.usersOnly' => [''],
	'dir.H350.group.utfSubset.1.start' => [''],
	'dir.H350.group.utfSubset.1.stop' => [''],
	'dir.H350.group.utfSubset.10.start' => [''],
	'dir.H350.group.utfSubset.10.stop' => [''],
	'dir.H350.group.utfSubset.11.start' => [''],
	'dir.H350.group.utfSubset.11.stop' => [''],
	'dir.H350.group.utfSubset.12.start' => [''],
	'dir.H350.group.utfSubset.12.stop' => [''],
	'dir.H350.group.utfSubset.13.start' => [''],
	'dir.H350.group.utfSubset.13.stop' => [''],
	'dir.H350.group.utfSubset.14.start' => [''],
	'dir.H350.group.utfSubset.14.stop' => [''],
	'dir.H350.group.utfSubset.15.start' => [''],
	'dir.H350.group.utfSubset.15.stop' => [''],
	'dir.H350.group.utfSubset.16.start' => [''],
	'dir.H350.group.utfSubset.16.stop' => [''],
	'dir.H350.group.utfSubset.17.start' => [''],
	'dir.H350.group.utfSubset.17.stop' => [''],
	'dir.H350.group.utfSubset.18.start' => [''],
	'dir.H350.group.utfSubset.18.stop' => [''],
	'dir.H350.group.utfSubset.19.start' => [''],
	'dir.H350.group.utfSubset.19.stop' => [''],
	'dir.H350.group.utfSubset.2.start' => [''],
	'dir.H350.group.utfSubset.2.stop' => [''],
	'dir.H350.group.utfSubset.20.start' => [''],
	'dir.H350.group.utfSubset.20.stop' => [''],
	'dir.H350.group.utfSubset.21.start' => [''],
	'dir.H350.group.utfSubset.21.stop' => [''],
	'dir.H350.group.utfSubset.22.start' => [''],
	'dir.H350.group.utfSubset.22.stop' => [''],
	'dir.H350.group.utfSubset.23.start' => [''],
	'dir.H350.group.utfSubset.23.stop' => [''],
	'dir.H350.group.utfSubset.24.start' => [''],
	'dir.H350.group.utfSubset.24.stop' => [''],
	'dir.H350.group.utfSubset.25.start' => [''],
	'dir.H350.group.utfSubset.25.stop' => [''],
	'dir.H350.group.utfSubset.26.start' => [''],
	'dir.H350.group.utfSubset.26.stop' => [''],
	'dir.H350.group.utfSubset.27.start' => [''],
	'dir.H350.group.utfSubset.27.stop' => [''],
	'dir.H350.group.utfSubset.28.start' => [''],
	'dir.H350.group.utfSubset.28.stop' => [''],
	'dir.H350.group.utfSubset.29.start' => [''],
	'dir.H350.group.utfSubset.29.stop' => [''],
	'dir.H350.group.utfSubset.3.start' => [''],
	'dir.H350.group.utfSubset.3.stop' => [''],
	'dir.H350.group.utfSubset.30.start' => [''],
	'dir.H350.group.utfSubset.30.stop' => [''],
	'dir.H350.group.utfSubset.31.start' => [''],
	'dir.H350.group.utfSubset.31.stop' => [''],
	'dir.H350.group.utfSubset.32.start' => [''],
	'dir.H350.group.utfSubset.32.stop' => [''],
	'dir.H350.group.utfSubset.4.start' => [''],
	'dir.H350.group.utfSubset.4.stop' => [''],
	'dir.H350.group.utfSubset.5.start' => [''],
	'dir.H350.group.utfSubset.5.stop' => [''],
	'dir.H350.group.utfSubset.6.start' => [''],
	'dir.H350.group.utfSubset.6.stop' => [''],
	'dir.H350.group.utfSubset.7.start' => [''],
	'dir.H350.group.utfSubset.7.stop' => [''],
	'dir.H350.group.utfSubset.8.start' => [''],
	'dir.H350.group.utfSubset.8.stop' => [''],
	'dir.H350.group.utfSubset.9.start' => [''],
	'dir.H350.group.utfSubset.9.stop' => [''],
	'dir.H350.group.verifyCert' => ['1'],
	'dir.H350.group.viewPersistence' => ['0'],
	'dir.H350.group.vlv.allow' => ['0'],
	'dir.H350.group.vlv.sortOrder' => [''],
	'dir.H350.person.address' => [''],
	'dir.H350.person.attribute.1.filter' => [''],
	'dir.H350.person.attribute.1.label' => [''],
	'dir.H350.person.attribute.1.name' => [''],
	'dir.H350.person.attribute.1.searchable' => ['0'],
	'dir.H350.person.attribute.1.sticky' => ['0'],
	'dir.H350.person.attribute.1.type' => [''],
	'dir.H350.person.attribute.2.filter' => [''],
	'dir.H350.person.attribute.2.label' => [''],
	'dir.H350.person.attribute.2.name' => [''],
	'dir.H350.person.attribute.2.searchable' => ['0'],
	'dir.H350.person.attribute.2.sticky' => ['0'],
	'dir.H350.person.attribute.2.type' => [''],
	'dir.H350.person.attribute.3.filter' => [''],
	'dir.H350.person.attribute.3.label' => [''],
	'dir.H350.person.attribute.3.name' => [''],
	'dir.H350.person.attribute.3.searchable' => ['0'],
	'dir.H350.person.attribute.3.sticky' => ['0'],
	'dir.H350.person.attribute.3.type' => [''],
	'dir.H350.person.attribute.4.filter' => [''],
	'dir.H350.person.attribute.4.label' => [''],
	'dir.H350.person.attribute.4.name' => [''],
	'dir.H350.person.attribute.4.searchable' => ['0'],
	'dir.H350.person.attribute.4.sticky' => ['0'],
	'dir.H350.person.attribute.4.type' => [''],
	'dir.H350.person.attribute.5.filter' => [''],
	'dir.H350.person.attribute.5.label' => [''],
	'dir.H350.person.attribute.5.name' => [''],
	'dir.H350.person.attribute.5.searchable' => ['0'],
	'dir.H350.person.attribute.5.sticky' => ['0'],
	'dir.H350.person.attribute.5.type' => [''],
	'dir.H350.person.attribute.6.filter' => [''],
	'dir.H350.person.attribute.6.label' => [''],
	'dir.H350.person.attribute.6.name' => [''],
	'dir.H350.person.attribute.6.searchable' => ['0'],
	'dir.H350.person.attribute.6.sticky' => ['0'],
	'dir.H350.person.attribute.6.type' => [''],
	'dir.H350.person.attribute.7.filter' => [''],
	'dir.H350.person.attribute.7.label' => [''],
	'dir.H350.person.attribute.7.name' => [''],
	'dir.H350.person.attribute.7.searchable' => ['0'],
	'dir.H350.person.attribute.7.sticky' => ['0'],
	'dir.H350.person.attribute.7.type' => [''],
	'dir.H350.person.attribute.8.filter' => [''],
	'dir.H350.person.attribute.8.label' => [''],
	'dir.H350.person.attribute.8.name' => [''],
	'dir.H350.person.attribute.8.searchable' => ['0'],
	'dir.H350.person.attribute.8.sticky' => ['0'],
	'dir.H350.person.attribute.8.type' => [''],
	'dir.H350.person.auth.useLoginCredentials' => ['0'],
	'dir.H350.person.autoQuerySubmitTimeout' => ['0'],
	'dir.H350.person.backGroundSync' => ['0'],
	'dir.H350.person.backGroundSync.period' => ['86400'],
	'dir.H350.person.baseDN' => [''],
	'dir.H350.person.cacheSize' => ['128'],
	'dir.H350.person.domain' => [''],
	'dir.H350.person.filterPrefix' => [''],
	'dir.H350.person.pageSize' => ['32'],
	'dir.H350.person.password' => [''],
	'dir.H350.person.port' => ['0'],
	'dir.H350.person.query.allUsers' => [''],
	'dir.H350.person.scope' => ['sub'],
	'dir.H350.person.secCacheSize' => ['32'],
	'dir.H350.person.sortControl' => ['0'],
	'dir.H350.person.transport' => [''],
	'dir.H350.person.user' => [''],
	'dir.H350.person.utfSubset.1.start' => [''],
	'dir.H350.person.utfSubset.1.stop' => [''],
	'dir.H350.person.utfSubset.10.start' => [''],
	'dir.H350.person.utfSubset.10.stop' => [''],
	'dir.H350.person.utfSubset.11.start' => [''],
	'dir.H350.person.utfSubset.11.stop' => [''],
	'dir.H350.person.utfSubset.12.start' => [''],
	'dir.H350.person.utfSubset.12.stop' => [''],
	'dir.H350.person.utfSubset.13.start' => [''],
	'dir.H350.person.utfSubset.13.stop' => [''],
	'dir.H350.person.utfSubset.14.start' => [''],
	'dir.H350.person.utfSubset.14.stop' => [''],
	'dir.H350.person.utfSubset.15.start' => [''],
	'dir.H350.person.utfSubset.15.stop' => [''],
	'dir.H350.person.utfSubset.16.start' => [''],
	'dir.H350.person.utfSubset.16.stop' => [''],
	'dir.H350.person.utfSubset.17.start' => [''],
	'dir.H350.person.utfSubset.17.stop' => [''],
	'dir.H350.person.utfSubset.18.start' => [''],
	'dir.H350.person.utfSubset.18.stop' => [''],
	'dir.H350.person.utfSubset.19.start' => [''],
	'dir.H350.person.utfSubset.19.stop' => [''],
	'dir.H350.person.utfSubset.2.start' => [''],
	'dir.H350.person.utfSubset.2.stop' => [''],
	'dir.H350.person.utfSubset.20.start' => [''],
	'dir.H350.person.utfSubset.20.stop' => [''],
	'dir.H350.person.utfSubset.21.start' => [''],
	'dir.H350.person.utfSubset.21.stop' => [''],
	'dir.H350.person.utfSubset.22.start' => [''],
	'dir.H350.person.utfSubset.22.stop' => [''],
	'dir.H350.person.utfSubset.23.start' => [''],
	'dir.H350.person.utfSubset.23.stop' => [''],
	'dir.H350.person.utfSubset.24.start' => [''],
	'dir.H350.person.utfSubset.24.stop' => [''],
	'dir.H350.person.utfSubset.25.start' => [''],
	'dir.H350.person.utfSubset.25.stop' => [''],
	'dir.H350.person.utfSubset.26.start' => [''],
	'dir.H350.person.utfSubset.26.stop' => [''],
	'dir.H350.person.utfSubset.27.start' => [''],
	'dir.H350.person.utfSubset.27.stop' => [''],
	'dir.H350.person.utfSubset.28.start' => [''],
	'dir.H350.person.utfSubset.28.stop' => [''],
	'dir.H350.person.utfSubset.29.start' => [''],
	'dir.H350.person.utfSubset.29.stop' => [''],
	'dir.H350.person.utfSubset.3.start' => [''],
	'dir.H350.person.utfSubset.3.stop' => [''],
	'dir.H350.person.utfSubset.30.start' => [''],
	'dir.H350.person.utfSubset.30.stop' => [''],
	'dir.H350.person.utfSubset.31.start' => [''],
	'dir.H350.person.utfSubset.31.stop' => [''],
	'dir.H350.person.utfSubset.32.start' => [''],
	'dir.H350.person.utfSubset.32.stop' => [''],
	'dir.H350.person.utfSubset.4.start' => [''],
	'dir.H350.person.utfSubset.4.stop' => [''],
	'dir.H350.person.utfSubset.5.start' => [''],
	'dir.H350.person.utfSubset.5.stop' => [''],
	'dir.H350.person.utfSubset.6.start' => [''],
	'dir.H350.person.utfSubset.6.stop' => [''],
	'dir.H350.person.utfSubset.7.start' => [''],
	'dir.H350.person.utfSubset.7.stop' => [''],
	'dir.H350.person.utfSubset.8.start' => [''],
	'dir.H350.person.utfSubset.8.stop' => [''],
	'dir.H350.person.utfSubset.9.start' => [''],
	'dir.H350.person.utfSubset.9.stop' => [''],
	'dir.H350.person.verifyCert' => ['1'],
	'dir.H350.person.viewPersistence' => ['0'],
	'dir.H350.person.vlv.allow' => ['0'],
	'dir.H350.person.vlv.sortOrder' => [''],
	'dir.corp.address' => [''],
	'dir.corp.attribute.1.filter' => [''],
	'dir.corp.attribute.1.label' => [''],
	'dir.corp.attribute.1.name' => [''],
	'dir.corp.attribute.1.searchable' => ['0'],
	'dir.corp.attribute.1.sticky' => ['0'],
	'dir.corp.attribute.1.type' => [''],
	'dir.corp.attribute.2.filter' => [''],
	'dir.corp.attribute.2.label' => [''],
	'dir.corp.attribute.2.name' => [''],
	'dir.corp.attribute.2.searchable' => ['0'],
	'dir.corp.attribute.2.sticky' => ['0'],
	'dir.corp.attribute.2.type' => [''],
	'dir.corp.attribute.3.filter' => [''],
	'dir.corp.attribute.3.label' => [''],
	'dir.corp.attribute.3.name' => [''],
	'dir.corp.attribute.3.searchable' => ['0'],
	'dir.corp.attribute.3.sticky' => ['0'],
	'dir.corp.attribute.3.type' => [''],
	'dir.corp.attribute.4.filter' => [''],
	'dir.corp.attribute.4.label' => [''],
	'dir.corp.attribute.4.name' => [''],
	'dir.corp.attribute.4.searchable' => ['0'],
	'dir.corp.attribute.4.sticky' => ['0'],
	'dir.corp.attribute.4.type' => [''],
	'dir.corp.attribute.5.filter' => [''],
	'dir.corp.attribute.5.label' => [''],
	'dir.corp.attribute.5.name' => [''],
	'dir.corp.attribute.5.searchable' => ['0'],
	'dir.corp.attribute.5.sticky' => ['0'],
	'dir.corp.attribute.5.type' => [''],
	'dir.corp.attribute.6.filter' => [''],
	'dir.corp.attribute.6.label' => [''],
	'dir.corp.attribute.6.name' => [''],
	'dir.corp.attribute.6.searchable' => ['0'],
	'dir.corp.attribute.6.sticky' => ['0'],
	'dir.corp.attribute.6.type' => [''],
	'dir.corp.attribute.7.filter' => [''],
	'dir.corp.attribute.7.label' => [''],
	'dir.corp.attribute.7.name' => [''],
	'dir.corp.attribute.7.searchable' => ['0'],
	'dir.corp.attribute.7.sticky' => ['0'],
	'dir.corp.attribute.7.type' => [''],
	'dir.corp.attribute.8.filter' => [''],
	'dir.corp.attribute.8.label' => [''],
	'dir.corp.attribute.8.name' => [''],
	'dir.corp.attribute.8.searchable' => ['0'],
	'dir.corp.attribute.8.sticky' => ['0'],
	'dir.corp.attribute.8.type' => [''],
	'dir.corp.auth.useLoginCredentials' => ['0'],
	'dir.corp.autoQuerySubmitTimeout' => ['0'],
	'dir.corp.backGroundSync' => ['0'],
	'dir.corp.backGroundSync.period' => ['86400', 300, 43200],
	'dir.corp.baseDN' => [''],
	'dir.corp.cacheSize' => ['128', 64],
	'dir.corp.domain' => [''],
	'dir.corp.filterPrefix' => ['(objectclass=person)'],
	'dir.corp.pageSize' => ['32', 16],
	'dir.corp.password' => [''],
	'dir.corp.port' => ['0'],
	'dir.corp.scope' => ['sub'],
	'dir.corp.secCacheSize' => ['32'],
	'dir.corp.sortControl' => ['0'],
	'dir.corp.transport' => [''],
	'dir.corp.user' => [''],
	'dir.corp.utfSubset.1.start' => [''],
	'dir.corp.utfSubset.1.stop' => [''],
	'dir.corp.utfSubset.10.start' => [''],
	'dir.corp.utfSubset.10.stop' => [''],
	'dir.corp.utfSubset.11.start' => [''],
	'dir.corp.utfSubset.11.stop' => [''],
	'dir.corp.utfSubset.12.start' => [''],
	'dir.corp.utfSubset.12.stop' => [''],
	'dir.corp.utfSubset.13.start' => [''],
	'dir.corp.utfSubset.13.stop' => [''],
	'dir.corp.utfSubset.14.start' => [''],
	'dir.corp.utfSubset.14.stop' => [''],
	'dir.corp.utfSubset.15.start' => [''],
	'dir.corp.utfSubset.15.stop' => [''],
	'dir.corp.utfSubset.16.start' => [''],
	'dir.corp.utfSubset.16.stop' => [''],
	'dir.corp.utfSubset.17.start' => [''],
	'dir.corp.utfSubset.17.stop' => [''],
	'dir.corp.utfSubset.18.start' => [''],
	'dir.corp.utfSubset.18.stop' => [''],
	'dir.corp.utfSubset.19.start' => [''],
	'dir.corp.utfSubset.19.stop' => [''],
	'dir.corp.utfSubset.2.start' => [''],
	'dir.corp.utfSubset.2.stop' => [''],
	'dir.corp.utfSubset.20.start' => [''],
	'dir.corp.utfSubset.20.stop' => [''],
	'dir.corp.utfSubset.21.start' => [''],
	'dir.corp.utfSubset.21.stop' => [''],
	'dir.corp.utfSubset.22.start' => [''],
	'dir.corp.utfSubset.22.stop' => [''],
	'dir.corp.utfSubset.23.start' => [''],
	'dir.corp.utfSubset.23.stop' => [''],
	'dir.corp.utfSubset.24.start' => [''],
	'dir.corp.utfSubset.24.stop' => [''],
	'dir.corp.utfSubset.25.start' => [''],
	'dir.corp.utfSubset.25.stop' => [''],
	'dir.corp.utfSubset.26.start' => [''],
	'dir.corp.utfSubset.26.stop' => [''],
	'dir.corp.utfSubset.27.start' => [''],
	'dir.corp.utfSubset.27.stop' => [''],
	'dir.corp.utfSubset.28.start' => [''],
	'dir.corp.utfSubset.28.stop' => [''],
	'dir.corp.utfSubset.29.start' => [''],
	'dir.corp.utfSubset.29.stop' => [''],
	'dir.corp.utfSubset.3.start' => [''],
	'dir.corp.utfSubset.3.stop' => [''],
	'dir.corp.utfSubset.30.start' => [''],
	'dir.corp.utfSubset.30.stop' => [''],
	'dir.corp.utfSubset.31.start' => [''],
	'dir.corp.utfSubset.31.stop' => [''],
	'dir.corp.utfSubset.32.start' => [''],
	'dir.corp.utfSubset.32.stop' => [''],
	'dir.corp.utfSubset.4.start' => [''],
	'dir.corp.utfSubset.4.stop' => [''],
	'dir.corp.utfSubset.5.start' => [''],
	'dir.corp.utfSubset.5.stop' => [''],
	'dir.corp.utfSubset.6.start' => [''],
	'dir.corp.utfSubset.6.stop' => [''],
	'dir.corp.utfSubset.7.start' => [''],
	'dir.corp.utfSubset.7.stop' => [''],
	'dir.corp.utfSubset.8.start' => [''],
	'dir.corp.utfSubset.8.stop' => [''],
	'dir.corp.utfSubset.9.start' => [''],
	'dir.corp.utfSubset.9.stop' => [''],
	'dir.corp.verifyCert' => ['1'],
	'dir.corp.viewPersistence' => ['0'],
	'dir.corp.vlv.allow' => ['0'],
	'dir.corp.vlv.sortOrder' => [''],
	'dir.local.contacts.maxNum' => ['9999'],
	'dir.local.contacts.maxNum.SPIP231' => ['99'],
	'dir.local.contacts.maxNum.SPIP235T' => ['99'],
	'dir.local.contacts.maxNum.SPIP320' => ['99'],
	'dir.local.contacts.maxNum.SPIP321' => ['99'],
	'dir.local.contacts.maxNum.SPIP330' => ['99'],
	'dir.local.contacts.maxNum.SPIP331' => ['99'],
	'dir.local.contacts.maxNum.SPIP335' => ['99'],
	'dir.local.contacts.maxNum.SSIP5000' => ['99'],
	'dir.local.contacts.maxNum.SSIP6000' => ['99'],
	'dir.local.contacts.maxNum.SSIP7000' => ['99'],
	'dir.local.nonVolatile.maxSize' => ['100'],
	'dir.local.nonVolatile.maxSize.SPIP320' => ['50'],
	'dir.local.nonVolatile.maxSize.SPIP330' => ['50'],
	'dir.local.readonly' => ['0'],
	'dir.local.volatile' => ['0'],
	'dir.local.volatile.maxSize' => ['200', 100],
	'dir.local.volatile.maxSize.SPIP320' => ['50'],
	'dir.local.volatile.maxSize.SPIP330' => ['50'],
	'dir.search.field' => ['0'],
	'divert.1.autoOnSpecificCaller' => ['1'],
	'divert.1.contact' => [''],
	'divert.1.sharedDisabled' => ['1'],
	'divert.10.autoOnSpecificCaller' => ['1'],
	'divert.10.contact' => [''],
	'divert.10.sharedDisabled' => ['1'],
	'divert.11.autoOnSpecificCaller' => ['1'],
	'divert.11.contact' => [''],
	'divert.11.sharedDisabled' => ['1'],
	'divert.12.autoOnSpecificCaller' => ['1'],
	'divert.12.contact' => [''],
	'divert.12.sharedDisabled' => ['1'],
	'divert.13.autoOnSpecificCaller' => ['1'],
	'divert.13.contact' => [''],
	'divert.13.sharedDisabled' => ['1'],
	'divert.14.autoOnSpecificCaller' => ['1'],
	'divert.14.contact' => [''],
	'divert.14.sharedDisabled' => ['1'],
	'divert.15.autoOnSpecificCaller' => ['1'],
	'divert.15.contact' => [''],
	'divert.15.sharedDisabled' => ['1'],
	'divert.16.autoOnSpecificCaller' => ['1'],
	'divert.16.contact' => [''],
	'divert.16.sharedDisabled' => ['1'],
	'divert.17.autoOnSpecificCaller' => ['1'],
	'divert.17.contact' => [''],
	'divert.17.sharedDisabled' => ['1'],
	'divert.18.autoOnSpecificCaller' => ['1'],
	'divert.18.contact' => [''],
	'divert.18.sharedDisabled' => ['1'],
	'divert.19.autoOnSpecificCaller' => ['1'],
	'divert.19.contact' => [''],
	'divert.19.sharedDisabled' => ['1'],
	'divert.2.autoOnSpecificCaller' => ['1'],
	'divert.2.contact' => [''],
	'divert.2.sharedDisabled' => ['1'],
	'divert.20.autoOnSpecificCaller' => ['1'],
	'divert.20.contact' => [''],
	'divert.20.sharedDisabled' => ['1'],
	'divert.21.autoOnSpecificCaller' => ['1'],
	'divert.21.contact' => [''],
	'divert.21.sharedDisabled' => ['1'],
	'divert.22.autoOnSpecificCaller' => ['1'],
	'divert.22.contact' => [''],
	'divert.22.sharedDisabled' => ['1'],
	'divert.23.autoOnSpecificCaller' => ['1'],
	'divert.23.contact' => [''],
	'divert.23.sharedDisabled' => ['1'],
	'divert.24.autoOnSpecificCaller' => ['1'],
	'divert.24.contact' => [''],
	'divert.24.sharedDisabled' => ['1'],
	'divert.25.autoOnSpecificCaller' => ['1'],
	'divert.25.contact' => [''],
	'divert.25.sharedDisabled' => ['1'],
	'divert.26.autoOnSpecificCaller' => ['1'],
	'divert.26.contact' => [''],
	'divert.26.sharedDisabled' => ['1'],
	'divert.27.autoOnSpecificCaller' => ['1'],
	'divert.27.contact' => [''],
	'divert.27.sharedDisabled' => ['1'],
	'divert.28.autoOnSpecificCaller' => ['1'],
	'divert.28.contact' => [''],
	'divert.28.sharedDisabled' => ['1'],
	'divert.29.autoOnSpecificCaller' => ['1'],
	'divert.29.contact' => [''],
	'divert.29.sharedDisabled' => ['1'],
	'divert.3.autoOnSpecificCaller' => ['1'],
	'divert.3.contact' => [''],
	'divert.3.sharedDisabled' => ['1'],
	'divert.30.autoOnSpecificCaller' => ['1'],
	'divert.30.contact' => [''],
	'divert.30.sharedDisabled' => ['1'],
	'divert.31.autoOnSpecificCaller' => ['1'],
	'divert.31.contact' => [''],
	'divert.31.sharedDisabled' => ['1'],
	'divert.32.autoOnSpecificCaller' => ['1'],
	'divert.32.contact' => [''],
	'divert.32.sharedDisabled' => ['1'],
	'divert.33.autoOnSpecificCaller' => ['1'],
	'divert.33.contact' => [''],
	'divert.33.sharedDisabled' => ['1'],
	'divert.34.autoOnSpecificCaller' => ['1'],
	'divert.34.contact' => [''],
	'divert.34.sharedDisabled' => ['1'],
	'divert.4.autoOnSpecificCaller' => ['1'],
	'divert.4.contact' => [''],
	'divert.4.sharedDisabled' => ['1'],
	'divert.5.autoOnSpecificCaller' => ['1'],
	'divert.5.contact' => [''],
	'divert.5.sharedDisabled' => ['1'],
	'divert.6.autoOnSpecificCaller' => ['1'],
	'divert.6.contact' => [''],
	'divert.6.sharedDisabled' => ['1'],
	'divert.7.autoOnSpecificCaller' => ['1'],
	'divert.7.contact' => [''],
	'divert.7.sharedDisabled' => ['1'],
	'divert.8.autoOnSpecificCaller' => ['1'],
	'divert.8.contact' => [''],
	'divert.8.sharedDisabled' => ['1'],
	'divert.9.autoOnSpecificCaller' => ['1'],
	'divert.9.contact' => [''],
	'divert.9.sharedDisabled' => ['1'],
	'divert.busy.1.contact' => [''],
	'divert.busy.1.enabled' => ['1'],
	'divert.busy.10.contact' => [''],
	'divert.busy.10.enabled' => ['1'],
	'divert.busy.11.contact' => [''],
	'divert.busy.11.enabled' => ['1'],
	'divert.busy.12.contact' => [''],
	'divert.busy.12.enabled' => ['1'],
	'divert.busy.13.contact' => [''],
	'divert.busy.13.enabled' => ['1'],
	'divert.busy.14.contact' => [''],
	'divert.busy.14.enabled' => ['1'],
	'divert.busy.15.contact' => [''],
	'divert.busy.15.enabled' => ['1'],
	'divert.busy.16.contact' => [''],
	'divert.busy.16.enabled' => ['1'],
	'divert.busy.17.contact' => [''],
	'divert.busy.17.enabled' => ['1'],
	'divert.busy.18.contact' => [''],
	'divert.busy.18.enabled' => ['1'],
	'divert.busy.19.contact' => [''],
	'divert.busy.19.enabled' => ['1'],
	'divert.busy.2.contact' => [''],
	'divert.busy.2.enabled' => ['1'],
	'divert.busy.20.contact' => [''],
	'divert.busy.20.enabled' => ['1'],
	'divert.busy.21.contact' => [''],
	'divert.busy.21.enabled' => ['1'],
	'divert.busy.22.contact' => [''],
	'divert.busy.22.enabled' => ['1'],
	'divert.busy.23.contact' => [''],
	'divert.busy.23.enabled' => ['1'],
	'divert.busy.24.contact' => [''],
	'divert.busy.24.enabled' => ['1'],
	'divert.busy.25.contact' => [''],
	'divert.busy.25.enabled' => ['1'],
	'divert.busy.26.contact' => [''],
	'divert.busy.26.enabled' => ['1'],
	'divert.busy.27.contact' => [''],
	'divert.busy.27.enabled' => ['1'],
	'divert.busy.28.contact' => [''],
	'divert.busy.28.enabled' => ['1'],
	'divert.busy.29.contact' => [''],
	'divert.busy.29.enabled' => ['1'],
	'divert.busy.3.contact' => [''],
	'divert.busy.3.enabled' => ['1'],
	'divert.busy.30.contact' => [''],
	'divert.busy.30.enabled' => ['1'],
	'divert.busy.31.contact' => [''],
	'divert.busy.31.enabled' => ['1'],
	'divert.busy.32.contact' => [''],
	'divert.busy.32.enabled' => ['1'],
	'divert.busy.33.contact' => [''],
	'divert.busy.33.enabled' => ['1'],
	'divert.busy.34.contact' => [''],
	'divert.busy.34.enabled' => ['1'],
	'divert.busy.4.contact' => [''],
	'divert.busy.4.enabled' => ['1'],
	'divert.busy.5.contact' => [''],
	'divert.busy.5.enabled' => ['1'],
	'divert.busy.6.contact' => [''],
	'divert.busy.6.enabled' => ['1'],
	'divert.busy.7.contact' => [''],
	'divert.busy.7.enabled' => ['1'],
	'divert.busy.8.contact' => [''],
	'divert.busy.8.enabled' => ['1'],
	'divert.busy.9.contact' => [''],
	'divert.busy.9.enabled' => ['1'],
	'divert.dnd.1.contact' => [''],
	'divert.dnd.1.enabled' => ['0'],
	'divert.dnd.10.contact' => [''],
	'divert.dnd.10.enabled' => ['0'],
	'divert.dnd.11.contact' => [''],
	'divert.dnd.11.enabled' => ['0'],
	'divert.dnd.12.contact' => [''],
	'divert.dnd.12.enabled' => ['0'],
	'divert.dnd.13.contact' => [''],
	'divert.dnd.13.enabled' => ['0'],
	'divert.dnd.14.contact' => [''],
	'divert.dnd.14.enabled' => ['0'],
	'divert.dnd.15.contact' => [''],
	'divert.dnd.15.enabled' => ['0'],
	'divert.dnd.16.contact' => [''],
	'divert.dnd.16.enabled' => ['0'],
	'divert.dnd.17.contact' => [''],
	'divert.dnd.17.enabled' => ['0'],
	'divert.dnd.18.contact' => [''],
	'divert.dnd.18.enabled' => ['0'],
	'divert.dnd.19.contact' => [''],
	'divert.dnd.19.enabled' => ['0'],
	'divert.dnd.2.contact' => [''],
	'divert.dnd.2.enabled' => ['0'],
	'divert.dnd.20.contact' => [''],
	'divert.dnd.20.enabled' => ['0'],
	'divert.dnd.21.contact' => [''],
	'divert.dnd.21.enabled' => ['0'],
	'divert.dnd.22.contact' => [''],
	'divert.dnd.22.enabled' => ['0'],
	'divert.dnd.23.contact' => [''],
	'divert.dnd.23.enabled' => ['0'],
	'divert.dnd.24.contact' => [''],
	'divert.dnd.24.enabled' => ['0'],
	'divert.dnd.25.contact' => [''],
	'divert.dnd.25.enabled' => ['0'],
	'divert.dnd.26.contact' => [''],
	'divert.dnd.26.enabled' => ['0'],
	'divert.dnd.27.contact' => [''],
	'divert.dnd.27.enabled' => ['0'],
	'divert.dnd.28.contact' => [''],
	'divert.dnd.28.enabled' => ['0'],
	'divert.dnd.29.contact' => [''],
	'divert.dnd.29.enabled' => ['0'],
	'divert.dnd.3.contact' => [''],
	'divert.dnd.3.enabled' => ['0'],
	'divert.dnd.30.contact' => [''],
	'divert.dnd.30.enabled' => ['0'],
	'divert.dnd.31.contact' => [''],
	'divert.dnd.31.enabled' => ['0'],
	'divert.dnd.32.contact' => [''],
	'divert.dnd.32.enabled' => ['0'],
	'divert.dnd.33.contact' => [''],
	'divert.dnd.33.enabled' => ['0'],
	'divert.dnd.34.contact' => [''],
	'divert.dnd.34.enabled' => ['0'],
	'divert.dnd.4.contact' => [''],
	'divert.dnd.4.enabled' => ['0'],
	'divert.dnd.5.contact' => [''],
	'divert.dnd.5.enabled' => ['0'],
	'divert.dnd.6.contact' => [''],
	'divert.dnd.6.enabled' => ['0'],
	'divert.dnd.7.contact' => [''],
	'divert.dnd.7.enabled' => ['0'],
	'divert.dnd.8.contact' => [''],
	'divert.dnd.8.enabled' => ['0'],
	'divert.dnd.9.contact' => [''],
	'divert.dnd.9.enabled' => ['0'],
	'divert.fwd.1.enabled' => ['1'],
	'divert.fwd.10.enabled' => ['1'],
	'divert.fwd.11.enabled' => ['1'],
	'divert.fwd.12.enabled' => ['1'],
	'divert.fwd.13.enabled' => ['1'],
	'divert.fwd.14.enabled' => ['1'],
	'divert.fwd.15.enabled' => ['1'],
	'divert.fwd.16.enabled' => ['1'],
	'divert.fwd.17.enabled' => ['1'],
	'divert.fwd.18.enabled' => ['1'],
	'divert.fwd.19.enabled' => ['1'],
	'divert.fwd.2.enabled' => ['1'],
	'divert.fwd.20.enabled' => ['1'],
	'divert.fwd.21.enabled' => ['1'],
	'divert.fwd.22.enabled' => ['1'],
	'divert.fwd.23.enabled' => ['1'],
	'divert.fwd.24.enabled' => ['1'],
	'divert.fwd.25.enabled' => ['1'],
	'divert.fwd.26.enabled' => ['1'],
	'divert.fwd.27.enabled' => ['1'],
	'divert.fwd.28.enabled' => ['1'],
	'divert.fwd.29.enabled' => ['1'],
	'divert.fwd.3.enabled' => ['1'],
	'divert.fwd.30.enabled' => ['1'],
	'divert.fwd.31.enabled' => ['1'],
	'divert.fwd.32.enabled' => ['1'],
	'divert.fwd.33.enabled' => ['1'],
	'divert.fwd.34.enabled' => ['1'],
	'divert.fwd.4.enabled' => ['1'],
	'divert.fwd.5.enabled' => ['1'],
	'divert.fwd.6.enabled' => ['1'],
	'divert.fwd.7.enabled' => ['1'],
	'divert.fwd.8.enabled' => ['1'],
	'divert.fwd.9.enabled' => ['1'],
	'divert.noanswer.1.contact' => [''],
	'divert.noanswer.1.enabled' => ['1'],
	'divert.noanswer.1.timeout' => ['55', '60' ],
	'divert.noanswer.10.contact' => [''],
	'divert.noanswer.10.enabled' => ['1'],
	'divert.noanswer.10.timeout' => ['55', '60' ],
	'divert.noanswer.11.contact' => [''],
	'divert.noanswer.11.enabled' => ['1'],
	'divert.noanswer.11.timeout' => ['55', '60' ],
	'divert.noanswer.12.contact' => [''],
	'divert.noanswer.12.enabled' => ['1'],
	'divert.noanswer.12.timeout' => ['55', '60' ],
	'divert.noanswer.13.contact' => [''],
	'divert.noanswer.13.enabled' => ['1'],
	'divert.noanswer.13.timeout' => ['55', '60' ],
	'divert.noanswer.14.contact' => [''],
	'divert.noanswer.14.enabled' => ['1'],
	'divert.noanswer.14.timeout' => ['55', '60' ],
	'divert.noanswer.15.contact' => [''],
	'divert.noanswer.15.enabled' => ['1'],
	'divert.noanswer.15.timeout' => ['55', '60' ],
	'divert.noanswer.16.contact' => [''],
	'divert.noanswer.16.enabled' => ['1'],
	'divert.noanswer.16.timeout' => ['55', '60' ],
	'divert.noanswer.17.contact' => [''],
	'divert.noanswer.17.enabled' => ['1'],
	'divert.noanswer.17.timeout' => ['55', '60' ],
	'divert.noanswer.18.contact' => [''],
	'divert.noanswer.18.enabled' => ['1'],
	'divert.noanswer.18.timeout' => ['55', '60' ],
	'divert.noanswer.19.contact' => [''],
	'divert.noanswer.19.enabled' => ['1'],
	'divert.noanswer.19.timeout' => ['55', '60' ],
	'divert.noanswer.2.contact' => [''],
	'divert.noanswer.2.enabled' => ['1'],
	'divert.noanswer.2.timeout' => ['55', '60' ],
	'divert.noanswer.20.contact' => [''],
	'divert.noanswer.20.enabled' => ['1'],
	'divert.noanswer.20.timeout' => ['55', '60' ],
	'divert.noanswer.21.contact' => [''],
	'divert.noanswer.21.enabled' => ['1'],
	'divert.noanswer.21.timeout' => ['55', '60' ],
	'divert.noanswer.22.contact' => [''],
	'divert.noanswer.22.enabled' => ['1'],
	'divert.noanswer.22.timeout' => ['55', '60' ],
	'divert.noanswer.23.contact' => [''],
	'divert.noanswer.23.enabled' => ['1'],
	'divert.noanswer.23.timeout' => ['55', '60' ],
	'divert.noanswer.24.contact' => [''],
	'divert.noanswer.24.enabled' => ['1'],
	'divert.noanswer.24.timeout' => ['55', '60' ],
	'divert.noanswer.25.contact' => [''],
	'divert.noanswer.25.enabled' => ['1'],
	'divert.noanswer.25.timeout' => ['55', '60' ],
	'divert.noanswer.26.contact' => [''],
	'divert.noanswer.26.enabled' => ['1'],
	'divert.noanswer.26.timeout' => ['55', '60' ],
	'divert.noanswer.27.contact' => [''],
	'divert.noanswer.27.enabled' => ['1'],
	'divert.noanswer.27.timeout' => ['55', '60' ],
	'divert.noanswer.28.contact' => [''],
	'divert.noanswer.28.enabled' => ['1'],
	'divert.noanswer.28.timeout' => ['55', '60' ],
	'divert.noanswer.29.contact' => [''],
	'divert.noanswer.29.enabled' => ['1'],
	'divert.noanswer.29.timeout' => ['55', '60' ],
	'divert.noanswer.3.contact' => [''],
	'divert.noanswer.3.enabled' => ['1'],
	'divert.noanswer.3.timeout' => ['55', '60' ],
	'divert.noanswer.30.contact' => [''],
	'divert.noanswer.30.enabled' => ['1'],
	'divert.noanswer.30.timeout' => ['55', '60' ],
	'divert.noanswer.31.contact' => [''],
	'divert.noanswer.31.enabled' => ['1'],
	'divert.noanswer.31.timeout' => ['55', '60' ],
	'divert.noanswer.32.contact' => [''],
	'divert.noanswer.32.enabled' => ['1'],
	'divert.noanswer.32.timeout' => ['55', '60' ],
	'divert.noanswer.33.contact' => [''],
	'divert.noanswer.33.enabled' => ['1'],
	'divert.noanswer.33.timeout' => ['55', '60' ],
	'divert.noanswer.34.contact' => [''],
	'divert.noanswer.34.enabled' => ['1'],
	'divert.noanswer.34.timeout' => ['55', '60' ],
	'divert.noanswer.4.contact' => [''],
	'divert.noanswer.4.enabled' => ['1'],
	'divert.noanswer.4.timeout' => ['55', '60' ],
	'divert.noanswer.5.contact' => [''],
	'divert.noanswer.5.enabled' => ['1'],
	'divert.noanswer.5.timeout' => ['55', '60' ],
	'divert.noanswer.6.contact' => [''],
	'divert.noanswer.6.enabled' => ['1'],
	'divert.noanswer.6.timeout' => ['55', '60' ],
	'divert.noanswer.7.contact' => [''],
	'divert.noanswer.7.enabled' => ['1'],
	'divert.noanswer.7.timeout' => ['55', '60' ],
	'divert.noanswer.8.contact' => [''],
	'divert.noanswer.8.enabled' => ['1'],
	'divert.noanswer.8.timeout' => ['55', '60' ],
	'divert.noanswer.9.contact' => [''],
	'divert.noanswer.9.enabled' => ['1'],
	'divert.noanswer.9.timeout' => ['55', '60' ],
	'dns.cache.A.1.address' => [''],
	'dns.cache.A.1.name' => [''],
	'dns.cache.A.1.ttl' => ['300'],
	'dns.cache.A.10.address' => [''],
	'dns.cache.A.10.name' => [''],
	'dns.cache.A.10.ttl' => ['300'],
	'dns.cache.A.11.address' => [''],
	'dns.cache.A.11.name' => [''],
	'dns.cache.A.11.ttl' => ['300'],
	'dns.cache.A.12.address' => [''],
	'dns.cache.A.12.name' => [''],
	'dns.cache.A.12.ttl' => ['300'],
	'dns.cache.A.2.address' => [''],
	'dns.cache.A.2.name' => [''],
	'dns.cache.A.2.ttl' => ['300'],
	'dns.cache.A.3.address' => [''],
	'dns.cache.A.3.name' => [''],
	'dns.cache.A.3.ttl' => ['300'],
	'dns.cache.A.4.address' => [''],
	'dns.cache.A.4.name' => [''],
	'dns.cache.A.4.ttl' => ['300'],
	'dns.cache.A.5.address' => [''],
	'dns.cache.A.5.name' => [''],
	'dns.cache.A.5.ttl' => ['300'],
	'dns.cache.A.6.address' => [''],
	'dns.cache.A.6.name' => [''],
	'dns.cache.A.6.ttl' => ['300'],
	'dns.cache.A.7.address' => [''],
	'dns.cache.A.7.name' => [''],
	'dns.cache.A.7.ttl' => ['300'],
	'dns.cache.A.8.address' => [''],
	'dns.cache.A.8.name' => [''],
	'dns.cache.A.8.ttl' => ['300'],
	'dns.cache.A.9.address' => [''],
	'dns.cache.A.9.name' => [''],
	'dns.cache.A.9.ttl' => ['300'],
	'dns.cache.NAPTR.1.flags' => [''],
	'dns.cache.NAPTR.1.name' => [''],
	'dns.cache.NAPTR.1.order' => ['0'],
	'dns.cache.NAPTR.1.preference' => ['0'],
	'dns.cache.NAPTR.1.regexp' => [''],
	'dns.cache.NAPTR.1.replacement' => [''],
	'dns.cache.NAPTR.1.service' => [''],
	'dns.cache.NAPTR.1.ttl' => ['300'],
	'dns.cache.NAPTR.10.flags' => [''],
	'dns.cache.NAPTR.10.name' => [''],
	'dns.cache.NAPTR.10.order' => ['0'],
	'dns.cache.NAPTR.10.preference' => ['0'],
	'dns.cache.NAPTR.10.regexp' => [''],
	'dns.cache.NAPTR.10.replacement' => [''],
	'dns.cache.NAPTR.10.service' => [''],
	'dns.cache.NAPTR.10.ttl' => ['300'],
	'dns.cache.NAPTR.11.flags' => [''],
	'dns.cache.NAPTR.11.name' => [''],
	'dns.cache.NAPTR.11.order' => ['0'],
	'dns.cache.NAPTR.11.preference' => ['0'],
	'dns.cache.NAPTR.11.regexp' => [''],
	'dns.cache.NAPTR.11.replacement' => [''],
	'dns.cache.NAPTR.11.service' => [''],
	'dns.cache.NAPTR.11.ttl' => ['300'],
	'dns.cache.NAPTR.12.flags' => [''],
	'dns.cache.NAPTR.12.name' => [''],
	'dns.cache.NAPTR.12.order' => ['0'],
	'dns.cache.NAPTR.12.preference' => ['0'],
	'dns.cache.NAPTR.12.regexp' => [''],
	'dns.cache.NAPTR.12.replacement' => [''],
	'dns.cache.NAPTR.12.service' => [''],
	'dns.cache.NAPTR.12.ttl' => ['300'],
	'dns.cache.NAPTR.2.flags' => [''],
	'dns.cache.NAPTR.2.name' => [''],
	'dns.cache.NAPTR.2.order' => ['0'],
	'dns.cache.NAPTR.2.preference' => ['0'],
	'dns.cache.NAPTR.2.regexp' => [''],
	'dns.cache.NAPTR.2.replacement' => [''],
	'dns.cache.NAPTR.2.service' => [''],
	'dns.cache.NAPTR.2.ttl' => ['300'],
	'dns.cache.NAPTR.3.flags' => [''],
	'dns.cache.NAPTR.3.name' => [''],
	'dns.cache.NAPTR.3.order' => ['0'],
	'dns.cache.NAPTR.3.preference' => ['0'],
	'dns.cache.NAPTR.3.regexp' => [''],
	'dns.cache.NAPTR.3.replacement' => [''],
	'dns.cache.NAPTR.3.service' => [''],
	'dns.cache.NAPTR.3.ttl' => ['300'],
	'dns.cache.NAPTR.4.flags' => [''],
	'dns.cache.NAPTR.4.name' => [''],
	'dns.cache.NAPTR.4.order' => ['0'],
	'dns.cache.NAPTR.4.preference' => ['0'],
	'dns.cache.NAPTR.4.regexp' => [''],
	'dns.cache.NAPTR.4.replacement' => [''],
	'dns.cache.NAPTR.4.service' => [''],
	'dns.cache.NAPTR.4.ttl' => ['300'],
	'dns.cache.NAPTR.5.flags' => [''],
	'dns.cache.NAPTR.5.name' => [''],
	'dns.cache.NAPTR.5.order' => ['0'],
	'dns.cache.NAPTR.5.preference' => ['0'],
	'dns.cache.NAPTR.5.regexp' => [''],
	'dns.cache.NAPTR.5.replacement' => [''],
	'dns.cache.NAPTR.5.service' => [''],
	'dns.cache.NAPTR.5.ttl' => ['300'],
	'dns.cache.NAPTR.6.flags' => [''],
	'dns.cache.NAPTR.6.name' => [''],
	'dns.cache.NAPTR.6.order' => ['0'],
	'dns.cache.NAPTR.6.preference' => ['0'],
	'dns.cache.NAPTR.6.regexp' => [''],
	'dns.cache.NAPTR.6.replacement' => [''],
	'dns.cache.NAPTR.6.service' => [''],
	'dns.cache.NAPTR.6.ttl' => ['300'],
	'dns.cache.NAPTR.7.flags' => [''],
	'dns.cache.NAPTR.7.name' => [''],
	'dns.cache.NAPTR.7.order' => ['0'],
	'dns.cache.NAPTR.7.preference' => ['0'],
	'dns.cache.NAPTR.7.regexp' => [''],
	'dns.cache.NAPTR.7.replacement' => [''],
	'dns.cache.NAPTR.7.service' => [''],
	'dns.cache.NAPTR.7.ttl' => ['300'],
	'dns.cache.NAPTR.8.flags' => [''],
	'dns.cache.NAPTR.8.name' => [''],
	'dns.cache.NAPTR.8.order' => ['0'],
	'dns.cache.NAPTR.8.preference' => ['0'],
	'dns.cache.NAPTR.8.regexp' => [''],
	'dns.cache.NAPTR.8.replacement' => [''],
	'dns.cache.NAPTR.8.service' => [''],
	'dns.cache.NAPTR.8.ttl' => ['300'],
	'dns.cache.NAPTR.9.flags' => [''],
	'dns.cache.NAPTR.9.name' => [''],
	'dns.cache.NAPTR.9.order' => ['0'],
	'dns.cache.NAPTR.9.preference' => ['0'],
	'dns.cache.NAPTR.9.regexp' => [''],
	'dns.cache.NAPTR.9.replacement' => [''],
	'dns.cache.NAPTR.9.service' => [''],
	'dns.cache.NAPTR.9.ttl' => ['300'],
	'dns.cache.SRV.1.name' => [''],
	'dns.cache.SRV.1.port' => ['0'],
	'dns.cache.SRV.1.priority' => ['0'],
	'dns.cache.SRV.1.target' => [''],
	'dns.cache.SRV.1.ttl' => ['300'],
	'dns.cache.SRV.1.weight' => ['0'],
	'dns.cache.SRV.10.name' => [''],
	'dns.cache.SRV.10.port' => ['0'],
	'dns.cache.SRV.10.priority' => ['0'],
	'dns.cache.SRV.10.target' => [''],
	'dns.cache.SRV.10.ttl' => ['300'],
	'dns.cache.SRV.10.weight' => ['0'],
	'dns.cache.SRV.11.name' => [''],
	'dns.cache.SRV.11.port' => ['0'],
	'dns.cache.SRV.11.priority' => ['0'],
	'dns.cache.SRV.11.target' => [''],
	'dns.cache.SRV.11.ttl' => ['300'],
	'dns.cache.SRV.11.weight' => ['0'],
	'dns.cache.SRV.12.name' => [''],
	'dns.cache.SRV.12.port' => ['0'],
	'dns.cache.SRV.12.priority' => ['0'],
	'dns.cache.SRV.12.target' => [''],
	'dns.cache.SRV.12.ttl' => ['300'],
	'dns.cache.SRV.12.weight' => ['0'],
	'dns.cache.SRV.2.name' => [''],
	'dns.cache.SRV.2.port' => ['0'],
	'dns.cache.SRV.2.priority' => ['0'],
	'dns.cache.SRV.2.target' => [''],
	'dns.cache.SRV.2.ttl' => ['300'],
	'dns.cache.SRV.2.weight' => ['0'],
	'dns.cache.SRV.3.name' => [''],
	'dns.cache.SRV.3.port' => ['0'],
	'dns.cache.SRV.3.priority' => ['0'],
	'dns.cache.SRV.3.target' => [''],
	'dns.cache.SRV.3.ttl' => ['300'],
	'dns.cache.SRV.3.weight' => ['0'],
	'dns.cache.SRV.4.name' => [''],
	'dns.cache.SRV.4.port' => ['0'],
	'dns.cache.SRV.4.priority' => ['0'],
	'dns.cache.SRV.4.target' => [''],
	'dns.cache.SRV.4.ttl' => ['300'],
	'dns.cache.SRV.4.weight' => ['0'],
	'dns.cache.SRV.5.name' => [''],
	'dns.cache.SRV.5.port' => ['0'],
	'dns.cache.SRV.5.priority' => ['0'],
	'dns.cache.SRV.5.target' => [''],
	'dns.cache.SRV.5.ttl' => ['300'],
	'dns.cache.SRV.5.weight' => ['0'],
	'dns.cache.SRV.6.name' => [''],
	'dns.cache.SRV.6.port' => ['0'],
	'dns.cache.SRV.6.priority' => ['0'],
	'dns.cache.SRV.6.target' => [''],
	'dns.cache.SRV.6.ttl' => ['300'],
	'dns.cache.SRV.6.weight' => ['0'],
	'dns.cache.SRV.7.name' => [''],
	'dns.cache.SRV.7.port' => ['0'],
	'dns.cache.SRV.7.priority' => ['0'],
	'dns.cache.SRV.7.target' => [''],
	'dns.cache.SRV.7.ttl' => ['300'],
	'dns.cache.SRV.7.weight' => ['0'],
	'dns.cache.SRV.8.name' => [''],
	'dns.cache.SRV.8.port' => ['0'],
	'dns.cache.SRV.8.priority' => ['0'],
	'dns.cache.SRV.8.target' => [''],
	'dns.cache.SRV.8.ttl' => ['300'],
	'dns.cache.SRV.8.weight' => ['0'],
	'dns.cache.SRV.9.name' => [''],
	'dns.cache.SRV.9.port' => ['0'],
	'dns.cache.SRV.9.priority' => ['0'],
	'dns.cache.SRV.9.target' => [''],
	'dns.cache.SRV.9.ttl' => ['300'],
	'dns.cache.SRV.9.weight' => ['0'],
	'efk.efklist.1.action.string' => [''],
	'efk.efklist.1.label' => [''],
	'efk.efklist.1.mname' => ['expanded_macro'],
	'efk.efklist.1.status' => ['0'],
	'efk.efklist.1.type' => ['invite'],
	'efk.efklist.10.action.string' => [''],
	'efk.efklist.10.label' => [''],
	'efk.efklist.10.mname' => ['expanded_macro'],
	'efk.efklist.10.status' => ['0'],
	'efk.efklist.10.type' => ['invite'],
	'efk.efklist.11.action.string' => [''],
	'efk.efklist.11.label' => [''],
	'efk.efklist.11.mname' => ['expanded_macro'],
	'efk.efklist.11.status' => ['0'],
	'efk.efklist.11.type' => ['invite'],
	'efk.efklist.12.action.string' => [''],
	'efk.efklist.12.label' => [''],
	'efk.efklist.12.mname' => ['expanded_macro'],
	'efk.efklist.12.status' => ['0'],
	'efk.efklist.12.type' => ['invite'],
	'efk.efklist.13.action.string' => [''],
	'efk.efklist.13.label' => [''],
	'efk.efklist.13.mname' => ['expanded_macro'],
	'efk.efklist.13.status' => ['0'],
	'efk.efklist.13.type' => ['invite'],
	'efk.efklist.14.action.string' => [''],
	'efk.efklist.14.label' => [''],
	'efk.efklist.14.mname' => ['expanded_macro'],
	'efk.efklist.14.status' => ['0'],
	'efk.efklist.14.type' => ['invite'],
	'efk.efklist.15.action.string' => [''],
	'efk.efklist.15.label' => [''],
	'efk.efklist.15.mname' => ['expanded_macro'],
	'efk.efklist.15.status' => ['0'],
	'efk.efklist.15.type' => ['invite'],
	'efk.efklist.16.action.string' => [''],
	'efk.efklist.16.label' => [''],
	'efk.efklist.16.mname' => ['expanded_macro'],
	'efk.efklist.16.status' => ['0'],
	'efk.efklist.16.type' => ['invite'],
	'efk.efklist.17.action.string' => [''],
	'efk.efklist.17.label' => [''],
	'efk.efklist.17.mname' => ['expanded_macro'],
	'efk.efklist.17.status' => ['0'],
	'efk.efklist.17.type' => ['invite'],
	'efk.efklist.18.action.string' => [''],
	'efk.efklist.18.label' => [''],
	'efk.efklist.18.mname' => ['expanded_macro'],
	'efk.efklist.18.status' => ['0'],
	'efk.efklist.18.type' => ['invite'],
	'efk.efklist.19.action.string' => [''],
	'efk.efklist.19.label' => [''],
	'efk.efklist.19.mname' => ['expanded_macro'],
	'efk.efklist.19.status' => ['0'],
	'efk.efklist.19.type' => ['invite'],
	'efk.efklist.2.action.string' => [''],
	'efk.efklist.2.label' => [''],
	'efk.efklist.2.mname' => ['expanded_macro'],
	'efk.efklist.2.status' => ['0'],
	'efk.efklist.2.type' => ['invite'],
	'efk.efklist.20.action.string' => [''],
	'efk.efklist.20.label' => [''],
	'efk.efklist.20.mname' => ['expanded_macro'],
	'efk.efklist.20.status' => ['0'],
	'efk.efklist.20.type' => ['invite'],
	'efk.efklist.21.action.string' => [''],
	'efk.efklist.21.label' => [''],
	'efk.efklist.21.mname' => ['expanded_macro'],
	'efk.efklist.21.status' => ['0'],
	'efk.efklist.21.type' => ['invite'],
	'efk.efklist.22.action.string' => [''],
	'efk.efklist.22.label' => [''],
	'efk.efklist.22.mname' => ['expanded_macro'],
	'efk.efklist.22.status' => ['0'],
	'efk.efklist.22.type' => ['invite'],
	'efk.efklist.23.action.string' => [''],
	'efk.efklist.23.label' => [''],
	'efk.efklist.23.mname' => ['expanded_macro'],
	'efk.efklist.23.status' => ['0'],
	'efk.efklist.23.type' => ['invite'],
	'efk.efklist.24.action.string' => [''],
	'efk.efklist.24.label' => [''],
	'efk.efklist.24.mname' => ['expanded_macro'],
	'efk.efklist.24.status' => ['0'],
	'efk.efklist.24.type' => ['invite'],
	'efk.efklist.25.action.string' => [''],
	'efk.efklist.25.label' => [''],
	'efk.efklist.25.mname' => ['expanded_macro'],
	'efk.efklist.25.status' => ['0'],
	'efk.efklist.25.type' => ['invite'],
	'efk.efklist.26.action.string' => [''],
	'efk.efklist.26.label' => [''],
	'efk.efklist.26.mname' => ['expanded_macro'],
	'efk.efklist.26.status' => ['0'],
	'efk.efklist.26.type' => ['invite'],
	'efk.efklist.27.action.string' => [''],
	'efk.efklist.27.label' => [''],
	'efk.efklist.27.mname' => ['expanded_macro'],
	'efk.efklist.27.status' => ['0'],
	'efk.efklist.27.type' => ['invite'],
	'efk.efklist.28.action.string' => [''],
	'efk.efklist.28.label' => [''],
	'efk.efklist.28.mname' => ['expanded_macro'],
	'efk.efklist.28.status' => ['0'],
	'efk.efklist.28.type' => ['invite'],
	'efk.efklist.29.action.string' => [''],
	'efk.efklist.29.label' => [''],
	'efk.efklist.29.mname' => ['expanded_macro'],
	'efk.efklist.29.status' => ['0'],
	'efk.efklist.29.type' => ['invite'],
	'efk.efklist.3.action.string' => [''],
	'efk.efklist.3.label' => [''],
	'efk.efklist.3.mname' => ['expanded_macro'],
	'efk.efklist.3.status' => ['0'],
	'efk.efklist.3.type' => ['invite'],
	'efk.efklist.30.action.string' => [''],
	'efk.efklist.30.label' => [''],
	'efk.efklist.30.mname' => ['expanded_macro'],
	'efk.efklist.30.status' => ['0'],
	'efk.efklist.30.type' => ['invite'],
	'efk.efklist.31.action.string' => [''],
	'efk.efklist.31.label' => [''],
	'efk.efklist.31.mname' => ['expanded_macro'],
	'efk.efklist.31.status' => ['0'],
	'efk.efklist.31.type' => ['invite'],
	'efk.efklist.32.action.string' => [''],
	'efk.efklist.32.label' => [''],
	'efk.efklist.32.mname' => ['expanded_macro'],
	'efk.efklist.32.status' => ['0'],
	'efk.efklist.32.type' => ['invite'],
	'efk.efklist.33.action.string' => [''],
	'efk.efklist.33.label' => [''],
	'efk.efklist.33.mname' => ['expanded_macro'],
	'efk.efklist.33.status' => ['0'],
	'efk.efklist.33.type' => ['invite'],
	'efk.efklist.34.action.string' => [''],
	'efk.efklist.34.label' => [''],
	'efk.efklist.34.mname' => ['expanded_macro'],
	'efk.efklist.34.status' => ['0'],
	'efk.efklist.34.type' => ['invite'],
	'efk.efklist.35.action.string' => [''],
	'efk.efklist.35.label' => [''],
	'efk.efklist.35.mname' => ['expanded_macro'],
	'efk.efklist.35.status' => ['0'],
	'efk.efklist.35.type' => ['invite'],
	'efk.efklist.36.action.string' => [''],
	'efk.efklist.36.label' => [''],
	'efk.efklist.36.mname' => ['expanded_macro'],
	'efk.efklist.36.status' => ['0'],
	'efk.efklist.36.type' => ['invite'],
	'efk.efklist.37.action.string' => [''],
	'efk.efklist.37.label' => [''],
	'efk.efklist.37.mname' => ['expanded_macro'],
	'efk.efklist.37.status' => ['0'],
	'efk.efklist.37.type' => ['invite'],
	'efk.efklist.38.action.string' => [''],
	'efk.efklist.38.label' => [''],
	'efk.efklist.38.mname' => ['expanded_macro'],
	'efk.efklist.38.status' => ['0'],
	'efk.efklist.38.type' => ['invite'],
	'efk.efklist.39.action.string' => [''],
	'efk.efklist.39.label' => [''],
	'efk.efklist.39.mname' => ['expanded_macro'],
	'efk.efklist.39.status' => ['0'],
	'efk.efklist.39.type' => ['invite'],
	'efk.efklist.4.action.string' => [''],
	'efk.efklist.4.label' => [''],
	'efk.efklist.4.mname' => ['expanded_macro'],
	'efk.efklist.4.status' => ['0'],
	'efk.efklist.4.type' => ['invite'],
	'efk.efklist.40.action.string' => [''],
	'efk.efklist.40.label' => [''],
	'efk.efklist.40.mname' => ['expanded_macro'],
	'efk.efklist.40.status' => ['0'],
	'efk.efklist.40.type' => ['invite'],
	'efk.efklist.41.action.string' => [''],
	'efk.efklist.41.label' => [''],
	'efk.efklist.41.mname' => ['expanded_macro'],
	'efk.efklist.41.status' => ['0'],
	'efk.efklist.41.type' => ['invite'],
	'efk.efklist.42.action.string' => [''],
	'efk.efklist.42.label' => [''],
	'efk.efklist.42.mname' => ['expanded_macro'],
	'efk.efklist.42.status' => ['0'],
	'efk.efklist.42.type' => ['invite'],
	'efk.efklist.43.action.string' => [''],
	'efk.efklist.43.label' => [''],
	'efk.efklist.43.mname' => ['expanded_macro'],
	'efk.efklist.43.status' => ['0'],
	'efk.efklist.43.type' => ['invite'],
	'efk.efklist.44.action.string' => [''],
	'efk.efklist.44.label' => [''],
	'efk.efklist.44.mname' => ['expanded_macro'],
	'efk.efklist.44.status' => ['0'],
	'efk.efklist.44.type' => ['invite'],
	'efk.efklist.45.action.string' => [''],
	'efk.efklist.45.label' => [''],
	'efk.efklist.45.mname' => ['expanded_macro'],
	'efk.efklist.45.status' => ['0'],
	'efk.efklist.45.type' => ['invite'],
	'efk.efklist.46.action.string' => [''],
	'efk.efklist.46.label' => [''],
	'efk.efklist.46.mname' => ['expanded_macro'],
	'efk.efklist.46.status' => ['0'],
	'efk.efklist.46.type' => ['invite'],
	'efk.efklist.47.action.string' => [''],
	'efk.efklist.47.label' => [''],
	'efk.efklist.47.mname' => ['expanded_macro'],
	'efk.efklist.47.status' => ['0'],
	'efk.efklist.47.type' => ['invite'],
	'efk.efklist.48.action.string' => [''],
	'efk.efklist.48.label' => [''],
	'efk.efklist.48.mname' => ['expanded_macro'],
	'efk.efklist.48.status' => ['0'],
	'efk.efklist.48.type' => ['invite'],
	'efk.efklist.49.action.string' => [''],
	'efk.efklist.49.label' => [''],
	'efk.efklist.49.mname' => ['expanded_macro'],
	'efk.efklist.49.status' => ['0'],
	'efk.efklist.49.type' => ['invite'],
	'efk.efklist.5.action.string' => [''],
	'efk.efklist.5.label' => [''],
	'efk.efklist.5.mname' => ['expanded_macro'],
	'efk.efklist.5.status' => ['0'],
	'efk.efklist.5.type' => ['invite'],
	'efk.efklist.50.action.string' => [''],
	'efk.efklist.50.label' => [''],
	'efk.efklist.50.mname' => ['expanded_macro'],
	'efk.efklist.50.status' => ['0'],
	'efk.efklist.50.type' => ['invite'],
	'efk.efklist.6.action.string' => [''],
	'efk.efklist.6.label' => [''],
	'efk.efklist.6.mname' => ['expanded_macro'],
	'efk.efklist.6.status' => ['0'],
	'efk.efklist.6.type' => ['invite'],
	'efk.efklist.7.action.string' => [''],
	'efk.efklist.7.label' => [''],
	'efk.efklist.7.mname' => ['expanded_macro'],
	'efk.efklist.7.status' => ['0'],
	'efk.efklist.7.type' => ['invite'],
	'efk.efklist.8.action.string' => [''],
	'efk.efklist.8.label' => [''],
	'efk.efklist.8.mname' => ['expanded_macro'],
	'efk.efklist.8.status' => ['0'],
	'efk.efklist.8.type' => ['invite'],
	'efk.efklist.9.action.string' => [''],
	'efk.efklist.9.label' => [''],
	'efk.efklist.9.mname' => ['expanded_macro'],
	'efk.efklist.9.status' => ['0'],
	'efk.efklist.9.type' => ['invite'],
	'efk.efkprompt.1.digitmatching' => ['none'],
	'efk.efkprompt.1.label' => [''],
	'efk.efkprompt.1.status' => ['0'],
	'efk.efkprompt.1.type' => ['text'],
	'efk.efkprompt.1.userfeedback' => ['visible'],
	'efk.efkprompt.10.digitmatching' => ['none'],
	'efk.efkprompt.10.label' => [''],
	'efk.efkprompt.10.status' => ['0'],
	'efk.efkprompt.10.type' => ['text'],
	'efk.efkprompt.10.userfeedback' => ['visible'],
	'efk.efkprompt.11.digitmatching' => ['none'],
	'efk.efkprompt.11.label' => [''],
	'efk.efkprompt.11.status' => ['0'],
	'efk.efkprompt.11.type' => ['text'],
	'efk.efkprompt.11.userfeedback' => ['visible'],
	'efk.efkprompt.12.digitmatching' => ['none'],
	'efk.efkprompt.12.label' => [''],
	'efk.efkprompt.12.status' => ['0'],
	'efk.efkprompt.12.type' => ['text'],
	'efk.efkprompt.12.userfeedback' => ['visible'],
	'efk.efkprompt.13.digitmatching' => ['none'],
	'efk.efkprompt.13.label' => [''],
	'efk.efkprompt.13.status' => ['0'],
	'efk.efkprompt.13.type' => ['text'],
	'efk.efkprompt.13.userfeedback' => ['visible'],
	'efk.efkprompt.14.digitmatching' => ['none'],
	'efk.efkprompt.14.label' => [''],
	'efk.efkprompt.14.status' => ['0'],
	'efk.efkprompt.14.type' => ['text'],
	'efk.efkprompt.14.userfeedback' => ['visible'],
	'efk.efkprompt.15.digitmatching' => ['none'],
	'efk.efkprompt.15.label' => [''],
	'efk.efkprompt.15.status' => ['0'],
	'efk.efkprompt.15.type' => ['text'],
	'efk.efkprompt.15.userfeedback' => ['visible'],
	'efk.efkprompt.16.digitmatching' => ['none'],
	'efk.efkprompt.16.label' => [''],
	'efk.efkprompt.16.status' => ['0'],
	'efk.efkprompt.16.type' => ['text'],
	'efk.efkprompt.16.userfeedback' => ['visible'],
	'efk.efkprompt.17.digitmatching' => ['none'],
	'efk.efkprompt.17.label' => [''],
	'efk.efkprompt.17.status' => ['0'],
	'efk.efkprompt.17.type' => ['text'],
	'efk.efkprompt.17.userfeedback' => ['visible'],
	'efk.efkprompt.18.digitmatching' => ['none'],
	'efk.efkprompt.18.label' => [''],
	'efk.efkprompt.18.status' => ['0'],
	'efk.efkprompt.18.type' => ['text'],
	'efk.efkprompt.18.userfeedback' => ['visible'],
	'efk.efkprompt.19.digitmatching' => ['none'],
	'efk.efkprompt.19.label' => [''],
	'efk.efkprompt.19.status' => ['0'],
	'efk.efkprompt.19.type' => ['text'],
	'efk.efkprompt.19.userfeedback' => ['visible'],
	'efk.efkprompt.2.digitmatching' => ['none'],
	'efk.efkprompt.2.label' => [''],
	'efk.efkprompt.2.status' => ['0'],
	'efk.efkprompt.2.type' => ['text'],
	'efk.efkprompt.2.userfeedback' => ['visible'],
	'efk.efkprompt.20.digitmatching' => ['none'],
	'efk.efkprompt.20.label' => [''],
	'efk.efkprompt.20.status' => ['0'],
	'efk.efkprompt.20.type' => ['text'],
	'efk.efkprompt.20.userfeedback' => ['visible'],
	'efk.efkprompt.21.digitmatching' => ['none'],
	'efk.efkprompt.21.label' => [''],
	'efk.efkprompt.21.status' => ['0'],
	'efk.efkprompt.21.type' => ['text'],
	'efk.efkprompt.21.userfeedback' => ['visible'],
	'efk.efkprompt.22.digitmatching' => ['none'],
	'efk.efkprompt.22.label' => [''],
	'efk.efkprompt.22.status' => ['0'],
	'efk.efkprompt.22.type' => ['text'],
	'efk.efkprompt.22.userfeedback' => ['visible'],
	'efk.efkprompt.23.digitmatching' => ['none'],
	'efk.efkprompt.23.label' => [''],
	'efk.efkprompt.23.status' => ['0'],
	'efk.efkprompt.23.type' => ['text'],
	'efk.efkprompt.23.userfeedback' => ['visible'],
	'efk.efkprompt.24.digitmatching' => ['none'],
	'efk.efkprompt.24.label' => [''],
	'efk.efkprompt.24.status' => ['0'],
	'efk.efkprompt.24.type' => ['text'],
	'efk.efkprompt.24.userfeedback' => ['visible'],
	'efk.efkprompt.25.digitmatching' => ['none'],
	'efk.efkprompt.25.label' => [''],
	'efk.efkprompt.25.status' => ['0'],
	'efk.efkprompt.25.type' => ['text'],
	'efk.efkprompt.25.userfeedback' => ['visible'],
	'efk.efkprompt.26.digitmatching' => ['none'],
	'efk.efkprompt.26.label' => [''],
	'efk.efkprompt.26.status' => ['0'],
	'efk.efkprompt.26.type' => ['text'],
	'efk.efkprompt.26.userfeedback' => ['visible'],
	'efk.efkprompt.27.digitmatching' => ['none'],
	'efk.efkprompt.27.label' => [''],
	'efk.efkprompt.27.status' => ['0'],
	'efk.efkprompt.27.type' => ['text'],
	'efk.efkprompt.27.userfeedback' => ['visible'],
	'efk.efkprompt.28.digitmatching' => ['none'],
	'efk.efkprompt.28.label' => [''],
	'efk.efkprompt.28.status' => ['0'],
	'efk.efkprompt.28.type' => ['text'],
	'efk.efkprompt.28.userfeedback' => ['visible'],
	'efk.efkprompt.29.digitmatching' => ['none'],
	'efk.efkprompt.29.label' => [''],
	'efk.efkprompt.29.status' => ['0'],
	'efk.efkprompt.29.type' => ['text'],
	'efk.efkprompt.29.userfeedback' => ['visible'],
	'efk.efkprompt.3.digitmatching' => ['none'],
	'efk.efkprompt.3.label' => [''],
	'efk.efkprompt.3.status' => ['0'],
	'efk.efkprompt.3.type' => ['text'],
	'efk.efkprompt.3.userfeedback' => ['visible'],
	'efk.efkprompt.30.digitmatching' => ['none'],
	'efk.efkprompt.30.label' => [''],
	'efk.efkprompt.30.status' => ['0'],
	'efk.efkprompt.30.type' => ['text'],
	'efk.efkprompt.30.userfeedback' => ['visible'],
	'efk.efkprompt.31.digitmatching' => ['none'],
	'efk.efkprompt.31.label' => [''],
	'efk.efkprompt.31.status' => ['0'],
	'efk.efkprompt.31.type' => ['text'],
	'efk.efkprompt.31.userfeedback' => ['visible'],
	'efk.efkprompt.32.digitmatching' => ['none'],
	'efk.efkprompt.32.label' => [''],
	'efk.efkprompt.32.status' => ['0'],
	'efk.efkprompt.32.type' => ['text'],
	'efk.efkprompt.32.userfeedback' => ['visible'],
	'efk.efkprompt.33.digitmatching' => ['none'],
	'efk.efkprompt.33.label' => [''],
	'efk.efkprompt.33.status' => ['0'],
	'efk.efkprompt.33.type' => ['text'],
	'efk.efkprompt.33.userfeedback' => ['visible'],
	'efk.efkprompt.34.digitmatching' => ['none'],
	'efk.efkprompt.34.label' => [''],
	'efk.efkprompt.34.status' => ['0'],
	'efk.efkprompt.34.type' => ['text'],
	'efk.efkprompt.34.userfeedback' => ['visible'],
	'efk.efkprompt.35.digitmatching' => ['none'],
	'efk.efkprompt.35.label' => [''],
	'efk.efkprompt.35.status' => ['0'],
	'efk.efkprompt.35.type' => ['text'],
	'efk.efkprompt.35.userfeedback' => ['visible'],
	'efk.efkprompt.36.digitmatching' => ['none'],
	'efk.efkprompt.36.label' => [''],
	'efk.efkprompt.36.status' => ['0'],
	'efk.efkprompt.36.type' => ['text'],
	'efk.efkprompt.36.userfeedback' => ['visible'],
	'efk.efkprompt.37.digitmatching' => ['none'],
	'efk.efkprompt.37.label' => [''],
	'efk.efkprompt.37.status' => ['0'],
	'efk.efkprompt.37.type' => ['text'],
	'efk.efkprompt.37.userfeedback' => ['visible'],
	'efk.efkprompt.38.digitmatching' => ['none'],
	'efk.efkprompt.38.label' => [''],
	'efk.efkprompt.38.status' => ['0'],
	'efk.efkprompt.38.type' => ['text'],
	'efk.efkprompt.38.userfeedback' => ['visible'],
	'efk.efkprompt.39.digitmatching' => ['none'],
	'efk.efkprompt.39.label' => [''],
	'efk.efkprompt.39.status' => ['0'],
	'efk.efkprompt.39.type' => ['text'],
	'efk.efkprompt.39.userfeedback' => ['visible'],
	'efk.efkprompt.4.digitmatching' => ['none'],
	'efk.efkprompt.4.label' => [''],
	'efk.efkprompt.4.status' => ['0'],
	'efk.efkprompt.4.type' => ['text'],
	'efk.efkprompt.4.userfeedback' => ['visible'],
	'efk.efkprompt.40.digitmatching' => ['none'],
	'efk.efkprompt.40.label' => [''],
	'efk.efkprompt.40.status' => ['0'],
	'efk.efkprompt.40.type' => ['text'],
	'efk.efkprompt.40.userfeedback' => ['visible'],
	'efk.efkprompt.41.digitmatching' => ['none'],
	'efk.efkprompt.41.label' => [''],
	'efk.efkprompt.41.status' => ['0'],
	'efk.efkprompt.41.type' => ['text'],
	'efk.efkprompt.41.userfeedback' => ['visible'],
	'efk.efkprompt.42.digitmatching' => ['none'],
	'efk.efkprompt.42.label' => [''],
	'efk.efkprompt.42.status' => ['0'],
	'efk.efkprompt.42.type' => ['text'],
	'efk.efkprompt.42.userfeedback' => ['visible'],
	'efk.efkprompt.43.digitmatching' => ['none'],
	'efk.efkprompt.43.label' => [''],
	'efk.efkprompt.43.status' => ['0'],
	'efk.efkprompt.43.type' => ['text'],
	'efk.efkprompt.43.userfeedback' => ['visible'],
	'efk.efkprompt.44.digitmatching' => ['none'],
	'efk.efkprompt.44.label' => [''],
	'efk.efkprompt.44.status' => ['0'],
	'efk.efkprompt.44.type' => ['text'],
	'efk.efkprompt.44.userfeedback' => ['visible'],
	'efk.efkprompt.45.digitmatching' => ['none'],
	'efk.efkprompt.45.label' => [''],
	'efk.efkprompt.45.status' => ['0'],
	'efk.efkprompt.45.type' => ['text'],
	'efk.efkprompt.45.userfeedback' => ['visible'],
	'efk.efkprompt.46.digitmatching' => ['none'],
	'efk.efkprompt.46.label' => [''],
	'efk.efkprompt.46.status' => ['0'],
	'efk.efkprompt.46.type' => ['text'],
	'efk.efkprompt.46.userfeedback' => ['visible'],
	'efk.efkprompt.47.digitmatching' => ['none'],
	'efk.efkprompt.47.label' => [''],
	'efk.efkprompt.47.status' => ['0'],
	'efk.efkprompt.47.type' => ['text'],
	'efk.efkprompt.47.userfeedback' => ['visible'],
	'efk.efkprompt.48.digitmatching' => ['none'],
	'efk.efkprompt.48.label' => [''],
	'efk.efkprompt.48.status' => ['0'],
	'efk.efkprompt.48.type' => ['text'],
	'efk.efkprompt.48.userfeedback' => ['visible'],
	'efk.efkprompt.49.digitmatching' => ['none'],
	'efk.efkprompt.49.label' => [''],
	'efk.efkprompt.49.status' => ['0'],
	'efk.efkprompt.49.type' => ['text'],
	'efk.efkprompt.49.userfeedback' => ['visible'],
	'efk.efkprompt.5.digitmatching' => ['none'],
	'efk.efkprompt.5.label' => [''],
	'efk.efkprompt.5.status' => ['0'],
	'efk.efkprompt.5.type' => ['text'],
	'efk.efkprompt.5.userfeedback' => ['visible'],
	'efk.efkprompt.50.digitmatching' => ['none'],
	'efk.efkprompt.50.label' => [''],
	'efk.efkprompt.50.status' => ['0'],
	'efk.efkprompt.50.type' => ['text'],
	'efk.efkprompt.50.userfeedback' => ['visible'],
	'efk.efkprompt.6.digitmatching' => ['none'],
	'efk.efkprompt.6.label' => [''],
	'efk.efkprompt.6.status' => ['0'],
	'efk.efkprompt.6.type' => ['text'],
	'efk.efkprompt.6.userfeedback' => ['visible'],
	'efk.efkprompt.7.digitmatching' => ['none'],
	'efk.efkprompt.7.label' => [''],
	'efk.efkprompt.7.status' => ['0'],
	'efk.efkprompt.7.type' => ['text'],
	'efk.efkprompt.7.userfeedback' => ['visible'],
	'efk.efkprompt.8.digitmatching' => ['none'],
	'efk.efkprompt.8.label' => [''],
	'efk.efkprompt.8.status' => ['0'],
	'efk.efkprompt.8.type' => ['text'],
	'efk.efkprompt.8.userfeedback' => ['visible'],
	'efk.efkprompt.9.digitmatching' => ['none'],
	'efk.efkprompt.9.label' => [''],
	'efk.efkprompt.9.status' => ['0'],
	'efk.efkprompt.9.type' => ['text'],
	'efk.efkprompt.9.userfeedback' => ['visible'],
	'efk.version' => ['2'],
	'encoding' => ['UTF-8'],
	'exchange.server.address' => [''],
	'feature.H350Directory.enabled' => ['0'],
	'feature.acdAgentAvailability.enabled' => ['0'],
	'feature.acdLoginLogout.enabled' => ['0'],
	'feature.acdServiceControlUri.enabled' => ['0'],
	'feature.autoLocalHold' => ['0'],
	'feature.callList.enabled' => ['1'],
	'feature.callListMissed.enabled' => ['1'],
	'feature.callListPlaced.enabled' => ['1'],
	'feature.callListReceived.enabled' => ['1'],
	'feature.callPark.enabled' => ['0'],
	'feature.callRecording.enabled' => ['0'],
	'feature.corporateDirectory.enabled' => ['0'],
	'feature.directedCallPickup.enabled' => ['0'],
	'feature.directory.enabled' => ['1'],
	'feature.enhancedFeatureKeys.enabled' => ['0'],
	'feature.groupCallPickup.enabled' => ['0'],
	'feature.lastCallReturn.enabled' => ['0'],
	'feature.localConf' => ['0'],
	'feature.messaging.enabled' => ['0'],
	'feature.nWayConference.enabled' => ['0'],
	'feature.noServerDisable' => ['0'],
	'feature.pictureFrame.enabled' => ['1'],
	'feature.presence.enabled' => ['0'],
	'feature.ringDownload.enabled' => ['1'],
	'feature.suppServices' => ['0'],
	'feature.urlDialing.enabled' => ['1'],
	'font.1.name' => [''],
	'font.10.name' => [''],
	'font.100.name' => [''],
	'font.101.name' => [''],
	'font.102.name' => [''],
	'font.103.name' => [''],
	'font.104.name' => [''],
	'font.105.name' => [''],
	'font.106.name' => [''],
	'font.107.name' => [''],
	'font.108.name' => [''],
	'font.109.name' => [''],
	'font.11.name' => [''],
	'font.110.name' => [''],
	'font.111.name' => [''],
	'font.112.name' => [''],
	'font.113.name' => [''],
	'font.114.name' => [''],
	'font.115.name' => [''],
	'font.116.name' => [''],
	'font.117.name' => [''],
	'font.118.name' => [''],
	'font.119.name' => [''],
	'font.12.name' => [''],
	'font.120.name' => [''],
	'font.121.name' => [''],
	'font.122.name' => [''],
	'font.123.name' => [''],
	'font.124.name' => [''],
	'font.125.name' => [''],
	'font.126.name' => [''],
	'font.127.name' => [''],
	'font.128.name' => [''],
	'font.129.name' => [''],
	'font.13.name' => [''],
	'font.130.name' => [''],
	'font.131.name' => [''],
	'font.132.name' => [''],
	'font.133.name' => [''],
	'font.134.name' => [''],
	'font.135.name' => [''],
	'font.136.name' => [''],
	'font.137.name' => [''],
	'font.138.name' => [''],
	'font.139.name' => [''],
	'font.14.name' => [''],
	'font.140.name' => [''],
	'font.141.name' => [''],
	'font.142.name' => [''],
	'font.143.name' => [''],
	'font.144.name' => [''],
	'font.145.name' => [''],
	'font.146.name' => [''],
	'font.147.name' => [''],
	'font.148.name' => [''],
	'font.149.name' => [''],
	'font.15.name' => [''],
	'font.150.name' => [''],
	'font.151.name' => [''],
	'font.152.name' => [''],
	'font.153.name' => [''],
	'font.154.name' => [''],
	'font.155.name' => [''],
	'font.156.name' => [''],
	'font.157.name' => [''],
	'font.158.name' => [''],
	'font.159.name' => [''],
	'font.16.name' => [''],
	'font.160.name' => [''],
	'font.161.name' => [''],
	'font.162.name' => [''],
	'font.163.name' => [''],
	'font.164.name' => [''],
	'font.165.name' => [''],
	'font.166.name' => [''],
	'font.167.name' => [''],
	'font.168.name' => [''],
	'font.169.name' => [''],
	'font.17.name' => [''],
	'font.170.name' => [''],
	'font.171.name' => [''],
	'font.172.name' => [''],
	'font.173.name' => [''],
	'font.174.name' => [''],
	'font.175.name' => [''],
	'font.176.name' => [''],
	'font.177.name' => [''],
	'font.178.name' => [''],
	'font.179.name' => [''],
	'font.18.name' => [''],
	'font.180.name' => [''],
	'font.181.name' => [''],
	'font.182.name' => [''],
	'font.183.name' => [''],
	'font.184.name' => [''],
	'font.185.name' => [''],
	'font.186.name' => [''],
	'font.187.name' => [''],
	'font.188.name' => [''],
	'font.189.name' => [''],
	'font.19.name' => [''],
	'font.190.name' => [''],
	'font.191.name' => [''],
	'font.192.name' => [''],
	'font.193.name' => [''],
	'font.194.name' => [''],
	'font.195.name' => [''],
	'font.196.name' => [''],
	'font.197.name' => [''],
	'font.198.name' => [''],
	'font.199.name' => [''],
	'font.2.name' => [''],
	'font.20.name' => [''],
	'font.200.name' => [''],
	'font.201.name' => [''],
	'font.202.name' => [''],
	'font.203.name' => [''],
	'font.204.name' => [''],
	'font.205.name' => [''],
	'font.206.name' => [''],
	'font.207.name' => [''],
	'font.208.name' => [''],
	'font.209.name' => [''],
	'font.21.name' => [''],
	'font.210.name' => [''],
	'font.211.name' => [''],
	'font.212.name' => [''],
	'font.213.name' => [''],
	'font.214.name' => [''],
	'font.215.name' => [''],
	'font.216.name' => [''],
	'font.217.name' => [''],
	'font.218.name' => [''],
	'font.219.name' => [''],
	'font.22.name' => [''],
	'font.220.name' => [''],
	'font.221.name' => [''],
	'font.222.name' => [''],
	'font.223.name' => [''],
	'font.224.name' => [''],
	'font.225.name' => [''],
	'font.226.name' => [''],
	'font.227.name' => [''],
	'font.228.name' => [''],
	'font.229.name' => [''],
	'font.23.name' => [''],
	'font.230.name' => [''],
	'font.231.name' => [''],
	'font.232.name' => [''],
	'font.233.name' => [''],
	'font.234.name' => [''],
	'font.235.name' => [''],
	'font.236.name' => [''],
	'font.237.name' => [''],
	'font.238.name' => [''],
	'font.239.name' => [''],
	'font.24.name' => [''],
	'font.240.name' => [''],
	'font.241.name' => [''],
	'font.242.name' => [''],
	'font.243.name' => [''],
	'font.244.name' => [''],
	'font.245.name' => [''],
	'font.246.name' => [''],
	'font.247.name' => [''],
	'font.248.name' => [''],
	'font.249.name' => [''],
	'font.25.name' => [''],
	'font.250.name' => [''],
	'font.251.name' => [''],
	'font.252.name' => [''],
	'font.253.name' => [''],
	'font.254.name' => [''],
	'font.255.name' => [''],
	'font.256.name' => [''],
	'font.26.name' => [''],
	'font.27.name' => [''],
	'font.28.name' => [''],
	'font.29.name' => [''],
	'font.3.name' => [''],
	'font.30.name' => [''],
	'font.31.name' => [''],
	'font.32.name' => [''],
	'font.33.name' => [''],
	'font.34.name' => [''],
	'font.35.name' => [''],
	'font.36.name' => [''],
	'font.37.name' => [''],
	'font.38.name' => [''],
	'font.39.name' => [''],
	'font.4.name' => [''],
	'font.40.name' => [''],
	'font.41.name' => [''],
	'font.42.name' => [''],
	'font.43.name' => [''],
	'font.44.name' => [''],
	'font.45.name' => [''],
	'font.46.name' => [''],
	'font.47.name' => [''],
	'font.48.name' => [''],
	'font.49.name' => [''],
	'font.5.name' => [''],
	'font.50.name' => [''],
	'font.51.name' => [''],
	'font.52.name' => [''],
	'font.53.name' => [''],
	'font.54.name' => [''],
	'font.55.name' => [''],
	'font.56.name' => [''],
	'font.57.name' => [''],
	'font.58.name' => [''],
	'font.59.name' => [''],
	'font.6.name' => [''],
	'font.60.name' => [''],
	'font.61.name' => [''],
	'font.62.name' => [''],
	'font.63.name' => [''],
	'font.64.name' => [''],
	'font.65.name' => [''],
	'font.66.name' => [''],
	'font.67.name' => [''],
	'font.68.name' => [''],
	'font.69.name' => [''],
	'font.7.name' => [''],
	'font.70.name' => [''],
	'font.71.name' => [''],
	'font.72.name' => [''],
	'font.73.name' => [''],
	'font.74.name' => [''],
	'font.75.name' => [''],
	'font.76.name' => [''],
	'font.77.name' => [''],
	'font.78.name' => [''],
	'font.79.name' => [''],
	'font.8.name' => [''],
	'font.80.name' => [''],
	'font.81.name' => [''],
	'font.82.name' => [''],
	'font.83.name' => [''],
	'font.84.name' => [''],
	'font.85.name' => [''],
	'font.86.name' => [''],
	'font.87.name' => [''],
	'font.88.name' => [''],
	'font.89.name' => [''],
	'font.9.name' => [''],
	'font.90.name' => [''],
	'font.91.name' => [''],
	'font.92.name' => [''],
	'font.93.name' => [''],
	'font.94.name' => [''],
	'font.95.name' => [''],
	'font.96.name' => [''],
	'font.97.name' => [''],
	'font.98.name' => [''],
	'font.99.name' => [''],
	'font.delimiter' => [''],
	'httpd.cfg.enabled' => ['1'],
	'httpd.cfg.port' => ['80'],
	'httpd.enabled' => ['1'],
	'httpd.lp.port' => ['80'],
	'httpd.ta.enabled' => ['0'],
	'httpd.ta.port' => ['80'],
	'ind.led.1.index' => ['1'],
	'ind.led.1.physNum' => ['1'],
	'ind.led.10.index' => ['22'],
	'ind.led.10.physNum' => ['10'],
	'ind.led.11.index' => ['7'],
	'ind.led.11.physNum' => ['11'],
	'ind.led.2.index' => ['14'],
	'ind.led.2.physNum' => ['2'],
	'ind.led.3.index' => ['15'],
	'ind.led.3.physNum' => ['3'],
	'ind.led.4.index' => ['16'],
	'ind.led.4.physNum' => ['4'],
	'ind.led.5.index' => ['17'],
	'ind.led.5.physNum' => ['5'],
	'ind.led.6.index' => ['18'],
	'ind.led.6.physNum' => ['6'],
	'ind.led.7.index' => ['19'],
	'ind.led.7.physNum' => ['7'],
	'ind.led.8.index' => ['20'],
	'ind.led.8.physNum' => ['8'],
	'ind.led.9.index' => ['21'],
	'ind.led.9.physNum' => ['9'],
	'ind.pattern.active.step.1.color' => ['Green'],
	'ind.pattern.active.step.1.duration' => ['0'],
	'ind.pattern.active.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.10.color' => ['Green'],
	'ind.pattern.active.step.10.duration' => ['0'],
	'ind.pattern.active.step.10.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.11.color' => ['Green'],
	'ind.pattern.active.step.11.duration' => ['0'],
	'ind.pattern.active.step.11.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.12.color' => ['Green'],
	'ind.pattern.active.step.12.duration' => ['0'],
	'ind.pattern.active.step.12.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.13.color' => ['Green'],
	'ind.pattern.active.step.13.duration' => ['0'],
	'ind.pattern.active.step.13.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.14.color' => ['Green'],
	'ind.pattern.active.step.14.duration' => ['0'],
	'ind.pattern.active.step.14.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.15.color' => ['Green'],
	'ind.pattern.active.step.15.duration' => ['0'],
	'ind.pattern.active.step.15.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.16.color' => ['Green'],
	'ind.pattern.active.step.16.duration' => ['0'],
	'ind.pattern.active.step.16.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.17.color' => ['Green'],
	'ind.pattern.active.step.17.duration' => ['0'],
	'ind.pattern.active.step.17.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.18.color' => ['Green'],
	'ind.pattern.active.step.18.duration' => ['0'],
	'ind.pattern.active.step.18.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.19.color' => ['Green'],
	'ind.pattern.active.step.19.duration' => ['0'],
	'ind.pattern.active.step.19.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.2.color' => ['Green'],
	'ind.pattern.active.step.2.duration' => ['0'],
	'ind.pattern.active.step.2.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.20.color' => ['Green'],
	'ind.pattern.active.step.20.duration' => ['0'],
	'ind.pattern.active.step.20.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.3.color' => ['Green'],
	'ind.pattern.active.step.3.duration' => ['0'],
	'ind.pattern.active.step.3.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.4.color' => ['Green'],
	'ind.pattern.active.step.4.duration' => ['0'],
	'ind.pattern.active.step.4.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.5.color' => ['Green'],
	'ind.pattern.active.step.5.duration' => ['0'],
	'ind.pattern.active.step.5.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.6.color' => ['Green'],
	'ind.pattern.active.step.6.duration' => ['0'],
	'ind.pattern.active.step.6.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.7.color' => ['Green'],
	'ind.pattern.active.step.7.duration' => ['0'],
	'ind.pattern.active.step.7.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.8.color' => ['Green'],
	'ind.pattern.active.step.8.duration' => ['0'],
	'ind.pattern.active.step.8.state' => ['1', 'On', 'on'],
	'ind.pattern.active.step.9.color' => ['Green'],
	'ind.pattern.active.step.9.duration' => ['0'],
	'ind.pattern.active.step.9.state' => ['1', 'On', 'on'],
	'ind.pattern.brokenFlutter.step.1.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.1.duration' => ['250'],
	'ind.pattern.brokenFlutter.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.brokenFlutter.step.10.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.10.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.11.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.11.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.12.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.12.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.13.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.13.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.14.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.14.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.15.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.15.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.16.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.16.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.17.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.17.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.18.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.18.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.19.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.19.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.2.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.2.duration' => ['250'],
	'ind.pattern.brokenFlutter.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.20.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.20.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.3.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.3.duration' => ['250'],
	'ind.pattern.brokenFlutter.step.3.state' => ['1', 'On', 'on'],
	'ind.pattern.brokenFlutter.step.4.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.4.duration' => ['250'],
	'ind.pattern.brokenFlutter.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.5.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.5.duration' => ['250'],
	'ind.pattern.brokenFlutter.step.5.state' => ['1', 'On', 'on'],
	'ind.pattern.brokenFlutter.step.6.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.6.duration' => ['1500'],
	'ind.pattern.brokenFlutter.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.7.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.7.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.8.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.8.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.brokenFlutter.step.9.color' => ['Red'],
	'ind.pattern.brokenFlutter.step.9.duration' => ['0'],
	'ind.pattern.brokenFlutter.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.1.color' => ['Red'],
	'ind.pattern.flash.step.1.duration' => ['500'],
	'ind.pattern.flash.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.flash.step.10.color' => ['Red'],
	'ind.pattern.flash.step.10.duration' => ['0'],
	'ind.pattern.flash.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.11.color' => ['Red'],
	'ind.pattern.flash.step.11.duration' => ['0'],
	'ind.pattern.flash.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.12.color' => ['Red'],
	'ind.pattern.flash.step.12.duration' => ['0'],
	'ind.pattern.flash.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.13.color' => ['Red'],
	'ind.pattern.flash.step.13.duration' => ['0'],
	'ind.pattern.flash.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.14.color' => ['Red'],
	'ind.pattern.flash.step.14.duration' => ['0'],
	'ind.pattern.flash.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.15.color' => ['Red'],
	'ind.pattern.flash.step.15.duration' => ['0'],
	'ind.pattern.flash.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.16.color' => ['Red'],
	'ind.pattern.flash.step.16.duration' => ['0'],
	'ind.pattern.flash.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.17.color' => ['Red'],
	'ind.pattern.flash.step.17.duration' => ['0'],
	'ind.pattern.flash.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.18.color' => ['Red'],
	'ind.pattern.flash.step.18.duration' => ['0'],
	'ind.pattern.flash.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.19.color' => ['Red'],
	'ind.pattern.flash.step.19.duration' => ['0'],
	'ind.pattern.flash.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.2.color' => ['Red'],
	'ind.pattern.flash.step.2.duration' => ['500'],
	'ind.pattern.flash.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.20.color' => ['Red'],
	'ind.pattern.flash.step.20.duration' => ['0'],
	'ind.pattern.flash.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.3.color' => ['Red'],
	'ind.pattern.flash.step.3.duration' => ['0'],
	'ind.pattern.flash.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.4.color' => ['Red'],
	'ind.pattern.flash.step.4.duration' => ['0'],
	'ind.pattern.flash.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.5.color' => ['Red'],
	'ind.pattern.flash.step.5.duration' => ['0'],
	'ind.pattern.flash.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.6.color' => ['Red'],
	'ind.pattern.flash.step.6.duration' => ['0'],
	'ind.pattern.flash.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.7.color' => ['Red'],
	'ind.pattern.flash.step.7.duration' => ['0'],
	'ind.pattern.flash.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.8.color' => ['Red'],
	'ind.pattern.flash.step.8.duration' => ['0'],
	'ind.pattern.flash.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.flash.step.9.color' => ['Red'],
	'ind.pattern.flash.step.9.duration' => ['0'],
	'ind.pattern.flash.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.1.color' => ['Red'],
	'ind.pattern.flashSlow.step.1.duration' => ['1000'],
	'ind.pattern.flashSlow.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.flashSlow.step.10.color' => ['Red'],
	'ind.pattern.flashSlow.step.10.duration' => ['0'],
	'ind.pattern.flashSlow.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.11.color' => ['Red'],
	'ind.pattern.flashSlow.step.11.duration' => ['0'],
	'ind.pattern.flashSlow.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.12.color' => ['Red'],
	'ind.pattern.flashSlow.step.12.duration' => ['0'],
	'ind.pattern.flashSlow.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.13.color' => ['Red'],
	'ind.pattern.flashSlow.step.13.duration' => ['0'],
	'ind.pattern.flashSlow.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.14.color' => ['Red'],
	'ind.pattern.flashSlow.step.14.duration' => ['0'],
	'ind.pattern.flashSlow.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.15.color' => ['Red'],
	'ind.pattern.flashSlow.step.15.duration' => ['0'],
	'ind.pattern.flashSlow.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.16.color' => ['Red'],
	'ind.pattern.flashSlow.step.16.duration' => ['0'],
	'ind.pattern.flashSlow.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.17.color' => ['Red'],
	'ind.pattern.flashSlow.step.17.duration' => ['0'],
	'ind.pattern.flashSlow.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.18.color' => ['Red'],
	'ind.pattern.flashSlow.step.18.duration' => ['0'],
	'ind.pattern.flashSlow.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.19.color' => ['Red'],
	'ind.pattern.flashSlow.step.19.duration' => ['0'],
	'ind.pattern.flashSlow.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.2.color' => ['Red'],
	'ind.pattern.flashSlow.step.2.duration' => ['1000'],
	'ind.pattern.flashSlow.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.20.color' => ['Red'],
	'ind.pattern.flashSlow.step.20.duration' => ['0'],
	'ind.pattern.flashSlow.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.3.color' => ['Red'],
	'ind.pattern.flashSlow.step.3.duration' => ['0'],
	'ind.pattern.flashSlow.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.4.color' => ['Red'],
	'ind.pattern.flashSlow.step.4.duration' => ['0'],
	'ind.pattern.flashSlow.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.5.color' => ['Red'],
	'ind.pattern.flashSlow.step.5.duration' => ['0'],
	'ind.pattern.flashSlow.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.6.color' => ['Red'],
	'ind.pattern.flashSlow.step.6.duration' => ['0'],
	'ind.pattern.flashSlow.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.7.color' => ['Red'],
	'ind.pattern.flashSlow.step.7.duration' => ['0'],
	'ind.pattern.flashSlow.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.8.color' => ['Red'],
	'ind.pattern.flashSlow.step.8.duration' => ['0'],
	'ind.pattern.flashSlow.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.flashSlow.step.9.color' => ['Red'],
	'ind.pattern.flashSlow.step.9.duration' => ['0'],
	'ind.pattern.flashSlow.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.1.color' => ['Red'],
	'ind.pattern.flutter.step.1.duration' => ['250'],
	'ind.pattern.flutter.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.flutter.step.10.color' => ['Red'],
	'ind.pattern.flutter.step.10.duration' => ['0'],
	'ind.pattern.flutter.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.11.color' => ['Red'],
	'ind.pattern.flutter.step.11.duration' => ['0'],
	'ind.pattern.flutter.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.12.color' => ['Red'],
	'ind.pattern.flutter.step.12.duration' => ['0'],
	'ind.pattern.flutter.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.13.color' => ['Red'],
	'ind.pattern.flutter.step.13.duration' => ['0'],
	'ind.pattern.flutter.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.14.color' => ['Red'],
	'ind.pattern.flutter.step.14.duration' => ['0'],
	'ind.pattern.flutter.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.15.color' => ['Red'],
	'ind.pattern.flutter.step.15.duration' => ['0'],
	'ind.pattern.flutter.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.16.color' => ['Red'],
	'ind.pattern.flutter.step.16.duration' => ['0'],
	'ind.pattern.flutter.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.17.color' => ['Red'],
	'ind.pattern.flutter.step.17.duration' => ['0'],
	'ind.pattern.flutter.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.18.color' => ['Red'],
	'ind.pattern.flutter.step.18.duration' => ['0'],
	'ind.pattern.flutter.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.19.color' => ['Red'],
	'ind.pattern.flutter.step.19.duration' => ['0'],
	'ind.pattern.flutter.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.2.color' => ['Red'],
	'ind.pattern.flutter.step.2.duration' => ['250'],
	'ind.pattern.flutter.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.20.color' => ['Red'],
	'ind.pattern.flutter.step.20.duration' => ['0'],
	'ind.pattern.flutter.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.3.color' => ['Red'],
	'ind.pattern.flutter.step.3.duration' => ['0'],
	'ind.pattern.flutter.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.4.color' => ['Red'],
	'ind.pattern.flutter.step.4.duration' => ['0'],
	'ind.pattern.flutter.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.5.color' => ['Red'],
	'ind.pattern.flutter.step.5.duration' => ['0'],
	'ind.pattern.flutter.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.6.color' => ['Red'],
	'ind.pattern.flutter.step.6.duration' => ['0'],
	'ind.pattern.flutter.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.7.color' => ['Red'],
	'ind.pattern.flutter.step.7.duration' => ['0'],
	'ind.pattern.flutter.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.8.color' => ['Red'],
	'ind.pattern.flutter.step.8.duration' => ['0'],
	'ind.pattern.flutter.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.flutter.step.9.color' => ['Red'],
	'ind.pattern.flutter.step.9.duration' => ['0'],
	'ind.pattern.flutter.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.1.color' => ['Green'],
	'ind.pattern.held.step.1.duration' => ['750'],
	'ind.pattern.held.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.held.step.10.color' => ['Green'],
	'ind.pattern.held.step.10.duration' => ['0'],
	'ind.pattern.held.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.11.color' => ['Green'],
	'ind.pattern.held.step.11.duration' => ['0'],
	'ind.pattern.held.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.12.color' => ['Green'],
	'ind.pattern.held.step.12.duration' => ['0'],
	'ind.pattern.held.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.13.color' => ['Green'],
	'ind.pattern.held.step.13.duration' => ['0'],
	'ind.pattern.held.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.14.color' => ['Green'],
	'ind.pattern.held.step.14.duration' => ['0'],
	'ind.pattern.held.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.15.color' => ['Green'],
	'ind.pattern.held.step.15.duration' => ['0'],
	'ind.pattern.held.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.16.color' => ['Green'],
	'ind.pattern.held.step.16.duration' => ['0'],
	'ind.pattern.held.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.17.color' => ['Green'],
	'ind.pattern.held.step.17.duration' => ['0'],
	'ind.pattern.held.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.18.color' => ['Green'],
	'ind.pattern.held.step.18.duration' => ['0'],
	'ind.pattern.held.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.19.color' => ['Green'],
	'ind.pattern.held.step.19.duration' => ['0'],
	'ind.pattern.held.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.2.color' => ['Green'],
	'ind.pattern.held.step.2.duration' => ['250'],
	'ind.pattern.held.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.20.color' => ['Green'],
	'ind.pattern.held.step.20.duration' => ['0'],
	'ind.pattern.held.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.3.color' => ['Green'],
	'ind.pattern.held.step.3.duration' => ['0'],
	'ind.pattern.held.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.4.color' => ['Green'],
	'ind.pattern.held.step.4.duration' => ['0'],
	'ind.pattern.held.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.5.color' => ['Green'],
	'ind.pattern.held.step.5.duration' => ['0'],
	'ind.pattern.held.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.6.color' => ['Green'],
	'ind.pattern.held.step.6.duration' => ['0'],
	'ind.pattern.held.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.7.color' => ['Green'],
	'ind.pattern.held.step.7.duration' => ['0'],
	'ind.pattern.held.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.8.color' => ['Green'],
	'ind.pattern.held.step.8.duration' => ['0'],
	'ind.pattern.held.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.held.step.9.color' => ['Green'],
	'ind.pattern.held.step.9.duration' => ['0'],
	'ind.pattern.held.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.1.color' => ['Red'],
	'ind.pattern.ledCustom1.step.1.duration' => ['0'],
	'ind.pattern.ledCustom1.step.1.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.10.color' => ['Red'],
	'ind.pattern.ledCustom1.step.10.duration' => ['0'],
	'ind.pattern.ledCustom1.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.11.color' => ['Red'],
	'ind.pattern.ledCustom1.step.11.duration' => ['0'],
	'ind.pattern.ledCustom1.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.12.color' => ['Red'],
	'ind.pattern.ledCustom1.step.12.duration' => ['0'],
	'ind.pattern.ledCustom1.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.13.color' => ['Red'],
	'ind.pattern.ledCustom1.step.13.duration' => ['0'],
	'ind.pattern.ledCustom1.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.14.color' => ['Red'],
	'ind.pattern.ledCustom1.step.14.duration' => ['0'],
	'ind.pattern.ledCustom1.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.15.color' => ['Red'],
	'ind.pattern.ledCustom1.step.15.duration' => ['0'],
	'ind.pattern.ledCustom1.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.16.color' => ['Red'],
	'ind.pattern.ledCustom1.step.16.duration' => ['0'],
	'ind.pattern.ledCustom1.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.17.color' => ['Red'],
	'ind.pattern.ledCustom1.step.17.duration' => ['0'],
	'ind.pattern.ledCustom1.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.18.color' => ['Red'],
	'ind.pattern.ledCustom1.step.18.duration' => ['0'],
	'ind.pattern.ledCustom1.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.19.color' => ['Red'],
	'ind.pattern.ledCustom1.step.19.duration' => ['0'],
	'ind.pattern.ledCustom1.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.2.color' => ['Red'],
	'ind.pattern.ledCustom1.step.2.duration' => ['0'],
	'ind.pattern.ledCustom1.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.20.color' => ['Red'],
	'ind.pattern.ledCustom1.step.20.duration' => ['0'],
	'ind.pattern.ledCustom1.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.3.color' => ['Red'],
	'ind.pattern.ledCustom1.step.3.duration' => ['0'],
	'ind.pattern.ledCustom1.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.4.color' => ['Red'],
	'ind.pattern.ledCustom1.step.4.duration' => ['0'],
	'ind.pattern.ledCustom1.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.5.color' => ['Red'],
	'ind.pattern.ledCustom1.step.5.duration' => ['0'],
	'ind.pattern.ledCustom1.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.6.color' => ['Red'],
	'ind.pattern.ledCustom1.step.6.duration' => ['0'],
	'ind.pattern.ledCustom1.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.7.color' => ['Red'],
	'ind.pattern.ledCustom1.step.7.duration' => ['0'],
	'ind.pattern.ledCustom1.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.8.color' => ['Red'],
	'ind.pattern.ledCustom1.step.8.duration' => ['0'],
	'ind.pattern.ledCustom1.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.ledCustom1.step.9.color' => ['Red'],
	'ind.pattern.ledCustom1.step.9.duration' => ['0'],
	'ind.pattern.ledCustom1.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.1.color' => ['Red'],
	'ind.pattern.lockedOut.step.1.duration' => ['0'],
	'ind.pattern.lockedOut.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.lockedOut.step.10.color' => ['Red'],
	'ind.pattern.lockedOut.step.10.duration' => ['0'],
	'ind.pattern.lockedOut.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.11.color' => ['Red'],
	'ind.pattern.lockedOut.step.11.duration' => ['0'],
	'ind.pattern.lockedOut.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.12.color' => ['Red'],
	'ind.pattern.lockedOut.step.12.duration' => ['0'],
	'ind.pattern.lockedOut.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.13.color' => ['Red'],
	'ind.pattern.lockedOut.step.13.duration' => ['0'],
	'ind.pattern.lockedOut.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.14.color' => ['Red'],
	'ind.pattern.lockedOut.step.14.duration' => ['0'],
	'ind.pattern.lockedOut.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.15.color' => ['Red'],
	'ind.pattern.lockedOut.step.15.duration' => ['0'],
	'ind.pattern.lockedOut.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.16.color' => ['Red'],
	'ind.pattern.lockedOut.step.16.duration' => ['0'],
	'ind.pattern.lockedOut.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.17.color' => ['Red'],
	'ind.pattern.lockedOut.step.17.duration' => ['0'],
	'ind.pattern.lockedOut.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.18.color' => ['Red'],
	'ind.pattern.lockedOut.step.18.duration' => ['0'],
	'ind.pattern.lockedOut.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.19.color' => ['Red'],
	'ind.pattern.lockedOut.step.19.duration' => ['0'],
	'ind.pattern.lockedOut.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.2.color' => ['Red'],
	'ind.pattern.lockedOut.step.2.duration' => ['0'],
	'ind.pattern.lockedOut.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.20.color' => ['Red'],
	'ind.pattern.lockedOut.step.20.duration' => ['0'],
	'ind.pattern.lockedOut.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.3.color' => ['Red'],
	'ind.pattern.lockedOut.step.3.duration' => ['0'],
	'ind.pattern.lockedOut.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.4.color' => ['Red'],
	'ind.pattern.lockedOut.step.4.duration' => ['0'],
	'ind.pattern.lockedOut.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.5.color' => ['Red'],
	'ind.pattern.lockedOut.step.5.duration' => ['0'],
	'ind.pattern.lockedOut.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.6.color' => ['Red'],
	'ind.pattern.lockedOut.step.6.duration' => ['0'],
	'ind.pattern.lockedOut.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.7.color' => ['Red'],
	'ind.pattern.lockedOut.step.7.duration' => ['0'],
	'ind.pattern.lockedOut.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.8.color' => ['Red'],
	'ind.pattern.lockedOut.step.8.duration' => ['0'],
	'ind.pattern.lockedOut.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.lockedOut.step.9.color' => ['Red'],
	'ind.pattern.lockedOut.step.9.duration' => ['0'],
	'ind.pattern.lockedOut.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.1.color' => ['Red'],
	'ind.pattern.off.step.1.duration' => ['0'],
	'ind.pattern.off.step.1.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.10.color' => ['Red'],
	'ind.pattern.off.step.10.duration' => ['0'],
	'ind.pattern.off.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.11.color' => ['Red'],
	'ind.pattern.off.step.11.duration' => ['0'],
	'ind.pattern.off.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.12.color' => ['Red'],
	'ind.pattern.off.step.12.duration' => ['0'],
	'ind.pattern.off.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.13.color' => ['Red'],
	'ind.pattern.off.step.13.duration' => ['0'],
	'ind.pattern.off.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.14.color' => ['Red'],
	'ind.pattern.off.step.14.duration' => ['0'],
	'ind.pattern.off.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.15.color' => ['Red'],
	'ind.pattern.off.step.15.duration' => ['0'],
	'ind.pattern.off.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.16.color' => ['Red'],
	'ind.pattern.off.step.16.duration' => ['0'],
	'ind.pattern.off.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.17.color' => ['Red'],
	'ind.pattern.off.step.17.duration' => ['0'],
	'ind.pattern.off.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.18.color' => ['Red'],
	'ind.pattern.off.step.18.duration' => ['0'],
	'ind.pattern.off.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.19.color' => ['Red'],
	'ind.pattern.off.step.19.duration' => ['0'],
	'ind.pattern.off.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.2.color' => ['Red'],
	'ind.pattern.off.step.2.duration' => ['0'],
	'ind.pattern.off.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.20.color' => ['Red'],
	'ind.pattern.off.step.20.duration' => ['0'],
	'ind.pattern.off.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.3.color' => ['Red'],
	'ind.pattern.off.step.3.duration' => ['0'],
	'ind.pattern.off.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.4.color' => ['Red'],
	'ind.pattern.off.step.4.duration' => ['0'],
	'ind.pattern.off.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.5.color' => ['Red'],
	'ind.pattern.off.step.5.duration' => ['0'],
	'ind.pattern.off.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.6.color' => ['Red'],
	'ind.pattern.off.step.6.duration' => ['0'],
	'ind.pattern.off.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.7.color' => ['Red'],
	'ind.pattern.off.step.7.duration' => ['0'],
	'ind.pattern.off.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.8.color' => ['Red'],
	'ind.pattern.off.step.8.duration' => ['0'],
	'ind.pattern.off.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.off.step.9.color' => ['Red'],
	'ind.pattern.off.step.9.duration' => ['0'],
	'ind.pattern.off.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.1.color' => ['Green'],
	'ind.pattern.offering.step.1.duration' => ['250'],
	'ind.pattern.offering.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.offering.step.10.color' => ['Green'],
	'ind.pattern.offering.step.10.duration' => ['0'],
	'ind.pattern.offering.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.11.color' => ['Green'],
	'ind.pattern.offering.step.11.duration' => ['0'],
	'ind.pattern.offering.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.12.color' => ['Green'],
	'ind.pattern.offering.step.12.duration' => ['0'],
	'ind.pattern.offering.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.13.color' => ['Green'],
	'ind.pattern.offering.step.13.duration' => ['0'],
	'ind.pattern.offering.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.14.color' => ['Green'],
	'ind.pattern.offering.step.14.duration' => ['0'],
	'ind.pattern.offering.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.15.color' => ['Green'],
	'ind.pattern.offering.step.15.duration' => ['0'],
	'ind.pattern.offering.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.16.color' => ['Green'],
	'ind.pattern.offering.step.16.duration' => ['0'],
	'ind.pattern.offering.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.17.color' => ['Green'],
	'ind.pattern.offering.step.17.duration' => ['0'],
	'ind.pattern.offering.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.18.color' => ['Green'],
	'ind.pattern.offering.step.18.duration' => ['0'],
	'ind.pattern.offering.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.19.color' => ['Green'],
	'ind.pattern.offering.step.19.duration' => ['0'],
	'ind.pattern.offering.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.2.color' => ['Green'],
	'ind.pattern.offering.step.2.duration' => ['250'],
	'ind.pattern.offering.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.20.color' => ['Green'],
	'ind.pattern.offering.step.20.duration' => ['0'],
	'ind.pattern.offering.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.3.color' => ['Green'],
	'ind.pattern.offering.step.3.duration' => ['0'],
	'ind.pattern.offering.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.4.color' => ['Green'],
	'ind.pattern.offering.step.4.duration' => ['0'],
	'ind.pattern.offering.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.5.color' => ['Green'],
	'ind.pattern.offering.step.5.duration' => ['0'],
	'ind.pattern.offering.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.6.color' => ['Green'],
	'ind.pattern.offering.step.6.duration' => ['0'],
	'ind.pattern.offering.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.7.color' => ['Green'],
	'ind.pattern.offering.step.7.duration' => ['0'],
	'ind.pattern.offering.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.8.color' => ['Green'],
	'ind.pattern.offering.step.8.duration' => ['0'],
	'ind.pattern.offering.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.offering.step.9.color' => ['Green'],
	'ind.pattern.offering.step.9.duration' => ['0'],
	'ind.pattern.offering.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.on.step.1.color' => ['Red'],
	'ind.pattern.on.step.1.duration' => ['0'],
	'ind.pattern.on.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.10.color' => ['Red'],
	'ind.pattern.on.step.10.duration' => ['0'],
	'ind.pattern.on.step.10.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.11.color' => ['Red'],
	'ind.pattern.on.step.11.duration' => ['0'],
	'ind.pattern.on.step.11.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.12.color' => ['Red'],
	'ind.pattern.on.step.12.duration' => ['0'],
	'ind.pattern.on.step.12.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.13.color' => ['Red'],
	'ind.pattern.on.step.13.duration' => ['0'],
	'ind.pattern.on.step.13.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.14.color' => ['Red'],
	'ind.pattern.on.step.14.duration' => ['0'],
	'ind.pattern.on.step.14.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.15.color' => ['Red'],
	'ind.pattern.on.step.15.duration' => ['0'],
	'ind.pattern.on.step.15.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.16.color' => ['Red'],
	'ind.pattern.on.step.16.duration' => ['0'],
	'ind.pattern.on.step.16.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.17.color' => ['Red'],
	'ind.pattern.on.step.17.duration' => ['0'],
	'ind.pattern.on.step.17.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.18.color' => ['Red'],
	'ind.pattern.on.step.18.duration' => ['0'],
	'ind.pattern.on.step.18.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.19.color' => ['Red'],
	'ind.pattern.on.step.19.duration' => ['0'],
	'ind.pattern.on.step.19.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.2.color' => ['Red'],
	'ind.pattern.on.step.2.duration' => ['0'],
	'ind.pattern.on.step.2.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.20.color' => ['Red'],
	'ind.pattern.on.step.20.duration' => ['0'],
	'ind.pattern.on.step.20.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.3.color' => ['Red'],
	'ind.pattern.on.step.3.duration' => ['0'],
	'ind.pattern.on.step.3.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.4.color' => ['Red'],
	'ind.pattern.on.step.4.duration' => ['0'],
	'ind.pattern.on.step.4.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.5.color' => ['Red'],
	'ind.pattern.on.step.5.duration' => ['0'],
	'ind.pattern.on.step.5.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.6.color' => ['Red'],
	'ind.pattern.on.step.6.duration' => ['0'],
	'ind.pattern.on.step.6.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.7.color' => ['Red'],
	'ind.pattern.on.step.7.duration' => ['0'],
	'ind.pattern.on.step.7.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.8.color' => ['Red'],
	'ind.pattern.on.step.8.duration' => ['0'],
	'ind.pattern.on.step.8.state' => ['1', 'On', 'on'],
	'ind.pattern.on.step.9.color' => ['Red'],
	'ind.pattern.on.step.9.duration' => ['0'],
	'ind.pattern.on.step.9.state' => ['1', 'On', 'on'],
	'ind.pattern.powerSaving.step.1.color' => ['Red'],
	'ind.pattern.powerSaving.step.1.duration' => ['100', 1000],
	'ind.pattern.powerSaving.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.powerSaving.step.10.color' => ['Red'],
	'ind.pattern.powerSaving.step.10.duration' => ['0'],
	'ind.pattern.powerSaving.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.11.color' => ['Red'],
	'ind.pattern.powerSaving.step.11.duration' => ['0'],
	'ind.pattern.powerSaving.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.12.color' => ['Red'],
	'ind.pattern.powerSaving.step.12.duration' => ['0'],
	'ind.pattern.powerSaving.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.13.color' => ['Red'],
	'ind.pattern.powerSaving.step.13.duration' => ['0'],
	'ind.pattern.powerSaving.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.14.color' => ['Red'],
	'ind.pattern.powerSaving.step.14.duration' => ['0'],
	'ind.pattern.powerSaving.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.15.color' => ['Red'],
	'ind.pattern.powerSaving.step.15.duration' => ['0'],
	'ind.pattern.powerSaving.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.16.color' => ['Red'],
	'ind.pattern.powerSaving.step.16.duration' => ['0'],
	'ind.pattern.powerSaving.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.17.color' => ['Red'],
	'ind.pattern.powerSaving.step.17.duration' => ['0'],
	'ind.pattern.powerSaving.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.18.color' => ['Red'],
	'ind.pattern.powerSaving.step.18.duration' => ['0'],
	'ind.pattern.powerSaving.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.19.color' => ['Red'],
	'ind.pattern.powerSaving.step.19.duration' => ['0'],
	'ind.pattern.powerSaving.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.2.color' => ['Red'],
	'ind.pattern.powerSaving.step.2.duration' => ['2900'],
	'ind.pattern.powerSaving.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.20.color' => ['Red'],
	'ind.pattern.powerSaving.step.20.duration' => ['0'],
	'ind.pattern.powerSaving.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.3.color' => ['Red'],
	'ind.pattern.powerSaving.step.3.duration' => ['0'],
	'ind.pattern.powerSaving.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.4.color' => ['Red'],
	'ind.pattern.powerSaving.step.4.duration' => ['0'],
	'ind.pattern.powerSaving.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.5.color' => ['Red'],
	'ind.pattern.powerSaving.step.5.duration' => ['0'],
	'ind.pattern.powerSaving.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.6.color' => ['Red'],
	'ind.pattern.powerSaving.step.6.duration' => ['0'],
	'ind.pattern.powerSaving.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.7.color' => ['Red'],
	'ind.pattern.powerSaving.step.7.duration' => ['0'],
	'ind.pattern.powerSaving.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.8.color' => ['Red'],
	'ind.pattern.powerSaving.step.8.duration' => ['0'],
	'ind.pattern.powerSaving.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.powerSaving.step.9.color' => ['Red'],
	'ind.pattern.powerSaving.step.9.duration' => ['0'],
	'ind.pattern.powerSaving.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.1.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.1.duration' => ['1000', 1000],
	'ind.pattern.remoteBusyOffering.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.remoteBusyOffering.step.10.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.10.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.11.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.11.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.12.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.12.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.13.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.13.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.14.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.14.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.15.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.15.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.16.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.16.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.17.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.17.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.18.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.18.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.19.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.19.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.2.color' => ['Green'],
	'ind.pattern.remoteBusyOffering.step.2.duration' => ['250'],
	'ind.pattern.remoteBusyOffering.step.2.state' => ['1', 'On', 'on'],
	'ind.pattern.remoteBusyOffering.step.20.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.20.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.3.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.3.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.4.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.4.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.5.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.5.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.6.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.6.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.7.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.7.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.8.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.8.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.remoteBusyOffering.step.9.color' => ['Red'],
	'ind.pattern.remoteBusyOffering.step.9.duration' => ['0'],
	'ind.pattern.remoteBusyOffering.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.1.color' => ['Green'],
	'ind.pattern.scaHeld.step.1.duration' => ['750'],
	'ind.pattern.scaHeld.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.scaHeld.step.10.color' => ['Green'],
	'ind.pattern.scaHeld.step.10.duration' => ['0'],
	'ind.pattern.scaHeld.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.11.color' => ['Green'],
	'ind.pattern.scaHeld.step.11.duration' => ['0'],
	'ind.pattern.scaHeld.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.12.color' => ['Green'],
	'ind.pattern.scaHeld.step.12.duration' => ['0'],
	'ind.pattern.scaHeld.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.13.color' => ['Green'],
	'ind.pattern.scaHeld.step.13.duration' => ['0'],
	'ind.pattern.scaHeld.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.14.color' => ['Green'],
	'ind.pattern.scaHeld.step.14.duration' => ['0'],
	'ind.pattern.scaHeld.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.15.color' => ['Green'],
	'ind.pattern.scaHeld.step.15.duration' => ['0'],
	'ind.pattern.scaHeld.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.16.color' => ['Green'],
	'ind.pattern.scaHeld.step.16.duration' => ['0'],
	'ind.pattern.scaHeld.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.17.color' => ['Green'],
	'ind.pattern.scaHeld.step.17.duration' => ['0'],
	'ind.pattern.scaHeld.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.18.color' => ['Green'],
	'ind.pattern.scaHeld.step.18.duration' => ['0'],
	'ind.pattern.scaHeld.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.19.color' => ['Green'],
	'ind.pattern.scaHeld.step.19.duration' => ['0'],
	'ind.pattern.scaHeld.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.2.color' => ['Green'],
	'ind.pattern.scaHeld.step.2.duration' => ['250'],
	'ind.pattern.scaHeld.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.20.color' => ['Green'],
	'ind.pattern.scaHeld.step.20.duration' => ['0'],
	'ind.pattern.scaHeld.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.3.color' => ['Green'],
	'ind.pattern.scaHeld.step.3.duration' => ['0'],
	'ind.pattern.scaHeld.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.4.color' => ['Green'],
	'ind.pattern.scaHeld.step.4.duration' => ['0'],
	'ind.pattern.scaHeld.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.5.color' => ['Green'],
	'ind.pattern.scaHeld.step.5.duration' => ['0'],
	'ind.pattern.scaHeld.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.6.color' => ['Green'],
	'ind.pattern.scaHeld.step.6.duration' => ['0'],
	'ind.pattern.scaHeld.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.7.color' => ['Green'],
	'ind.pattern.scaHeld.step.7.duration' => ['0'],
	'ind.pattern.scaHeld.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.8.color' => ['Green'],
	'ind.pattern.scaHeld.step.8.duration' => ['0'],
	'ind.pattern.scaHeld.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.scaHeld.step.9.color' => ['Green'],
	'ind.pattern.scaHeld.step.9.duration' => ['0'],
	'ind.pattern.scaHeld.step.9.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.1.color' => ['Red'],
	'ind.pattern.wink.step.1.duration' => ['250'],
	'ind.pattern.wink.step.1.state' => ['1', 'On', 'on'],
	'ind.pattern.wink.step.10.color' => ['Red'],
	'ind.pattern.wink.step.10.duration' => ['0'],
	'ind.pattern.wink.step.10.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.11.color' => ['Red'],
	'ind.pattern.wink.step.11.duration' => ['0'],
	'ind.pattern.wink.step.11.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.12.color' => ['Red'],
	'ind.pattern.wink.step.12.duration' => ['0'],
	'ind.pattern.wink.step.12.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.13.color' => ['Red'],
	'ind.pattern.wink.step.13.duration' => ['0'],
	'ind.pattern.wink.step.13.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.14.color' => ['Red'],
	'ind.pattern.wink.step.14.duration' => ['0'],
	'ind.pattern.wink.step.14.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.15.color' => ['Red'],
	'ind.pattern.wink.step.15.duration' => ['0'],
	'ind.pattern.wink.step.15.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.16.color' => ['Red'],
	'ind.pattern.wink.step.16.duration' => ['0'],
	'ind.pattern.wink.step.16.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.17.color' => ['Red'],
	'ind.pattern.wink.step.17.duration' => ['0'],
	'ind.pattern.wink.step.17.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.18.color' => ['Red'],
	'ind.pattern.wink.step.18.duration' => ['0'],
	'ind.pattern.wink.step.18.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.19.color' => ['Red'],
	'ind.pattern.wink.step.19.duration' => ['0'],
	'ind.pattern.wink.step.19.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.2.color' => ['Red'],
	'ind.pattern.wink.step.2.duration' => ['750'],
	'ind.pattern.wink.step.2.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.20.color' => ['Red'],
	'ind.pattern.wink.step.20.duration' => ['0'],
	'ind.pattern.wink.step.20.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.3.color' => ['Red'],
	'ind.pattern.wink.step.3.duration' => ['0'],
	'ind.pattern.wink.step.3.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.4.color' => ['Red'],
	'ind.pattern.wink.step.4.duration' => ['0'],
	'ind.pattern.wink.step.4.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.5.color' => ['Red'],
	'ind.pattern.wink.step.5.duration' => ['0'],
	'ind.pattern.wink.step.5.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.6.color' => ['Red'],
	'ind.pattern.wink.step.6.duration' => ['0'],
	'ind.pattern.wink.step.6.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.7.color' => ['Red'],
	'ind.pattern.wink.step.7.duration' => ['0'],
	'ind.pattern.wink.step.7.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.8.color' => ['Red'],
	'ind.pattern.wink.step.8.duration' => ['0'],
	'ind.pattern.wink.step.8.state' => ['0', 'Off', 'off'],
	'ind.pattern.wink.step.9.color' => ['Red'],
	'ind.pattern.wink.step.9.duration' => ['0'],
	'ind.pattern.wink.step.9.state' => ['0', 'Off', 'off'],
	'key.1.function.prim' => [''],
	'key.1.function.sec' => [''],
	'key.1.remote.prim' => [''],
	'key.1.remote.sec' => [''],
	'key.1.subPoint.prim' => [''],
	'key.1.subPoint.sec' => [''],
	'key.10.function.prim' => [''],
	'key.10.function.sec' => [''],
	'key.10.remote.prim' => [''],
	'key.10.remote.sec' => [''],
	'key.10.subPoint.prim' => [''],
	'key.10.subPoint.sec' => [''],
	'key.11.function.prim' => [''],
	'key.11.function.sec' => [''],
	'key.11.remote.prim' => [''],
	'key.11.remote.sec' => [''],
	'key.11.subPoint.prim' => [''],
	'key.11.subPoint.sec' => [''],
	'key.12.function.prim' => [''],
	'key.12.function.sec' => [''],
	'key.12.remote.prim' => [''],
	'key.12.remote.sec' => [''],
	'key.12.subPoint.prim' => [''],
	'key.12.subPoint.sec' => [''],
	'key.13.function.prim' => [''],
	'key.13.function.sec' => [''],
	'key.13.remote.prim' => [''],
	'key.13.remote.sec' => [''],
	'key.13.subPoint.prim' => [''],
	'key.13.subPoint.sec' => [''],
	'key.14.function.prim' => [''],
	'key.14.function.sec' => [''],
	'key.14.remote.prim' => [''],
	'key.14.remote.sec' => [''],
	'key.14.subPoint.prim' => [''],
	'key.14.subPoint.sec' => [''],
	'key.15.function.prim' => [''],
	'key.15.function.sec' => [''],
	'key.15.remote.prim' => [''],
	'key.15.remote.sec' => [''],
	'key.15.subPoint.prim' => [''],
	'key.15.subPoint.sec' => [''],
	'key.16.function.prim' => [''],
	'key.16.function.sec' => [''],
	'key.16.remote.prim' => [''],
	'key.16.remote.sec' => [''],
	'key.16.subPoint.prim' => [''],
	'key.16.subPoint.sec' => [''],
	'key.17.function.prim' => [''],
	'key.17.function.sec' => [''],
	'key.17.remote.prim' => [''],
	'key.17.remote.sec' => [''],
	'key.17.subPoint.prim' => [''],
	'key.17.subPoint.sec' => [''],
	'key.18.function.prim' => [''],
	'key.18.function.sec' => [''],
	'key.18.remote.prim' => [''],
	'key.18.remote.sec' => [''],
	'key.18.subPoint.prim' => [''],
	'key.18.subPoint.sec' => [''],
	'key.19.function.prim' => [''],
	'key.19.function.sec' => [''],
	'key.19.remote.prim' => [''],
	'key.19.remote.sec' => [''],
	'key.19.subPoint.prim' => [''],
	'key.19.subPoint.sec' => [''],
	'key.2.function.prim' => [''],
	'key.2.function.sec' => [''],
	'key.2.remote.prim' => [''],
	'key.2.remote.sec' => [''],
	'key.2.subPoint.prim' => [''],
	'key.2.subPoint.sec' => [''],
	'key.20.function.prim' => [''],
	'key.20.function.sec' => [''],
	'key.20.remote.prim' => [''],
	'key.20.remote.sec' => [''],
	'key.20.subPoint.prim' => [''],
	'key.20.subPoint.sec' => [''],
	'key.21.function.prim' => [''],
	'key.21.function.sec' => [''],
	'key.21.remote.prim' => [''],
	'key.21.remote.sec' => [''],
	'key.21.subPoint.prim' => [''],
	'key.21.subPoint.sec' => [''],
	'key.22.function.prim' => [''],
	'key.22.function.sec' => [''],
	'key.22.remote.prim' => [''],
	'key.22.remote.sec' => [''],
	'key.22.subPoint.prim' => [''],
	'key.22.subPoint.sec' => [''],
	'key.23.function.prim' => [''],
	'key.23.function.sec' => [''],
	'key.23.remote.prim' => [''],
	'key.23.remote.sec' => [''],
	'key.23.subPoint.prim' => [''],
	'key.23.subPoint.sec' => [''],
	'key.24.function.prim' => [''],
	'key.24.function.sec' => [''],
	'key.24.remote.prim' => [''],
	'key.24.remote.sec' => [''],
	'key.24.subPoint.prim' => [''],
	'key.24.subPoint.sec' => [''],
	'key.25.function.prim' => [''],
	'key.25.function.sec' => [''],
	'key.25.remote.prim' => [''],
	'key.25.remote.sec' => [''],
	'key.25.subPoint.prim' => [''],
	'key.25.subPoint.sec' => [''],
	'key.26.function.prim' => [''],
	'key.26.function.sec' => [''],
	'key.26.remote.prim' => [''],
	'key.26.remote.sec' => [''],
	'key.26.subPoint.prim' => [''],
	'key.26.subPoint.sec' => [''],
	'key.27.function.prim' => [''],
	'key.27.function.sec' => [''],
	'key.27.remote.prim' => [''],
	'key.27.remote.sec' => [''],
	'key.27.subPoint.prim' => [''],
	'key.27.subPoint.sec' => [''],
	'key.28.function.prim' => [''],
	'key.28.function.sec' => [''],
	'key.28.remote.prim' => [''],
	'key.28.remote.sec' => [''],
	'key.28.subPoint.prim' => [''],
	'key.28.subPoint.sec' => [''],
	'key.29.function.prim' => [''],
	'key.29.function.sec' => [''],
	'key.29.remote.prim' => [''],
	'key.29.remote.sec' => [''],
	'key.29.subPoint.prim' => [''],
	'key.29.subPoint.sec' => [''],
	'key.3.function.prim' => [''],
	'key.3.function.sec' => [''],
	'key.3.remote.prim' => [''],
	'key.3.remote.sec' => [''],
	'key.3.subPoint.prim' => [''],
	'key.3.subPoint.sec' => [''],
	'key.30.function.prim' => [''],
	'key.30.function.sec' => [''],
	'key.30.remote.prim' => [''],
	'key.30.remote.sec' => [''],
	'key.30.subPoint.prim' => [''],
	'key.30.subPoint.sec' => [''],
	'key.31.function.prim' => [''],
	'key.31.function.sec' => [''],
	'key.31.remote.prim' => [''],
	'key.31.remote.sec' => [''],
	'key.31.subPoint.prim' => [''],
	'key.31.subPoint.sec' => [''],
	'key.32.function.prim' => [''],
	'key.32.function.sec' => [''],
	'key.32.remote.prim' => [''],
	'key.32.remote.sec' => [''],
	'key.32.subPoint.prim' => [''],
	'key.32.subPoint.sec' => [''],
	'key.33.function.prim' => [''],
	'key.33.function.sec' => [''],
	'key.33.remote.prim' => [''],
	'key.33.remote.sec' => [''],
	'key.33.subPoint.prim' => [''],
	'key.33.subPoint.sec' => [''],
	'key.34.function.prim' => [''],
	'key.34.function.sec' => [''],
	'key.34.remote.prim' => [''],
	'key.34.remote.sec' => [''],
	'key.34.subPoint.prim' => [''],
	'key.34.subPoint.sec' => [''],
	'key.35.function.prim' => [''],
	'key.35.function.sec' => [''],
	'key.35.remote.prim' => [''],
	'key.35.remote.sec' => [''],
	'key.35.subPoint.prim' => [''],
	'key.35.subPoint.sec' => [''],
	'key.36.function.prim' => [''],
	'key.36.function.sec' => [''],
	'key.36.remote.prim' => [''],
	'key.36.remote.sec' => [''],
	'key.36.subPoint.prim' => [''],
	'key.36.subPoint.sec' => [''],
	'key.37.function.prim' => [''],
	'key.37.function.sec' => [''],
	'key.37.remote.prim' => [''],
	'key.37.remote.sec' => [''],
	'key.37.subPoint.prim' => [''],
	'key.37.subPoint.sec' => [''],
	'key.38.function.prim' => [''],
	'key.38.function.sec' => [''],
	'key.38.remote.prim' => [''],
	'key.38.remote.sec' => [''],
	'key.38.subPoint.prim' => [''],
	'key.38.subPoint.sec' => [''],
	'key.39.function.prim' => [''],
	'key.39.function.sec' => [''],
	'key.39.remote.prim' => [''],
	'key.39.remote.sec' => [''],
	'key.39.subPoint.prim' => [''],
	'key.39.subPoint.sec' => [''],
	'key.4.function.prim' => [''],
	'key.4.function.sec' => [''],
	'key.4.remote.prim' => [''],
	'key.4.remote.sec' => [''],
	'key.4.subPoint.prim' => [''],
	'key.4.subPoint.sec' => [''],
	'key.40.function.prim' => [''],
	'key.40.function.sec' => [''],
	'key.40.remote.prim' => [''],
	'key.40.remote.sec' => [''],
	'key.40.subPoint.prim' => [''],
	'key.40.subPoint.sec' => [''],
	'key.41.function.prim' => [''],
	'key.41.function.sec' => [''],
	'key.41.remote.prim' => [''],
	'key.41.remote.sec' => [''],
	'key.41.subPoint.prim' => [''],
	'key.41.subPoint.sec' => [''],
	'key.42.function.prim' => [''],
	'key.42.function.sec' => [''],
	'key.42.remote.prim' => [''],
	'key.42.remote.sec' => [''],
	'key.42.subPoint.prim' => [''],
	'key.42.subPoint.sec' => [''],
	'key.43.function.prim' => [''],
	'key.43.function.sec' => [''],
	'key.43.remote.prim' => [''],
	'key.43.remote.sec' => [''],
	'key.43.subPoint.prim' => [''],
	'key.43.subPoint.sec' => [''],
	'key.44.function.prim' => [''],
	'key.44.function.sec' => [''],
	'key.44.remote.prim' => [''],
	'key.44.remote.sec' => [''],
	'key.44.subPoint.prim' => [''],
	'key.44.subPoint.sec' => [''],
	'key.45.function.prim' => [''],
	'key.45.function.sec' => [''],
	'key.45.remote.prim' => [''],
	'key.45.remote.sec' => [''],
	'key.45.subPoint.prim' => [''],
	'key.45.subPoint.sec' => [''],
	'key.46.function.prim' => [''],
	'key.46.function.sec' => [''],
	'key.46.remote.prim' => [''],
	'key.46.remote.sec' => [''],
	'key.46.subPoint.prim' => [''],
	'key.46.subPoint.sec' => [''],
	'key.47.function.prim' => [''],
	'key.47.function.sec' => [''],
	'key.47.remote.prim' => [''],
	'key.47.remote.sec' => [''],
	'key.47.subPoint.prim' => [''],
	'key.47.subPoint.sec' => [''],
	'key.48.function.prim' => [''],
	'key.48.function.sec' => [''],
	'key.48.remote.prim' => [''],
	'key.48.remote.sec' => [''],
	'key.48.subPoint.prim' => [''],
	'key.48.subPoint.sec' => [''],
	'key.49.function.prim' => [''],
	'key.49.function.sec' => [''],
	'key.49.remote.prim' => [''],
	'key.49.remote.sec' => [''],
	'key.49.subPoint.prim' => [''],
	'key.49.subPoint.sec' => [''],
	'key.5.function.prim' => [''],
	'key.5.function.sec' => [''],
	'key.5.remote.prim' => [''],
	'key.5.remote.sec' => [''],
	'key.5.subPoint.prim' => [''],
	'key.5.subPoint.sec' => [''],
	'key.50.function.prim' => [''],
	'key.50.function.sec' => [''],
	'key.50.remote.prim' => [''],
	'key.50.remote.sec' => [''],
	'key.50.subPoint.prim' => [''],
	'key.50.subPoint.sec' => [''],
	'key.51.function.prim' => [''],
	'key.51.function.sec' => [''],
	'key.51.remote.prim' => [''],
	'key.51.remote.sec' => [''],
	'key.51.subPoint.prim' => [''],
	'key.51.subPoint.sec' => [''],
	'key.52.function.prim' => [''],
	'key.52.function.sec' => [''],
	'key.52.remote.prim' => [''],
	'key.52.remote.sec' => [''],
	'key.52.subPoint.prim' => [''],
	'key.52.subPoint.sec' => [''],
	'key.53.function.prim' => [''],
	'key.53.function.sec' => [''],
	'key.53.remote.prim' => [''],
	'key.53.remote.sec' => [''],
	'key.53.subPoint.prim' => [''],
	'key.53.subPoint.sec' => [''],
	'key.54.function.prim' => [''],
	'key.54.function.sec' => [''],
	'key.54.remote.prim' => [''],
	'key.54.remote.sec' => [''],
	'key.54.subPoint.prim' => [''],
	'key.54.subPoint.sec' => [''],
	'key.55.function.prim' => [''],
	'key.55.function.sec' => [''],
	'key.55.remote.prim' => [''],
	'key.55.remote.sec' => [''],
	'key.55.subPoint.prim' => [''],
	'key.55.subPoint.sec' => [''],
	'key.56.function.prim' => [''],
	'key.56.function.sec' => [''],
	'key.56.remote.prim' => [''],
	'key.56.remote.sec' => [''],
	'key.56.subPoint.prim' => [''],
	'key.56.subPoint.sec' => [''],
	'key.57.function.prim' => [''],
	'key.57.function.sec' => [''],
	'key.57.remote.prim' => [''],
	'key.57.remote.sec' => [''],
	'key.57.subPoint.prim' => [''],
	'key.57.subPoint.sec' => [''],
	'key.58.function.prim' => [''],
	'key.58.function.sec' => [''],
	'key.58.remote.prim' => [''],
	'key.58.remote.sec' => [''],
	'key.58.subPoint.prim' => [''],
	'key.58.subPoint.sec' => [''],
	'key.59.function.prim' => [''],
	'key.59.function.sec' => [''],
	'key.59.remote.prim' => [''],
	'key.59.remote.sec' => [''],
	'key.59.subPoint.prim' => [''],
	'key.59.subPoint.sec' => [''],
	'key.6.function.prim' => [''],
	'key.6.function.sec' => [''],
	'key.6.remote.prim' => [''],
	'key.6.remote.sec' => [''],
	'key.6.subPoint.prim' => [''],
	'key.6.subPoint.sec' => [''],
	'key.60.function.prim' => [''],
	'key.60.function.sec' => [''],
	'key.60.remote.prim' => [''],
	'key.60.remote.sec' => [''],
	'key.60.subPoint.prim' => [''],
	'key.60.subPoint.sec' => [''],
	'key.61.function.prim' => [''],
	'key.61.function.sec' => [''],
	'key.61.remote.prim' => [''],
	'key.61.remote.sec' => [''],
	'key.61.subPoint.prim' => [''],
	'key.61.subPoint.sec' => [''],
	'key.62.function.prim' => [''],
	'key.62.function.sec' => [''],
	'key.62.remote.prim' => [''],
	'key.62.remote.sec' => [''],
	'key.62.subPoint.prim' => [''],
	'key.62.subPoint.sec' => [''],
	'key.63.function.prim' => [''],
	'key.63.function.sec' => [''],
	'key.63.remote.prim' => [''],
	'key.63.remote.sec' => [''],
	'key.63.subPoint.prim' => [''],
	'key.63.subPoint.sec' => [''],
	'key.64.function.prim' => [''],
	'key.64.function.sec' => [''],
	'key.64.remote.prim' => [''],
	'key.64.remote.sec' => [''],
	'key.64.subPoint.prim' => [''],
	'key.64.subPoint.sec' => [''],
	'key.65.function.prim' => [''],
	'key.65.function.sec' => [''],
	'key.65.remote.prim' => [''],
	'key.65.remote.sec' => [''],
	'key.65.subPoint.prim' => [''],
	'key.65.subPoint.sec' => [''],
	'key.66.function.prim' => [''],
	'key.66.function.sec' => [''],
	'key.66.remote.prim' => [''],
	'key.66.remote.sec' => [''],
	'key.66.subPoint.prim' => [''],
	'key.66.subPoint.sec' => [''],
	'key.67.function.prim' => [''],
	'key.67.function.sec' => [''],
	'key.67.remote.prim' => [''],
	'key.67.remote.sec' => [''],
	'key.67.subPoint.prim' => [''],
	'key.67.subPoint.sec' => [''],
	'key.68.function.prim' => [''],
	'key.68.function.sec' => [''],
	'key.68.remote.prim' => [''],
	'key.68.remote.sec' => [''],
	'key.68.subPoint.prim' => [''],
	'key.68.subPoint.sec' => [''],
	'key.69.function.prim' => [''],
	'key.69.function.sec' => [''],
	'key.69.remote.prim' => [''],
	'key.69.remote.sec' => [''],
	'key.69.subPoint.prim' => [''],
	'key.69.subPoint.sec' => [''],
	'key.7.function.prim' => [''],
	'key.7.function.sec' => [''],
	'key.7.remote.prim' => [''],
	'key.7.remote.sec' => [''],
	'key.7.subPoint.prim' => [''],
	'key.7.subPoint.sec' => [''],
	'key.70.function.prim' => [''],
	'key.70.function.sec' => [''],
	'key.70.remote.prim' => [''],
	'key.70.remote.sec' => [''],
	'key.70.subPoint.prim' => [''],
	'key.70.subPoint.sec' => [''],
	'key.71.function.prim' => [''],
	'key.71.function.sec' => [''],
	'key.71.remote.prim' => [''],
	'key.71.remote.sec' => [''],
	'key.71.subPoint.prim' => [''],
	'key.71.subPoint.sec' => [''],
	'key.72.function.prim' => [''],
	'key.72.function.sec' => [''],
	'key.72.remote.prim' => [''],
	'key.72.remote.sec' => [''],
	'key.72.subPoint.prim' => [''],
	'key.72.subPoint.sec' => [''],
	'key.73.function.prim' => [''],
	'key.73.function.sec' => [''],
	'key.73.remote.prim' => [''],
	'key.73.remote.sec' => [''],
	'key.73.subPoint.prim' => [''],
	'key.73.subPoint.sec' => [''],
	'key.74.function.prim' => [''],
	'key.74.function.sec' => [''],
	'key.74.remote.prim' => [''],
	'key.74.remote.sec' => [''],
	'key.74.subPoint.prim' => [''],
	'key.74.subPoint.sec' => [''],
	'key.75.function.prim' => [''],
	'key.75.function.sec' => [''],
	'key.75.remote.prim' => [''],
	'key.75.remote.sec' => [''],
	'key.75.subPoint.prim' => [''],
	'key.75.subPoint.sec' => [''],
	'key.76.function.prim' => [''],
	'key.76.function.sec' => [''],
	'key.76.remote.prim' => [''],
	'key.76.remote.sec' => [''],
	'key.76.subPoint.prim' => [''],
	'key.76.subPoint.sec' => [''],
	'key.77.function.prim' => [''],
	'key.77.function.sec' => [''],
	'key.77.remote.prim' => [''],
	'key.77.remote.sec' => [''],
	'key.77.subPoint.prim' => [''],
	'key.77.subPoint.sec' => [''],
	'key.78.function.prim' => [''],
	'key.78.function.sec' => [''],
	'key.78.remote.prim' => [''],
	'key.78.remote.sec' => [''],
	'key.78.subPoint.prim' => [''],
	'key.78.subPoint.sec' => [''],
	'key.79.function.prim' => [''],
	'key.79.function.sec' => [''],
	'key.79.remote.prim' => [''],
	'key.79.remote.sec' => [''],
	'key.79.subPoint.prim' => [''],
	'key.79.subPoint.sec' => [''],
	'key.8.function.prim' => [''],
	'key.8.function.sec' => [''],
	'key.8.remote.prim' => [''],
	'key.8.remote.sec' => [''],
	'key.8.subPoint.prim' => [''],
	'key.8.subPoint.sec' => [''],
	'key.80.function.prim' => [''],
	'key.80.function.sec' => [''],
	'key.80.remote.prim' => [''],
	'key.80.remote.sec' => [''],
	'key.80.subPoint.prim' => [''],
	'key.80.subPoint.sec' => [''],
	'key.81.function.prim' => [''],
	'key.81.function.sec' => [''],
	'key.81.remote.prim' => [''],
	'key.81.remote.sec' => [''],
	'key.81.subPoint.prim' => [''],
	'key.81.subPoint.sec' => [''],
	'key.82.function.prim' => [''],
	'key.82.function.sec' => [''],
	'key.82.remote.prim' => [''],
	'key.82.remote.sec' => [''],
	'key.82.subPoint.prim' => [''],
	'key.82.subPoint.sec' => [''],
	'key.83.function.prim' => [''],
	'key.83.function.sec' => [''],
	'key.83.remote.prim' => [''],
	'key.83.remote.sec' => [''],
	'key.83.subPoint.prim' => [''],
	'key.83.subPoint.sec' => [''],
	'key.84.function.prim' => [''],
	'key.84.function.sec' => [''],
	'key.84.remote.prim' => [''],
	'key.84.remote.sec' => [''],
	'key.84.subPoint.prim' => [''],
	'key.84.subPoint.sec' => [''],
	'key.85.function.prim' => [''],
	'key.85.function.sec' => [''],
	'key.85.remote.prim' => [''],
	'key.85.remote.sec' => [''],
	'key.85.subPoint.prim' => [''],
	'key.85.subPoint.sec' => [''],
	'key.86.function.prim' => [''],
	'key.86.function.sec' => [''],
	'key.86.remote.prim' => [''],
	'key.86.remote.sec' => [''],
	'key.86.subPoint.prim' => [''],
	'key.86.subPoint.sec' => [''],
	'key.87.function.prim' => [''],
	'key.87.function.sec' => [''],
	'key.87.remote.prim' => [''],
	'key.87.remote.sec' => [''],
	'key.87.subPoint.prim' => [''],
	'key.87.subPoint.sec' => [''],
	'key.88.function.prim' => [''],
	'key.88.function.sec' => [''],
	'key.88.remote.prim' => [''],
	'key.88.remote.sec' => [''],
	'key.88.subPoint.prim' => [''],
	'key.88.subPoint.sec' => [''],
	'key.89.function.prim' => [''],
	'key.89.function.sec' => [''],
	'key.89.remote.prim' => [''],
	'key.89.remote.sec' => [''],
	'key.89.subPoint.prim' => [''],
	'key.89.subPoint.sec' => [''],
	'key.9.function.prim' => [''],
	'key.9.function.sec' => [''],
	'key.9.remote.prim' => [''],
	'key.9.remote.sec' => [''],
	'key.9.subPoint.prim' => [''],
	'key.9.subPoint.sec' => [''],
	'key.90.function.prim' => [''],
	'key.90.function.sec' => [''],
	'key.90.remote.prim' => [''],
	'key.90.remote.sec' => [''],
	'key.90.subPoint.prim' => [''],
	'key.90.subPoint.sec' => [''],
	'key.scrolling.timeout' => ['1'],
	'keypadLock.enabled' => ['0'],
	'keypadLock.idleTimeout' => ['0'],
	'keystrokeSimulation' => [''],
	'lcl.datetime.date.dateTop' => ['1'],
	'lcl.datetime.date.digitFormatEnable' => ['0'],
	'lcl.datetime.date.format' => ['D,Md'],
	'lcl.datetime.date.longFormat' => ['1'],
	'lcl.datetime.time.24HourClock' => ['0'],
	'lcl.ml.lang' => [''],
	'lcl.ml.lang.charset' => [''],
	'lcl.ml.lang.clock.1.24HourClock' => ['1'],
	'lcl.ml.lang.clock.1.dateTop' => ['1'],
	'lcl.ml.lang.clock.1.format' => ['D,dM'],
	'lcl.ml.lang.clock.1.longFormat' => ['1'],
	'lcl.ml.lang.clock.10.24HourClock' => ['1'],
	'lcl.ml.lang.clock.10.dateTop' => ['1'],
	'lcl.ml.lang.clock.10.format' => ['Md,D'],
	'lcl.ml.lang.clock.10.longFormat' => ['1'],
	'lcl.ml.lang.clock.11.24HourClock' => ['1'],
	'lcl.ml.lang.clock.11.dateTop' => ['1'],
	'lcl.ml.lang.clock.11.format' => ['D,dM'],
	'lcl.ml.lang.clock.11.longFormat' => ['1'],
	'lcl.ml.lang.clock.12.24HourClock' => ['1'],
	'lcl.ml.lang.clock.12.dateTop' => ['1'],
	'lcl.ml.lang.clock.12.format' => ['D,dM'],
	'lcl.ml.lang.clock.12.longFormat' => ['1'],
	'lcl.ml.lang.clock.13.24HourClock' => ['1'],
	'lcl.ml.lang.clock.13.dateTop' => ['1'],
	'lcl.ml.lang.clock.13.format' => ['D,dM'],
	'lcl.ml.lang.clock.13.longFormat' => ['1'],
	'lcl.ml.lang.clock.14.24HourClock' => ['1'],
	'lcl.ml.lang.clock.14.dateTop' => ['1'],
	'lcl.ml.lang.clock.14.format' => ['D,dM'],
	'lcl.ml.lang.clock.14.longFormat' => ['1'],
	'lcl.ml.lang.clock.15.24HourClock' => ['1'],
	'lcl.ml.lang.clock.15.dateTop' => ['1'],
	'lcl.ml.lang.clock.15.format' => ['D,dM'],
	'lcl.ml.lang.clock.15.longFormat' => ['1'],
	'lcl.ml.lang.clock.16.24HourClock' => ['1'],
	'lcl.ml.lang.clock.16.dateTop' => ['1'],
	'lcl.ml.lang.clock.16.format' => ['D,dM'],
	'lcl.ml.lang.clock.16.longFormat' => ['1'],
	'lcl.ml.lang.clock.17.24HourClock' => ['1'],
	'lcl.ml.lang.clock.17.dateTop' => ['1'],
	'lcl.ml.lang.clock.17.format' => ['D,dM'],
	'lcl.ml.lang.clock.17.longFormat' => ['1'],
	'lcl.ml.lang.clock.18.24HourClock' => ['1'],
	'lcl.ml.lang.clock.18.dateTop' => ['1'],
	'lcl.ml.lang.clock.18.format' => ['D,dM'],
	'lcl.ml.lang.clock.18.longFormat' => ['1'],
	'lcl.ml.lang.clock.19.24HourClock' => ['1'],
	'lcl.ml.lang.clock.19.dateTop' => ['1'],
	'lcl.ml.lang.clock.19.format' => ['D,dM'],
	'lcl.ml.lang.clock.19.longFormat' => ['1'],
	'lcl.ml.lang.clock.2.24HourClock' => ['1'],
	'lcl.ml.lang.clock.2.dateTop' => ['1'],
	'lcl.ml.lang.clock.2.format' => ['D,dM'],
	'lcl.ml.lang.clock.2.longFormat' => ['1'],
	'lcl.ml.lang.clock.20.24HourClock' => ['1'],
	'lcl.ml.lang.clock.20.dateTop' => ['1'],
	'lcl.ml.lang.clock.20.format' => ['D,dM'],
	'lcl.ml.lang.clock.20.longFormat' => ['1'],
	'lcl.ml.lang.clock.21.24HourClock' => ['1'],
	'lcl.ml.lang.clock.21.dateTop' => ['1'],
	'lcl.ml.lang.clock.21.format' => ['D,dM'],
	'lcl.ml.lang.clock.21.longFormat' => ['1'],
	'lcl.ml.lang.clock.22.24HourClock' => ['1'],
	'lcl.ml.lang.clock.22.dateTop' => ['1'],
	'lcl.ml.lang.clock.22.format' => ['D,dM'],
	'lcl.ml.lang.clock.22.longFormat' => ['1'],
	'lcl.ml.lang.clock.23.24HourClock' => ['1'],
	'lcl.ml.lang.clock.23.dateTop' => ['1'],
	'lcl.ml.lang.clock.23.format' => ['D,dM'],
	'lcl.ml.lang.clock.23.longFormat' => ['1'],
	'lcl.ml.lang.clock.24.24HourClock' => ['1'],
	'lcl.ml.lang.clock.24.dateTop' => ['1'],
	'lcl.ml.lang.clock.24.format' => ['D,dM'],
	'lcl.ml.lang.clock.24.longFormat' => ['1'],
	'lcl.ml.lang.clock.3.24HourClock' => ['1'],
	'lcl.ml.lang.clock.3.dateTop' => ['1'],
	'lcl.ml.lang.clock.3.format' => ['D,dM'],
	'lcl.ml.lang.clock.3.longFormat' => ['1'],
	'lcl.ml.lang.clock.4.24HourClock' => ['0'],
	'lcl.ml.lang.clock.4.dateTop' => ['1'],
	'lcl.ml.lang.clock.4.format' => ['D,Md'],
	'lcl.ml.lang.clock.4.longFormat' => ['1'],
	'lcl.ml.lang.clock.5.24HourClock' => ['1', 0 ],
	'lcl.ml.lang.clock.5.dateTop' => ['1'],
	'lcl.ml.lang.clock.5.format' => ['D,Md'],
	'lcl.ml.lang.clock.5.longFormat' => ['1'],
	'lcl.ml.lang.clock.6.24HourClock' => ['0'],
	'lcl.ml.lang.clock.6.dateTop' => ['1'],
	'lcl.ml.lang.clock.6.format' => ['D,Md'],
	'lcl.ml.lang.clock.6.longFormat' => ['1'],
	'lcl.ml.lang.clock.7.24HourClock' => ['1'],
	'lcl.ml.lang.clock.7.dateTop' => ['1'],
	'lcl.ml.lang.clock.7.format' => ['D,Md', 'D,dM' ],
	'lcl.ml.lang.clock.7.longFormat' => ['1'],
	'lcl.ml.lang.clock.8.24HourClock' => ['1'],
	'lcl.ml.lang.clock.8.dateTop' => ['1'],
	'lcl.ml.lang.clock.8.format' => ['D,Md', 'D,dM' ],
	'lcl.ml.lang.clock.8.longFormat' => ['1'],
	'lcl.ml.lang.clock.9.24HourClock' => ['1'],
	'lcl.ml.lang.clock.9.dateTop' => ['1'],
	'lcl.ml.lang.clock.9.format' => ['D,Md', 'D,dM' ],
	'lcl.ml.lang.clock.9.longFormat' => ['1'],
	'lcl.ml.lang.font.1' => [''],
	'lcl.ml.lang.font.10' => [''],
	'lcl.ml.lang.font.11' => [''],
	'lcl.ml.lang.font.12' => [''],
	'lcl.ml.lang.font.13' => [''],
	'lcl.ml.lang.font.14' => [''],
	'lcl.ml.lang.font.15' => [''],
	'lcl.ml.lang.font.16' => [''],
	'lcl.ml.lang.font.17' => [''],
	'lcl.ml.lang.font.18' => [''],
	'lcl.ml.lang.font.19' => [''],
	'lcl.ml.lang.font.2' => [''],
	'lcl.ml.lang.font.20' => [''],
	'lcl.ml.lang.font.21' => [''],
	'lcl.ml.lang.font.22' => [''],
	'lcl.ml.lang.font.23' => [''],
	'lcl.ml.lang.font.24' => [''],
	'lcl.ml.lang.font.3' => [''],
	'lcl.ml.lang.font.4' => [''],
	'lcl.ml.lang.font.5' => [''],
	'lcl.ml.lang.font.6' => [''],
	'lcl.ml.lang.font.7' => [''],
	'lcl.ml.lang.font.8' => [''],
	'lcl.ml.lang.font.9' => [''],
	'lcl.ml.lang.list' => ['All'],
	'lcl.ml.lang.list.SPIP231' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18'],
	'lcl.ml.lang.list.SPIP235T' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18'],
	'lcl.ml.lang.list.SPIP320' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18', '2,3,4,5,6,7,8,9,12,13,14,15,16' ],
	'lcl.ml.lang.list.SPIP321' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18', '2,3,4,5,6,7,8,9,12,13,14,15,16' ],
	'lcl.ml.lang.list.SPIP330' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18', '2,3,4,5,6,7,8,9,12,13,14,15,16' ],
	'lcl.ml.lang.list.SPIP331' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18', '2,3,4,5,6,7,8,9,12,13,14,15,16' ],
	'lcl.ml.lang.list.SPIP335' => ['2,3,4,5,6,7,8,9,12,13,14,15,16,17,18', '2,3,4,5,6,7,8,9,12,13,14,15,16' ],
	'lcl.ml.lang.menu.1' => ['Chinese_China'],
	'lcl.ml.lang.menu.1.label' => ['ç®ä½ä¸­æ (zh-cn)'],
	'lcl.ml.lang.menu.10' => ['Japanese_Japan'],
	'lcl.ml.lang.menu.10.label' => ['æ¥æ¬èª (ja-jp)'],
	'lcl.ml.lang.menu.11' => ['Korean_Korea'],
	'lcl.ml.lang.menu.11.label' => ['íêµ­ì´ (ko-kr)'],
	'lcl.ml.lang.menu.12' => ['Norwegian_Norway'],
	'lcl.ml.lang.menu.12.label' => ['Norsk (no-no)'],
	'lcl.ml.lang.menu.13' => ['Polish_Poland'],
	'lcl.ml.lang.menu.13.label' => ['Polski (pl-pl)'],
	'lcl.ml.lang.menu.14' => ['Portuguese_Portugal'],
	'lcl.ml.lang.menu.14.label' => ['PortuguÃªs (pt-br)'],
	'lcl.ml.lang.menu.15' => ['Russian_Russia'],
	'lcl.ml.lang.menu.15.label' => ['Ð ÑÑÑÐºÐ¸Ð¹ (ru-ru)'],
	'lcl.ml.lang.menu.16' => ['Slovenian_Slovenia'],
	'lcl.ml.lang.menu.16.label' => ['Slovenski (sl-si)'],
	'lcl.ml.lang.menu.17' => ['Spanish_Spain'],
	'lcl.ml.lang.menu.17.label' => ['EspaÃ±ol (es-es)'],
	'lcl.ml.lang.menu.18' => ['Swedish_Sweden'],
	'lcl.ml.lang.menu.18.label' => ['Svenska (sv-se)'],
	'lcl.ml.lang.menu.19' => [''],
	'lcl.ml.lang.menu.19.label' => [''],
	'lcl.ml.lang.menu.2' => ['Danish_Denmark'],
	'lcl.ml.lang.menu.2.label' => ['Dansk (da-dk)'],
	'lcl.ml.lang.menu.20' => [''],
	'lcl.ml.lang.menu.20.label' => [''],
	'lcl.ml.lang.menu.21' => [''],
	'lcl.ml.lang.menu.21.label' => [''],
	'lcl.ml.lang.menu.22' => [''],
	'lcl.ml.lang.menu.22.label' => [''],
	'lcl.ml.lang.menu.23' => [''],
	'lcl.ml.lang.menu.23.label' => [''],
	'lcl.ml.lang.menu.24' => [''],
	'lcl.ml.lang.menu.24.label' => [''],
	'lcl.ml.lang.menu.3' => ['Dutch_Netherlands'],
	'lcl.ml.lang.menu.3.label' => ['Nederlands (nl-nl)'],
	'lcl.ml.lang.menu.4' => ['English_Canada'],
	'lcl.ml.lang.menu.4.label' => ['English (en-ca)'],
	'lcl.ml.lang.menu.5' => ['English_United_Kingdom'],
	'lcl.ml.lang.menu.5.label' => ['English (en-gb)'],
	'lcl.ml.lang.menu.6' => ['English_United_States'],
	'lcl.ml.lang.menu.6.label' => ['English (en-us)'],
	'lcl.ml.lang.menu.7' => ['French_France'],
	'lcl.ml.lang.menu.7.label' => ['FranÃ§ais (fr-fr)'],
	'lcl.ml.lang.menu.8' => ['German_Germany'],
	'lcl.ml.lang.menu.8.label' => ['Deutsch (de-de)'],
	'lcl.ml.lang.menu.9' => ['Italian_Italy'],
	'lcl.ml.lang.menu.9.label' => ['Italiano (it-it)'],
	'lcl.ml.lang.tags.1' => ['zh-cn,zh;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.10' => ['ja-jp,ja;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.11' => ['ko-kr,ko;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.12' => ['no-no,no;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.13' => ['pl-pl,pl;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.14' => ['pt-pt,pt;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.15' => ['ru-ru,ru;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.16' => ['sl-si,sl;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.17' => ['es-es,es;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.18' => ['sv-se,sv;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.19' => [''],
	'lcl.ml.lang.tags.2' => ['da-dk,da;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.20' => [''],
	'lcl.ml.lang.tags.21' => [''],
	'lcl.ml.lang.tags.22' => [''],
	'lcl.ml.lang.tags.23' => [''],
	'lcl.ml.lang.tags.24' => [''],
	'lcl.ml.lang.tags.3' => ['nl-nl,nl;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.4' => ['en-ca,en;q=0.9'],
	'lcl.ml.lang.tags.5' => ['en-gb,en;q=0.9'],
	'lcl.ml.lang.tags.6' => ['en-us,en;q=0.9'],
	'lcl.ml.lang.tags.7' => ['fr-fr,fr;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.8' => ['de-de,de;q=0.9,en;q=0.8'],
	'lcl.ml.lang.tags.9' => ['it-it,it;q=0.9,en;q=0.8'],
	'license.polling.time' => ['02:00'],
	'log.diagnosticMonitor.processMemoryLimit.enable' => ['1'],
	'log.diagnosticMonitor.totalMemory.enable' => ['1'],
	'log.level.change.acom' => ['4'],
	'log.level.change.app1' => ['4'],
	'log.level.change.ares' => ['4'],
	'log.level.change.bdiag' => ['4'],
	'log.level.change.brow' => ['4'],
	'log.level.change.cap' => ['4'],
	'log.level.change.cdp' => ['4'],
	'log.level.change.cert' => ['4'],
	'log.level.change.cfg' => ['4'],
	'log.level.change.clink' => ['4'],
	'log.level.change.cmp' => ['4'],
	'log.level.change.cmr' => ['4'],
	'log.level.change.copy' => ['4'],
	'log.level.change.curl' => ['4'],
	'log.level.change.dbs' => ['4'],
	'log.level.change.dbuf' => ['4'],
	'log.level.change.dhcpc' => ['4'],
	'log.level.change.dis' => ['4'],
	'log.level.change.dns' => ['4'],
	'log.level.change.dot1x' => ['4'],
	'log.level.change.ec' => ['4'],
	'log.level.change.efk' => ['4'],
	'log.level.change.ethf' => ['4'],
	'log.level.change.h323' => ['4'],
	'log.level.change.hset' => ['4'],
	'log.level.change.ht' => ['4'],
	'log.level.change.httpa' => ['4'],
	'log.level.change.httpd' => ['4'],
	'log.level.change.hw' => ['4'],
	'log.level.change.ib' => ['4'],
	'log.level.change.key' => ['4'],
	'log.level.change.ldap' => ['4'],
	'log.level.change.lic' => ['4'],
	'log.level.change.lldp' => ['4'],
	'log.level.change.log' => ['4'],
	'log.level.change.lp' => ['4'],
	'log.level.change.mb' => ['4'],
	'log.level.change.mobil' => ['4'],
	'log.level.change.net' => ['4'],
	'log.level.change.niche' => ['4'],
	'log.level.change.nwmgr' => ['4'],
	'log.level.change.osd' => ['4'],
	'log.level.change.pcd' => ['4'],
	'log.level.change.peer' => ['4'],
	'log.level.change.pgui' => ['4'],
	'log.level.change.pmt' => ['4'],
	'log.level.change.pnetm' => ['4'],
	'log.level.change.poll' => ['4'],
	'log.level.change.pps' => ['4'],
	'log.level.change.push' => ['4'],
	'log.level.change.pwrsv' => ['4'],
	'log.level.change.rdisk' => ['4'],
	'log.level.change.res' => ['4'],
	'log.level.change.rtos' => ['4'],
	'log.level.change.sec' => ['4'],
	'log.level.change.sig' => ['4'],
	'log.level.change.sip' => ['4'],
	'log.level.change.slog' => ['4'],
	'log.level.change.so' => ['4'],
	'log.level.change.soem' => ['4'],
	'log.level.change.srtp' => ['4'],
	'log.level.change.sshc' => ['4'],
	'log.level.change.ssps' => ['4'],
	'log.level.change.style' => ['4'],
	'log.level.change.sync' => ['4'],
	'log.level.change.sys' => ['4'],
	'log.level.change.ta' => ['6'],
	'log.level.change.task' => ['4'],
	'log.level.change.tr69' => ['4'],
	'log.level.change.trace' => ['4'],
	'log.level.change.ttrs' => ['4'],
	'log.level.change.usb' => ['4'],
	'log.level.change.usbio' => ['4'],
	'log.level.change.utilm' => ['4'],
	'log.level.change.wdog' => ['4'],
	'log.level.change.wlan' => ['4'],
	'log.level.change.wmgr' => ['4'],
	'log.level.change.xmpp' => ['4'],
	'log.render.file' => ['1'],
	'log.render.file.size' => ['16'],
	'log.render.file.upload.append' => ['1'],
	'log.render.file.upload.append.limitMode' => ['delete'],
	'log.render.file.upload.append.sizeLimit' => ['512'],
	'log.render.file.upload.period' => ['172800'],
	'log.render.level' => ['1'],
	'log.render.realtime' => ['1'],
	'log.render.stdout' => ['1'],
	'log.render.type' => ['2'],
	'log.sched.1.level' => ['3'],
	'log.sched.1.name' => ['showCpuLoad'],
	'log.sched.1.period' => ['15'],
	'log.sched.1.startDay' => ['0'],
	'log.sched.1.startMode' => ['rel'],
	'log.sched.1.startTime' => ['0'],
	'log.sched.10.level' => ['3'],
	'log.sched.10.name' => [''],
	'log.sched.10.period' => ['15'],
	'log.sched.10.startDay' => ['0'],
	'log.sched.10.startMode' => [''],
	'log.sched.10.startTime' => [''],
	'log.sched.2.level' => ['3'],
	'log.sched.2.name' => [''],
	'log.sched.2.period' => ['15'],
	'log.sched.2.startDay' => ['0'],
	'log.sched.2.startMode' => [''],
	'log.sched.2.startTime' => [''],
	'log.sched.3.level' => ['3'],
	'log.sched.3.name' => [''],
	'log.sched.3.period' => ['15'],
	'log.sched.3.startDay' => ['0'],
	'log.sched.3.startMode' => [''],
	'log.sched.3.startTime' => [''],
	'log.sched.4.level' => ['3'],
	'log.sched.4.name' => [''],
	'log.sched.4.period' => ['15'],
	'log.sched.4.startDay' => ['0'],
	'log.sched.4.startMode' => [''],
	'log.sched.4.startTime' => [''],
	'log.sched.5.level' => ['3'],
	'log.sched.5.name' => [''],
	'log.sched.5.period' => ['15'],
	'log.sched.5.startDay' => ['0'],
	'log.sched.5.startMode' => [''],
	'log.sched.5.startTime' => [''],
	'log.sched.6.level' => ['3'],
	'log.sched.6.name' => [''],
	'log.sched.6.period' => ['15'],
	'log.sched.6.startDay' => ['0'],
	'log.sched.6.startMode' => [''],
	'log.sched.6.startTime' => [''],
	'log.sched.7.level' => ['3'],
	'log.sched.7.name' => [''],
	'log.sched.7.period' => ['15'],
	'log.sched.7.startDay' => ['0'],
	'log.sched.7.startMode' => [''],
	'log.sched.7.startTime' => [''],
	'log.sched.8.level' => ['3'],
	'log.sched.8.name' => [''],
	'log.sched.8.period' => ['15'],
	'log.sched.8.startDay' => ['0'],
	'log.sched.8.startMode' => [''],
	'log.sched.8.startTime' => [''],
	'log.sched.9.level' => ['3'],
	'log.sched.9.name' => [''],
	'log.sched.9.period' => ['15'],
	'log.sched.9.startDay' => ['0'],
	'log.sched.9.startMode' => [''],
	'log.sched.9.startTime' => [''],
	'manf.cert' => ['0'],
	'manf.dmt' => ['0'],
	'manf.kpt' => ['0'],
	'mb.idleDisplay.home' => [''],
	'mb.idleDisplay.refresh' => ['0'],
	'mb.limits.cache' => ['400'],
	'mb.limits.cache.SPIP320' => ['200'],
	'mb.limits.cache.SPIP330' => ['200'],
	'mb.limits.cache.SSIP6000' => ['800'],
	'mb.limits.cache.SSIP7000' => ['800'],
	'mb.limits.cache.VVX1500' => ['1024'],
	'mb.main.autoBackKey' => ['1'],
	'mb.main.home' => [''],
	'mb.main.idleTimeout' => ['40'],
	'mb.main.statusbar' => ['0'],
	'mb.proxy' => [''],
	'mb.ssawc.call.mode' => ['passive', '' ],
	'mb.ssawc.enabled' => ['0'],
	'msg.bypassInstantMessage' => ['0'],
	'msg.mwi.1.callBack' => [''],
	'msg.mwi.1.callBackMode' => ['registration'],
	'msg.mwi.1.subscribe' => [''],
	'msg.mwi.10.callBack' => [''],
	'msg.mwi.10.callBackMode' => ['registration'],
	'msg.mwi.10.subscribe' => [''],
	'msg.mwi.11.callBack' => [''],
	'msg.mwi.11.callBackMode' => ['registration'],
	'msg.mwi.11.subscribe' => [''],
	'msg.mwi.12.callBack' => [''],
	'msg.mwi.12.callBackMode' => ['registration'],
	'msg.mwi.12.subscribe' => [''],
	'msg.mwi.13.callBack' => [''],
	'msg.mwi.13.callBackMode' => ['registration'],
	'msg.mwi.13.subscribe' => [''],
	'msg.mwi.14.callBack' => [''],
	'msg.mwi.14.callBackMode' => ['registration'],
	'msg.mwi.14.subscribe' => [''],
	'msg.mwi.15.callBack' => [''],
	'msg.mwi.15.callBackMode' => ['registration'],
	'msg.mwi.15.subscribe' => [''],
	'msg.mwi.16.callBack' => [''],
	'msg.mwi.16.callBackMode' => ['registration'],
	'msg.mwi.16.subscribe' => [''],
	'msg.mwi.17.callBack' => [''],
	'msg.mwi.17.callBackMode' => ['registration'],
	'msg.mwi.17.subscribe' => [''],
	'msg.mwi.18.callBack' => [''],
	'msg.mwi.18.callBackMode' => ['registration'],
	'msg.mwi.18.subscribe' => [''],
	'msg.mwi.19.callBack' => [''],
	'msg.mwi.19.callBackMode' => ['registration'],
	'msg.mwi.19.subscribe' => [''],
	'msg.mwi.2.callBack' => [''],
	'msg.mwi.2.callBackMode' => ['registration'],
	'msg.mwi.2.subscribe' => [''],
	'msg.mwi.20.callBack' => [''],
	'msg.mwi.20.callBackMode' => ['registration'],
	'msg.mwi.20.subscribe' => [''],
	'msg.mwi.21.callBack' => [''],
	'msg.mwi.21.callBackMode' => ['registration'],
	'msg.mwi.21.subscribe' => [''],
	'msg.mwi.22.callBack' => [''],
	'msg.mwi.22.callBackMode' => ['registration'],
	'msg.mwi.22.subscribe' => [''],
	'msg.mwi.23.callBack' => [''],
	'msg.mwi.23.callBackMode' => ['registration'],
	'msg.mwi.23.subscribe' => [''],
	'msg.mwi.24.callBack' => [''],
	'msg.mwi.24.callBackMode' => ['registration'],
	'msg.mwi.24.subscribe' => [''],
	'msg.mwi.25.callBack' => [''],
	'msg.mwi.25.callBackMode' => ['registration'],
	'msg.mwi.25.subscribe' => [''],
	'msg.mwi.26.callBack' => [''],
	'msg.mwi.26.callBackMode' => ['registration'],
	'msg.mwi.26.subscribe' => [''],
	'msg.mwi.27.callBack' => [''],
	'msg.mwi.27.callBackMode' => ['registration'],
	'msg.mwi.27.subscribe' => [''],
	'msg.mwi.28.callBack' => [''],
	'msg.mwi.28.callBackMode' => ['registration'],
	'msg.mwi.28.subscribe' => [''],
	'msg.mwi.29.callBack' => [''],
	'msg.mwi.29.callBackMode' => ['registration'],
	'msg.mwi.29.subscribe' => [''],
	'msg.mwi.3.callBack' => [''],
	'msg.mwi.3.callBackMode' => ['registration'],
	'msg.mwi.3.subscribe' => [''],
	'msg.mwi.30.callBack' => [''],
	'msg.mwi.30.callBackMode' => ['registration'],
	'msg.mwi.30.subscribe' => [''],
	'msg.mwi.31.callBack' => [''],
	'msg.mwi.31.callBackMode' => ['registration'],
	'msg.mwi.31.subscribe' => [''],
	'msg.mwi.32.callBack' => [''],
	'msg.mwi.32.callBackMode' => ['registration'],
	'msg.mwi.32.subscribe' => [''],
	'msg.mwi.33.callBack' => [''],
	'msg.mwi.33.callBackMode' => ['registration'],
	'msg.mwi.33.subscribe' => [''],
	'msg.mwi.34.callBack' => [''],
	'msg.mwi.34.callBackMode' => ['registration'],
	'msg.mwi.34.subscribe' => [''],
	'msg.mwi.4.callBack' => [''],
	'msg.mwi.4.callBackMode' => ['registration'],
	'msg.mwi.4.subscribe' => [''],
	'msg.mwi.5.callBack' => [''],
	'msg.mwi.5.callBackMode' => ['registration'],
	'msg.mwi.5.subscribe' => [''],
	'msg.mwi.6.callBack' => [''],
	'msg.mwi.6.callBackMode' => ['registration'],
	'msg.mwi.6.subscribe' => [''],
	'msg.mwi.7.callBack' => [''],
	'msg.mwi.7.callBackMode' => ['registration'],
	'msg.mwi.7.subscribe' => [''],
	'msg.mwi.8.callBack' => [''],
	'msg.mwi.8.callBackMode' => ['registration'],
	'msg.mwi.8.subscribe' => [''],
	'msg.mwi.9.callBack' => [''],
	'msg.mwi.9.callBackMode' => ['registration'],
	'msg.mwi.9.subscribe' => [''],
	'nat.ip' => [''],
	'nat.keepalive.interval' => ['0'],
	'nat.mediaPortStart' => ['0'],
	'nat.signalPort' => ['0'],
	'phoneLock.authorized.1.description' => [''],
	'phoneLock.authorized.1.value' => [''],
	'phoneLock.authorized.2.description' => [''],
	'phoneLock.authorized.2.value' => [''],
	'phoneLock.authorized.3.description' => [''],
	'phoneLock.authorized.3.value' => [''],
	'phoneLock.authorized.4.description' => [''],
	'phoneLock.authorized.4.value' => [''],
	'phoneLock.authorized.5.description' => [''],
	'phoneLock.authorized.5.value' => [''],
	'phoneLock.browserEnabled' => ['0'],
	'phoneLock.dndWhenLocked' => ['0'],
	'phoneLock.enabled' => ['0'],
	'phoneLock.idleTimeout' => ['0'],
	'phoneLock.lockState' => ['0'],
	'phoneLock.powerUpUnlocked' => ['0'],
	'pnet.debug.1' => ['0'],
	'pnet.debug.2' => ['0'],
	'pnet.debug.3' => ['0'],
	'pnet.debug.4' => ['0'],
	'pnet.debug.5' => ['0'],
	'pnet.debug.6' => ['0'],
	'pnet.debug.7' => ['0'],
	'pnet.debug.8' => ['0'],
	'pnet.hdx.ext' => [''],
	'pnet.remoteCall.callProgAtten' => ['-15', '' ],
	'pnet.remoteCall.dtmfDuration' => ['300'],
	'pnet.remoteCall.localDialtone' => ['0'],
	'pnet.role' => ['auto', '' ],
	'powerSaving.enable' => ['1'],
	'powerSaving.idleTimeout.offHours' => ['1'],
	'powerSaving.idleTimeout.officeHours' => ['10'],
	'powerSaving.idleTimeout.userInputExtension' => ['10'],
	'powerSaving.motionDetection.frameRate' => ['10'],
	'powerSaving.officeHours.duration.friday' => ['10'],
	'powerSaving.officeHours.duration.monday' => ['10'],
	'powerSaving.officeHours.duration.saturday' => ['0'],
	'powerSaving.officeHours.duration.sunday' => ['0'],
	'powerSaving.officeHours.duration.thursday' => ['10'],
	'powerSaving.officeHours.duration.tuesday' => ['10'],
	'powerSaving.officeHours.duration.wednesday' => ['10'],
	'powerSaving.officeHours.startHour.friday' => ['8'],
	'powerSaving.officeHours.startHour.monday' => ['8'],
	'powerSaving.officeHours.startHour.saturday' => ['8'],
	'powerSaving.officeHours.startHour.sunday' => ['8'],
	'powerSaving.officeHours.startHour.thursday' => ['8'],
	'powerSaving.officeHours.startHour.tuesday' => ['8'],
	'powerSaving.officeHours.startHour.wednesday' => ['8'],
	'powerSaving.userDetectionSensitivity.offHours' => ['2'],
	'powerSaving.userDetectionSensitivity.officeHours' => ['7'],
	'pres.idleSoftKeys' => ['1'],
	'pres.reg' => ['1'],
	'prov.configUploadPath' => [''],
	'prov.fileSystem.ffs0.minFreeSpace' => ['512'],
	'prov.fileSystem.ffs0.minFreeSpace.SPIP320' => ['420'],
	'prov.fileSystem.ffs0.minFreeSpace.SPIP330' => ['420'],
	'prov.fileSystem.rfs0.minFreeSpace' => ['10'],
	'prov.fileSystem.rfs0.minFreeSpace.SPIP320' => ['5'],
	'prov.fileSystem.rfs0.minFreeSpace.SPIP330' => ['5'],
	'prov.fileSystem.rfs0.minFreeSpace.SSIP6000' => ['20'],
	'prov.fileSystem.rfs0.minFreeSpace.SSIP7000' => ['20'],
	'prov.lineMap.cma.1' => ['1'],
	'prov.polling.enabled' => ['0'],
	'prov.polling.mode' => ['abs'],
	'prov.polling.period' => ['86400'],
	'prov.polling.time' => ['03:00'],
	'prov.quickSetup.enabled' => ['0'],
	'qos.ethernet.callControl.user_priority' => ['5'],
	'qos.ethernet.other.user_priority' => ['2'],
	'qos.ethernet.rtp.user_priority' => ['5'],
	'qos.ethernet.rtp.video.user_priority' => ['5'],
	'qos.ip.callControl.dscp' => [''],
	'qos.ip.callControl.dscp.assuredService.1' => ['48'],
	'qos.ip.callControl.dscp.assuredService.2' => ['48'],
	'qos.ip.callControl.dscp.assuredService.3' => ['48'],
	'qos.ip.callControl.dscp.assuredService.4' => ['48'],
	'qos.ip.callControl.dscp.assuredService.5' => ['48'],
	'qos.ip.callControl.dscp.assuredService.6' => ['48'],
	'qos.ip.callControl.dscp.assuredService.7' => ['48'],
	'qos.ip.callControl.dscp.assuredService.8' => ['48'],
	'qos.ip.callControl.dscp.assuredService.9' => ['48'],
	'qos.ip.callControl.max_reliability' => ['0'],
	'qos.ip.callControl.max_throughput' => ['0'],
	'qos.ip.callControl.min_cost' => ['0'],
	'qos.ip.callControl.min_delay' => ['1'],
	'qos.ip.callControl.precedence' => ['5'],
	'qos.ip.rtp.dscp' => [''],
	'qos.ip.rtp.dscp.assuredService.1' => ['46'],
	'qos.ip.rtp.dscp.assuredService.2' => ['45'],
	'qos.ip.rtp.dscp.assuredService.3' => ['43'],
	'qos.ip.rtp.dscp.assuredService.4' => ['42'],
	'qos.ip.rtp.dscp.assuredService.5' => ['41'],
	'qos.ip.rtp.dscp.assuredService.6' => ['41'],
	'qos.ip.rtp.dscp.assuredService.7' => ['41'],
	'qos.ip.rtp.dscp.assuredService.8' => ['41'],
	'qos.ip.rtp.dscp.assuredService.9' => ['41'],
	'qos.ip.rtp.max_reliability' => ['0'],
	'qos.ip.rtp.max_throughput' => ['1'],
	'qos.ip.rtp.min_cost' => ['0'],
	'qos.ip.rtp.min_delay' => ['1'],
	'qos.ip.rtp.precedence' => ['5'],
	'qos.ip.rtp.video.dscp' => [''],
	'qos.ip.rtp.video.dscp.assuredService.1' => ['38'],
	'qos.ip.rtp.video.dscp.assuredService.2' => ['37'],
	'qos.ip.rtp.video.dscp.assuredService.3' => ['35'],
	'qos.ip.rtp.video.dscp.assuredService.4' => ['34'],
	'qos.ip.rtp.video.dscp.assuredService.5' => ['33'],
	'qos.ip.rtp.video.dscp.assuredService.6' => ['33'],
	'qos.ip.rtp.video.dscp.assuredService.7' => ['33'],
	'qos.ip.rtp.video.dscp.assuredService.8' => ['33'],
	'qos.ip.rtp.video.dscp.assuredService.9' => ['33'],
	'qos.ip.rtp.video.max_reliability' => ['0'],
	'qos.ip.rtp.video.max_throughput' => ['1'],
	'qos.ip.rtp.video.min_cost' => ['0'],
	'qos.ip.rtp.video.min_delay' => ['1'],
	'qos.ip.rtp.video.precedence' => ['5'],
	'ramdisk.enable' => ['1'],
	'ramdisk.minfree' => ['3150', 3072 ],
	'ramdisk.minsize' => ['50'],
	'ramdisk.size' => ['4096'],
	'ramdisk.size.SPIP320' => ['2048'],
	'ramdisk.size.SPIP330' => ['2048'],
	'ramdisk.size.SPIP650' => ['2048'],
	'ramdisk.size.SPIP670' => ['2048'],
	'ramdisk.size.SSIP6000' => ['8192'],
	'ramdisk.size.SSIP7000' => ['8192'],
	'ramdisk.size.VVX1500' => ['16384'],
	'reg.1.address' => [''],
	'reg.1.auth.optimizedInFailover' => ['0'],
	'reg.1.auth.password' => [''],
	'reg.1.auth.userId' => [''],
	'reg.1.bargeInEnabled' => ['0'],
	'reg.1.callsPerLineKey' => ['24'],
	'reg.1.csta' => ['0'],
	'reg.1.displayName' => [''],
	'reg.1.dndStatus' => ['0'],
	'reg.1.fwd.busy.contact' => [''],
	'reg.1.fwd.busy.status' => ['0'],
	'reg.1.fwd.noanswer.contact' => [''],
	'reg.1.fwd.noanswer.ringCount' => ['0'],
	'reg.1.fwd.noanswer.status' => ['0'],
	'reg.1.fwdContact' => [''],
	'reg.1.fwdStatus' => ['0'],
	'reg.1.label' => [''],
	'reg.1.lcs' => ['0'],
	'reg.1.lineKeys' => ['1'],
	'reg.1.musicOnHold.uri' => [''],
	'reg.1.mwiNew' => ['0'],
	'reg.1.mwiOld' => ['0'],
	'reg.1.mwiUrg' => ['0'],
	'reg.1.outboundProxy.address' => [''],
	'reg.1.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.1.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.1.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.1.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.1.outboundProxy.port' => ['0', 5060 ],
	'reg.1.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.1.protocol' => [''],
	'reg.1.protocol.H323' => ['0'],
	'reg.1.protocol.SIP' => ['1'],
	'reg.1.proxyRequire' => [''],
	'reg.1.ringType' => ['ringer2'],
	'reg.1.server.1.address' => [''],
	'reg.1.server.1.expires' => ['3600'],
	'reg.1.server.1.expires.lineSeize' => ['30'],
	'reg.1.server.1.expires.overlap' => ['60'],
	'reg.1.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.1.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.1.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.1.server.1.failOver.reRegisterOn' => ['0'],
	'reg.1.server.1.lcs' => ['0'],
	'reg.1.server.1.port' => ['0', '5060' ],
	'reg.1.server.1.register' => ['1'],
	'reg.1.server.1.retryMaxCount' => ['3'],
	'reg.1.server.1.retryTimeOut' => ['0'],
	'reg.1.server.1.transport' => ['DNSnaptr', '' ],
	'reg.1.server.2.address' => [''],
	'reg.1.server.2.expires' => ['3600'],
	'reg.1.server.2.expires.lineSeize' => ['30'],
	'reg.1.server.2.expires.overlap' => ['60'],
	'reg.1.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.1.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.1.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.1.server.2.failOver.reRegisterOn' => ['0'],
	'reg.1.server.2.lcs' => ['0'],
	'reg.1.server.2.port' => ['0', '5060' ],
	'reg.1.server.2.register' => ['1'],
	'reg.1.server.2.retryMaxCount' => ['3'],
	'reg.1.server.2.retryTimeOut' => ['0'],
	'reg.1.server.2.transport' => ['DNSnaptr', '' ],
	'reg.1.server.3.address' => [''],
	'reg.1.server.3.expires' => ['3600'],
	'reg.1.server.3.expires.lineSeize' => ['30'],
	'reg.1.server.3.expires.overlap' => ['60'],
	'reg.1.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.1.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.1.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.1.server.3.failOver.reRegisterOn' => ['0'],
	'reg.1.server.3.lcs' => ['0'],
	'reg.1.server.3.port' => ['0', '5060' ],
	'reg.1.server.3.register' => ['1'],
	'reg.1.server.3.retryMaxCount' => ['3'],
	'reg.1.server.3.retryTimeOut' => ['0'],
	'reg.1.server.3.transport' => ['DNSnaptr', '' ],
	'reg.1.server.4.address' => [''],
	'reg.1.server.4.expires' => ['3600'],
	'reg.1.server.4.expires.lineSeize' => ['30'],
	'reg.1.server.4.expires.overlap' => ['60'],
	'reg.1.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.1.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.1.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.1.server.4.failOver.reRegisterOn' => ['0'],
	'reg.1.server.4.lcs' => ['0'],
	'reg.1.server.4.port' => ['0', '5060' ],
	'reg.1.server.4.register' => ['1'],
	'reg.1.server.4.retryMaxCount' => ['3'],
	'reg.1.server.4.retryTimeOut' => ['0'],
	'reg.1.server.4.transport' => ['DNSnaptr', '' ],
	'reg.1.server.H323.1.address' => [''],
	'reg.1.server.H323.1.expires' => ['3600'],
	'reg.1.server.H323.1.port' => ['0'],
	'reg.1.server.H323.1.register' => ['1'],
	'reg.1.server.H323.2.address' => [''],
	'reg.1.server.H323.2.expires' => ['3600'],
	'reg.1.server.H323.2.port' => ['0'],
	'reg.1.server.H323.2.register' => ['1'],
	'reg.1.server.H323.3.address' => [''],
	'reg.1.server.H323.3.expires' => ['3600'],
	'reg.1.server.H323.3.port' => ['0'],
	'reg.1.server.H323.3.register' => ['1'],
	'reg.1.server.H323.4.address' => [''],
	'reg.1.server.H323.4.expires' => ['3600'],
	'reg.1.server.H323.4.port' => ['0'],
	'reg.1.server.H323.4.register' => ['1'],
	'reg.1.serverFeatureControl.cf' => ['1'],
	'reg.1.serverFeatureControl.dnd' => ['1'],
	'reg.1.strictLineSeize' => ['0'],
	'reg.1.tcpFastFailover' => ['0'],
	'reg.1.thirdPartyName' => [''],
	'reg.1.type' => ['private'],
	'reg.1.useCompleteUriForRetrieve' => ['1'],
	'reg.10.address' => [''],
	'reg.10.auth.optimizedInFailover' => ['0'],
	'reg.10.auth.password' => [''],
	'reg.10.auth.userId' => [''],
	'reg.10.bargeInEnabled' => ['0'],
	'reg.10.callsPerLineKey' => ['24'],
	'reg.10.csta' => ['0'],
	'reg.10.displayName' => [''],
	'reg.10.dndStatus' => ['0'],
	'reg.10.fwd.busy.contact' => [''],
	'reg.10.fwd.busy.status' => ['0'],
	'reg.10.fwd.noanswer.contact' => [''],
	'reg.10.fwd.noanswer.ringCount' => ['0'],
	'reg.10.fwd.noanswer.status' => ['0'],
	'reg.10.fwdContact' => [''],
	'reg.10.fwdStatus' => ['0'],
	'reg.10.label' => [''],
	'reg.10.lcs' => ['0'],
	'reg.10.lineKeys' => ['1'],
	'reg.10.musicOnHold.uri' => [''],
	'reg.10.mwiNew' => ['0'],
	'reg.10.mwiOld' => ['0'],
	'reg.10.mwiUrg' => ['0'],
	'reg.10.outboundProxy.address' => [''],
	'reg.10.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.10.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.10.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.10.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.10.outboundProxy.port' => ['0', 5060 ],
	'reg.10.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.10.protocol' => [''],
	'reg.10.protocol.H323' => ['0'],
	'reg.10.protocol.SIP' => ['1'],
	'reg.10.proxyRequire' => [''],
	'reg.10.ringType' => ['ringer2'],
	'reg.10.server.1.address' => [''],
	'reg.10.server.1.expires' => ['3600'],
	'reg.10.server.1.expires.lineSeize' => ['30'],
	'reg.10.server.1.expires.overlap' => ['60'],
	'reg.10.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.10.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.10.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.10.server.1.failOver.reRegisterOn' => ['0'],
	'reg.10.server.1.lcs' => ['0'],
	'reg.10.server.1.port' => ['0', '5060' ],
	'reg.10.server.1.register' => ['1'],
	'reg.10.server.1.retryMaxCount' => ['3'],
	'reg.10.server.1.retryTimeOut' => ['0'],
	'reg.10.server.1.transport' => ['DNSnaptr', '' ],
	'reg.10.server.2.address' => [''],
	'reg.10.server.2.expires' => ['3600'],
	'reg.10.server.2.expires.lineSeize' => ['30'],
	'reg.10.server.2.expires.overlap' => ['60'],
	'reg.10.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.10.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.10.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.10.server.2.failOver.reRegisterOn' => ['0'],
	'reg.10.server.2.lcs' => ['0'],
	'reg.10.server.2.port' => ['0', '5060' ],
	'reg.10.server.2.register' => ['1'],
	'reg.10.server.2.retryMaxCount' => ['3'],
	'reg.10.server.2.retryTimeOut' => ['0'],
	'reg.10.server.2.transport' => ['DNSnaptr', '' ],
	'reg.10.server.3.address' => [''],
	'reg.10.server.3.expires' => ['3600'],
	'reg.10.server.3.expires.lineSeize' => ['30'],
	'reg.10.server.3.expires.overlap' => ['60'],
	'reg.10.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.10.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.10.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.10.server.3.failOver.reRegisterOn' => ['0'],
	'reg.10.server.3.lcs' => ['0'],
	'reg.10.server.3.port' => ['0', '5060' ],
	'reg.10.server.3.register' => ['1'],
	'reg.10.server.3.retryMaxCount' => ['3'],
	'reg.10.server.3.retryTimeOut' => ['0'],
	'reg.10.server.3.transport' => ['DNSnaptr', '' ],
	'reg.10.server.4.address' => [''],
	'reg.10.server.4.expires' => ['3600'],
	'reg.10.server.4.expires.lineSeize' => ['30'],
	'reg.10.server.4.expires.overlap' => ['60'],
	'reg.10.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.10.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.10.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.10.server.4.failOver.reRegisterOn' => ['0'],
	'reg.10.server.4.lcs' => ['0'],
	'reg.10.server.4.port' => ['0', '5060' ],
	'reg.10.server.4.register' => ['1'],
	'reg.10.server.4.retryMaxCount' => ['3'],
	'reg.10.server.4.retryTimeOut' => ['0'],
	'reg.10.server.4.transport' => ['DNSnaptr', '' ],
	'reg.10.server.H323.1.address' => [''],
	'reg.10.server.H323.1.expires' => ['3600'],
	'reg.10.server.H323.1.port' => ['0'],
	'reg.10.server.H323.1.register' => ['1'],
	'reg.10.server.H323.2.address' => [''],
	'reg.10.server.H323.2.expires' => ['3600'],
	'reg.10.server.H323.2.port' => ['0'],
	'reg.10.server.H323.2.register' => ['1'],
	'reg.10.server.H323.3.address' => [''],
	'reg.10.server.H323.3.expires' => ['3600'],
	'reg.10.server.H323.3.port' => ['0'],
	'reg.10.server.H323.3.register' => ['1'],
	'reg.10.server.H323.4.address' => [''],
	'reg.10.server.H323.4.expires' => ['3600'],
	'reg.10.server.H323.4.port' => ['0'],
	'reg.10.server.H323.4.register' => ['1'],
	'reg.10.serverFeatureControl.cf' => ['1'],
	'reg.10.serverFeatureControl.dnd' => ['1'],
	'reg.10.strictLineSeize' => ['0'],
	'reg.10.tcpFastFailover' => ['0'],
	'reg.10.thirdPartyName' => [''],
	'reg.10.type' => ['private'],
	'reg.10.useCompleteUriForRetrieve' => ['1'],
	'reg.11.address' => [''],
	'reg.11.auth.optimizedInFailover' => ['0'],
	'reg.11.auth.password' => [''],
	'reg.11.auth.userId' => [''],
	'reg.11.bargeInEnabled' => ['0'],
	'reg.11.callsPerLineKey' => ['24'],
	'reg.11.csta' => ['0'],
	'reg.11.displayName' => [''],
	'reg.11.dndStatus' => ['0'],
	'reg.11.fwd.busy.contact' => [''],
	'reg.11.fwd.busy.status' => ['0'],
	'reg.11.fwd.noanswer.contact' => [''],
	'reg.11.fwd.noanswer.ringCount' => ['0'],
	'reg.11.fwd.noanswer.status' => ['0'],
	'reg.11.fwdContact' => [''],
	'reg.11.fwdStatus' => ['0'],
	'reg.11.label' => [''],
	'reg.11.lcs' => ['0'],
	'reg.11.lineKeys' => ['1'],
	'reg.11.musicOnHold.uri' => [''],
	'reg.11.mwiNew' => ['0'],
	'reg.11.mwiOld' => ['0'],
	'reg.11.mwiUrg' => ['0'],
	'reg.11.outboundProxy.address' => [''],
	'reg.11.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.11.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.11.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.11.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.11.outboundProxy.port' => ['0', 5060 ],
	'reg.11.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.11.protocol' => [''],
	'reg.11.protocol.H323' => ['0'],
	'reg.11.protocol.SIP' => ['1'],
	'reg.11.proxyRequire' => [''],
	'reg.11.ringType' => ['ringer2'],
	'reg.11.server.1.address' => [''],
	'reg.11.server.1.expires' => ['3600'],
	'reg.11.server.1.expires.lineSeize' => ['30'],
	'reg.11.server.1.expires.overlap' => ['60'],
	'reg.11.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.11.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.11.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.11.server.1.failOver.reRegisterOn' => ['0'],
	'reg.11.server.1.lcs' => ['0'],
	'reg.11.server.1.port' => ['0', '5060' ],
	'reg.11.server.1.register' => ['1'],
	'reg.11.server.1.retryMaxCount' => ['3'],
	'reg.11.server.1.retryTimeOut' => ['0'],
	'reg.11.server.1.transport' => ['DNSnaptr', '' ],
	'reg.11.server.2.address' => [''],
	'reg.11.server.2.expires' => ['3600'],
	'reg.11.server.2.expires.lineSeize' => ['30'],
	'reg.11.server.2.expires.overlap' => ['60'],
	'reg.11.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.11.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.11.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.11.server.2.failOver.reRegisterOn' => ['0'],
	'reg.11.server.2.lcs' => ['0'],
	'reg.11.server.2.port' => ['0', '5060' ],
	'reg.11.server.2.register' => ['1'],
	'reg.11.server.2.retryMaxCount' => ['3'],
	'reg.11.server.2.retryTimeOut' => ['0'],
	'reg.11.server.2.transport' => ['DNSnaptr', '' ],
	'reg.11.server.3.address' => [''],
	'reg.11.server.3.expires' => ['3600'],
	'reg.11.server.3.expires.lineSeize' => ['30'],
	'reg.11.server.3.expires.overlap' => ['60'],
	'reg.11.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.11.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.11.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.11.server.3.failOver.reRegisterOn' => ['0'],
	'reg.11.server.3.lcs' => ['0'],
	'reg.11.server.3.port' => ['0', '5060' ],
	'reg.11.server.3.register' => ['1'],
	'reg.11.server.3.retryMaxCount' => ['3'],
	'reg.11.server.3.retryTimeOut' => ['0'],
	'reg.11.server.3.transport' => ['DNSnaptr', '' ],
	'reg.11.server.4.address' => [''],
	'reg.11.server.4.expires' => ['3600'],
	'reg.11.server.4.expires.lineSeize' => ['30'],
	'reg.11.server.4.expires.overlap' => ['60'],
	'reg.11.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.11.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.11.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.11.server.4.failOver.reRegisterOn' => ['0'],
	'reg.11.server.4.lcs' => ['0'],
	'reg.11.server.4.port' => ['0', '5060' ],
	'reg.11.server.4.register' => ['1'],
	'reg.11.server.4.retryMaxCount' => ['3'],
	'reg.11.server.4.retryTimeOut' => ['0'],
	'reg.11.server.4.transport' => ['DNSnaptr', '' ],
	'reg.11.server.H323.1.address' => [''],
	'reg.11.server.H323.1.expires' => ['3600'],
	'reg.11.server.H323.1.port' => ['0'],
	'reg.11.server.H323.1.register' => ['1'],
	'reg.11.server.H323.2.address' => [''],
	'reg.11.server.H323.2.expires' => ['3600'],
	'reg.11.server.H323.2.port' => ['0'],
	'reg.11.server.H323.2.register' => ['1'],
	'reg.11.server.H323.3.address' => [''],
	'reg.11.server.H323.3.expires' => ['3600'],
	'reg.11.server.H323.3.port' => ['0'],
	'reg.11.server.H323.3.register' => ['1'],
	'reg.11.server.H323.4.address' => [''],
	'reg.11.server.H323.4.expires' => ['3600'],
	'reg.11.server.H323.4.port' => ['0'],
	'reg.11.server.H323.4.register' => ['1'],
	'reg.11.serverFeatureControl.cf' => ['1'],
	'reg.11.serverFeatureControl.dnd' => ['1'],
	'reg.11.strictLineSeize' => ['0'],
	'reg.11.tcpFastFailover' => ['0'],
	'reg.11.thirdPartyName' => [''],
	'reg.11.type' => ['private'],
	'reg.11.useCompleteUriForRetrieve' => ['1'],
	'reg.12.address' => [''],
	'reg.12.auth.optimizedInFailover' => ['0'],
	'reg.12.auth.password' => [''],
	'reg.12.auth.userId' => [''],
	'reg.12.bargeInEnabled' => ['0'],
	'reg.12.callsPerLineKey' => ['24'],
	'reg.12.csta' => ['0'],
	'reg.12.displayName' => [''],
	'reg.12.dndStatus' => ['0'],
	'reg.12.fwd.busy.contact' => [''],
	'reg.12.fwd.busy.status' => ['0'],
	'reg.12.fwd.noanswer.contact' => [''],
	'reg.12.fwd.noanswer.ringCount' => ['0'],
	'reg.12.fwd.noanswer.status' => ['0'],
	'reg.12.fwdContact' => [''],
	'reg.12.fwdStatus' => ['0'],
	'reg.12.label' => [''],
	'reg.12.lcs' => ['0'],
	'reg.12.lineKeys' => ['1'],
	'reg.12.musicOnHold.uri' => [''],
	'reg.12.mwiNew' => ['0'],
	'reg.12.mwiOld' => ['0'],
	'reg.12.mwiUrg' => ['0'],
	'reg.12.outboundProxy.address' => [''],
	'reg.12.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.12.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.12.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.12.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.12.outboundProxy.port' => ['0', 5060 ],
	'reg.12.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.12.protocol' => [''],
	'reg.12.protocol.H323' => ['0'],
	'reg.12.protocol.SIP' => ['1'],
	'reg.12.proxyRequire' => [''],
	'reg.12.ringType' => ['ringer2'],
	'reg.12.server.1.address' => [''],
	'reg.12.server.1.expires' => ['3600'],
	'reg.12.server.1.expires.lineSeize' => ['30'],
	'reg.12.server.1.expires.overlap' => ['60'],
	'reg.12.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.12.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.12.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.12.server.1.failOver.reRegisterOn' => ['0'],
	'reg.12.server.1.lcs' => ['0'],
	'reg.12.server.1.port' => ['0', '5060' ],
	'reg.12.server.1.register' => ['1'],
	'reg.12.server.1.retryMaxCount' => ['3'],
	'reg.12.server.1.retryTimeOut' => ['0'],
	'reg.12.server.1.transport' => ['DNSnaptr', '' ],
	'reg.12.server.2.address' => [''],
	'reg.12.server.2.expires' => ['3600'],
	'reg.12.server.2.expires.lineSeize' => ['30'],
	'reg.12.server.2.expires.overlap' => ['60'],
	'reg.12.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.12.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.12.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.12.server.2.failOver.reRegisterOn' => ['0'],
	'reg.12.server.2.lcs' => ['0'],
	'reg.12.server.2.port' => ['0', '5060' ],
	'reg.12.server.2.register' => ['1'],
	'reg.12.server.2.retryMaxCount' => ['3'],
	'reg.12.server.2.retryTimeOut' => ['0'],
	'reg.12.server.2.transport' => ['DNSnaptr', '' ],
	'reg.12.server.3.address' => [''],
	'reg.12.server.3.expires' => ['3600'],
	'reg.12.server.3.expires.lineSeize' => ['30'],
	'reg.12.server.3.expires.overlap' => ['60'],
	'reg.12.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.12.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.12.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.12.server.3.failOver.reRegisterOn' => ['0'],
	'reg.12.server.3.lcs' => ['0'],
	'reg.12.server.3.port' => ['0', '5060' ],
	'reg.12.server.3.register' => ['1'],
	'reg.12.server.3.retryMaxCount' => ['3'],
	'reg.12.server.3.retryTimeOut' => ['0'],
	'reg.12.server.3.transport' => ['DNSnaptr', '' ],
	'reg.12.server.4.address' => [''],
	'reg.12.server.4.expires' => ['3600'],
	'reg.12.server.4.expires.lineSeize' => ['30'],
	'reg.12.server.4.expires.overlap' => ['60'],
	'reg.12.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.12.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.12.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.12.server.4.failOver.reRegisterOn' => ['0'],
	'reg.12.server.4.lcs' => ['0'],
	'reg.12.server.4.port' => ['0', '5060' ],
	'reg.12.server.4.register' => ['1'],
	'reg.12.server.4.retryMaxCount' => ['3'],
	'reg.12.server.4.retryTimeOut' => ['0'],
	'reg.12.server.4.transport' => ['DNSnaptr', '' ],
	'reg.12.server.H323.1.address' => [''],
	'reg.12.server.H323.1.expires' => ['3600'],
	'reg.12.server.H323.1.port' => ['0'],
	'reg.12.server.H323.1.register' => ['1'],
	'reg.12.server.H323.2.address' => [''],
	'reg.12.server.H323.2.expires' => ['3600'],
	'reg.12.server.H323.2.port' => ['0'],
	'reg.12.server.H323.2.register' => ['1'],
	'reg.12.server.H323.3.address' => [''],
	'reg.12.server.H323.3.expires' => ['3600'],
	'reg.12.server.H323.3.port' => ['0'],
	'reg.12.server.H323.3.register' => ['1'],
	'reg.12.server.H323.4.address' => [''],
	'reg.12.server.H323.4.expires' => ['3600'],
	'reg.12.server.H323.4.port' => ['0'],
	'reg.12.server.H323.4.register' => ['1'],
	'reg.12.serverFeatureControl.cf' => ['1'],
	'reg.12.serverFeatureControl.dnd' => ['1'],
	'reg.12.strictLineSeize' => ['0'],
	'reg.12.tcpFastFailover' => ['0'],
	'reg.12.thirdPartyName' => [''],
	'reg.12.type' => ['private'],
	'reg.12.useCompleteUriForRetrieve' => ['1'],
	'reg.13.address' => [''],
	'reg.13.auth.optimizedInFailover' => ['0'],
	'reg.13.auth.password' => [''],
	'reg.13.auth.userId' => [''],
	'reg.13.bargeInEnabled' => ['0'],
	'reg.13.callsPerLineKey' => ['24'],
	'reg.13.csta' => ['0'],
	'reg.13.displayName' => [''],
	'reg.13.dndStatus' => ['0'],
	'reg.13.fwd.busy.contact' => [''],
	'reg.13.fwd.busy.status' => ['0'],
	'reg.13.fwd.noanswer.contact' => [''],
	'reg.13.fwd.noanswer.ringCount' => ['0'],
	'reg.13.fwd.noanswer.status' => ['0'],
	'reg.13.fwdContact' => [''],
	'reg.13.fwdStatus' => ['0'],
	'reg.13.label' => [''],
	'reg.13.lcs' => ['0'],
	'reg.13.lineKeys' => ['1'],
	'reg.13.musicOnHold.uri' => [''],
	'reg.13.mwiNew' => ['0'],
	'reg.13.mwiOld' => ['0'],
	'reg.13.mwiUrg' => ['0'],
	'reg.13.outboundProxy.address' => [''],
	'reg.13.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.13.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.13.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.13.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.13.outboundProxy.port' => ['0', 5060 ],
	'reg.13.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.13.protocol' => [''],
	'reg.13.protocol.H323' => ['0'],
	'reg.13.protocol.SIP' => ['1'],
	'reg.13.proxyRequire' => [''],
	'reg.13.ringType' => ['ringer2'],
	'reg.13.server.1.address' => [''],
	'reg.13.server.1.expires' => ['3600'],
	'reg.13.server.1.expires.lineSeize' => ['30'],
	'reg.13.server.1.expires.overlap' => ['60'],
	'reg.13.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.13.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.13.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.13.server.1.failOver.reRegisterOn' => ['0'],
	'reg.13.server.1.lcs' => ['0'],
	'reg.13.server.1.port' => ['0', '5060' ],
	'reg.13.server.1.register' => ['1'],
	'reg.13.server.1.retryMaxCount' => ['3'],
	'reg.13.server.1.retryTimeOut' => ['0'],
	'reg.13.server.1.transport' => ['DNSnaptr', '' ],
	'reg.13.server.2.address' => [''],
	'reg.13.server.2.expires' => ['3600'],
	'reg.13.server.2.expires.lineSeize' => ['30'],
	'reg.13.server.2.expires.overlap' => ['60'],
	'reg.13.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.13.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.13.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.13.server.2.failOver.reRegisterOn' => ['0'],
	'reg.13.server.2.lcs' => ['0'],
	'reg.13.server.2.port' => ['0', '5060' ],
	'reg.13.server.2.register' => ['1'],
	'reg.13.server.2.retryMaxCount' => ['3'],
	'reg.13.server.2.retryTimeOut' => ['0'],
	'reg.13.server.2.transport' => ['DNSnaptr', '' ],
	'reg.13.server.3.address' => [''],
	'reg.13.server.3.expires' => ['3600'],
	'reg.13.server.3.expires.lineSeize' => ['30'],
	'reg.13.server.3.expires.overlap' => ['60'],
	'reg.13.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.13.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.13.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.13.server.3.failOver.reRegisterOn' => ['0'],
	'reg.13.server.3.lcs' => ['0'],
	'reg.13.server.3.port' => ['0', '5060' ],
	'reg.13.server.3.register' => ['1'],
	'reg.13.server.3.retryMaxCount' => ['3'],
	'reg.13.server.3.retryTimeOut' => ['0'],
	'reg.13.server.3.transport' => ['DNSnaptr', '' ],
	'reg.13.server.4.address' => [''],
	'reg.13.server.4.expires' => ['3600'],
	'reg.13.server.4.expires.lineSeize' => ['30'],
	'reg.13.server.4.expires.overlap' => ['60'],
	'reg.13.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.13.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.13.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.13.server.4.failOver.reRegisterOn' => ['0'],
	'reg.13.server.4.lcs' => ['0'],
	'reg.13.server.4.port' => ['0', '5060' ],
	'reg.13.server.4.register' => ['1'],
	'reg.13.server.4.retryMaxCount' => ['3'],
	'reg.13.server.4.retryTimeOut' => ['0'],
	'reg.13.server.4.transport' => ['DNSnaptr', '' ],
	'reg.13.server.H323.1.address' => [''],
	'reg.13.server.H323.1.expires' => ['3600'],
	'reg.13.server.H323.1.port' => ['0'],
	'reg.13.server.H323.1.register' => ['1'],
	'reg.13.server.H323.2.address' => [''],
	'reg.13.server.H323.2.expires' => ['3600'],
	'reg.13.server.H323.2.port' => ['0'],
	'reg.13.server.H323.2.register' => ['1'],
	'reg.13.server.H323.3.address' => [''],
	'reg.13.server.H323.3.expires' => ['3600'],
	'reg.13.server.H323.3.port' => ['0'],
	'reg.13.server.H323.3.register' => ['1'],
	'reg.13.server.H323.4.address' => [''],
	'reg.13.server.H323.4.expires' => ['3600'],
	'reg.13.server.H323.4.port' => ['0'],
	'reg.13.server.H323.4.register' => ['1'],
	'reg.13.serverFeatureControl.cf' => ['1'],
	'reg.13.serverFeatureControl.dnd' => ['1'],
	'reg.13.strictLineSeize' => ['0'],
	'reg.13.tcpFastFailover' => ['0'],
	'reg.13.thirdPartyName' => [''],
	'reg.13.type' => ['private'],
	'reg.13.useCompleteUriForRetrieve' => ['1'],
	'reg.14.address' => [''],
	'reg.14.auth.optimizedInFailover' => ['0'],
	'reg.14.auth.password' => [''],
	'reg.14.auth.userId' => [''],
	'reg.14.bargeInEnabled' => ['0'],
	'reg.14.callsPerLineKey' => ['24'],
	'reg.14.csta' => ['0'],
	'reg.14.displayName' => [''],
	'reg.14.dndStatus' => ['0'],
	'reg.14.fwd.busy.contact' => [''],
	'reg.14.fwd.busy.status' => ['0'],
	'reg.14.fwd.noanswer.contact' => [''],
	'reg.14.fwd.noanswer.ringCount' => ['0'],
	'reg.14.fwd.noanswer.status' => ['0'],
	'reg.14.fwdContact' => [''],
	'reg.14.fwdStatus' => ['0'],
	'reg.14.label' => [''],
	'reg.14.lcs' => ['0'],
	'reg.14.lineKeys' => ['1'],
	'reg.14.musicOnHold.uri' => [''],
	'reg.14.mwiNew' => ['0'],
	'reg.14.mwiOld' => ['0'],
	'reg.14.mwiUrg' => ['0'],
	'reg.14.outboundProxy.address' => [''],
	'reg.14.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.14.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.14.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.14.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.14.outboundProxy.port' => ['0', 5060 ],
	'reg.14.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.14.protocol' => [''],
	'reg.14.protocol.H323' => ['0'],
	'reg.14.protocol.SIP' => ['1'],
	'reg.14.proxyRequire' => [''],
	'reg.14.ringType' => ['ringer2'],
	'reg.14.server.1.address' => [''],
	'reg.14.server.1.expires' => ['3600'],
	'reg.14.server.1.expires.lineSeize' => ['30'],
	'reg.14.server.1.expires.overlap' => ['60'],
	'reg.14.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.14.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.14.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.14.server.1.failOver.reRegisterOn' => ['0'],
	'reg.14.server.1.lcs' => ['0'],
	'reg.14.server.1.port' => ['0', '5060' ],
	'reg.14.server.1.register' => ['1'],
	'reg.14.server.1.retryMaxCount' => ['3'],
	'reg.14.server.1.retryTimeOut' => ['0'],
	'reg.14.server.1.transport' => ['DNSnaptr', '' ],
	'reg.14.server.2.address' => [''],
	'reg.14.server.2.expires' => ['3600'],
	'reg.14.server.2.expires.lineSeize' => ['30'],
	'reg.14.server.2.expires.overlap' => ['60'],
	'reg.14.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.14.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.14.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.14.server.2.failOver.reRegisterOn' => ['0'],
	'reg.14.server.2.lcs' => ['0'],
	'reg.14.server.2.port' => ['0', '5060' ],
	'reg.14.server.2.register' => ['1'],
	'reg.14.server.2.retryMaxCount' => ['3'],
	'reg.14.server.2.retryTimeOut' => ['0'],
	'reg.14.server.2.transport' => ['DNSnaptr', '' ],
	'reg.14.server.3.address' => [''],
	'reg.14.server.3.expires' => ['3600'],
	'reg.14.server.3.expires.lineSeize' => ['30'],
	'reg.14.server.3.expires.overlap' => ['60'],
	'reg.14.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.14.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.14.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.14.server.3.failOver.reRegisterOn' => ['0'],
	'reg.14.server.3.lcs' => ['0'],
	'reg.14.server.3.port' => ['0', '5060' ],
	'reg.14.server.3.register' => ['1'],
	'reg.14.server.3.retryMaxCount' => ['3'],
	'reg.14.server.3.retryTimeOut' => ['0'],
	'reg.14.server.3.transport' => ['DNSnaptr', '' ],
	'reg.14.server.4.address' => [''],
	'reg.14.server.4.expires' => ['3600'],
	'reg.14.server.4.expires.lineSeize' => ['30'],
	'reg.14.server.4.expires.overlap' => ['60'],
	'reg.14.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.14.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.14.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.14.server.4.failOver.reRegisterOn' => ['0'],
	'reg.14.server.4.lcs' => ['0'],
	'reg.14.server.4.port' => ['0', '5060' ],
	'reg.14.server.4.register' => ['1'],
	'reg.14.server.4.retryMaxCount' => ['3'],
	'reg.14.server.4.retryTimeOut' => ['0'],
	'reg.14.server.4.transport' => ['DNSnaptr', '' ],
	'reg.14.server.H323.1.address' => [''],
	'reg.14.server.H323.1.expires' => ['3600'],
	'reg.14.server.H323.1.port' => ['0'],
	'reg.14.server.H323.1.register' => ['1'],
	'reg.14.server.H323.2.address' => [''],
	'reg.14.server.H323.2.expires' => ['3600'],
	'reg.14.server.H323.2.port' => ['0'],
	'reg.14.server.H323.2.register' => ['1'],
	'reg.14.server.H323.3.address' => [''],
	'reg.14.server.H323.3.expires' => ['3600'],
	'reg.14.server.H323.3.port' => ['0'],
	'reg.14.server.H323.3.register' => ['1'],
	'reg.14.server.H323.4.address' => [''],
	'reg.14.server.H323.4.expires' => ['3600'],
	'reg.14.server.H323.4.port' => ['0'],
	'reg.14.server.H323.4.register' => ['1'],
	'reg.14.serverFeatureControl.cf' => ['1'],
	'reg.14.serverFeatureControl.dnd' => ['1'],
	'reg.14.strictLineSeize' => ['0'],
	'reg.14.tcpFastFailover' => ['0'],
	'reg.14.thirdPartyName' => [''],
	'reg.14.type' => ['private'],
	'reg.14.useCompleteUriForRetrieve' => ['1'],
	'reg.15.address' => [''],
	'reg.15.auth.optimizedInFailover' => ['0'],
	'reg.15.auth.password' => [''],
	'reg.15.auth.userId' => [''],
	'reg.15.bargeInEnabled' => ['0'],
	'reg.15.callsPerLineKey' => ['24'],
	'reg.15.csta' => ['0'],
	'reg.15.displayName' => [''],
	'reg.15.dndStatus' => ['0'],
	'reg.15.fwd.busy.contact' => [''],
	'reg.15.fwd.busy.status' => ['0'],
	'reg.15.fwd.noanswer.contact' => [''],
	'reg.15.fwd.noanswer.ringCount' => ['0'],
	'reg.15.fwd.noanswer.status' => ['0'],
	'reg.15.fwdContact' => [''],
	'reg.15.fwdStatus' => ['0'],
	'reg.15.label' => [''],
	'reg.15.lcs' => ['0'],
	'reg.15.lineKeys' => ['1'],
	'reg.15.musicOnHold.uri' => [''],
	'reg.15.mwiNew' => ['0'],
	'reg.15.mwiOld' => ['0'],
	'reg.15.mwiUrg' => ['0'],
	'reg.15.outboundProxy.address' => [''],
	'reg.15.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.15.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.15.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.15.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.15.outboundProxy.port' => ['0', 5060 ],
	'reg.15.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.15.protocol' => [''],
	'reg.15.protocol.H323' => ['0'],
	'reg.15.protocol.SIP' => ['1'],
	'reg.15.proxyRequire' => [''],
	'reg.15.ringType' => ['ringer2'],
	'reg.15.server.1.address' => [''],
	'reg.15.server.1.expires' => ['3600'],
	'reg.15.server.1.expires.lineSeize' => ['30'],
	'reg.15.server.1.expires.overlap' => ['60'],
	'reg.15.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.15.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.15.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.15.server.1.failOver.reRegisterOn' => ['0'],
	'reg.15.server.1.lcs' => ['0'],
	'reg.15.server.1.port' => ['0', '5060' ],
	'reg.15.server.1.register' => ['1'],
	'reg.15.server.1.retryMaxCount' => ['3'],
	'reg.15.server.1.retryTimeOut' => ['0'],
	'reg.15.server.1.transport' => ['DNSnaptr', '' ],
	'reg.15.server.2.address' => [''],
	'reg.15.server.2.expires' => ['3600'],
	'reg.15.server.2.expires.lineSeize' => ['30'],
	'reg.15.server.2.expires.overlap' => ['60'],
	'reg.15.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.15.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.15.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.15.server.2.failOver.reRegisterOn' => ['0'],
	'reg.15.server.2.lcs' => ['0'],
	'reg.15.server.2.port' => ['0', '5060' ],
	'reg.15.server.2.register' => ['1'],
	'reg.15.server.2.retryMaxCount' => ['3'],
	'reg.15.server.2.retryTimeOut' => ['0'],
	'reg.15.server.2.transport' => ['DNSnaptr', '' ],
	'reg.15.server.3.address' => [''],
	'reg.15.server.3.expires' => ['3600'],
	'reg.15.server.3.expires.lineSeize' => ['30'],
	'reg.15.server.3.expires.overlap' => ['60'],
	'reg.15.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.15.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.15.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.15.server.3.failOver.reRegisterOn' => ['0'],
	'reg.15.server.3.lcs' => ['0'],
	'reg.15.server.3.port' => ['0', '5060' ],
	'reg.15.server.3.register' => ['1'],
	'reg.15.server.3.retryMaxCount' => ['3'],
	'reg.15.server.3.retryTimeOut' => ['0'],
	'reg.15.server.3.transport' => ['DNSnaptr', '' ],
	'reg.15.server.4.address' => [''],
	'reg.15.server.4.expires' => ['3600'],
	'reg.15.server.4.expires.lineSeize' => ['30'],
	'reg.15.server.4.expires.overlap' => ['60'],
	'reg.15.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.15.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.15.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.15.server.4.failOver.reRegisterOn' => ['0'],
	'reg.15.server.4.lcs' => ['0'],
	'reg.15.server.4.port' => ['0', '5060' ],
	'reg.15.server.4.register' => ['1'],
	'reg.15.server.4.retryMaxCount' => ['3'],
	'reg.15.server.4.retryTimeOut' => ['0'],
	'reg.15.server.4.transport' => ['DNSnaptr', '' ],
	'reg.15.server.H323.1.address' => [''],
	'reg.15.server.H323.1.expires' => ['3600'],
	'reg.15.server.H323.1.port' => ['0'],
	'reg.15.server.H323.1.register' => ['1'],
	'reg.15.server.H323.2.address' => [''],
	'reg.15.server.H323.2.expires' => ['3600'],
	'reg.15.server.H323.2.port' => ['0'],
	'reg.15.server.H323.2.register' => ['1'],
	'reg.15.server.H323.3.address' => [''],
	'reg.15.server.H323.3.expires' => ['3600'],
	'reg.15.server.H323.3.port' => ['0'],
	'reg.15.server.H323.3.register' => ['1'],
	'reg.15.server.H323.4.address' => [''],
	'reg.15.server.H323.4.expires' => ['3600'],
	'reg.15.server.H323.4.port' => ['0'],
	'reg.15.server.H323.4.register' => ['1'],
	'reg.15.serverFeatureControl.cf' => ['1'],
	'reg.15.serverFeatureControl.dnd' => ['1'],
	'reg.15.strictLineSeize' => ['0'],
	'reg.15.tcpFastFailover' => ['0'],
	'reg.15.thirdPartyName' => [''],
	'reg.15.type' => ['private'],
	'reg.15.useCompleteUriForRetrieve' => ['1'],
	'reg.16.address' => [''],
	'reg.16.auth.optimizedInFailover' => ['0'],
	'reg.16.auth.password' => [''],
	'reg.16.auth.userId' => [''],
	'reg.16.bargeInEnabled' => ['0'],
	'reg.16.callsPerLineKey' => ['24'],
	'reg.16.csta' => ['0'],
	'reg.16.displayName' => [''],
	'reg.16.dndStatus' => ['0'],
	'reg.16.fwd.busy.contact' => [''],
	'reg.16.fwd.busy.status' => ['0'],
	'reg.16.fwd.noanswer.contact' => [''],
	'reg.16.fwd.noanswer.ringCount' => ['0'],
	'reg.16.fwd.noanswer.status' => ['0'],
	'reg.16.fwdContact' => [''],
	'reg.16.fwdStatus' => ['0'],
	'reg.16.label' => [''],
	'reg.16.lcs' => ['0'],
	'reg.16.lineKeys' => ['1'],
	'reg.16.musicOnHold.uri' => [''],
	'reg.16.mwiNew' => ['0'],
	'reg.16.mwiOld' => ['0'],
	'reg.16.mwiUrg' => ['0'],
	'reg.16.outboundProxy.address' => [''],
	'reg.16.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.16.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.16.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.16.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.16.outboundProxy.port' => ['0', 5060 ],
	'reg.16.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.16.protocol' => [''],
	'reg.16.protocol.H323' => ['0'],
	'reg.16.protocol.SIP' => ['1'],
	'reg.16.proxyRequire' => [''],
	'reg.16.ringType' => ['ringer2'],
	'reg.16.server.1.address' => [''],
	'reg.16.server.1.expires' => ['3600'],
	'reg.16.server.1.expires.lineSeize' => ['30'],
	'reg.16.server.1.expires.overlap' => ['60'],
	'reg.16.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.16.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.16.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.16.server.1.failOver.reRegisterOn' => ['0'],
	'reg.16.server.1.lcs' => ['0'],
	'reg.16.server.1.port' => ['0', '5060' ],
	'reg.16.server.1.register' => ['1'],
	'reg.16.server.1.retryMaxCount' => ['3'],
	'reg.16.server.1.retryTimeOut' => ['0'],
	'reg.16.server.1.transport' => ['DNSnaptr', '' ],
	'reg.16.server.2.address' => [''],
	'reg.16.server.2.expires' => ['3600'],
	'reg.16.server.2.expires.lineSeize' => ['30'],
	'reg.16.server.2.expires.overlap' => ['60'],
	'reg.16.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.16.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.16.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.16.server.2.failOver.reRegisterOn' => ['0'],
	'reg.16.server.2.lcs' => ['0'],
	'reg.16.server.2.port' => ['0', '5060' ],
	'reg.16.server.2.register' => ['1'],
	'reg.16.server.2.retryMaxCount' => ['3'],
	'reg.16.server.2.retryTimeOut' => ['0'],
	'reg.16.server.2.transport' => ['DNSnaptr', '' ],
	'reg.16.server.3.address' => [''],
	'reg.16.server.3.expires' => ['3600'],
	'reg.16.server.3.expires.lineSeize' => ['30'],
	'reg.16.server.3.expires.overlap' => ['60'],
	'reg.16.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.16.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.16.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.16.server.3.failOver.reRegisterOn' => ['0'],
	'reg.16.server.3.lcs' => ['0'],
	'reg.16.server.3.port' => ['0', '5060' ],
	'reg.16.server.3.register' => ['1'],
	'reg.16.server.3.retryMaxCount' => ['3'],
	'reg.16.server.3.retryTimeOut' => ['0'],
	'reg.16.server.3.transport' => ['DNSnaptr', '' ],
	'reg.16.server.4.address' => [''],
	'reg.16.server.4.expires' => ['3600'],
	'reg.16.server.4.expires.lineSeize' => ['30'],
	'reg.16.server.4.expires.overlap' => ['60'],
	'reg.16.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.16.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.16.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.16.server.4.failOver.reRegisterOn' => ['0'],
	'reg.16.server.4.lcs' => ['0'],
	'reg.16.server.4.port' => ['0', '5060' ],
	'reg.16.server.4.register' => ['1'],
	'reg.16.server.4.retryMaxCount' => ['3'],
	'reg.16.server.4.retryTimeOut' => ['0'],
	'reg.16.server.4.transport' => ['DNSnaptr', '' ],
	'reg.16.server.H323.1.address' => [''],
	'reg.16.server.H323.1.expires' => ['3600'],
	'reg.16.server.H323.1.port' => ['0'],
	'reg.16.server.H323.1.register' => ['1'],
	'reg.16.server.H323.2.address' => [''],
	'reg.16.server.H323.2.expires' => ['3600'],
	'reg.16.server.H323.2.port' => ['0'],
	'reg.16.server.H323.2.register' => ['1'],
	'reg.16.server.H323.3.address' => [''],
	'reg.16.server.H323.3.expires' => ['3600'],
	'reg.16.server.H323.3.port' => ['0'],
	'reg.16.server.H323.3.register' => ['1'],
	'reg.16.server.H323.4.address' => [''],
	'reg.16.server.H323.4.expires' => ['3600'],
	'reg.16.server.H323.4.port' => ['0'],
	'reg.16.server.H323.4.register' => ['1'],
	'reg.16.serverFeatureControl.cf' => ['1'],
	'reg.16.serverFeatureControl.dnd' => ['1'],
	'reg.16.strictLineSeize' => ['0'],
	'reg.16.tcpFastFailover' => ['0'],
	'reg.16.thirdPartyName' => [''],
	'reg.16.type' => ['private'],
	'reg.16.useCompleteUriForRetrieve' => ['1'],
	'reg.17.address' => [''],
	'reg.17.auth.optimizedInFailover' => ['0'],
	'reg.17.auth.password' => [''],
	'reg.17.auth.userId' => [''],
	'reg.17.bargeInEnabled' => ['0'],
	'reg.17.callsPerLineKey' => ['24'],
	'reg.17.csta' => ['0'],
	'reg.17.displayName' => [''],
	'reg.17.dndStatus' => ['0'],
	'reg.17.fwd.busy.contact' => [''],
	'reg.17.fwd.busy.status' => ['0'],
	'reg.17.fwd.noanswer.contact' => [''],
	'reg.17.fwd.noanswer.ringCount' => ['0'],
	'reg.17.fwd.noanswer.status' => ['0'],
	'reg.17.fwdContact' => [''],
	'reg.17.fwdStatus' => ['0'],
	'reg.17.label' => [''],
	'reg.17.lcs' => ['0'],
	'reg.17.lineKeys' => ['1'],
	'reg.17.musicOnHold.uri' => [''],
	'reg.17.mwiNew' => ['0'],
	'reg.17.mwiOld' => ['0'],
	'reg.17.mwiUrg' => ['0'],
	'reg.17.outboundProxy.address' => [''],
	'reg.17.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.17.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.17.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.17.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.17.outboundProxy.port' => ['0', 5060 ],
	'reg.17.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.17.protocol' => [''],
	'reg.17.protocol.H323' => ['0'],
	'reg.17.protocol.SIP' => ['1'],
	'reg.17.proxyRequire' => [''],
	'reg.17.ringType' => ['ringer2'],
	'reg.17.server.1.address' => [''],
	'reg.17.server.1.expires' => ['3600'],
	'reg.17.server.1.expires.lineSeize' => ['30'],
	'reg.17.server.1.expires.overlap' => ['60'],
	'reg.17.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.17.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.17.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.17.server.1.failOver.reRegisterOn' => ['0'],
	'reg.17.server.1.lcs' => ['0'],
	'reg.17.server.1.port' => ['0', '5060' ],
	'reg.17.server.1.register' => ['1'],
	'reg.17.server.1.retryMaxCount' => ['3'],
	'reg.17.server.1.retryTimeOut' => ['0'],
	'reg.17.server.1.transport' => ['DNSnaptr', '' ],
	'reg.17.server.2.address' => [''],
	'reg.17.server.2.expires' => ['3600'],
	'reg.17.server.2.expires.lineSeize' => ['30'],
	'reg.17.server.2.expires.overlap' => ['60'],
	'reg.17.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.17.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.17.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.17.server.2.failOver.reRegisterOn' => ['0'],
	'reg.17.server.2.lcs' => ['0'],
	'reg.17.server.2.port' => ['0', '5060' ],
	'reg.17.server.2.register' => ['1'],
	'reg.17.server.2.retryMaxCount' => ['3'],
	'reg.17.server.2.retryTimeOut' => ['0'],
	'reg.17.server.2.transport' => ['DNSnaptr', '' ],
	'reg.17.server.3.address' => [''],
	'reg.17.server.3.expires' => ['3600'],
	'reg.17.server.3.expires.lineSeize' => ['30'],
	'reg.17.server.3.expires.overlap' => ['60'],
	'reg.17.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.17.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.17.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.17.server.3.failOver.reRegisterOn' => ['0'],
	'reg.17.server.3.lcs' => ['0'],
	'reg.17.server.3.port' => ['0', '5060' ],
	'reg.17.server.3.register' => ['1'],
	'reg.17.server.3.retryMaxCount' => ['3'],
	'reg.17.server.3.retryTimeOut' => ['0'],
	'reg.17.server.3.transport' => ['DNSnaptr', '' ],
	'reg.17.server.4.address' => [''],
	'reg.17.server.4.expires' => ['3600'],
	'reg.17.server.4.expires.lineSeize' => ['30'],
	'reg.17.server.4.expires.overlap' => ['60'],
	'reg.17.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.17.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.17.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.17.server.4.failOver.reRegisterOn' => ['0'],
	'reg.17.server.4.lcs' => ['0'],
	'reg.17.server.4.port' => ['0', '5060' ],
	'reg.17.server.4.register' => ['1'],
	'reg.17.server.4.retryMaxCount' => ['3'],
	'reg.17.server.4.retryTimeOut' => ['0'],
	'reg.17.server.4.transport' => ['DNSnaptr', '' ],
	'reg.17.server.H323.1.address' => [''],
	'reg.17.server.H323.1.expires' => ['3600'],
	'reg.17.server.H323.1.port' => ['0'],
	'reg.17.server.H323.1.register' => ['1'],
	'reg.17.server.H323.2.address' => [''],
	'reg.17.server.H323.2.expires' => ['3600'],
	'reg.17.server.H323.2.port' => ['0'],
	'reg.17.server.H323.2.register' => ['1'],
	'reg.17.server.H323.3.address' => [''],
	'reg.17.server.H323.3.expires' => ['3600'],
	'reg.17.server.H323.3.port' => ['0'],
	'reg.17.server.H323.3.register' => ['1'],
	'reg.17.server.H323.4.address' => [''],
	'reg.17.server.H323.4.expires' => ['3600'],
	'reg.17.server.H323.4.port' => ['0'],
	'reg.17.server.H323.4.register' => ['1'],
	'reg.17.serverFeatureControl.cf' => ['1'],
	'reg.17.serverFeatureControl.dnd' => ['1'],
	'reg.17.strictLineSeize' => ['0'],
	'reg.17.tcpFastFailover' => ['0'],
	'reg.17.thirdPartyName' => [''],
	'reg.17.type' => ['private'],
	'reg.17.useCompleteUriForRetrieve' => ['1'],
	'reg.18.address' => [''],
	'reg.18.auth.optimizedInFailover' => ['0'],
	'reg.18.auth.password' => [''],
	'reg.18.auth.userId' => [''],
	'reg.18.bargeInEnabled' => ['0'],
	'reg.18.callsPerLineKey' => ['24'],
	'reg.18.csta' => ['0'],
	'reg.18.displayName' => [''],
	'reg.18.dndStatus' => ['0'],
	'reg.18.fwd.busy.contact' => [''],
	'reg.18.fwd.busy.status' => ['0'],
	'reg.18.fwd.noanswer.contact' => [''],
	'reg.18.fwd.noanswer.ringCount' => ['0'],
	'reg.18.fwd.noanswer.status' => ['0'],
	'reg.18.fwdContact' => [''],
	'reg.18.fwdStatus' => ['0'],
	'reg.18.label' => [''],
	'reg.18.lcs' => ['0'],
	'reg.18.lineKeys' => ['1'],
	'reg.18.musicOnHold.uri' => [''],
	'reg.18.mwiNew' => ['0'],
	'reg.18.mwiOld' => ['0'],
	'reg.18.mwiUrg' => ['0'],
	'reg.18.outboundProxy.address' => [''],
	'reg.18.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.18.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.18.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.18.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.18.outboundProxy.port' => ['0', 5060 ],
	'reg.18.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.18.protocol' => [''],
	'reg.18.protocol.H323' => ['0'],
	'reg.18.protocol.SIP' => ['1'],
	'reg.18.proxyRequire' => [''],
	'reg.18.ringType' => ['ringer2'],
	'reg.18.server.1.address' => [''],
	'reg.18.server.1.expires' => ['3600'],
	'reg.18.server.1.expires.lineSeize' => ['30'],
	'reg.18.server.1.expires.overlap' => ['60'],
	'reg.18.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.18.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.18.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.18.server.1.failOver.reRegisterOn' => ['0'],
	'reg.18.server.1.lcs' => ['0'],
	'reg.18.server.1.port' => ['0', '5060' ],
	'reg.18.server.1.register' => ['1'],
	'reg.18.server.1.retryMaxCount' => ['3'],
	'reg.18.server.1.retryTimeOut' => ['0'],
	'reg.18.server.1.transport' => ['DNSnaptr', '' ],
	'reg.18.server.2.address' => [''],
	'reg.18.server.2.expires' => ['3600'],
	'reg.18.server.2.expires.lineSeize' => ['30'],
	'reg.18.server.2.expires.overlap' => ['60'],
	'reg.18.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.18.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.18.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.18.server.2.failOver.reRegisterOn' => ['0'],
	'reg.18.server.2.lcs' => ['0'],
	'reg.18.server.2.port' => ['0', '5060' ],
	'reg.18.server.2.register' => ['1'],
	'reg.18.server.2.retryMaxCount' => ['3'],
	'reg.18.server.2.retryTimeOut' => ['0'],
	'reg.18.server.2.transport' => ['DNSnaptr', '' ],
	'reg.18.server.3.address' => [''],
	'reg.18.server.3.expires' => ['3600'],
	'reg.18.server.3.expires.lineSeize' => ['30'],
	'reg.18.server.3.expires.overlap' => ['60'],
	'reg.18.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.18.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.18.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.18.server.3.failOver.reRegisterOn' => ['0'],
	'reg.18.server.3.lcs' => ['0'],
	'reg.18.server.3.port' => ['0', '5060' ],
	'reg.18.server.3.register' => ['1'],
	'reg.18.server.3.retryMaxCount' => ['3'],
	'reg.18.server.3.retryTimeOut' => ['0'],
	'reg.18.server.3.transport' => ['DNSnaptr', '' ],
	'reg.18.server.4.address' => [''],
	'reg.18.server.4.expires' => ['3600'],
	'reg.18.server.4.expires.lineSeize' => ['30'],
	'reg.18.server.4.expires.overlap' => ['60'],
	'reg.18.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.18.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.18.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.18.server.4.failOver.reRegisterOn' => ['0'],
	'reg.18.server.4.lcs' => ['0'],
	'reg.18.server.4.port' => ['0', '5060' ],
	'reg.18.server.4.register' => ['1'],
	'reg.18.server.4.retryMaxCount' => ['3'],
	'reg.18.server.4.retryTimeOut' => ['0'],
	'reg.18.server.4.transport' => ['DNSnaptr', '' ],
	'reg.18.server.H323.1.address' => [''],
	'reg.18.server.H323.1.expires' => ['3600'],
	'reg.18.server.H323.1.port' => ['0'],
	'reg.18.server.H323.1.register' => ['1'],
	'reg.18.server.H323.2.address' => [''],
	'reg.18.server.H323.2.expires' => ['3600'],
	'reg.18.server.H323.2.port' => ['0'],
	'reg.18.server.H323.2.register' => ['1'],
	'reg.18.server.H323.3.address' => [''],
	'reg.18.server.H323.3.expires' => ['3600'],
	'reg.18.server.H323.3.port' => ['0'],
	'reg.18.server.H323.3.register' => ['1'],
	'reg.18.server.H323.4.address' => [''],
	'reg.18.server.H323.4.expires' => ['3600'],
	'reg.18.server.H323.4.port' => ['0'],
	'reg.18.server.H323.4.register' => ['1'],
	'reg.18.serverFeatureControl.cf' => ['1'],
	'reg.18.serverFeatureControl.dnd' => ['1'],
	'reg.18.strictLineSeize' => ['0'],
	'reg.18.tcpFastFailover' => ['0'],
	'reg.18.thirdPartyName' => [''],
	'reg.18.type' => ['private'],
	'reg.18.useCompleteUriForRetrieve' => ['1'],
	'reg.19.address' => [''],
	'reg.19.auth.optimizedInFailover' => ['0'],
	'reg.19.auth.password' => [''],
	'reg.19.auth.userId' => [''],
	'reg.19.bargeInEnabled' => ['0'],
	'reg.19.callsPerLineKey' => ['24'],
	'reg.19.csta' => ['0'],
	'reg.19.displayName' => [''],
	'reg.19.dndStatus' => ['0'],
	'reg.19.fwd.busy.contact' => [''],
	'reg.19.fwd.busy.status' => ['0'],
	'reg.19.fwd.noanswer.contact' => [''],
	'reg.19.fwd.noanswer.ringCount' => ['0'],
	'reg.19.fwd.noanswer.status' => ['0'],
	'reg.19.fwdContact' => [''],
	'reg.19.fwdStatus' => ['0'],
	'reg.19.label' => [''],
	'reg.19.lcs' => ['0'],
	'reg.19.lineKeys' => ['1'],
	'reg.19.musicOnHold.uri' => [''],
	'reg.19.mwiNew' => ['0'],
	'reg.19.mwiOld' => ['0'],
	'reg.19.mwiUrg' => ['0'],
	'reg.19.outboundProxy.address' => [''],
	'reg.19.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.19.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.19.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.19.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.19.outboundProxy.port' => ['0', 5060 ],
	'reg.19.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.19.protocol' => [''],
	'reg.19.protocol.H323' => ['0'],
	'reg.19.protocol.SIP' => ['1'],
	'reg.19.proxyRequire' => [''],
	'reg.19.ringType' => ['ringer2'],
	'reg.19.server.1.address' => [''],
	'reg.19.server.1.expires' => ['3600'],
	'reg.19.server.1.expires.lineSeize' => ['30'],
	'reg.19.server.1.expires.overlap' => ['60'],
	'reg.19.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.19.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.19.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.19.server.1.failOver.reRegisterOn' => ['0'],
	'reg.19.server.1.lcs' => ['0'],
	'reg.19.server.1.port' => ['0', '5060' ],
	'reg.19.server.1.register' => ['1'],
	'reg.19.server.1.retryMaxCount' => ['3'],
	'reg.19.server.1.retryTimeOut' => ['0'],
	'reg.19.server.1.transport' => ['DNSnaptr', '' ],
	'reg.19.server.2.address' => [''],
	'reg.19.server.2.expires' => ['3600'],
	'reg.19.server.2.expires.lineSeize' => ['30'],
	'reg.19.server.2.expires.overlap' => ['60'],
	'reg.19.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.19.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.19.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.19.server.2.failOver.reRegisterOn' => ['0'],
	'reg.19.server.2.lcs' => ['0'],
	'reg.19.server.2.port' => ['0', '5060' ],
	'reg.19.server.2.register' => ['1'],
	'reg.19.server.2.retryMaxCount' => ['3'],
	'reg.19.server.2.retryTimeOut' => ['0'],
	'reg.19.server.2.transport' => ['DNSnaptr', '' ],
	'reg.19.server.3.address' => [''],
	'reg.19.server.3.expires' => ['3600'],
	'reg.19.server.3.expires.lineSeize' => ['30'],
	'reg.19.server.3.expires.overlap' => ['60'],
	'reg.19.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.19.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.19.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.19.server.3.failOver.reRegisterOn' => ['0'],
	'reg.19.server.3.lcs' => ['0'],
	'reg.19.server.3.port' => ['0', '5060' ],
	'reg.19.server.3.register' => ['1'],
	'reg.19.server.3.retryMaxCount' => ['3'],
	'reg.19.server.3.retryTimeOut' => ['0'],
	'reg.19.server.3.transport' => ['DNSnaptr', '' ],
	'reg.19.server.4.address' => [''],
	'reg.19.server.4.expires' => ['3600'],
	'reg.19.server.4.expires.lineSeize' => ['30'],
	'reg.19.server.4.expires.overlap' => ['60'],
	'reg.19.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.19.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.19.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.19.server.4.failOver.reRegisterOn' => ['0'],
	'reg.19.server.4.lcs' => ['0'],
	'reg.19.server.4.port' => ['0', '5060' ],
	'reg.19.server.4.register' => ['1'],
	'reg.19.server.4.retryMaxCount' => ['3'],
	'reg.19.server.4.retryTimeOut' => ['0'],
	'reg.19.server.4.transport' => ['DNSnaptr', '' ],
	'reg.19.server.H323.1.address' => [''],
	'reg.19.server.H323.1.expires' => ['3600'],
	'reg.19.server.H323.1.port' => ['0'],
	'reg.19.server.H323.1.register' => ['1'],
	'reg.19.server.H323.2.address' => [''],
	'reg.19.server.H323.2.expires' => ['3600'],
	'reg.19.server.H323.2.port' => ['0'],
	'reg.19.server.H323.2.register' => ['1'],
	'reg.19.server.H323.3.address' => [''],
	'reg.19.server.H323.3.expires' => ['3600'],
	'reg.19.server.H323.3.port' => ['0'],
	'reg.19.server.H323.3.register' => ['1'],
	'reg.19.server.H323.4.address' => [''],
	'reg.19.server.H323.4.expires' => ['3600'],
	'reg.19.server.H323.4.port' => ['0'],
	'reg.19.server.H323.4.register' => ['1'],
	'reg.19.serverFeatureControl.cf' => ['1'],
	'reg.19.serverFeatureControl.dnd' => ['1'],
	'reg.19.strictLineSeize' => ['0'],
	'reg.19.tcpFastFailover' => ['0'],
	'reg.19.thirdPartyName' => [''],
	'reg.19.type' => ['private'],
	'reg.19.useCompleteUriForRetrieve' => ['1'],
	'reg.2.address' => [''],
	'reg.2.auth.optimizedInFailover' => ['0'],
	'reg.2.auth.password' => [''],
	'reg.2.auth.userId' => [''],
	'reg.2.bargeInEnabled' => ['0'],
	'reg.2.callsPerLineKey' => ['24'],
	'reg.2.csta' => ['0'],
	'reg.2.displayName' => [''],
	'reg.2.dndStatus' => ['0'],
	'reg.2.fwd.busy.contact' => [''],
	'reg.2.fwd.busy.status' => ['0'],
	'reg.2.fwd.noanswer.contact' => [''],
	'reg.2.fwd.noanswer.ringCount' => ['0'],
	'reg.2.fwd.noanswer.status' => ['0'],
	'reg.2.fwdContact' => [''],
	'reg.2.fwdStatus' => ['0'],
	'reg.2.label' => [''],
	'reg.2.lcs' => ['0'],
	'reg.2.lineKeys' => ['1'],
	'reg.2.musicOnHold.uri' => [''],
	'reg.2.mwiNew' => ['0'],
	'reg.2.mwiOld' => ['0'],
	'reg.2.mwiUrg' => ['0'],
	'reg.2.outboundProxy.address' => [''],
	'reg.2.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.2.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.2.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.2.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.2.outboundProxy.port' => ['0', 5060 ],
	'reg.2.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.2.protocol' => [''],
	'reg.2.protocol.H323' => ['0'],
	'reg.2.protocol.SIP' => ['1'],
	'reg.2.proxyRequire' => [''],
	'reg.2.ringType' => ['ringer2'],
	'reg.2.server.1.address' => [''],
	'reg.2.server.1.expires' => ['3600'],
	'reg.2.server.1.expires.lineSeize' => ['30'],
	'reg.2.server.1.expires.overlap' => ['60'],
	'reg.2.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.2.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.2.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.2.server.1.failOver.reRegisterOn' => ['0'],
	'reg.2.server.1.lcs' => ['0'],
	'reg.2.server.1.port' => ['0', '5060' ],
	'reg.2.server.1.register' => ['1'],
	'reg.2.server.1.retryMaxCount' => ['3'],
	'reg.2.server.1.retryTimeOut' => ['0'],
	'reg.2.server.1.transport' => ['DNSnaptr', '' ],
	'reg.2.server.2.address' => [''],
	'reg.2.server.2.expires' => ['3600'],
	'reg.2.server.2.expires.lineSeize' => ['30'],
	'reg.2.server.2.expires.overlap' => ['60'],
	'reg.2.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.2.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.2.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.2.server.2.failOver.reRegisterOn' => ['0'],
	'reg.2.server.2.lcs' => ['0'],
	'reg.2.server.2.port' => ['0', '5060' ],
	'reg.2.server.2.register' => ['1'],
	'reg.2.server.2.retryMaxCount' => ['3'],
	'reg.2.server.2.retryTimeOut' => ['0'],
	'reg.2.server.2.transport' => ['DNSnaptr', '' ],
	'reg.2.server.3.address' => [''],
	'reg.2.server.3.expires' => ['3600'],
	'reg.2.server.3.expires.lineSeize' => ['30'],
	'reg.2.server.3.expires.overlap' => ['60'],
	'reg.2.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.2.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.2.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.2.server.3.failOver.reRegisterOn' => ['0'],
	'reg.2.server.3.lcs' => ['0'],
	'reg.2.server.3.port' => ['0', '5060' ],
	'reg.2.server.3.register' => ['1'],
	'reg.2.server.3.retryMaxCount' => ['3'],
	'reg.2.server.3.retryTimeOut' => ['0'],
	'reg.2.server.3.transport' => ['DNSnaptr', '' ],
	'reg.2.server.4.address' => [''],
	'reg.2.server.4.expires' => ['3600'],
	'reg.2.server.4.expires.lineSeize' => ['30'],
	'reg.2.server.4.expires.overlap' => ['60'],
	'reg.2.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.2.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.2.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.2.server.4.failOver.reRegisterOn' => ['0'],
	'reg.2.server.4.lcs' => ['0'],
	'reg.2.server.4.port' => ['0', '5060' ],
	'reg.2.server.4.register' => ['1'],
	'reg.2.server.4.retryMaxCount' => ['3'],
	'reg.2.server.4.retryTimeOut' => ['0'],
	'reg.2.server.4.transport' => ['DNSnaptr', '' ],
	'reg.2.server.H323.1.address' => [''],
	'reg.2.server.H323.1.expires' => ['3600'],
	'reg.2.server.H323.1.port' => ['0'],
	'reg.2.server.H323.1.register' => ['1'],
	'reg.2.server.H323.2.address' => [''],
	'reg.2.server.H323.2.expires' => ['3600'],
	'reg.2.server.H323.2.port' => ['0'],
	'reg.2.server.H323.2.register' => ['1'],
	'reg.2.server.H323.3.address' => [''],
	'reg.2.server.H323.3.expires' => ['3600'],
	'reg.2.server.H323.3.port' => ['0'],
	'reg.2.server.H323.3.register' => ['1'],
	'reg.2.server.H323.4.address' => [''],
	'reg.2.server.H323.4.expires' => ['3600'],
	'reg.2.server.H323.4.port' => ['0'],
	'reg.2.server.H323.4.register' => ['1'],
	'reg.2.serverFeatureControl.cf' => ['1'],
	'reg.2.serverFeatureControl.dnd' => ['1'],
	'reg.2.strictLineSeize' => ['0'],
	'reg.2.tcpFastFailover' => ['0'],
	'reg.2.thirdPartyName' => [''],
	'reg.2.type' => ['private'],
	'reg.2.useCompleteUriForRetrieve' => ['1'],
	'reg.20.address' => [''],
	'reg.20.auth.optimizedInFailover' => ['0'],
	'reg.20.auth.password' => [''],
	'reg.20.auth.userId' => [''],
	'reg.20.bargeInEnabled' => ['0'],
	'reg.20.callsPerLineKey' => ['24'],
	'reg.20.csta' => ['0'],
	'reg.20.displayName' => [''],
	'reg.20.dndStatus' => ['0'],
	'reg.20.fwd.busy.contact' => [''],
	'reg.20.fwd.busy.status' => ['0'],
	'reg.20.fwd.noanswer.contact' => [''],
	'reg.20.fwd.noanswer.ringCount' => ['0'],
	'reg.20.fwd.noanswer.status' => ['0'],
	'reg.20.fwdContact' => [''],
	'reg.20.fwdStatus' => ['0'],
	'reg.20.label' => [''],
	'reg.20.lcs' => ['0'],
	'reg.20.lineKeys' => ['1'],
	'reg.20.musicOnHold.uri' => [''],
	'reg.20.mwiNew' => ['0'],
	'reg.20.mwiOld' => ['0'],
	'reg.20.mwiUrg' => ['0'],
	'reg.20.outboundProxy.address' => [''],
	'reg.20.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.20.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.20.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.20.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.20.outboundProxy.port' => ['0', 5060 ],
	'reg.20.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.20.protocol' => [''],
	'reg.20.protocol.H323' => ['0'],
	'reg.20.protocol.SIP' => ['1'],
	'reg.20.proxyRequire' => [''],
	'reg.20.ringType' => ['ringer2'],
	'reg.20.server.1.address' => [''],
	'reg.20.server.1.expires' => ['3600'],
	'reg.20.server.1.expires.lineSeize' => ['30'],
	'reg.20.server.1.expires.overlap' => ['60'],
	'reg.20.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.20.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.20.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.20.server.1.failOver.reRegisterOn' => ['0'],
	'reg.20.server.1.lcs' => ['0'],
	'reg.20.server.1.port' => ['0', '5060' ],
	'reg.20.server.1.register' => ['1'],
	'reg.20.server.1.retryMaxCount' => ['3'],
	'reg.20.server.1.retryTimeOut' => ['0'],
	'reg.20.server.1.transport' => ['DNSnaptr', '' ],
	'reg.20.server.2.address' => [''],
	'reg.20.server.2.expires' => ['3600'],
	'reg.20.server.2.expires.lineSeize' => ['30'],
	'reg.20.server.2.expires.overlap' => ['60'],
	'reg.20.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.20.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.20.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.20.server.2.failOver.reRegisterOn' => ['0'],
	'reg.20.server.2.lcs' => ['0'],
	'reg.20.server.2.port' => ['0', '5060' ],
	'reg.20.server.2.register' => ['1'],
	'reg.20.server.2.retryMaxCount' => ['3'],
	'reg.20.server.2.retryTimeOut' => ['0'],
	'reg.20.server.2.transport' => ['DNSnaptr', '' ],
	'reg.20.server.3.address' => [''],
	'reg.20.server.3.expires' => ['3600'],
	'reg.20.server.3.expires.lineSeize' => ['30'],
	'reg.20.server.3.expires.overlap' => ['60'],
	'reg.20.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.20.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.20.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.20.server.3.failOver.reRegisterOn' => ['0'],
	'reg.20.server.3.lcs' => ['0'],
	'reg.20.server.3.port' => ['0', '5060' ],
	'reg.20.server.3.register' => ['1'],
	'reg.20.server.3.retryMaxCount' => ['3'],
	'reg.20.server.3.retryTimeOut' => ['0'],
	'reg.20.server.3.transport' => ['DNSnaptr', '' ],
	'reg.20.server.4.address' => [''],
	'reg.20.server.4.expires' => ['3600'],
	'reg.20.server.4.expires.lineSeize' => ['30'],
	'reg.20.server.4.expires.overlap' => ['60'],
	'reg.20.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.20.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.20.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.20.server.4.failOver.reRegisterOn' => ['0'],
	'reg.20.server.4.lcs' => ['0'],
	'reg.20.server.4.port' => ['0', '5060' ],
	'reg.20.server.4.register' => ['1'],
	'reg.20.server.4.retryMaxCount' => ['3'],
	'reg.20.server.4.retryTimeOut' => ['0'],
	'reg.20.server.4.transport' => ['DNSnaptr', '' ],
	'reg.20.server.H323.1.address' => [''],
	'reg.20.server.H323.1.expires' => ['3600'],
	'reg.20.server.H323.1.port' => ['0'],
	'reg.20.server.H323.1.register' => ['1'],
	'reg.20.server.H323.2.address' => [''],
	'reg.20.server.H323.2.expires' => ['3600'],
	'reg.20.server.H323.2.port' => ['0'],
	'reg.20.server.H323.2.register' => ['1'],
	'reg.20.server.H323.3.address' => [''],
	'reg.20.server.H323.3.expires' => ['3600'],
	'reg.20.server.H323.3.port' => ['0'],
	'reg.20.server.H323.3.register' => ['1'],
	'reg.20.server.H323.4.address' => [''],
	'reg.20.server.H323.4.expires' => ['3600'],
	'reg.20.server.H323.4.port' => ['0'],
	'reg.20.server.H323.4.register' => ['1'],
	'reg.20.serverFeatureControl.cf' => ['1'],
	'reg.20.serverFeatureControl.dnd' => ['1'],
	'reg.20.strictLineSeize' => ['0'],
	'reg.20.tcpFastFailover' => ['0'],
	'reg.20.thirdPartyName' => [''],
	'reg.20.type' => ['private'],
	'reg.20.useCompleteUriForRetrieve' => ['1'],
	'reg.21.address' => [''],
	'reg.21.auth.optimizedInFailover' => ['0'],
	'reg.21.auth.password' => [''],
	'reg.21.auth.userId' => [''],
	'reg.21.bargeInEnabled' => ['0'],
	'reg.21.callsPerLineKey' => ['24'],
	'reg.21.csta' => ['0'],
	'reg.21.displayName' => [''],
	'reg.21.dndStatus' => ['0'],
	'reg.21.fwd.busy.contact' => [''],
	'reg.21.fwd.busy.status' => ['0'],
	'reg.21.fwd.noanswer.contact' => [''],
	'reg.21.fwd.noanswer.ringCount' => ['0'],
	'reg.21.fwd.noanswer.status' => ['0'],
	'reg.21.fwdContact' => [''],
	'reg.21.fwdStatus' => ['0'],
	'reg.21.label' => [''],
	'reg.21.lcs' => ['0'],
	'reg.21.lineKeys' => ['1'],
	'reg.21.musicOnHold.uri' => [''],
	'reg.21.mwiNew' => ['0'],
	'reg.21.mwiOld' => ['0'],
	'reg.21.mwiUrg' => ['0'],
	'reg.21.outboundProxy.address' => [''],
	'reg.21.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.21.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.21.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.21.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.21.outboundProxy.port' => ['0', 5060 ],
	'reg.21.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.21.protocol' => [''],
	'reg.21.protocol.H323' => ['0'],
	'reg.21.protocol.SIP' => ['1'],
	'reg.21.proxyRequire' => [''],
	'reg.21.ringType' => ['ringer2'],
	'reg.21.server.1.address' => [''],
	'reg.21.server.1.expires' => ['3600'],
	'reg.21.server.1.expires.lineSeize' => ['30'],
	'reg.21.server.1.expires.overlap' => ['60'],
	'reg.21.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.21.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.21.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.21.server.1.failOver.reRegisterOn' => ['0'],
	'reg.21.server.1.lcs' => ['0'],
	'reg.21.server.1.port' => ['0', '5060' ],
	'reg.21.server.1.register' => ['1'],
	'reg.21.server.1.retryMaxCount' => ['3'],
	'reg.21.server.1.retryTimeOut' => ['0'],
	'reg.21.server.1.transport' => ['DNSnaptr', '' ],
	'reg.21.server.2.address' => [''],
	'reg.21.server.2.expires' => ['3600'],
	'reg.21.server.2.expires.lineSeize' => ['30'],
	'reg.21.server.2.expires.overlap' => ['60'],
	'reg.21.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.21.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.21.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.21.server.2.failOver.reRegisterOn' => ['0'],
	'reg.21.server.2.lcs' => ['0'],
	'reg.21.server.2.port' => ['0', '5060' ],
	'reg.21.server.2.register' => ['1'],
	'reg.21.server.2.retryMaxCount' => ['3'],
	'reg.21.server.2.retryTimeOut' => ['0'],
	'reg.21.server.2.transport' => ['DNSnaptr', '' ],
	'reg.21.server.3.address' => [''],
	'reg.21.server.3.expires' => ['3600'],
	'reg.21.server.3.expires.lineSeize' => ['30'],
	'reg.21.server.3.expires.overlap' => ['60'],
	'reg.21.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.21.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.21.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.21.server.3.failOver.reRegisterOn' => ['0'],
	'reg.21.server.3.lcs' => ['0'],
	'reg.21.server.3.port' => ['0', '5060' ],
	'reg.21.server.3.register' => ['1'],
	'reg.21.server.3.retryMaxCount' => ['3'],
	'reg.21.server.3.retryTimeOut' => ['0'],
	'reg.21.server.3.transport' => ['DNSnaptr', '' ],
	'reg.21.server.4.address' => [''],
	'reg.21.server.4.expires' => ['3600'],
	'reg.21.server.4.expires.lineSeize' => ['30'],
	'reg.21.server.4.expires.overlap' => ['60'],
	'reg.21.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.21.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.21.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.21.server.4.failOver.reRegisterOn' => ['0'],
	'reg.21.server.4.lcs' => ['0'],
	'reg.21.server.4.port' => ['0', '5060' ],
	'reg.21.server.4.register' => ['1'],
	'reg.21.server.4.retryMaxCount' => ['3'],
	'reg.21.server.4.retryTimeOut' => ['0'],
	'reg.21.server.4.transport' => ['DNSnaptr', '' ],
	'reg.21.server.H323.1.address' => [''],
	'reg.21.server.H323.1.expires' => ['3600'],
	'reg.21.server.H323.1.port' => ['0'],
	'reg.21.server.H323.1.register' => ['1'],
	'reg.21.server.H323.2.address' => [''],
	'reg.21.server.H323.2.expires' => ['3600'],
	'reg.21.server.H323.2.port' => ['0'],
	'reg.21.server.H323.2.register' => ['1'],
	'reg.21.server.H323.3.address' => [''],
	'reg.21.server.H323.3.expires' => ['3600'],
	'reg.21.server.H323.3.port' => ['0'],
	'reg.21.server.H323.3.register' => ['1'],
	'reg.21.server.H323.4.address' => [''],
	'reg.21.server.H323.4.expires' => ['3600'],
	'reg.21.server.H323.4.port' => ['0'],
	'reg.21.server.H323.4.register' => ['1'],
	'reg.21.serverFeatureControl.cf' => ['1'],
	'reg.21.serverFeatureControl.dnd' => ['1'],
	'reg.21.strictLineSeize' => ['0'],
	'reg.21.tcpFastFailover' => ['0'],
	'reg.21.thirdPartyName' => [''],
	'reg.21.type' => ['private'],
	'reg.21.useCompleteUriForRetrieve' => ['1'],
	'reg.22.address' => [''],
	'reg.22.auth.optimizedInFailover' => ['0'],
	'reg.22.auth.password' => [''],
	'reg.22.auth.userId' => [''],
	'reg.22.bargeInEnabled' => ['0'],
	'reg.22.callsPerLineKey' => ['24'],
	'reg.22.csta' => ['0'],
	'reg.22.displayName' => [''],
	'reg.22.dndStatus' => ['0'],
	'reg.22.fwd.busy.contact' => [''],
	'reg.22.fwd.busy.status' => ['0'],
	'reg.22.fwd.noanswer.contact' => [''],
	'reg.22.fwd.noanswer.ringCount' => ['0'],
	'reg.22.fwd.noanswer.status' => ['0'],
	'reg.22.fwdContact' => [''],
	'reg.22.fwdStatus' => ['0'],
	'reg.22.label' => [''],
	'reg.22.lcs' => ['0'],
	'reg.22.lineKeys' => ['1'],
	'reg.22.musicOnHold.uri' => [''],
	'reg.22.mwiNew' => ['0'],
	'reg.22.mwiOld' => ['0'],
	'reg.22.mwiUrg' => ['0'],
	'reg.22.outboundProxy.address' => [''],
	'reg.22.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.22.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.22.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.22.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.22.outboundProxy.port' => ['0', 5060 ],
	'reg.22.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.22.protocol' => [''],
	'reg.22.protocol.H323' => ['0'],
	'reg.22.protocol.SIP' => ['1'],
	'reg.22.proxyRequire' => [''],
	'reg.22.ringType' => ['ringer2'],
	'reg.22.server.1.address' => [''],
	'reg.22.server.1.expires' => ['3600'],
	'reg.22.server.1.expires.lineSeize' => ['30'],
	'reg.22.server.1.expires.overlap' => ['60'],
	'reg.22.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.22.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.22.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.22.server.1.failOver.reRegisterOn' => ['0'],
	'reg.22.server.1.lcs' => ['0'],
	'reg.22.server.1.port' => ['0', '5060' ],
	'reg.22.server.1.register' => ['1'],
	'reg.22.server.1.retryMaxCount' => ['3'],
	'reg.22.server.1.retryTimeOut' => ['0'],
	'reg.22.server.1.transport' => ['DNSnaptr', '' ],
	'reg.22.server.2.address' => [''],
	'reg.22.server.2.expires' => ['3600'],
	'reg.22.server.2.expires.lineSeize' => ['30'],
	'reg.22.server.2.expires.overlap' => ['60'],
	'reg.22.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.22.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.22.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.22.server.2.failOver.reRegisterOn' => ['0'],
	'reg.22.server.2.lcs' => ['0'],
	'reg.22.server.2.port' => ['0', '5060' ],
	'reg.22.server.2.register' => ['1'],
	'reg.22.server.2.retryMaxCount' => ['3'],
	'reg.22.server.2.retryTimeOut' => ['0'],
	'reg.22.server.2.transport' => ['DNSnaptr', '' ],
	'reg.22.server.3.address' => [''],
	'reg.22.server.3.expires' => ['3600'],
	'reg.22.server.3.expires.lineSeize' => ['30'],
	'reg.22.server.3.expires.overlap' => ['60'],
	'reg.22.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.22.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.22.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.22.server.3.failOver.reRegisterOn' => ['0'],
	'reg.22.server.3.lcs' => ['0'],
	'reg.22.server.3.port' => ['0', '5060' ],
	'reg.22.server.3.register' => ['1'],
	'reg.22.server.3.retryMaxCount' => ['3'],
	'reg.22.server.3.retryTimeOut' => ['0'],
	'reg.22.server.3.transport' => ['DNSnaptr', '' ],
	'reg.22.server.4.address' => [''],
	'reg.22.server.4.expires' => ['3600'],
	'reg.22.server.4.expires.lineSeize' => ['30'],
	'reg.22.server.4.expires.overlap' => ['60'],
	'reg.22.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.22.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.22.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.22.server.4.failOver.reRegisterOn' => ['0'],
	'reg.22.server.4.lcs' => ['0'],
	'reg.22.server.4.port' => ['0', '5060' ],
	'reg.22.server.4.register' => ['1'],
	'reg.22.server.4.retryMaxCount' => ['3'],
	'reg.22.server.4.retryTimeOut' => ['0'],
	'reg.22.server.4.transport' => ['DNSnaptr', '' ],
	'reg.22.server.H323.1.address' => [''],
	'reg.22.server.H323.1.expires' => ['3600'],
	'reg.22.server.H323.1.port' => ['0'],
	'reg.22.server.H323.1.register' => ['1'],
	'reg.22.server.H323.2.address' => [''],
	'reg.22.server.H323.2.expires' => ['3600'],
	'reg.22.server.H323.2.port' => ['0'],
	'reg.22.server.H323.2.register' => ['1'],
	'reg.22.server.H323.3.address' => [''],
	'reg.22.server.H323.3.expires' => ['3600'],
	'reg.22.server.H323.3.port' => ['0'],
	'reg.22.server.H323.3.register' => ['1'],
	'reg.22.server.H323.4.address' => [''],
	'reg.22.server.H323.4.expires' => ['3600'],
	'reg.22.server.H323.4.port' => ['0'],
	'reg.22.server.H323.4.register' => ['1'],
	'reg.22.serverFeatureControl.cf' => ['1'],
	'reg.22.serverFeatureControl.dnd' => ['1'],
	'reg.22.strictLineSeize' => ['0'],
	'reg.22.tcpFastFailover' => ['0'],
	'reg.22.thirdPartyName' => [''],
	'reg.22.type' => ['private'],
	'reg.22.useCompleteUriForRetrieve' => ['1'],
	'reg.23.address' => [''],
	'reg.23.auth.optimizedInFailover' => ['0'],
	'reg.23.auth.password' => [''],
	'reg.23.auth.userId' => [''],
	'reg.23.bargeInEnabled' => ['0'],
	'reg.23.callsPerLineKey' => ['24'],
	'reg.23.csta' => ['0'],
	'reg.23.displayName' => [''],
	'reg.23.dndStatus' => ['0'],
	'reg.23.fwd.busy.contact' => [''],
	'reg.23.fwd.busy.status' => ['0'],
	'reg.23.fwd.noanswer.contact' => [''],
	'reg.23.fwd.noanswer.ringCount' => ['0'],
	'reg.23.fwd.noanswer.status' => ['0'],
	'reg.23.fwdContact' => [''],
	'reg.23.fwdStatus' => ['0'],
	'reg.23.label' => [''],
	'reg.23.lcs' => ['0'],
	'reg.23.lineKeys' => ['1'],
	'reg.23.musicOnHold.uri' => [''],
	'reg.23.mwiNew' => ['0'],
	'reg.23.mwiOld' => ['0'],
	'reg.23.mwiUrg' => ['0'],
	'reg.23.outboundProxy.address' => [''],
	'reg.23.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.23.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.23.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.23.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.23.outboundProxy.port' => ['0', 5060 ],
	'reg.23.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.23.protocol' => [''],
	'reg.23.protocol.H323' => ['0'],
	'reg.23.protocol.SIP' => ['1'],
	'reg.23.proxyRequire' => [''],
	'reg.23.ringType' => ['ringer2'],
	'reg.23.server.1.address' => [''],
	'reg.23.server.1.expires' => ['3600'],
	'reg.23.server.1.expires.lineSeize' => ['30'],
	'reg.23.server.1.expires.overlap' => ['60'],
	'reg.23.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.23.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.23.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.23.server.1.failOver.reRegisterOn' => ['0'],
	'reg.23.server.1.lcs' => ['0'],
	'reg.23.server.1.port' => ['0', '5060' ],
	'reg.23.server.1.register' => ['1'],
	'reg.23.server.1.retryMaxCount' => ['3'],
	'reg.23.server.1.retryTimeOut' => ['0'],
	'reg.23.server.1.transport' => ['DNSnaptr', '' ],
	'reg.23.server.2.address' => [''],
	'reg.23.server.2.expires' => ['3600'],
	'reg.23.server.2.expires.lineSeize' => ['30'],
	'reg.23.server.2.expires.overlap' => ['60'],
	'reg.23.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.23.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.23.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.23.server.2.failOver.reRegisterOn' => ['0'],
	'reg.23.server.2.lcs' => ['0'],
	'reg.23.server.2.port' => ['0', '5060' ],
	'reg.23.server.2.register' => ['1'],
	'reg.23.server.2.retryMaxCount' => ['3'],
	'reg.23.server.2.retryTimeOut' => ['0'],
	'reg.23.server.2.transport' => ['DNSnaptr', '' ],
	'reg.23.server.3.address' => [''],
	'reg.23.server.3.expires' => ['3600'],
	'reg.23.server.3.expires.lineSeize' => ['30'],
	'reg.23.server.3.expires.overlap' => ['60'],
	'reg.23.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.23.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.23.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.23.server.3.failOver.reRegisterOn' => ['0'],
	'reg.23.server.3.lcs' => ['0'],
	'reg.23.server.3.port' => ['0', '5060' ],
	'reg.23.server.3.register' => ['1'],
	'reg.23.server.3.retryMaxCount' => ['3'],
	'reg.23.server.3.retryTimeOut' => ['0'],
	'reg.23.server.3.transport' => ['DNSnaptr', '' ],
	'reg.23.server.4.address' => [''],
	'reg.23.server.4.expires' => ['3600'],
	'reg.23.server.4.expires.lineSeize' => ['30'],
	'reg.23.server.4.expires.overlap' => ['60'],
	'reg.23.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.23.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.23.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.23.server.4.failOver.reRegisterOn' => ['0'],
	'reg.23.server.4.lcs' => ['0'],
	'reg.23.server.4.port' => ['0', '5060' ],
	'reg.23.server.4.register' => ['1'],
	'reg.23.server.4.retryMaxCount' => ['3'],
	'reg.23.server.4.retryTimeOut' => ['0'],
	'reg.23.server.4.transport' => ['DNSnaptr', '' ],
	'reg.23.server.H323.1.address' => [''],
	'reg.23.server.H323.1.expires' => ['3600'],
	'reg.23.server.H323.1.port' => ['0'],
	'reg.23.server.H323.1.register' => ['1'],
	'reg.23.server.H323.2.address' => [''],
	'reg.23.server.H323.2.expires' => ['3600'],
	'reg.23.server.H323.2.port' => ['0'],
	'reg.23.server.H323.2.register' => ['1'],
	'reg.23.server.H323.3.address' => [''],
	'reg.23.server.H323.3.expires' => ['3600'],
	'reg.23.server.H323.3.port' => ['0'],
	'reg.23.server.H323.3.register' => ['1'],
	'reg.23.server.H323.4.address' => [''],
	'reg.23.server.H323.4.expires' => ['3600'],
	'reg.23.server.H323.4.port' => ['0'],
	'reg.23.server.H323.4.register' => ['1'],
	'reg.23.serverFeatureControl.cf' => ['1'],
	'reg.23.serverFeatureControl.dnd' => ['1'],
	'reg.23.strictLineSeize' => ['0'],
	'reg.23.tcpFastFailover' => ['0'],
	'reg.23.thirdPartyName' => [''],
	'reg.23.type' => ['private'],
	'reg.23.useCompleteUriForRetrieve' => ['1'],
	'reg.24.address' => [''],
	'reg.24.auth.optimizedInFailover' => ['0'],
	'reg.24.auth.password' => [''],
	'reg.24.auth.userId' => [''],
	'reg.24.bargeInEnabled' => ['0'],
	'reg.24.callsPerLineKey' => ['24'],
	'reg.24.csta' => ['0'],
	'reg.24.displayName' => [''],
	'reg.24.dndStatus' => ['0'],
	'reg.24.fwd.busy.contact' => [''],
	'reg.24.fwd.busy.status' => ['0'],
	'reg.24.fwd.noanswer.contact' => [''],
	'reg.24.fwd.noanswer.ringCount' => ['0'],
	'reg.24.fwd.noanswer.status' => ['0'],
	'reg.24.fwdContact' => [''],
	'reg.24.fwdStatus' => ['0'],
	'reg.24.label' => [''],
	'reg.24.lcs' => ['0'],
	'reg.24.lineKeys' => ['1'],
	'reg.24.musicOnHold.uri' => [''],
	'reg.24.mwiNew' => ['0'],
	'reg.24.mwiOld' => ['0'],
	'reg.24.mwiUrg' => ['0'],
	'reg.24.outboundProxy.address' => [''],
	'reg.24.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.24.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.24.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.24.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.24.outboundProxy.port' => ['0', 5060 ],
	'reg.24.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.24.protocol' => [''],
	'reg.24.protocol.H323' => ['0'],
	'reg.24.protocol.SIP' => ['1'],
	'reg.24.proxyRequire' => [''],
	'reg.24.ringType' => ['ringer2'],
	'reg.24.server.1.address' => [''],
	'reg.24.server.1.expires' => ['3600'],
	'reg.24.server.1.expires.lineSeize' => ['30'],
	'reg.24.server.1.expires.overlap' => ['60'],
	'reg.24.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.24.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.24.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.24.server.1.failOver.reRegisterOn' => ['0'],
	'reg.24.server.1.lcs' => ['0'],
	'reg.24.server.1.port' => ['0', '5060' ],
	'reg.24.server.1.register' => ['1'],
	'reg.24.server.1.retryMaxCount' => ['3'],
	'reg.24.server.1.retryTimeOut' => ['0'],
	'reg.24.server.1.transport' => ['DNSnaptr', '' ],
	'reg.24.server.2.address' => [''],
	'reg.24.server.2.expires' => ['3600'],
	'reg.24.server.2.expires.lineSeize' => ['30'],
	'reg.24.server.2.expires.overlap' => ['60'],
	'reg.24.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.24.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.24.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.24.server.2.failOver.reRegisterOn' => ['0'],
	'reg.24.server.2.lcs' => ['0'],
	'reg.24.server.2.port' => ['0', '5060' ],
	'reg.24.server.2.register' => ['1'],
	'reg.24.server.2.retryMaxCount' => ['3'],
	'reg.24.server.2.retryTimeOut' => ['0'],
	'reg.24.server.2.transport' => ['DNSnaptr', '' ],
	'reg.24.server.3.address' => [''],
	'reg.24.server.3.expires' => ['3600'],
	'reg.24.server.3.expires.lineSeize' => ['30'],
	'reg.24.server.3.expires.overlap' => ['60'],
	'reg.24.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.24.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.24.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.24.server.3.failOver.reRegisterOn' => ['0'],
	'reg.24.server.3.lcs' => ['0'],
	'reg.24.server.3.port' => ['0', '5060' ],
	'reg.24.server.3.register' => ['1'],
	'reg.24.server.3.retryMaxCount' => ['3'],
	'reg.24.server.3.retryTimeOut' => ['0'],
	'reg.24.server.3.transport' => ['DNSnaptr', '' ],
	'reg.24.server.4.address' => [''],
	'reg.24.server.4.expires' => ['3600'],
	'reg.24.server.4.expires.lineSeize' => ['30'],
	'reg.24.server.4.expires.overlap' => ['60'],
	'reg.24.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.24.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.24.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.24.server.4.failOver.reRegisterOn' => ['0'],
	'reg.24.server.4.lcs' => ['0'],
	'reg.24.server.4.port' => ['0', '5060' ],
	'reg.24.server.4.register' => ['1'],
	'reg.24.server.4.retryMaxCount' => ['3'],
	'reg.24.server.4.retryTimeOut' => ['0'],
	'reg.24.server.4.transport' => ['DNSnaptr', '' ],
	'reg.24.server.H323.1.address' => [''],
	'reg.24.server.H323.1.expires' => ['3600'],
	'reg.24.server.H323.1.port' => ['0'],
	'reg.24.server.H323.1.register' => ['1'],
	'reg.24.server.H323.2.address' => [''],
	'reg.24.server.H323.2.expires' => ['3600'],
	'reg.24.server.H323.2.port' => ['0'],
	'reg.24.server.H323.2.register' => ['1'],
	'reg.24.server.H323.3.address' => [''],
	'reg.24.server.H323.3.expires' => ['3600'],
	'reg.24.server.H323.3.port' => ['0'],
	'reg.24.server.H323.3.register' => ['1'],
	'reg.24.server.H323.4.address' => [''],
	'reg.24.server.H323.4.expires' => ['3600'],
	'reg.24.server.H323.4.port' => ['0'],
	'reg.24.server.H323.4.register' => ['1'],
	'reg.24.serverFeatureControl.cf' => ['1'],
	'reg.24.serverFeatureControl.dnd' => ['1'],
	'reg.24.strictLineSeize' => ['0'],
	'reg.24.tcpFastFailover' => ['0'],
	'reg.24.thirdPartyName' => [''],
	'reg.24.type' => ['private'],
	'reg.24.useCompleteUriForRetrieve' => ['1'],
	'reg.25.address' => [''],
	'reg.25.auth.optimizedInFailover' => ['0'],
	'reg.25.auth.password' => [''],
	'reg.25.auth.userId' => [''],
	'reg.25.bargeInEnabled' => ['0'],
	'reg.25.callsPerLineKey' => ['24'],
	'reg.25.csta' => ['0'],
	'reg.25.displayName' => [''],
	'reg.25.dndStatus' => ['0'],
	'reg.25.fwd.busy.contact' => [''],
	'reg.25.fwd.busy.status' => ['0'],
	'reg.25.fwd.noanswer.contact' => [''],
	'reg.25.fwd.noanswer.ringCount' => ['0'],
	'reg.25.fwd.noanswer.status' => ['0'],
	'reg.25.fwdContact' => [''],
	'reg.25.fwdStatus' => ['0'],
	'reg.25.label' => [''],
	'reg.25.lcs' => ['0'],
	'reg.25.lineKeys' => ['1'],
	'reg.25.musicOnHold.uri' => [''],
	'reg.25.mwiNew' => ['0'],
	'reg.25.mwiOld' => ['0'],
	'reg.25.mwiUrg' => ['0'],
	'reg.25.outboundProxy.address' => [''],
	'reg.25.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.25.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.25.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.25.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.25.outboundProxy.port' => ['0', 5060 ],
	'reg.25.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.25.protocol' => [''],
	'reg.25.protocol.H323' => ['0'],
	'reg.25.protocol.SIP' => ['1'],
	'reg.25.proxyRequire' => [''],
	'reg.25.ringType' => ['ringer2'],
	'reg.25.server.1.address' => [''],
	'reg.25.server.1.expires' => ['3600'],
	'reg.25.server.1.expires.lineSeize' => ['30'],
	'reg.25.server.1.expires.overlap' => ['60'],
	'reg.25.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.25.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.25.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.25.server.1.failOver.reRegisterOn' => ['0'],
	'reg.25.server.1.lcs' => ['0'],
	'reg.25.server.1.port' => ['0', '5060' ],
	'reg.25.server.1.register' => ['1'],
	'reg.25.server.1.retryMaxCount' => ['3'],
	'reg.25.server.1.retryTimeOut' => ['0'],
	'reg.25.server.1.transport' => ['DNSnaptr', '' ],
	'reg.25.server.2.address' => [''],
	'reg.25.server.2.expires' => ['3600'],
	'reg.25.server.2.expires.lineSeize' => ['30'],
	'reg.25.server.2.expires.overlap' => ['60'],
	'reg.25.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.25.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.25.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.25.server.2.failOver.reRegisterOn' => ['0'],
	'reg.25.server.2.lcs' => ['0'],
	'reg.25.server.2.port' => ['0', '5060' ],
	'reg.25.server.2.register' => ['1'],
	'reg.25.server.2.retryMaxCount' => ['3'],
	'reg.25.server.2.retryTimeOut' => ['0'],
	'reg.25.server.2.transport' => ['DNSnaptr', '' ],
	'reg.25.server.3.address' => [''],
	'reg.25.server.3.expires' => ['3600'],
	'reg.25.server.3.expires.lineSeize' => ['30'],
	'reg.25.server.3.expires.overlap' => ['60'],
	'reg.25.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.25.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.25.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.25.server.3.failOver.reRegisterOn' => ['0'],
	'reg.25.server.3.lcs' => ['0'],
	'reg.25.server.3.port' => ['0', '5060' ],
	'reg.25.server.3.register' => ['1'],
	'reg.25.server.3.retryMaxCount' => ['3'],
	'reg.25.server.3.retryTimeOut' => ['0'],
	'reg.25.server.3.transport' => ['DNSnaptr', '' ],
	'reg.25.server.4.address' => [''],
	'reg.25.server.4.expires' => ['3600'],
	'reg.25.server.4.expires.lineSeize' => ['30'],
	'reg.25.server.4.expires.overlap' => ['60'],
	'reg.25.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.25.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.25.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.25.server.4.failOver.reRegisterOn' => ['0'],
	'reg.25.server.4.lcs' => ['0'],
	'reg.25.server.4.port' => ['0', '5060' ],
	'reg.25.server.4.register' => ['1'],
	'reg.25.server.4.retryMaxCount' => ['3'],
	'reg.25.server.4.retryTimeOut' => ['0'],
	'reg.25.server.4.transport' => ['DNSnaptr', '' ],
	'reg.25.server.H323.1.address' => [''],
	'reg.25.server.H323.1.expires' => ['3600'],
	'reg.25.server.H323.1.port' => ['0'],
	'reg.25.server.H323.1.register' => ['1'],
	'reg.25.server.H323.2.address' => [''],
	'reg.25.server.H323.2.expires' => ['3600'],
	'reg.25.server.H323.2.port' => ['0'],
	'reg.25.server.H323.2.register' => ['1'],
	'reg.25.server.H323.3.address' => [''],
	'reg.25.server.H323.3.expires' => ['3600'],
	'reg.25.server.H323.3.port' => ['0'],
	'reg.25.server.H323.3.register' => ['1'],
	'reg.25.server.H323.4.address' => [''],
	'reg.25.server.H323.4.expires' => ['3600'],
	'reg.25.server.H323.4.port' => ['0'],
	'reg.25.server.H323.4.register' => ['1'],
	'reg.25.serverFeatureControl.cf' => ['1'],
	'reg.25.serverFeatureControl.dnd' => ['1'],
	'reg.25.strictLineSeize' => ['0'],
	'reg.25.tcpFastFailover' => ['0'],
	'reg.25.thirdPartyName' => [''],
	'reg.25.type' => ['private'],
	'reg.25.useCompleteUriForRetrieve' => ['1'],
	'reg.26.address' => [''],
	'reg.26.auth.optimizedInFailover' => ['0'],
	'reg.26.auth.password' => [''],
	'reg.26.auth.userId' => [''],
	'reg.26.bargeInEnabled' => ['0'],
	'reg.26.callsPerLineKey' => ['24'],
	'reg.26.csta' => ['0'],
	'reg.26.displayName' => [''],
	'reg.26.dndStatus' => ['0'],
	'reg.26.fwd.busy.contact' => [''],
	'reg.26.fwd.busy.status' => ['0'],
	'reg.26.fwd.noanswer.contact' => [''],
	'reg.26.fwd.noanswer.ringCount' => ['0'],
	'reg.26.fwd.noanswer.status' => ['0'],
	'reg.26.fwdContact' => [''],
	'reg.26.fwdStatus' => ['0'],
	'reg.26.label' => [''],
	'reg.26.lcs' => ['0'],
	'reg.26.lineKeys' => ['1'],
	'reg.26.musicOnHold.uri' => [''],
	'reg.26.mwiNew' => ['0'],
	'reg.26.mwiOld' => ['0'],
	'reg.26.mwiUrg' => ['0'],
	'reg.26.outboundProxy.address' => [''],
	'reg.26.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.26.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.26.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.26.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.26.outboundProxy.port' => ['0', 5060 ],
	'reg.26.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.26.protocol' => [''],
	'reg.26.protocol.H323' => ['0'],
	'reg.26.protocol.SIP' => ['1'],
	'reg.26.proxyRequire' => [''],
	'reg.26.ringType' => ['ringer2'],
	'reg.26.server.1.address' => [''],
	'reg.26.server.1.expires' => ['3600'],
	'reg.26.server.1.expires.lineSeize' => ['30'],
	'reg.26.server.1.expires.overlap' => ['60'],
	'reg.26.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.26.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.26.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.26.server.1.failOver.reRegisterOn' => ['0'],
	'reg.26.server.1.lcs' => ['0'],
	'reg.26.server.1.port' => ['0', '5060' ],
	'reg.26.server.1.register' => ['1'],
	'reg.26.server.1.retryMaxCount' => ['3'],
	'reg.26.server.1.retryTimeOut' => ['0'],
	'reg.26.server.1.transport' => ['DNSnaptr', '' ],
	'reg.26.server.2.address' => [''],
	'reg.26.server.2.expires' => ['3600'],
	'reg.26.server.2.expires.lineSeize' => ['30'],
	'reg.26.server.2.expires.overlap' => ['60'],
	'reg.26.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.26.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.26.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.26.server.2.failOver.reRegisterOn' => ['0'],
	'reg.26.server.2.lcs' => ['0'],
	'reg.26.server.2.port' => ['0', '5060' ],
	'reg.26.server.2.register' => ['1'],
	'reg.26.server.2.retryMaxCount' => ['3'],
	'reg.26.server.2.retryTimeOut' => ['0'],
	'reg.26.server.2.transport' => ['DNSnaptr', '' ],
	'reg.26.server.3.address' => [''],
	'reg.26.server.3.expires' => ['3600'],
	'reg.26.server.3.expires.lineSeize' => ['30'],
	'reg.26.server.3.expires.overlap' => ['60'],
	'reg.26.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.26.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.26.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.26.server.3.failOver.reRegisterOn' => ['0'],
	'reg.26.server.3.lcs' => ['0'],
	'reg.26.server.3.port' => ['0', '5060' ],
	'reg.26.server.3.register' => ['1'],
	'reg.26.server.3.retryMaxCount' => ['3'],
	'reg.26.server.3.retryTimeOut' => ['0'],
	'reg.26.server.3.transport' => ['DNSnaptr', '' ],
	'reg.26.server.4.address' => [''],
	'reg.26.server.4.expires' => ['3600'],
	'reg.26.server.4.expires.lineSeize' => ['30'],
	'reg.26.server.4.expires.overlap' => ['60'],
	'reg.26.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.26.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.26.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.26.server.4.failOver.reRegisterOn' => ['0'],
	'reg.26.server.4.lcs' => ['0'],
	'reg.26.server.4.port' => ['0', '5060' ],
	'reg.26.server.4.register' => ['1'],
	'reg.26.server.4.retryMaxCount' => ['3'],
	'reg.26.server.4.retryTimeOut' => ['0'],
	'reg.26.server.4.transport' => ['DNSnaptr', '' ],
	'reg.26.server.H323.1.address' => [''],
	'reg.26.server.H323.1.expires' => ['3600'],
	'reg.26.server.H323.1.port' => ['0'],
	'reg.26.server.H323.1.register' => ['1'],
	'reg.26.server.H323.2.address' => [''],
	'reg.26.server.H323.2.expires' => ['3600'],
	'reg.26.server.H323.2.port' => ['0'],
	'reg.26.server.H323.2.register' => ['1'],
	'reg.26.server.H323.3.address' => [''],
	'reg.26.server.H323.3.expires' => ['3600'],
	'reg.26.server.H323.3.port' => ['0'],
	'reg.26.server.H323.3.register' => ['1'],
	'reg.26.server.H323.4.address' => [''],
	'reg.26.server.H323.4.expires' => ['3600'],
	'reg.26.server.H323.4.port' => ['0'],
	'reg.26.server.H323.4.register' => ['1'],
	'reg.26.serverFeatureControl.cf' => ['1'],
	'reg.26.serverFeatureControl.dnd' => ['1'],
	'reg.26.strictLineSeize' => ['0'],
	'reg.26.tcpFastFailover' => ['0'],
	'reg.26.thirdPartyName' => [''],
	'reg.26.type' => ['private'],
	'reg.26.useCompleteUriForRetrieve' => ['1'],
	'reg.27.address' => [''],
	'reg.27.auth.optimizedInFailover' => ['0'],
	'reg.27.auth.password' => [''],
	'reg.27.auth.userId' => [''],
	'reg.27.bargeInEnabled' => ['0'],
	'reg.27.callsPerLineKey' => ['24'],
	'reg.27.csta' => ['0'],
	'reg.27.displayName' => [''],
	'reg.27.dndStatus' => ['0'],
	'reg.27.fwd.busy.contact' => [''],
	'reg.27.fwd.busy.status' => ['0'],
	'reg.27.fwd.noanswer.contact' => [''],
	'reg.27.fwd.noanswer.ringCount' => ['0'],
	'reg.27.fwd.noanswer.status' => ['0'],
	'reg.27.fwdContact' => [''],
	'reg.27.fwdStatus' => ['0'],
	'reg.27.label' => [''],
	'reg.27.lcs' => ['0'],
	'reg.27.lineKeys' => ['1'],
	'reg.27.musicOnHold.uri' => [''],
	'reg.27.mwiNew' => ['0'],
	'reg.27.mwiOld' => ['0'],
	'reg.27.mwiUrg' => ['0'],
	'reg.27.outboundProxy.address' => [''],
	'reg.27.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.27.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.27.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.27.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.27.outboundProxy.port' => ['0', 5060 ],
	'reg.27.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.27.protocol' => [''],
	'reg.27.protocol.H323' => ['0'],
	'reg.27.protocol.SIP' => ['1'],
	'reg.27.proxyRequire' => [''],
	'reg.27.ringType' => ['ringer2'],
	'reg.27.server.1.address' => [''],
	'reg.27.server.1.expires' => ['3600'],
	'reg.27.server.1.expires.lineSeize' => ['30'],
	'reg.27.server.1.expires.overlap' => ['60'],
	'reg.27.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.27.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.27.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.27.server.1.failOver.reRegisterOn' => ['0'],
	'reg.27.server.1.lcs' => ['0'],
	'reg.27.server.1.port' => ['0', '5060' ],
	'reg.27.server.1.register' => ['1'],
	'reg.27.server.1.retryMaxCount' => ['3'],
	'reg.27.server.1.retryTimeOut' => ['0'],
	'reg.27.server.1.transport' => ['DNSnaptr', '' ],
	'reg.27.server.2.address' => [''],
	'reg.27.server.2.expires' => ['3600'],
	'reg.27.server.2.expires.lineSeize' => ['30'],
	'reg.27.server.2.expires.overlap' => ['60'],
	'reg.27.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.27.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.27.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.27.server.2.failOver.reRegisterOn' => ['0'],
	'reg.27.server.2.lcs' => ['0'],
	'reg.27.server.2.port' => ['0', '5060' ],
	'reg.27.server.2.register' => ['1'],
	'reg.27.server.2.retryMaxCount' => ['3'],
	'reg.27.server.2.retryTimeOut' => ['0'],
	'reg.27.server.2.transport' => ['DNSnaptr', '' ],
	'reg.27.server.3.address' => [''],
	'reg.27.server.3.expires' => ['3600'],
	'reg.27.server.3.expires.lineSeize' => ['30'],
	'reg.27.server.3.expires.overlap' => ['60'],
	'reg.27.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.27.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.27.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.27.server.3.failOver.reRegisterOn' => ['0'],
	'reg.27.server.3.lcs' => ['0'],
	'reg.27.server.3.port' => ['0', '5060' ],
	'reg.27.server.3.register' => ['1'],
	'reg.27.server.3.retryMaxCount' => ['3'],
	'reg.27.server.3.retryTimeOut' => ['0'],
	'reg.27.server.3.transport' => ['DNSnaptr', '' ],
	'reg.27.server.4.address' => [''],
	'reg.27.server.4.expires' => ['3600'],
	'reg.27.server.4.expires.lineSeize' => ['30'],
	'reg.27.server.4.expires.overlap' => ['60'],
	'reg.27.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.27.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.27.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.27.server.4.failOver.reRegisterOn' => ['0'],
	'reg.27.server.4.lcs' => ['0'],
	'reg.27.server.4.port' => ['0', '5060' ],
	'reg.27.server.4.register' => ['1'],
	'reg.27.server.4.retryMaxCount' => ['3'],
	'reg.27.server.4.retryTimeOut' => ['0'],
	'reg.27.server.4.transport' => ['DNSnaptr', '' ],
	'reg.27.server.H323.1.address' => [''],
	'reg.27.server.H323.1.expires' => ['3600'],
	'reg.27.server.H323.1.port' => ['0'],
	'reg.27.server.H323.1.register' => ['1'],
	'reg.27.server.H323.2.address' => [''],
	'reg.27.server.H323.2.expires' => ['3600'],
	'reg.27.server.H323.2.port' => ['0'],
	'reg.27.server.H323.2.register' => ['1'],
	'reg.27.server.H323.3.address' => [''],
	'reg.27.server.H323.3.expires' => ['3600'],
	'reg.27.server.H323.3.port' => ['0'],
	'reg.27.server.H323.3.register' => ['1'],
	'reg.27.server.H323.4.address' => [''],
	'reg.27.server.H323.4.expires' => ['3600'],
	'reg.27.server.H323.4.port' => ['0'],
	'reg.27.server.H323.4.register' => ['1'],
	'reg.27.serverFeatureControl.cf' => ['1'],
	'reg.27.serverFeatureControl.dnd' => ['1'],
	'reg.27.strictLineSeize' => ['0'],
	'reg.27.tcpFastFailover' => ['0'],
	'reg.27.thirdPartyName' => [''],
	'reg.27.type' => ['private'],
	'reg.27.useCompleteUriForRetrieve' => ['1'],
	'reg.28.address' => [''],
	'reg.28.auth.optimizedInFailover' => ['0'],
	'reg.28.auth.password' => [''],
	'reg.28.auth.userId' => [''],
	'reg.28.bargeInEnabled' => ['0'],
	'reg.28.callsPerLineKey' => ['24'],
	'reg.28.csta' => ['0'],
	'reg.28.displayName' => [''],
	'reg.28.dndStatus' => ['0'],
	'reg.28.fwd.busy.contact' => [''],
	'reg.28.fwd.busy.status' => ['0'],
	'reg.28.fwd.noanswer.contact' => [''],
	'reg.28.fwd.noanswer.ringCount' => ['0'],
	'reg.28.fwd.noanswer.status' => ['0'],
	'reg.28.fwdContact' => [''],
	'reg.28.fwdStatus' => ['0'],
	'reg.28.label' => [''],
	'reg.28.lcs' => ['0'],
	'reg.28.lineKeys' => ['1'],
	'reg.28.musicOnHold.uri' => [''],
	'reg.28.mwiNew' => ['0'],
	'reg.28.mwiOld' => ['0'],
	'reg.28.mwiUrg' => ['0'],
	'reg.28.outboundProxy.address' => [''],
	'reg.28.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.28.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.28.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.28.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.28.outboundProxy.port' => ['0', 5060 ],
	'reg.28.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.28.protocol' => [''],
	'reg.28.protocol.H323' => ['0'],
	'reg.28.protocol.SIP' => ['1'],
	'reg.28.proxyRequire' => [''],
	'reg.28.ringType' => ['ringer2'],
	'reg.28.server.1.address' => [''],
	'reg.28.server.1.expires' => ['3600'],
	'reg.28.server.1.expires.lineSeize' => ['30'],
	'reg.28.server.1.expires.overlap' => ['60'],
	'reg.28.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.28.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.28.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.28.server.1.failOver.reRegisterOn' => ['0'],
	'reg.28.server.1.lcs' => ['0'],
	'reg.28.server.1.port' => ['0', '5060' ],
	'reg.28.server.1.register' => ['1'],
	'reg.28.server.1.retryMaxCount' => ['3'],
	'reg.28.server.1.retryTimeOut' => ['0'],
	'reg.28.server.1.transport' => ['DNSnaptr', '' ],
	'reg.28.server.2.address' => [''],
	'reg.28.server.2.expires' => ['3600'],
	'reg.28.server.2.expires.lineSeize' => ['30'],
	'reg.28.server.2.expires.overlap' => ['60'],
	'reg.28.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.28.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.28.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.28.server.2.failOver.reRegisterOn' => ['0'],
	'reg.28.server.2.lcs' => ['0'],
	'reg.28.server.2.port' => ['0', '5060' ],
	'reg.28.server.2.register' => ['1'],
	'reg.28.server.2.retryMaxCount' => ['3'],
	'reg.28.server.2.retryTimeOut' => ['0'],
	'reg.28.server.2.transport' => ['DNSnaptr', '' ],
	'reg.28.server.3.address' => [''],
	'reg.28.server.3.expires' => ['3600'],
	'reg.28.server.3.expires.lineSeize' => ['30'],
	'reg.28.server.3.expires.overlap' => ['60'],
	'reg.28.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.28.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.28.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.28.server.3.failOver.reRegisterOn' => ['0'],
	'reg.28.server.3.lcs' => ['0'],
	'reg.28.server.3.port' => ['0', '5060' ],
	'reg.28.server.3.register' => ['1'],
	'reg.28.server.3.retryMaxCount' => ['3'],
	'reg.28.server.3.retryTimeOut' => ['0'],
	'reg.28.server.3.transport' => ['DNSnaptr', '' ],
	'reg.28.server.4.address' => [''],
	'reg.28.server.4.expires' => ['3600'],
	'reg.28.server.4.expires.lineSeize' => ['30'],
	'reg.28.server.4.expires.overlap' => ['60'],
	'reg.28.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.28.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.28.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.28.server.4.failOver.reRegisterOn' => ['0'],
	'reg.28.server.4.lcs' => ['0'],
	'reg.28.server.4.port' => ['0', '5060' ],
	'reg.28.server.4.register' => ['1'],
	'reg.28.server.4.retryMaxCount' => ['3'],
	'reg.28.server.4.retryTimeOut' => ['0'],
	'reg.28.server.4.transport' => ['DNSnaptr', '' ],
	'reg.28.server.H323.1.address' => [''],
	'reg.28.server.H323.1.expires' => ['3600'],
	'reg.28.server.H323.1.port' => ['0'],
	'reg.28.server.H323.1.register' => ['1'],
	'reg.28.server.H323.2.address' => [''],
	'reg.28.server.H323.2.expires' => ['3600'],
	'reg.28.server.H323.2.port' => ['0'],
	'reg.28.server.H323.2.register' => ['1'],
	'reg.28.server.H323.3.address' => [''],
	'reg.28.server.H323.3.expires' => ['3600'],
	'reg.28.server.H323.3.port' => ['0'],
	'reg.28.server.H323.3.register' => ['1'],
	'reg.28.server.H323.4.address' => [''],
	'reg.28.server.H323.4.expires' => ['3600'],
	'reg.28.server.H323.4.port' => ['0'],
	'reg.28.server.H323.4.register' => ['1'],
	'reg.28.serverFeatureControl.cf' => ['1'],
	'reg.28.serverFeatureControl.dnd' => ['1'],
	'reg.28.strictLineSeize' => ['0'],
	'reg.28.tcpFastFailover' => ['0'],
	'reg.28.thirdPartyName' => [''],
	'reg.28.type' => ['private'],
	'reg.28.useCompleteUriForRetrieve' => ['1'],
	'reg.29.address' => [''],
	'reg.29.auth.optimizedInFailover' => ['0'],
	'reg.29.auth.password' => [''],
	'reg.29.auth.userId' => [''],
	'reg.29.bargeInEnabled' => ['0'],
	'reg.29.callsPerLineKey' => ['24'],
	'reg.29.csta' => ['0'],
	'reg.29.displayName' => [''],
	'reg.29.dndStatus' => ['0'],
	'reg.29.fwd.busy.contact' => [''],
	'reg.29.fwd.busy.status' => ['0'],
	'reg.29.fwd.noanswer.contact' => [''],
	'reg.29.fwd.noanswer.ringCount' => ['0'],
	'reg.29.fwd.noanswer.status' => ['0'],
	'reg.29.fwdContact' => [''],
	'reg.29.fwdStatus' => ['0'],
	'reg.29.label' => [''],
	'reg.29.lcs' => ['0'],
	'reg.29.lineKeys' => ['1'],
	'reg.29.musicOnHold.uri' => [''],
	'reg.29.mwiNew' => ['0'],
	'reg.29.mwiOld' => ['0'],
	'reg.29.mwiUrg' => ['0'],
	'reg.29.outboundProxy.address' => [''],
	'reg.29.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.29.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.29.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.29.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.29.outboundProxy.port' => ['0', 5060 ],
	'reg.29.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.29.protocol' => [''],
	'reg.29.protocol.H323' => ['0'],
	'reg.29.protocol.SIP' => ['1'],
	'reg.29.proxyRequire' => [''],
	'reg.29.ringType' => ['ringer2'],
	'reg.29.server.1.address' => [''],
	'reg.29.server.1.expires' => ['3600'],
	'reg.29.server.1.expires.lineSeize' => ['30'],
	'reg.29.server.1.expires.overlap' => ['60'],
	'reg.29.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.29.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.29.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.29.server.1.failOver.reRegisterOn' => ['0'],
	'reg.29.server.1.lcs' => ['0'],
	'reg.29.server.1.port' => ['0', '5060' ],
	'reg.29.server.1.register' => ['1'],
	'reg.29.server.1.retryMaxCount' => ['3'],
	'reg.29.server.1.retryTimeOut' => ['0'],
	'reg.29.server.1.transport' => ['DNSnaptr', '' ],
	'reg.29.server.2.address' => [''],
	'reg.29.server.2.expires' => ['3600'],
	'reg.29.server.2.expires.lineSeize' => ['30'],
	'reg.29.server.2.expires.overlap' => ['60'],
	'reg.29.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.29.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.29.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.29.server.2.failOver.reRegisterOn' => ['0'],
	'reg.29.server.2.lcs' => ['0'],
	'reg.29.server.2.port' => ['0', '5060' ],
	'reg.29.server.2.register' => ['1'],
	'reg.29.server.2.retryMaxCount' => ['3'],
	'reg.29.server.2.retryTimeOut' => ['0'],
	'reg.29.server.2.transport' => ['DNSnaptr', '' ],
	'reg.29.server.3.address' => [''],
	'reg.29.server.3.expires' => ['3600'],
	'reg.29.server.3.expires.lineSeize' => ['30'],
	'reg.29.server.3.expires.overlap' => ['60'],
	'reg.29.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.29.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.29.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.29.server.3.failOver.reRegisterOn' => ['0'],
	'reg.29.server.3.lcs' => ['0'],
	'reg.29.server.3.port' => ['0', '5060' ],
	'reg.29.server.3.register' => ['1'],
	'reg.29.server.3.retryMaxCount' => ['3'],
	'reg.29.server.3.retryTimeOut' => ['0'],
	'reg.29.server.3.transport' => ['DNSnaptr', '' ],
	'reg.29.server.4.address' => [''],
	'reg.29.server.4.expires' => ['3600'],
	'reg.29.server.4.expires.lineSeize' => ['30'],
	'reg.29.server.4.expires.overlap' => ['60'],
	'reg.29.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.29.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.29.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.29.server.4.failOver.reRegisterOn' => ['0'],
	'reg.29.server.4.lcs' => ['0'],
	'reg.29.server.4.port' => ['0', '5060' ],
	'reg.29.server.4.register' => ['1'],
	'reg.29.server.4.retryMaxCount' => ['3'],
	'reg.29.server.4.retryTimeOut' => ['0'],
	'reg.29.server.4.transport' => ['DNSnaptr', '' ],
	'reg.29.server.H323.1.address' => [''],
	'reg.29.server.H323.1.expires' => ['3600'],
	'reg.29.server.H323.1.port' => ['0'],
	'reg.29.server.H323.1.register' => ['1'],
	'reg.29.server.H323.2.address' => [''],
	'reg.29.server.H323.2.expires' => ['3600'],
	'reg.29.server.H323.2.port' => ['0'],
	'reg.29.server.H323.2.register' => ['1'],
	'reg.29.server.H323.3.address' => [''],
	'reg.29.server.H323.3.expires' => ['3600'],
	'reg.29.server.H323.3.port' => ['0'],
	'reg.29.server.H323.3.register' => ['1'],
	'reg.29.server.H323.4.address' => [''],
	'reg.29.server.H323.4.expires' => ['3600'],
	'reg.29.server.H323.4.port' => ['0'],
	'reg.29.server.H323.4.register' => ['1'],
	'reg.29.serverFeatureControl.cf' => ['1'],
	'reg.29.serverFeatureControl.dnd' => ['1'],
	'reg.29.strictLineSeize' => ['0'],
	'reg.29.tcpFastFailover' => ['0'],
	'reg.29.thirdPartyName' => [''],
	'reg.29.type' => ['private'],
	'reg.29.useCompleteUriForRetrieve' => ['1'],
	'reg.3.address' => [''],
	'reg.3.auth.optimizedInFailover' => ['0'],
	'reg.3.auth.password' => [''],
	'reg.3.auth.userId' => [''],
	'reg.3.bargeInEnabled' => ['0'],
	'reg.3.callsPerLineKey' => ['24'],
	'reg.3.csta' => ['0'],
	'reg.3.displayName' => [''],
	'reg.3.dndStatus' => ['0'],
	'reg.3.fwd.busy.contact' => [''],
	'reg.3.fwd.busy.status' => ['0'],
	'reg.3.fwd.noanswer.contact' => [''],
	'reg.3.fwd.noanswer.ringCount' => ['0'],
	'reg.3.fwd.noanswer.status' => ['0'],
	'reg.3.fwdContact' => [''],
	'reg.3.fwdStatus' => ['0'],
	'reg.3.label' => [''],
	'reg.3.lcs' => ['0'],
	'reg.3.lineKeys' => ['1'],
	'reg.3.musicOnHold.uri' => [''],
	'reg.3.mwiNew' => ['0'],
	'reg.3.mwiOld' => ['0'],
	'reg.3.mwiUrg' => ['0'],
	'reg.3.outboundProxy.address' => [''],
	'reg.3.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.3.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.3.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.3.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.3.outboundProxy.port' => ['0', 5060 ],
	'reg.3.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.3.protocol' => [''],
	'reg.3.protocol.H323' => ['0'],
	'reg.3.protocol.SIP' => ['1'],
	'reg.3.proxyRequire' => [''],
	'reg.3.ringType' => ['ringer2'],
	'reg.3.server.1.address' => [''],
	'reg.3.server.1.expires' => ['3600'],
	'reg.3.server.1.expires.lineSeize' => ['30'],
	'reg.3.server.1.expires.overlap' => ['60'],
	'reg.3.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.3.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.3.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.3.server.1.failOver.reRegisterOn' => ['0'],
	'reg.3.server.1.lcs' => ['0'],
	'reg.3.server.1.port' => ['0', '5060' ],
	'reg.3.server.1.register' => ['1'],
	'reg.3.server.1.retryMaxCount' => ['3'],
	'reg.3.server.1.retryTimeOut' => ['0'],
	'reg.3.server.1.transport' => ['DNSnaptr', '' ],
	'reg.3.server.2.address' => [''],
	'reg.3.server.2.expires' => ['3600'],
	'reg.3.server.2.expires.lineSeize' => ['30'],
	'reg.3.server.2.expires.overlap' => ['60'],
	'reg.3.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.3.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.3.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.3.server.2.failOver.reRegisterOn' => ['0'],
	'reg.3.server.2.lcs' => ['0'],
	'reg.3.server.2.port' => ['0', '5060' ],
	'reg.3.server.2.register' => ['1'],
	'reg.3.server.2.retryMaxCount' => ['3'],
	'reg.3.server.2.retryTimeOut' => ['0'],
	'reg.3.server.2.transport' => ['DNSnaptr', '' ],
	'reg.3.server.3.address' => [''],
	'reg.3.server.3.expires' => ['3600'],
	'reg.3.server.3.expires.lineSeize' => ['30'],
	'reg.3.server.3.expires.overlap' => ['60'],
	'reg.3.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.3.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.3.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.3.server.3.failOver.reRegisterOn' => ['0'],
	'reg.3.server.3.lcs' => ['0'],
	'reg.3.server.3.port' => ['0', '5060' ],
	'reg.3.server.3.register' => ['1'],
	'reg.3.server.3.retryMaxCount' => ['3'],
	'reg.3.server.3.retryTimeOut' => ['0'],
	'reg.3.server.3.transport' => ['DNSnaptr', '' ],
	'reg.3.server.4.address' => [''],
	'reg.3.server.4.expires' => ['3600'],
	'reg.3.server.4.expires.lineSeize' => ['30'],
	'reg.3.server.4.expires.overlap' => ['60'],
	'reg.3.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.3.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.3.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.3.server.4.failOver.reRegisterOn' => ['0'],
	'reg.3.server.4.lcs' => ['0'],
	'reg.3.server.4.port' => ['0', '5060' ],
	'reg.3.server.4.register' => ['1'],
	'reg.3.server.4.retryMaxCount' => ['3'],
	'reg.3.server.4.retryTimeOut' => ['0'],
	'reg.3.server.4.transport' => ['DNSnaptr', '' ],
	'reg.3.server.H323.1.address' => [''],
	'reg.3.server.H323.1.expires' => ['3600'],
	'reg.3.server.H323.1.port' => ['0'],
	'reg.3.server.H323.1.register' => ['1'],
	'reg.3.server.H323.2.address' => [''],
	'reg.3.server.H323.2.expires' => ['3600'],
	'reg.3.server.H323.2.port' => ['0'],
	'reg.3.server.H323.2.register' => ['1'],
	'reg.3.server.H323.3.address' => [''],
	'reg.3.server.H323.3.expires' => ['3600'],
	'reg.3.server.H323.3.port' => ['0'],
	'reg.3.server.H323.3.register' => ['1'],
	'reg.3.server.H323.4.address' => [''],
	'reg.3.server.H323.4.expires' => ['3600'],
	'reg.3.server.H323.4.port' => ['0'],
	'reg.3.server.H323.4.register' => ['1'],
	'reg.3.serverFeatureControl.cf' => ['1'],
	'reg.3.serverFeatureControl.dnd' => ['1'],
	'reg.3.strictLineSeize' => ['0'],
	'reg.3.tcpFastFailover' => ['0'],
	'reg.3.thirdPartyName' => [''],
	'reg.3.type' => ['private'],
	'reg.3.useCompleteUriForRetrieve' => ['1'],
	'reg.30.address' => [''],
	'reg.30.auth.optimizedInFailover' => ['0'],
	'reg.30.auth.password' => [''],
	'reg.30.auth.userId' => [''],
	'reg.30.bargeInEnabled' => ['0'],
	'reg.30.callsPerLineKey' => ['24'],
	'reg.30.csta' => ['0'],
	'reg.30.displayName' => [''],
	'reg.30.dndStatus' => ['0'],
	'reg.30.fwd.busy.contact' => [''],
	'reg.30.fwd.busy.status' => ['0'],
	'reg.30.fwd.noanswer.contact' => [''],
	'reg.30.fwd.noanswer.ringCount' => ['0'],
	'reg.30.fwd.noanswer.status' => ['0'],
	'reg.30.fwdContact' => [''],
	'reg.30.fwdStatus' => ['0'],
	'reg.30.label' => [''],
	'reg.30.lcs' => ['0'],
	'reg.30.lineKeys' => ['1'],
	'reg.30.musicOnHold.uri' => [''],
	'reg.30.mwiNew' => ['0'],
	'reg.30.mwiOld' => ['0'],
	'reg.30.mwiUrg' => ['0'],
	'reg.30.outboundProxy.address' => [''],
	'reg.30.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.30.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.30.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.30.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.30.outboundProxy.port' => ['0', 5060 ],
	'reg.30.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.30.protocol' => [''],
	'reg.30.protocol.H323' => ['0'],
	'reg.30.protocol.SIP' => ['1'],
	'reg.30.proxyRequire' => [''],
	'reg.30.ringType' => ['ringer2'],
	'reg.30.server.1.address' => [''],
	'reg.30.server.1.expires' => ['3600'],
	'reg.30.server.1.expires.lineSeize' => ['30'],
	'reg.30.server.1.expires.overlap' => ['60'],
	'reg.30.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.30.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.30.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.30.server.1.failOver.reRegisterOn' => ['0'],
	'reg.30.server.1.lcs' => ['0'],
	'reg.30.server.1.port' => ['0', '5060' ],
	'reg.30.server.1.register' => ['1'],
	'reg.30.server.1.retryMaxCount' => ['3'],
	'reg.30.server.1.retryTimeOut' => ['0'],
	'reg.30.server.1.transport' => ['DNSnaptr', '' ],
	'reg.30.server.2.address' => [''],
	'reg.30.server.2.expires' => ['3600'],
	'reg.30.server.2.expires.lineSeize' => ['30'],
	'reg.30.server.2.expires.overlap' => ['60'],
	'reg.30.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.30.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.30.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.30.server.2.failOver.reRegisterOn' => ['0'],
	'reg.30.server.2.lcs' => ['0'],
	'reg.30.server.2.port' => ['0', '5060' ],
	'reg.30.server.2.register' => ['1'],
	'reg.30.server.2.retryMaxCount' => ['3'],
	'reg.30.server.2.retryTimeOut' => ['0'],
	'reg.30.server.2.transport' => ['DNSnaptr', '' ],
	'reg.30.server.3.address' => [''],
	'reg.30.server.3.expires' => ['3600'],
	'reg.30.server.3.expires.lineSeize' => ['30'],
	'reg.30.server.3.expires.overlap' => ['60'],
	'reg.30.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.30.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.30.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.30.server.3.failOver.reRegisterOn' => ['0'],
	'reg.30.server.3.lcs' => ['0'],
	'reg.30.server.3.port' => ['0', '5060' ],
	'reg.30.server.3.register' => ['1'],
	'reg.30.server.3.retryMaxCount' => ['3'],
	'reg.30.server.3.retryTimeOut' => ['0'],
	'reg.30.server.3.transport' => ['DNSnaptr', '' ],
	'reg.30.server.4.address' => [''],
	'reg.30.server.4.expires' => ['3600'],
	'reg.30.server.4.expires.lineSeize' => ['30'],
	'reg.30.server.4.expires.overlap' => ['60'],
	'reg.30.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.30.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.30.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.30.server.4.failOver.reRegisterOn' => ['0'],
	'reg.30.server.4.lcs' => ['0'],
	'reg.30.server.4.port' => ['0', '5060' ],
	'reg.30.server.4.register' => ['1'],
	'reg.30.server.4.retryMaxCount' => ['3'],
	'reg.30.server.4.retryTimeOut' => ['0'],
	'reg.30.server.4.transport' => ['DNSnaptr', '' ],
	'reg.30.server.H323.1.address' => [''],
	'reg.30.server.H323.1.expires' => ['3600'],
	'reg.30.server.H323.1.port' => ['0'],
	'reg.30.server.H323.1.register' => ['1'],
	'reg.30.server.H323.2.address' => [''],
	'reg.30.server.H323.2.expires' => ['3600'],
	'reg.30.server.H323.2.port' => ['0'],
	'reg.30.server.H323.2.register' => ['1'],
	'reg.30.server.H323.3.address' => [''],
	'reg.30.server.H323.3.expires' => ['3600'],
	'reg.30.server.H323.3.port' => ['0'],
	'reg.30.server.H323.3.register' => ['1'],
	'reg.30.server.H323.4.address' => [''],
	'reg.30.server.H323.4.expires' => ['3600'],
	'reg.30.server.H323.4.port' => ['0'],
	'reg.30.server.H323.4.register' => ['1'],
	'reg.30.serverFeatureControl.cf' => ['1'],
	'reg.30.serverFeatureControl.dnd' => ['1'],
	'reg.30.strictLineSeize' => ['0'],
	'reg.30.tcpFastFailover' => ['0'],
	'reg.30.thirdPartyName' => [''],
	'reg.30.type' => ['private'],
	'reg.30.useCompleteUriForRetrieve' => ['1'],
	'reg.31.address' => [''],
	'reg.31.auth.optimizedInFailover' => ['0'],
	'reg.31.auth.password' => [''],
	'reg.31.auth.userId' => [''],
	'reg.31.bargeInEnabled' => ['0'],
	'reg.31.callsPerLineKey' => ['24'],
	'reg.31.csta' => ['0'],
	'reg.31.displayName' => [''],
	'reg.31.dndStatus' => ['0'],
	'reg.31.fwd.busy.contact' => [''],
	'reg.31.fwd.busy.status' => ['0'],
	'reg.31.fwd.noanswer.contact' => [''],
	'reg.31.fwd.noanswer.ringCount' => ['0'],
	'reg.31.fwd.noanswer.status' => ['0'],
	'reg.31.fwdContact' => [''],
	'reg.31.fwdStatus' => ['0'],
	'reg.31.label' => [''],
	'reg.31.lcs' => ['0'],
	'reg.31.lineKeys' => ['1'],
	'reg.31.musicOnHold.uri' => [''],
	'reg.31.mwiNew' => ['0'],
	'reg.31.mwiOld' => ['0'],
	'reg.31.mwiUrg' => ['0'],
	'reg.31.outboundProxy.address' => [''],
	'reg.31.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.31.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.31.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.31.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.31.outboundProxy.port' => ['0', 5060 ],
	'reg.31.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.31.protocol' => [''],
	'reg.31.protocol.H323' => ['0'],
	'reg.31.protocol.SIP' => ['1'],
	'reg.31.proxyRequire' => [''],
	'reg.31.ringType' => ['ringer2'],
	'reg.31.server.1.address' => [''],
	'reg.31.server.1.expires' => ['3600'],
	'reg.31.server.1.expires.lineSeize' => ['30'],
	'reg.31.server.1.expires.overlap' => ['60'],
	'reg.31.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.31.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.31.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.31.server.1.failOver.reRegisterOn' => ['0'],
	'reg.31.server.1.lcs' => ['0'],
	'reg.31.server.1.port' => ['0', '5060' ],
	'reg.31.server.1.register' => ['1'],
	'reg.31.server.1.retryMaxCount' => ['3'],
	'reg.31.server.1.retryTimeOut' => ['0'],
	'reg.31.server.1.transport' => ['DNSnaptr', '' ],
	'reg.31.server.2.address' => [''],
	'reg.31.server.2.expires' => ['3600'],
	'reg.31.server.2.expires.lineSeize' => ['30'],
	'reg.31.server.2.expires.overlap' => ['60'],
	'reg.31.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.31.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.31.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.31.server.2.failOver.reRegisterOn' => ['0'],
	'reg.31.server.2.lcs' => ['0'],
	'reg.31.server.2.port' => ['0', '5060' ],
	'reg.31.server.2.register' => ['1'],
	'reg.31.server.2.retryMaxCount' => ['3'],
	'reg.31.server.2.retryTimeOut' => ['0'],
	'reg.31.server.2.transport' => ['DNSnaptr', '' ],
	'reg.31.server.3.address' => [''],
	'reg.31.server.3.expires' => ['3600'],
	'reg.31.server.3.expires.lineSeize' => ['30'],
	'reg.31.server.3.expires.overlap' => ['60'],
	'reg.31.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.31.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.31.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.31.server.3.failOver.reRegisterOn' => ['0'],
	'reg.31.server.3.lcs' => ['0'],
	'reg.31.server.3.port' => ['0', '5060' ],
	'reg.31.server.3.register' => ['1'],
	'reg.31.server.3.retryMaxCount' => ['3'],
	'reg.31.server.3.retryTimeOut' => ['0'],
	'reg.31.server.3.transport' => ['DNSnaptr', '' ],
	'reg.31.server.4.address' => [''],
	'reg.31.server.4.expires' => ['3600'],
	'reg.31.server.4.expires.lineSeize' => ['30'],
	'reg.31.server.4.expires.overlap' => ['60'],
	'reg.31.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.31.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.31.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.31.server.4.failOver.reRegisterOn' => ['0'],
	'reg.31.server.4.lcs' => ['0'],
	'reg.31.server.4.port' => ['0', '5060' ],
	'reg.31.server.4.register' => ['1'],
	'reg.31.server.4.retryMaxCount' => ['3'],
	'reg.31.server.4.retryTimeOut' => ['0'],
	'reg.31.server.4.transport' => ['DNSnaptr', '' ],
	'reg.31.server.H323.1.address' => [''],
	'reg.31.server.H323.1.expires' => ['3600'],
	'reg.31.server.H323.1.port' => ['0'],
	'reg.31.server.H323.1.register' => ['1'],
	'reg.31.server.H323.2.address' => [''],
	'reg.31.server.H323.2.expires' => ['3600'],
	'reg.31.server.H323.2.port' => ['0'],
	'reg.31.server.H323.2.register' => ['1'],
	'reg.31.server.H323.3.address' => [''],
	'reg.31.server.H323.3.expires' => ['3600'],
	'reg.31.server.H323.3.port' => ['0'],
	'reg.31.server.H323.3.register' => ['1'],
	'reg.31.server.H323.4.address' => [''],
	'reg.31.server.H323.4.expires' => ['3600'],
	'reg.31.server.H323.4.port' => ['0'],
	'reg.31.server.H323.4.register' => ['1'],
	'reg.31.serverFeatureControl.cf' => ['1'],
	'reg.31.serverFeatureControl.dnd' => ['1'],
	'reg.31.strictLineSeize' => ['0'],
	'reg.31.tcpFastFailover' => ['0'],
	'reg.31.thirdPartyName' => [''],
	'reg.31.type' => ['private'],
	'reg.31.useCompleteUriForRetrieve' => ['1'],
	'reg.32.address' => [''],
	'reg.32.auth.optimizedInFailover' => ['0'],
	'reg.32.auth.password' => [''],
	'reg.32.auth.userId' => [''],
	'reg.32.bargeInEnabled' => ['0'],
	'reg.32.callsPerLineKey' => ['24'],
	'reg.32.csta' => ['0'],
	'reg.32.displayName' => [''],
	'reg.32.dndStatus' => ['0'],
	'reg.32.fwd.busy.contact' => [''],
	'reg.32.fwd.busy.status' => ['0'],
	'reg.32.fwd.noanswer.contact' => [''],
	'reg.32.fwd.noanswer.ringCount' => ['0'],
	'reg.32.fwd.noanswer.status' => ['0'],
	'reg.32.fwdContact' => [''],
	'reg.32.fwdStatus' => ['0'],
	'reg.32.label' => [''],
	'reg.32.lcs' => ['0'],
	'reg.32.lineKeys' => ['1'],
	'reg.32.musicOnHold.uri' => [''],
	'reg.32.mwiNew' => ['0'],
	'reg.32.mwiOld' => ['0'],
	'reg.32.mwiUrg' => ['0'],
	'reg.32.outboundProxy.address' => [''],
	'reg.32.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.32.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.32.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.32.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.32.outboundProxy.port' => ['0', 5060 ],
	'reg.32.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.32.protocol' => [''],
	'reg.32.protocol.H323' => ['0'],
	'reg.32.protocol.SIP' => ['1'],
	'reg.32.proxyRequire' => [''],
	'reg.32.ringType' => ['ringer2'],
	'reg.32.server.1.address' => [''],
	'reg.32.server.1.expires' => ['3600'],
	'reg.32.server.1.expires.lineSeize' => ['30'],
	'reg.32.server.1.expires.overlap' => ['60'],
	'reg.32.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.32.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.32.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.32.server.1.failOver.reRegisterOn' => ['0'],
	'reg.32.server.1.lcs' => ['0'],
	'reg.32.server.1.port' => ['0', '5060' ],
	'reg.32.server.1.register' => ['1'],
	'reg.32.server.1.retryMaxCount' => ['3'],
	'reg.32.server.1.retryTimeOut' => ['0'],
	'reg.32.server.1.transport' => ['DNSnaptr', '' ],
	'reg.32.server.2.address' => [''],
	'reg.32.server.2.expires' => ['3600'],
	'reg.32.server.2.expires.lineSeize' => ['30'],
	'reg.32.server.2.expires.overlap' => ['60'],
	'reg.32.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.32.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.32.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.32.server.2.failOver.reRegisterOn' => ['0'],
	'reg.32.server.2.lcs' => ['0'],
	'reg.32.server.2.port' => ['0', '5060' ],
	'reg.32.server.2.register' => ['1'],
	'reg.32.server.2.retryMaxCount' => ['3'],
	'reg.32.server.2.retryTimeOut' => ['0'],
	'reg.32.server.2.transport' => ['DNSnaptr', '' ],
	'reg.32.server.3.address' => [''],
	'reg.32.server.3.expires' => ['3600'],
	'reg.32.server.3.expires.lineSeize' => ['30'],
	'reg.32.server.3.expires.overlap' => ['60'],
	'reg.32.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.32.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.32.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.32.server.3.failOver.reRegisterOn' => ['0'],
	'reg.32.server.3.lcs' => ['0'],
	'reg.32.server.3.port' => ['0', '5060' ],
	'reg.32.server.3.register' => ['1'],
	'reg.32.server.3.retryMaxCount' => ['3'],
	'reg.32.server.3.retryTimeOut' => ['0'],
	'reg.32.server.3.transport' => ['DNSnaptr', '' ],
	'reg.32.server.4.address' => [''],
	'reg.32.server.4.expires' => ['3600'],
	'reg.32.server.4.expires.lineSeize' => ['30'],
	'reg.32.server.4.expires.overlap' => ['60'],
	'reg.32.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.32.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.32.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.32.server.4.failOver.reRegisterOn' => ['0'],
	'reg.32.server.4.lcs' => ['0'],
	'reg.32.server.4.port' => ['0', '5060' ],
	'reg.32.server.4.register' => ['1'],
	'reg.32.server.4.retryMaxCount' => ['3'],
	'reg.32.server.4.retryTimeOut' => ['0'],
	'reg.32.server.4.transport' => ['DNSnaptr', '' ],
	'reg.32.server.H323.1.address' => [''],
	'reg.32.server.H323.1.expires' => ['3600'],
	'reg.32.server.H323.1.port' => ['0'],
	'reg.32.server.H323.1.register' => ['1'],
	'reg.32.server.H323.2.address' => [''],
	'reg.32.server.H323.2.expires' => ['3600'],
	'reg.32.server.H323.2.port' => ['0'],
	'reg.32.server.H323.2.register' => ['1'],
	'reg.32.server.H323.3.address' => [''],
	'reg.32.server.H323.3.expires' => ['3600'],
	'reg.32.server.H323.3.port' => ['0'],
	'reg.32.server.H323.3.register' => ['1'],
	'reg.32.server.H323.4.address' => [''],
	'reg.32.server.H323.4.expires' => ['3600'],
	'reg.32.server.H323.4.port' => ['0'],
	'reg.32.server.H323.4.register' => ['1'],
	'reg.32.serverFeatureControl.cf' => ['1'],
	'reg.32.serverFeatureControl.dnd' => ['1'],
	'reg.32.strictLineSeize' => ['0'],
	'reg.32.tcpFastFailover' => ['0'],
	'reg.32.thirdPartyName' => [''],
	'reg.32.type' => ['private'],
	'reg.32.useCompleteUriForRetrieve' => ['1'],
	'reg.33.address' => [''],
	'reg.33.auth.optimizedInFailover' => ['0'],
	'reg.33.auth.password' => [''],
	'reg.33.auth.userId' => [''],
	'reg.33.bargeInEnabled' => ['0'],
	'reg.33.callsPerLineKey' => ['24'],
	'reg.33.csta' => ['0'],
	'reg.33.displayName' => [''],
	'reg.33.dndStatus' => ['0'],
	'reg.33.fwd.busy.contact' => [''],
	'reg.33.fwd.busy.status' => ['0'],
	'reg.33.fwd.noanswer.contact' => [''],
	'reg.33.fwd.noanswer.ringCount' => ['0'],
	'reg.33.fwd.noanswer.status' => ['0'],
	'reg.33.fwdContact' => [''],
	'reg.33.fwdStatus' => ['0'],
	'reg.33.label' => [''],
	'reg.33.lcs' => ['0'],
	'reg.33.lineKeys' => ['1'],
	'reg.33.musicOnHold.uri' => [''],
	'reg.33.mwiNew' => ['0'],
	'reg.33.mwiOld' => ['0'],
	'reg.33.mwiUrg' => ['0'],
	'reg.33.outboundProxy.address' => [''],
	'reg.33.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.33.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.33.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.33.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.33.outboundProxy.port' => ['0', 5060 ],
	'reg.33.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.33.protocol' => [''],
	'reg.33.protocol.H323' => ['0'],
	'reg.33.protocol.SIP' => ['1'],
	'reg.33.proxyRequire' => [''],
	'reg.33.ringType' => ['ringer2'],
	'reg.33.server.1.address' => [''],
	'reg.33.server.1.expires' => ['3600'],
	'reg.33.server.1.expires.lineSeize' => ['30'],
	'reg.33.server.1.expires.overlap' => ['60'],
	'reg.33.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.33.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.33.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.33.server.1.failOver.reRegisterOn' => ['0'],
	'reg.33.server.1.lcs' => ['0'],
	'reg.33.server.1.port' => ['0', '5060' ],
	'reg.33.server.1.register' => ['1'],
	'reg.33.server.1.retryMaxCount' => ['3'],
	'reg.33.server.1.retryTimeOut' => ['0'],
	'reg.33.server.1.transport' => ['DNSnaptr', '' ],
	'reg.33.server.2.address' => [''],
	'reg.33.server.2.expires' => ['3600'],
	'reg.33.server.2.expires.lineSeize' => ['30'],
	'reg.33.server.2.expires.overlap' => ['60'],
	'reg.33.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.33.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.33.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.33.server.2.failOver.reRegisterOn' => ['0'],
	'reg.33.server.2.lcs' => ['0'],
	'reg.33.server.2.port' => ['0', '5060' ],
	'reg.33.server.2.register' => ['1'],
	'reg.33.server.2.retryMaxCount' => ['3'],
	'reg.33.server.2.retryTimeOut' => ['0'],
	'reg.33.server.2.transport' => ['DNSnaptr', '' ],
	'reg.33.server.3.address' => [''],
	'reg.33.server.3.expires' => ['3600'],
	'reg.33.server.3.expires.lineSeize' => ['30'],
	'reg.33.server.3.expires.overlap' => ['60'],
	'reg.33.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.33.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.33.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.33.server.3.failOver.reRegisterOn' => ['0'],
	'reg.33.server.3.lcs' => ['0'],
	'reg.33.server.3.port' => ['0', '5060' ],
	'reg.33.server.3.register' => ['1'],
	'reg.33.server.3.retryMaxCount' => ['3'],
	'reg.33.server.3.retryTimeOut' => ['0'],
	'reg.33.server.3.transport' => ['DNSnaptr', '' ],
	'reg.33.server.4.address' => [''],
	'reg.33.server.4.expires' => ['3600'],
	'reg.33.server.4.expires.lineSeize' => ['30'],
	'reg.33.server.4.expires.overlap' => ['60'],
	'reg.33.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.33.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.33.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.33.server.4.failOver.reRegisterOn' => ['0'],
	'reg.33.server.4.lcs' => ['0'],
	'reg.33.server.4.port' => ['0', '5060' ],
	'reg.33.server.4.register' => ['1'],
	'reg.33.server.4.retryMaxCount' => ['3'],
	'reg.33.server.4.retryTimeOut' => ['0'],
	'reg.33.server.4.transport' => ['DNSnaptr', '' ],
	'reg.33.server.H323.1.address' => [''],
	'reg.33.server.H323.1.expires' => ['3600'],
	'reg.33.server.H323.1.port' => ['0'],
	'reg.33.server.H323.1.register' => ['1'],
	'reg.33.server.H323.2.address' => [''],
	'reg.33.server.H323.2.expires' => ['3600'],
	'reg.33.server.H323.2.port' => ['0'],
	'reg.33.server.H323.2.register' => ['1'],
	'reg.33.server.H323.3.address' => [''],
	'reg.33.server.H323.3.expires' => ['3600'],
	'reg.33.server.H323.3.port' => ['0'],
	'reg.33.server.H323.3.register' => ['1'],
	'reg.33.server.H323.4.address' => [''],
	'reg.33.server.H323.4.expires' => ['3600'],
	'reg.33.server.H323.4.port' => ['0'],
	'reg.33.server.H323.4.register' => ['1'],
	'reg.33.serverFeatureControl.cf' => ['1'],
	'reg.33.serverFeatureControl.dnd' => ['1'],
	'reg.33.strictLineSeize' => ['0'],
	'reg.33.tcpFastFailover' => ['0'],
	'reg.33.thirdPartyName' => [''],
	'reg.33.type' => ['private'],
	'reg.33.useCompleteUriForRetrieve' => ['1'],
	'reg.34.address' => [''],
	'reg.34.auth.optimizedInFailover' => ['0'],
	'reg.34.auth.password' => [''],
	'reg.34.auth.userId' => [''],
	'reg.34.bargeInEnabled' => ['0'],
	'reg.34.callsPerLineKey' => ['24'],
	'reg.34.csta' => ['0'],
	'reg.34.displayName' => [''],
	'reg.34.dndStatus' => ['0'],
	'reg.34.fwd.busy.contact' => [''],
	'reg.34.fwd.busy.status' => ['0'],
	'reg.34.fwd.noanswer.contact' => [''],
	'reg.34.fwd.noanswer.ringCount' => ['0'],
	'reg.34.fwd.noanswer.status' => ['0'],
	'reg.34.fwdContact' => [''],
	'reg.34.fwdStatus' => ['0'],
	'reg.34.label' => [''],
	'reg.34.lcs' => ['0'],
	'reg.34.lineKeys' => ['1'],
	'reg.34.musicOnHold.uri' => [''],
	'reg.34.mwiNew' => ['0'],
	'reg.34.mwiOld' => ['0'],
	'reg.34.mwiUrg' => ['0'],
	'reg.34.outboundProxy.address' => [''],
	'reg.34.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.34.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.34.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.34.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.34.outboundProxy.port' => ['0', 5060 ],
	'reg.34.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.34.protocol' => [''],
	'reg.34.protocol.H323' => ['0'],
	'reg.34.protocol.SIP' => ['1'],
	'reg.34.proxyRequire' => [''],
	'reg.34.ringType' => ['ringer2'],
	'reg.34.server.1.address' => [''],
	'reg.34.server.1.expires' => ['3600'],
	'reg.34.server.1.expires.lineSeize' => ['30'],
	'reg.34.server.1.expires.overlap' => ['60'],
	'reg.34.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.34.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.34.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.34.server.1.failOver.reRegisterOn' => ['0'],
	'reg.34.server.1.lcs' => ['0'],
	'reg.34.server.1.port' => ['0', '5060' ],
	'reg.34.server.1.register' => ['1'],
	'reg.34.server.1.retryMaxCount' => ['3'],
	'reg.34.server.1.retryTimeOut' => ['0'],
	'reg.34.server.1.transport' => ['DNSnaptr', '' ],
	'reg.34.server.2.address' => [''],
	'reg.34.server.2.expires' => ['3600'],
	'reg.34.server.2.expires.lineSeize' => ['30'],
	'reg.34.server.2.expires.overlap' => ['60'],
	'reg.34.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.34.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.34.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.34.server.2.failOver.reRegisterOn' => ['0'],
	'reg.34.server.2.lcs' => ['0'],
	'reg.34.server.2.port' => ['0', '5060' ],
	'reg.34.server.2.register' => ['1'],
	'reg.34.server.2.retryMaxCount' => ['3'],
	'reg.34.server.2.retryTimeOut' => ['0'],
	'reg.34.server.2.transport' => ['DNSnaptr', '' ],
	'reg.34.server.3.address' => [''],
	'reg.34.server.3.expires' => ['3600'],
	'reg.34.server.3.expires.lineSeize' => ['30'],
	'reg.34.server.3.expires.overlap' => ['60'],
	'reg.34.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.34.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.34.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.34.server.3.failOver.reRegisterOn' => ['0'],
	'reg.34.server.3.lcs' => ['0'],
	'reg.34.server.3.port' => ['0', '5060' ],
	'reg.34.server.3.register' => ['1'],
	'reg.34.server.3.retryMaxCount' => ['3'],
	'reg.34.server.3.retryTimeOut' => ['0'],
	'reg.34.server.3.transport' => ['DNSnaptr', '' ],
	'reg.34.server.4.address' => [''],
	'reg.34.server.4.expires' => ['3600'],
	'reg.34.server.4.expires.lineSeize' => ['30'],
	'reg.34.server.4.expires.overlap' => ['60'],
	'reg.34.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.34.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.34.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.34.server.4.failOver.reRegisterOn' => ['0'],
	'reg.34.server.4.lcs' => ['0'],
	'reg.34.server.4.port' => ['0', '5060' ],
	'reg.34.server.4.register' => ['1'],
	'reg.34.server.4.retryMaxCount' => ['3'],
	'reg.34.server.4.retryTimeOut' => ['0'],
	'reg.34.server.4.transport' => ['DNSnaptr', '' ],
	'reg.34.server.H323.1.address' => [''],
	'reg.34.server.H323.1.expires' => ['3600'],
	'reg.34.server.H323.1.port' => ['0'],
	'reg.34.server.H323.1.register' => ['1'],
	'reg.34.server.H323.2.address' => [''],
	'reg.34.server.H323.2.expires' => ['3600'],
	'reg.34.server.H323.2.port' => ['0'],
	'reg.34.server.H323.2.register' => ['1'],
	'reg.34.server.H323.3.address' => [''],
	'reg.34.server.H323.3.expires' => ['3600'],
	'reg.34.server.H323.3.port' => ['0'],
	'reg.34.server.H323.3.register' => ['1'],
	'reg.34.server.H323.4.address' => [''],
	'reg.34.server.H323.4.expires' => ['3600'],
	'reg.34.server.H323.4.port' => ['0'],
	'reg.34.server.H323.4.register' => ['1'],
	'reg.34.serverFeatureControl.cf' => ['1'],
	'reg.34.serverFeatureControl.dnd' => ['1'],
	'reg.34.strictLineSeize' => ['0'],
	'reg.34.tcpFastFailover' => ['0'],
	'reg.34.thirdPartyName' => [''],
	'reg.34.type' => ['private'],
	'reg.34.useCompleteUriForRetrieve' => ['1'],
	'reg.4.address' => [''],
	'reg.4.auth.optimizedInFailover' => ['0'],
	'reg.4.auth.password' => [''],
	'reg.4.auth.userId' => [''],
	'reg.4.bargeInEnabled' => ['0'],
	'reg.4.callsPerLineKey' => ['24'],
	'reg.4.csta' => ['0'],
	'reg.4.displayName' => [''],
	'reg.4.dndStatus' => ['0'],
	'reg.4.fwd.busy.contact' => [''],
	'reg.4.fwd.busy.status' => ['0'],
	'reg.4.fwd.noanswer.contact' => [''],
	'reg.4.fwd.noanswer.ringCount' => ['0'],
	'reg.4.fwd.noanswer.status' => ['0'],
	'reg.4.fwdContact' => [''],
	'reg.4.fwdStatus' => ['0'],
	'reg.4.label' => [''],
	'reg.4.lcs' => ['0'],
	'reg.4.lineKeys' => ['1'],
	'reg.4.musicOnHold.uri' => [''],
	'reg.4.mwiNew' => ['0'],
	'reg.4.mwiOld' => ['0'],
	'reg.4.mwiUrg' => ['0'],
	'reg.4.outboundProxy.address' => [''],
	'reg.4.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.4.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.4.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.4.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.4.outboundProxy.port' => ['0', 5060 ],
	'reg.4.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.4.protocol' => [''],
	'reg.4.protocol.H323' => ['0'],
	'reg.4.protocol.SIP' => ['1'],
	'reg.4.proxyRequire' => [''],
	'reg.4.ringType' => ['ringer2'],
	'reg.4.server.1.address' => [''],
	'reg.4.server.1.expires' => ['3600'],
	'reg.4.server.1.expires.lineSeize' => ['30'],
	'reg.4.server.1.expires.overlap' => ['60'],
	'reg.4.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.4.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.4.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.4.server.1.failOver.reRegisterOn' => ['0'],
	'reg.4.server.1.lcs' => ['0'],
	'reg.4.server.1.port' => ['0', '5060' ],
	'reg.4.server.1.register' => ['1'],
	'reg.4.server.1.retryMaxCount' => ['3'],
	'reg.4.server.1.retryTimeOut' => ['0'],
	'reg.4.server.1.transport' => ['DNSnaptr', '' ],
	'reg.4.server.2.address' => [''],
	'reg.4.server.2.expires' => ['3600'],
	'reg.4.server.2.expires.lineSeize' => ['30'],
	'reg.4.server.2.expires.overlap' => ['60'],
	'reg.4.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.4.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.4.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.4.server.2.failOver.reRegisterOn' => ['0'],
	'reg.4.server.2.lcs' => ['0'],
	'reg.4.server.2.port' => ['0', '5060' ],
	'reg.4.server.2.register' => ['1'],
	'reg.4.server.2.retryMaxCount' => ['3'],
	'reg.4.server.2.retryTimeOut' => ['0'],
	'reg.4.server.2.transport' => ['DNSnaptr', '' ],
	'reg.4.server.3.address' => [''],
	'reg.4.server.3.expires' => ['3600'],
	'reg.4.server.3.expires.lineSeize' => ['30'],
	'reg.4.server.3.expires.overlap' => ['60'],
	'reg.4.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.4.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.4.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.4.server.3.failOver.reRegisterOn' => ['0'],
	'reg.4.server.3.lcs' => ['0'],
	'reg.4.server.3.port' => ['0', '5060' ],
	'reg.4.server.3.register' => ['1'],
	'reg.4.server.3.retryMaxCount' => ['3'],
	'reg.4.server.3.retryTimeOut' => ['0'],
	'reg.4.server.3.transport' => ['DNSnaptr', '' ],
	'reg.4.server.4.address' => [''],
	'reg.4.server.4.expires' => ['3600'],
	'reg.4.server.4.expires.lineSeize' => ['30'],
	'reg.4.server.4.expires.overlap' => ['60'],
	'reg.4.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.4.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.4.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.4.server.4.failOver.reRegisterOn' => ['0'],
	'reg.4.server.4.lcs' => ['0'],
	'reg.4.server.4.port' => ['0', '5060' ],
	'reg.4.server.4.register' => ['1'],
	'reg.4.server.4.retryMaxCount' => ['3'],
	'reg.4.server.4.retryTimeOut' => ['0'],
	'reg.4.server.4.transport' => ['DNSnaptr', '' ],
	'reg.4.server.H323.1.address' => [''],
	'reg.4.server.H323.1.expires' => ['3600'],
	'reg.4.server.H323.1.port' => ['0'],
	'reg.4.server.H323.1.register' => ['1'],
	'reg.4.server.H323.2.address' => [''],
	'reg.4.server.H323.2.expires' => ['3600'],
	'reg.4.server.H323.2.port' => ['0'],
	'reg.4.server.H323.2.register' => ['1'],
	'reg.4.server.H323.3.address' => [''],
	'reg.4.server.H323.3.expires' => ['3600'],
	'reg.4.server.H323.3.port' => ['0'],
	'reg.4.server.H323.3.register' => ['1'],
	'reg.4.server.H323.4.address' => [''],
	'reg.4.server.H323.4.expires' => ['3600'],
	'reg.4.server.H323.4.port' => ['0'],
	'reg.4.server.H323.4.register' => ['1'],
	'reg.4.serverFeatureControl.cf' => ['1'],
	'reg.4.serverFeatureControl.dnd' => ['1'],
	'reg.4.strictLineSeize' => ['0'],
	'reg.4.tcpFastFailover' => ['0'],
	'reg.4.thirdPartyName' => [''],
	'reg.4.type' => ['private'],
	'reg.4.useCompleteUriForRetrieve' => ['1'],
	'reg.5.address' => [''],
	'reg.5.auth.optimizedInFailover' => ['0'],
	'reg.5.auth.password' => [''],
	'reg.5.auth.userId' => [''],
	'reg.5.bargeInEnabled' => ['0'],
	'reg.5.callsPerLineKey' => ['24'],
	'reg.5.csta' => ['0'],
	'reg.5.displayName' => [''],
	'reg.5.dndStatus' => ['0'],
	'reg.5.fwd.busy.contact' => [''],
	'reg.5.fwd.busy.status' => ['0'],
	'reg.5.fwd.noanswer.contact' => [''],
	'reg.5.fwd.noanswer.ringCount' => ['0'],
	'reg.5.fwd.noanswer.status' => ['0'],
	'reg.5.fwdContact' => [''],
	'reg.5.fwdStatus' => ['0'],
	'reg.5.label' => [''],
	'reg.5.lcs' => ['0'],
	'reg.5.lineKeys' => ['1'],
	'reg.5.musicOnHold.uri' => [''],
	'reg.5.mwiNew' => ['0'],
	'reg.5.mwiOld' => ['0'],
	'reg.5.mwiUrg' => ['0'],
	'reg.5.outboundProxy.address' => [''],
	'reg.5.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.5.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.5.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.5.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.5.outboundProxy.port' => ['0', 5060 ],
	'reg.5.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.5.protocol' => [''],
	'reg.5.protocol.H323' => ['0'],
	'reg.5.protocol.SIP' => ['1'],
	'reg.5.proxyRequire' => [''],
	'reg.5.ringType' => ['ringer2'],
	'reg.5.server.1.address' => [''],
	'reg.5.server.1.expires' => ['3600'],
	'reg.5.server.1.expires.lineSeize' => ['30'],
	'reg.5.server.1.expires.overlap' => ['60'],
	'reg.5.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.5.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.5.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.5.server.1.failOver.reRegisterOn' => ['0'],
	'reg.5.server.1.lcs' => ['0'],
	'reg.5.server.1.port' => ['0', '5060' ],
	'reg.5.server.1.register' => ['1'],
	'reg.5.server.1.retryMaxCount' => ['3'],
	'reg.5.server.1.retryTimeOut' => ['0'],
	'reg.5.server.1.transport' => ['DNSnaptr', '' ],
	'reg.5.server.2.address' => [''],
	'reg.5.server.2.expires' => ['3600'],
	'reg.5.server.2.expires.lineSeize' => ['30'],
	'reg.5.server.2.expires.overlap' => ['60'],
	'reg.5.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.5.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.5.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.5.server.2.failOver.reRegisterOn' => ['0'],
	'reg.5.server.2.lcs' => ['0'],
	'reg.5.server.2.port' => ['0', '5060' ],
	'reg.5.server.2.register' => ['1'],
	'reg.5.server.2.retryMaxCount' => ['3'],
	'reg.5.server.2.retryTimeOut' => ['0'],
	'reg.5.server.2.transport' => ['DNSnaptr', '' ],
	'reg.5.server.3.address' => [''],
	'reg.5.server.3.expires' => ['3600'],
	'reg.5.server.3.expires.lineSeize' => ['30'],
	'reg.5.server.3.expires.overlap' => ['60'],
	'reg.5.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.5.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.5.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.5.server.3.failOver.reRegisterOn' => ['0'],
	'reg.5.server.3.lcs' => ['0'],
	'reg.5.server.3.port' => ['0', '5060' ],
	'reg.5.server.3.register' => ['1'],
	'reg.5.server.3.retryMaxCount' => ['3'],
	'reg.5.server.3.retryTimeOut' => ['0'],
	'reg.5.server.3.transport' => ['DNSnaptr', '' ],
	'reg.5.server.4.address' => [''],
	'reg.5.server.4.expires' => ['3600'],
	'reg.5.server.4.expires.lineSeize' => ['30'],
	'reg.5.server.4.expires.overlap' => ['60'],
	'reg.5.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.5.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.5.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.5.server.4.failOver.reRegisterOn' => ['0'],
	'reg.5.server.4.lcs' => ['0'],
	'reg.5.server.4.port' => ['0', '5060' ],
	'reg.5.server.4.register' => ['1'],
	'reg.5.server.4.retryMaxCount' => ['3'],
	'reg.5.server.4.retryTimeOut' => ['0'],
	'reg.5.server.4.transport' => ['DNSnaptr', '' ],
	'reg.5.server.H323.1.address' => [''],
	'reg.5.server.H323.1.expires' => ['3600'],
	'reg.5.server.H323.1.port' => ['0'],
	'reg.5.server.H323.1.register' => ['1'],
	'reg.5.server.H323.2.address' => [''],
	'reg.5.server.H323.2.expires' => ['3600'],
	'reg.5.server.H323.2.port' => ['0'],
	'reg.5.server.H323.2.register' => ['1'],
	'reg.5.server.H323.3.address' => [''],
	'reg.5.server.H323.3.expires' => ['3600'],
	'reg.5.server.H323.3.port' => ['0'],
	'reg.5.server.H323.3.register' => ['1'],
	'reg.5.server.H323.4.address' => [''],
	'reg.5.server.H323.4.expires' => ['3600'],
	'reg.5.server.H323.4.port' => ['0'],
	'reg.5.server.H323.4.register' => ['1'],
	'reg.5.serverFeatureControl.cf' => ['1'],
	'reg.5.serverFeatureControl.dnd' => ['1'],
	'reg.5.strictLineSeize' => ['0'],
	'reg.5.tcpFastFailover' => ['0'],
	'reg.5.thirdPartyName' => [''],
	'reg.5.type' => ['private'],
	'reg.5.useCompleteUriForRetrieve' => ['1'],
	'reg.6.address' => [''],
	'reg.6.auth.optimizedInFailover' => ['0'],
	'reg.6.auth.password' => [''],
	'reg.6.auth.userId' => [''],
	'reg.6.bargeInEnabled' => ['0'],
	'reg.6.callsPerLineKey' => ['24'],
	'reg.6.csta' => ['0'],
	'reg.6.displayName' => [''],
	'reg.6.dndStatus' => ['0'],
	'reg.6.fwd.busy.contact' => [''],
	'reg.6.fwd.busy.status' => ['0'],
	'reg.6.fwd.noanswer.contact' => [''],
	'reg.6.fwd.noanswer.ringCount' => ['0'],
	'reg.6.fwd.noanswer.status' => ['0'],
	'reg.6.fwdContact' => [''],
	'reg.6.fwdStatus' => ['0'],
	'reg.6.label' => [''],
	'reg.6.lcs' => ['0'],
	'reg.6.lineKeys' => ['1'],
	'reg.6.musicOnHold.uri' => [''],
	'reg.6.mwiNew' => ['0'],
	'reg.6.mwiOld' => ['0'],
	'reg.6.mwiUrg' => ['0'],
	'reg.6.outboundProxy.address' => [''],
	'reg.6.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.6.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.6.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.6.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.6.outboundProxy.port' => ['0', 5060 ],
	'reg.6.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.6.protocol' => [''],
	'reg.6.protocol.H323' => ['0'],
	'reg.6.protocol.SIP' => ['1'],
	'reg.6.proxyRequire' => [''],
	'reg.6.ringType' => ['ringer2'],
	'reg.6.server.1.address' => [''],
	'reg.6.server.1.expires' => ['3600'],
	'reg.6.server.1.expires.lineSeize' => ['30'],
	'reg.6.server.1.expires.overlap' => ['60'],
	'reg.6.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.6.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.6.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.6.server.1.failOver.reRegisterOn' => ['0'],
	'reg.6.server.1.lcs' => ['0'],
	'reg.6.server.1.port' => ['0', '5060' ],
	'reg.6.server.1.register' => ['1'],
	'reg.6.server.1.retryMaxCount' => ['3'],
	'reg.6.server.1.retryTimeOut' => ['0'],
	'reg.6.server.1.transport' => ['DNSnaptr', '' ],
	'reg.6.server.2.address' => [''],
	'reg.6.server.2.expires' => ['3600'],
	'reg.6.server.2.expires.lineSeize' => ['30'],
	'reg.6.server.2.expires.overlap' => ['60'],
	'reg.6.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.6.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.6.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.6.server.2.failOver.reRegisterOn' => ['0'],
	'reg.6.server.2.lcs' => ['0'],
	'reg.6.server.2.port' => ['0', '5060' ],
	'reg.6.server.2.register' => ['1'],
	'reg.6.server.2.retryMaxCount' => ['3'],
	'reg.6.server.2.retryTimeOut' => ['0'],
	'reg.6.server.2.transport' => ['DNSnaptr', '' ],
	'reg.6.server.3.address' => [''],
	'reg.6.server.3.expires' => ['3600'],
	'reg.6.server.3.expires.lineSeize' => ['30'],
	'reg.6.server.3.expires.overlap' => ['60'],
	'reg.6.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.6.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.6.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.6.server.3.failOver.reRegisterOn' => ['0'],
	'reg.6.server.3.lcs' => ['0'],
	'reg.6.server.3.port' => ['0', '5060' ],
	'reg.6.server.3.register' => ['1'],
	'reg.6.server.3.retryMaxCount' => ['3'],
	'reg.6.server.3.retryTimeOut' => ['0'],
	'reg.6.server.3.transport' => ['DNSnaptr', '' ],
	'reg.6.server.4.address' => [''],
	'reg.6.server.4.expires' => ['3600'],
	'reg.6.server.4.expires.lineSeize' => ['30'],
	'reg.6.server.4.expires.overlap' => ['60'],
	'reg.6.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.6.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.6.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.6.server.4.failOver.reRegisterOn' => ['0'],
	'reg.6.server.4.lcs' => ['0'],
	'reg.6.server.4.port' => ['0', '5060' ],
	'reg.6.server.4.register' => ['1'],
	'reg.6.server.4.retryMaxCount' => ['3'],
	'reg.6.server.4.retryTimeOut' => ['0'],
	'reg.6.server.4.transport' => ['DNSnaptr', '' ],
	'reg.6.server.H323.1.address' => [''],
	'reg.6.server.H323.1.expires' => ['3600'],
	'reg.6.server.H323.1.port' => ['0'],
	'reg.6.server.H323.1.register' => ['1'],
	'reg.6.server.H323.2.address' => [''],
	'reg.6.server.H323.2.expires' => ['3600'],
	'reg.6.server.H323.2.port' => ['0'],
	'reg.6.server.H323.2.register' => ['1'],
	'reg.6.server.H323.3.address' => [''],
	'reg.6.server.H323.3.expires' => ['3600'],
	'reg.6.server.H323.3.port' => ['0'],
	'reg.6.server.H323.3.register' => ['1'],
	'reg.6.server.H323.4.address' => [''],
	'reg.6.server.H323.4.expires' => ['3600'],
	'reg.6.server.H323.4.port' => ['0'],
	'reg.6.server.H323.4.register' => ['1'],
	'reg.6.serverFeatureControl.cf' => ['1'],
	'reg.6.serverFeatureControl.dnd' => ['1'],
	'reg.6.strictLineSeize' => ['0'],
	'reg.6.tcpFastFailover' => ['0'],
	'reg.6.thirdPartyName' => [''],
	'reg.6.type' => ['private'],
	'reg.6.useCompleteUriForRetrieve' => ['1'],
	'reg.7.address' => [''],
	'reg.7.auth.optimizedInFailover' => ['0'],
	'reg.7.auth.password' => [''],
	'reg.7.auth.userId' => [''],
	'reg.7.bargeInEnabled' => ['0'],
	'reg.7.callsPerLineKey' => ['24'],
	'reg.7.csta' => ['0'],
	'reg.7.displayName' => [''],
	'reg.7.dndStatus' => ['0'],
	'reg.7.fwd.busy.contact' => [''],
	'reg.7.fwd.busy.status' => ['0'],
	'reg.7.fwd.noanswer.contact' => [''],
	'reg.7.fwd.noanswer.ringCount' => ['0'],
	'reg.7.fwd.noanswer.status' => ['0'],
	'reg.7.fwdContact' => [''],
	'reg.7.fwdStatus' => ['0'],
	'reg.7.label' => [''],
	'reg.7.lcs' => ['0'],
	'reg.7.lineKeys' => ['1'],
	'reg.7.musicOnHold.uri' => [''],
	'reg.7.mwiNew' => ['0'],
	'reg.7.mwiOld' => ['0'],
	'reg.7.mwiUrg' => ['0'],
	'reg.7.outboundProxy.address' => [''],
	'reg.7.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.7.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.7.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.7.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.7.outboundProxy.port' => ['0', 5060 ],
	'reg.7.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.7.protocol' => [''],
	'reg.7.protocol.H323' => ['0'],
	'reg.7.protocol.SIP' => ['1'],
	'reg.7.proxyRequire' => [''],
	'reg.7.ringType' => ['ringer2'],
	'reg.7.server.1.address' => [''],
	'reg.7.server.1.expires' => ['3600'],
	'reg.7.server.1.expires.lineSeize' => ['30'],
	'reg.7.server.1.expires.overlap' => ['60'],
	'reg.7.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.7.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.7.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.7.server.1.failOver.reRegisterOn' => ['0'],
	'reg.7.server.1.lcs' => ['0'],
	'reg.7.server.1.port' => ['0', '5060' ],
	'reg.7.server.1.register' => ['1'],
	'reg.7.server.1.retryMaxCount' => ['3'],
	'reg.7.server.1.retryTimeOut' => ['0'],
	'reg.7.server.1.transport' => ['DNSnaptr', '' ],
	'reg.7.server.2.address' => [''],
	'reg.7.server.2.expires' => ['3600'],
	'reg.7.server.2.expires.lineSeize' => ['30'],
	'reg.7.server.2.expires.overlap' => ['60'],
	'reg.7.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.7.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.7.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.7.server.2.failOver.reRegisterOn' => ['0'],
	'reg.7.server.2.lcs' => ['0'],
	'reg.7.server.2.port' => ['0', '5060' ],
	'reg.7.server.2.register' => ['1'],
	'reg.7.server.2.retryMaxCount' => ['3'],
	'reg.7.server.2.retryTimeOut' => ['0'],
	'reg.7.server.2.transport' => ['DNSnaptr', '' ],
	'reg.7.server.3.address' => [''],
	'reg.7.server.3.expires' => ['3600'],
	'reg.7.server.3.expires.lineSeize' => ['30'],
	'reg.7.server.3.expires.overlap' => ['60'],
	'reg.7.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.7.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.7.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.7.server.3.failOver.reRegisterOn' => ['0'],
	'reg.7.server.3.lcs' => ['0'],
	'reg.7.server.3.port' => ['0', '5060' ],
	'reg.7.server.3.register' => ['1'],
	'reg.7.server.3.retryMaxCount' => ['3'],
	'reg.7.server.3.retryTimeOut' => ['0'],
	'reg.7.server.3.transport' => ['DNSnaptr', '' ],
	'reg.7.server.4.address' => [''],
	'reg.7.server.4.expires' => ['3600'],
	'reg.7.server.4.expires.lineSeize' => ['30'],
	'reg.7.server.4.expires.overlap' => ['60'],
	'reg.7.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.7.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.7.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.7.server.4.failOver.reRegisterOn' => ['0'],
	'reg.7.server.4.lcs' => ['0'],
	'reg.7.server.4.port' => ['0', '5060' ],
	'reg.7.server.4.register' => ['1'],
	'reg.7.server.4.retryMaxCount' => ['3'],
	'reg.7.server.4.retryTimeOut' => ['0'],
	'reg.7.server.4.transport' => ['DNSnaptr', '' ],
	'reg.7.server.H323.1.address' => [''],
	'reg.7.server.H323.1.expires' => ['3600'],
	'reg.7.server.H323.1.port' => ['0'],
	'reg.7.server.H323.1.register' => ['1'],
	'reg.7.server.H323.2.address' => [''],
	'reg.7.server.H323.2.expires' => ['3600'],
	'reg.7.server.H323.2.port' => ['0'],
	'reg.7.server.H323.2.register' => ['1'],
	'reg.7.server.H323.3.address' => [''],
	'reg.7.server.H323.3.expires' => ['3600'],
	'reg.7.server.H323.3.port' => ['0'],
	'reg.7.server.H323.3.register' => ['1'],
	'reg.7.server.H323.4.address' => [''],
	'reg.7.server.H323.4.expires' => ['3600'],
	'reg.7.server.H323.4.port' => ['0'],
	'reg.7.server.H323.4.register' => ['1'],
	'reg.7.serverFeatureControl.cf' => ['1'],
	'reg.7.serverFeatureControl.dnd' => ['1'],
	'reg.7.strictLineSeize' => ['0'],
	'reg.7.tcpFastFailover' => ['0'],
	'reg.7.thirdPartyName' => [''],
	'reg.7.type' => ['private'],
	'reg.7.useCompleteUriForRetrieve' => ['1'],
	'reg.8.address' => [''],
	'reg.8.auth.optimizedInFailover' => ['0'],
	'reg.8.auth.password' => [''],
	'reg.8.auth.userId' => [''],
	'reg.8.bargeInEnabled' => ['0'],
	'reg.8.callsPerLineKey' => ['24'],
	'reg.8.csta' => ['0'],
	'reg.8.displayName' => [''],
	'reg.8.dndStatus' => ['0'],
	'reg.8.fwd.busy.contact' => [''],
	'reg.8.fwd.busy.status' => ['0'],
	'reg.8.fwd.noanswer.contact' => [''],
	'reg.8.fwd.noanswer.ringCount' => ['0'],
	'reg.8.fwd.noanswer.status' => ['0'],
	'reg.8.fwdContact' => [''],
	'reg.8.fwdStatus' => ['0'],
	'reg.8.label' => [''],
	'reg.8.lcs' => ['0'],
	'reg.8.lineKeys' => ['1'],
	'reg.8.musicOnHold.uri' => [''],
	'reg.8.mwiNew' => ['0'],
	'reg.8.mwiOld' => ['0'],
	'reg.8.mwiUrg' => ['0'],
	'reg.8.outboundProxy.address' => [''],
	'reg.8.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.8.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.8.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.8.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.8.outboundProxy.port' => ['0', 5060 ],
	'reg.8.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.8.protocol' => [''],
	'reg.8.protocol.H323' => ['0'],
	'reg.8.protocol.SIP' => ['1'],
	'reg.8.proxyRequire' => [''],
	'reg.8.ringType' => ['ringer2'],
	'reg.8.server.1.address' => [''],
	'reg.8.server.1.expires' => ['3600'],
	'reg.8.server.1.expires.lineSeize' => ['30'],
	'reg.8.server.1.expires.overlap' => ['60'],
	'reg.8.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.8.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.8.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.8.server.1.failOver.reRegisterOn' => ['0'],
	'reg.8.server.1.lcs' => ['0'],
	'reg.8.server.1.port' => ['0', '5060' ],
	'reg.8.server.1.register' => ['1'],
	'reg.8.server.1.retryMaxCount' => ['3'],
	'reg.8.server.1.retryTimeOut' => ['0'],
	'reg.8.server.1.transport' => ['DNSnaptr', '' ],
	'reg.8.server.2.address' => [''],
	'reg.8.server.2.expires' => ['3600'],
	'reg.8.server.2.expires.lineSeize' => ['30'],
	'reg.8.server.2.expires.overlap' => ['60'],
	'reg.8.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.8.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.8.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.8.server.2.failOver.reRegisterOn' => ['0'],
	'reg.8.server.2.lcs' => ['0'],
	'reg.8.server.2.port' => ['0', '5060' ],
	'reg.8.server.2.register' => ['1'],
	'reg.8.server.2.retryMaxCount' => ['3'],
	'reg.8.server.2.retryTimeOut' => ['0'],
	'reg.8.server.2.transport' => ['DNSnaptr', '' ],
	'reg.8.server.3.address' => [''],
	'reg.8.server.3.expires' => ['3600'],
	'reg.8.server.3.expires.lineSeize' => ['30'],
	'reg.8.server.3.expires.overlap' => ['60'],
	'reg.8.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.8.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.8.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.8.server.3.failOver.reRegisterOn' => ['0'],
	'reg.8.server.3.lcs' => ['0'],
	'reg.8.server.3.port' => ['0', '5060' ],
	'reg.8.server.3.register' => ['1'],
	'reg.8.server.3.retryMaxCount' => ['3'],
	'reg.8.server.3.retryTimeOut' => ['0'],
	'reg.8.server.3.transport' => ['DNSnaptr', '' ],
	'reg.8.server.4.address' => [''],
	'reg.8.server.4.expires' => ['3600'],
	'reg.8.server.4.expires.lineSeize' => ['30'],
	'reg.8.server.4.expires.overlap' => ['60'],
	'reg.8.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.8.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.8.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.8.server.4.failOver.reRegisterOn' => ['0'],
	'reg.8.server.4.lcs' => ['0'],
	'reg.8.server.4.port' => ['0', '5060' ],
	'reg.8.server.4.register' => ['1'],
	'reg.8.server.4.retryMaxCount' => ['3'],
	'reg.8.server.4.retryTimeOut' => ['0'],
	'reg.8.server.4.transport' => ['DNSnaptr', '' ],
	'reg.8.server.H323.1.address' => [''],
	'reg.8.server.H323.1.expires' => ['3600'],
	'reg.8.server.H323.1.port' => ['0'],
	'reg.8.server.H323.1.register' => ['1'],
	'reg.8.server.H323.2.address' => [''],
	'reg.8.server.H323.2.expires' => ['3600'],
	'reg.8.server.H323.2.port' => ['0'],
	'reg.8.server.H323.2.register' => ['1'],
	'reg.8.server.H323.3.address' => [''],
	'reg.8.server.H323.3.expires' => ['3600'],
	'reg.8.server.H323.3.port' => ['0'],
	'reg.8.server.H323.3.register' => ['1'],
	'reg.8.server.H323.4.address' => [''],
	'reg.8.server.H323.4.expires' => ['3600'],
	'reg.8.server.H323.4.port' => ['0'],
	'reg.8.server.H323.4.register' => ['1'],
	'reg.8.serverFeatureControl.cf' => ['1'],
	'reg.8.serverFeatureControl.dnd' => ['1'],
	'reg.8.strictLineSeize' => ['0'],
	'reg.8.tcpFastFailover' => ['0'],
	'reg.8.thirdPartyName' => [''],
	'reg.8.type' => ['private'],
	'reg.8.useCompleteUriForRetrieve' => ['1'],
	'reg.9.address' => [''],
	'reg.9.auth.optimizedInFailover' => ['0'],
	'reg.9.auth.password' => [''],
	'reg.9.auth.userId' => [''],
	'reg.9.bargeInEnabled' => ['0'],
	'reg.9.callsPerLineKey' => ['24'],
	'reg.9.csta' => ['0'],
	'reg.9.displayName' => [''],
	'reg.9.dndStatus' => ['0'],
	'reg.9.fwd.busy.contact' => [''],
	'reg.9.fwd.busy.status' => ['0'],
	'reg.9.fwd.noanswer.contact' => [''],
	'reg.9.fwd.noanswer.ringCount' => ['0'],
	'reg.9.fwd.noanswer.status' => ['0'],
	'reg.9.fwdContact' => [''],
	'reg.9.fwdStatus' => ['0'],
	'reg.9.label' => [''],
	'reg.9.lcs' => ['0'],
	'reg.9.lineKeys' => ['1'],
	'reg.9.musicOnHold.uri' => [''],
	'reg.9.mwiNew' => ['0'],
	'reg.9.mwiOld' => ['0'],
	'reg.9.mwiUrg' => ['0'],
	'reg.9.outboundProxy.address' => [''],
	'reg.9.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.9.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'reg.9.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'reg.9.outboundProxy.failOver.reRegisterOn' => ['0'],
	'reg.9.outboundProxy.port' => ['0', 5060 ],
	'reg.9.outboundProxy.transport' => ['DNSnaptr', '' ],
	'reg.9.protocol' => [''],
	'reg.9.protocol.H323' => ['0'],
	'reg.9.protocol.SIP' => ['1'],
	'reg.9.proxyRequire' => [''],
	'reg.9.ringType' => ['ringer2'],
	'reg.9.server.1.address' => [''],
	'reg.9.server.1.expires' => ['3600'],
	'reg.9.server.1.expires.lineSeize' => ['30'],
	'reg.9.server.1.expires.overlap' => ['60'],
	'reg.9.server.1.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.9.server.1.failOver.failBack.timeout' => ['3600'],
	'reg.9.server.1.failOver.failRegistrationOn' => ['1'],
	'reg.9.server.1.failOver.reRegisterOn' => ['0'],
	'reg.9.server.1.lcs' => ['0'],
	'reg.9.server.1.port' => ['0', '5060' ],
	'reg.9.server.1.register' => ['1'],
	'reg.9.server.1.retryMaxCount' => ['3'],
	'reg.9.server.1.retryTimeOut' => ['0'],
	'reg.9.server.1.transport' => ['DNSnaptr', '' ],
	'reg.9.server.2.address' => [''],
	'reg.9.server.2.expires' => ['3600'],
	'reg.9.server.2.expires.lineSeize' => ['30'],
	'reg.9.server.2.expires.overlap' => ['60'],
	'reg.9.server.2.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.9.server.2.failOver.failBack.timeout' => ['3600'],
	'reg.9.server.2.failOver.failRegistrationOn' => ['1'],
	'reg.9.server.2.failOver.reRegisterOn' => ['0'],
	'reg.9.server.2.lcs' => ['0'],
	'reg.9.server.2.port' => ['0', '5060' ],
	'reg.9.server.2.register' => ['1'],
	'reg.9.server.2.retryMaxCount' => ['3'],
	'reg.9.server.2.retryTimeOut' => ['0'],
	'reg.9.server.2.transport' => ['DNSnaptr', '' ],
	'reg.9.server.3.address' => [''],
	'reg.9.server.3.expires' => ['3600'],
	'reg.9.server.3.expires.lineSeize' => ['30'],
	'reg.9.server.3.expires.overlap' => ['60'],
	'reg.9.server.3.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.9.server.3.failOver.failBack.timeout' => ['3600'],
	'reg.9.server.3.failOver.failRegistrationOn' => ['1'],
	'reg.9.server.3.failOver.reRegisterOn' => ['0'],
	'reg.9.server.3.lcs' => ['0'],
	'reg.9.server.3.port' => ['0', '5060' ],
	'reg.9.server.3.register' => ['1'],
	'reg.9.server.3.retryMaxCount' => ['3'],
	'reg.9.server.3.retryTimeOut' => ['0'],
	'reg.9.server.3.transport' => ['DNSnaptr', '' ],
	'reg.9.server.4.address' => [''],
	'reg.9.server.4.expires' => ['3600'],
	'reg.9.server.4.expires.lineSeize' => ['30'],
	'reg.9.server.4.expires.overlap' => ['60'],
	'reg.9.server.4.failOver.failBack.mode' => ['newRequests', '' ],
	'reg.9.server.4.failOver.failBack.timeout' => ['3600'],
	'reg.9.server.4.failOver.failRegistrationOn' => ['1'],
	'reg.9.server.4.failOver.reRegisterOn' => ['0'],
	'reg.9.server.4.lcs' => ['0'],
	'reg.9.server.4.port' => ['0', '5060' ],
	'reg.9.server.4.register' => ['1'],
	'reg.9.server.4.retryMaxCount' => ['3'],
	'reg.9.server.4.retryTimeOut' => ['0'],
	'reg.9.server.4.transport' => ['DNSnaptr', '' ],
	'reg.9.server.H323.1.address' => [''],
	'reg.9.server.H323.1.expires' => ['3600'],
	'reg.9.server.H323.1.port' => ['0'],
	'reg.9.server.H323.1.register' => ['1'],
	'reg.9.server.H323.2.address' => [''],
	'reg.9.server.H323.2.expires' => ['3600'],
	'reg.9.server.H323.2.port' => ['0'],
	'reg.9.server.H323.2.register' => ['1'],
	'reg.9.server.H323.3.address' => [''],
	'reg.9.server.H323.3.expires' => ['3600'],
	'reg.9.server.H323.3.port' => ['0'],
	'reg.9.server.H323.3.register' => ['1'],
	'reg.9.server.H323.4.address' => [''],
	'reg.9.server.H323.4.expires' => ['3600'],
	'reg.9.server.H323.4.port' => ['0'],
	'reg.9.server.H323.4.register' => ['1'],
	'reg.9.serverFeatureControl.cf' => ['1'],
	'reg.9.serverFeatureControl.dnd' => ['1'],
	'reg.9.strictLineSeize' => ['0'],
	'reg.9.tcpFastFailover' => ['0'],
	'reg.9.thirdPartyName' => [''],
	'reg.9.type' => ['private'],
	'reg.9.useCompleteUriForRetrieve' => ['1'],
	'request.delay.type' => ['call'],
	'res.finder.minFree' => ['1200', 600 ],
	'res.finder.minFree.SPIP320' => ['600'],
	'res.finder.minFree.SPIP330' => ['600'],
	'res.finder.minFree.SSIP6000' => ['2400'],
	'res.finder.minFree.SSIP7000' => ['2400'],
	'res.finder.sizeLimit' => ['600', 300 ],
	'res.finder.sizeLimit.SPIP320' => ['300'],
	'res.finder.sizeLimit.SPIP330' => ['300'],
	'res.finder.sizeLimit.SSIP6000' => ['1200'],
	'res.finder.sizeLimit.SSIP7000' => ['1200'],
	'res.quotas.background' => ['1200'],
	'res.quotas.background.SPIP320' => ['600'],
	'res.quotas.background.SPIP330' => ['600'],
	'res.quotas.background.SSIP6000' => ['2400'],
	'res.quotas.background.SSIP7000' => ['2400'],
	'res.quotas.bitmap' => ['20'],
	'res.quotas.bitmap.SPIP320' => ['10'],
	'res.quotas.bitmap.SPIP330' => ['10'],
	'res.quotas.bitmap.SSIP6000' => ['40'],
	'res.quotas.bitmap.SSIP7000' => ['40'],
	'res.quotas.cache' => ['80'],
	'res.quotas.cache.SPIP320' => ['40'],
	'res.quotas.cache.SPIP330' => ['40'],
	'res.quotas.cache.SSIP6000' => ['160'],
	'res.quotas.cache.SSIP7000' => ['160'],
	'res.quotas.font' => ['20'],
	'res.quotas.font.SPIP320' => ['10'],
	'res.quotas.font.SPIP330' => ['10'],
	'res.quotas.font.SSIP6000' => ['40'],
	'res.quotas.font.SSIP7000' => ['40'],
	'res.quotas.tone' => ['600'],
	'res.quotas.tone.SPIP320' => ['300'],
	'res.quotas.tone.SPIP330' => ['300'],
	'res.quotas.tone.SSIP6000' => ['1200'],
	'res.quotas.tone.SSIP7000' => ['1200'],
	'res.quotas.xmlui' => ['20'],
	'res.quotas.xmlui.SPIP320' => ['10'],
	'res.quotas.xmlui.SPIP330' => ['10'],
	'res.quotas.xmlui.SSIP6000' => ['40'],
	'res.quotas.xmlui.SSIP7000' => ['40'],
	'roaming_buddies.reg' => ['0'],
	'roaming_privacy.reg' => ['0'],
	'saf.1' => [''],
	'saf.10' => [''],
	'saf.11' => [''],
	'saf.12' => [''],
	'saf.13' => [''],
	'saf.14' => [''],
	'saf.15' => [''],
	'saf.16' => [''],
	'saf.17' => [''],
	'saf.18' => [''],
	'saf.19' => [''],
	'saf.2' => [''],
	'saf.20' => [''],
	'saf.21' => [''],
	'saf.22' => [''],
	'saf.23' => [''],
	'saf.24' => [''],
	'saf.3' => [''],
	'saf.4' => [''],
	'saf.5' => [''],
	'saf.6' => [''],
	'saf.7' => [''],
	'saf.8' => [''],
	'saf.9' => [''],
	'se.appLocalEnabled' => ['1'],
	'se.destination' => ['chassis'],
	'se.pat.callProg.alerting.inst.1.atten' => ['0'],
	'se.pat.callProg.alerting.inst.1.param' => ['2000'],
	'se.pat.callProg.alerting.inst.1.type' => ['chord'],
	'se.pat.callProg.alerting.inst.1.value' => ['recWarning'],
	'se.pat.callProg.alerting.inst.2.atten' => ['0'],
	'se.pat.callProg.alerting.inst.2.param' => ['0'],
	'se.pat.callProg.alerting.inst.2.type' => ['silence'],
	'se.pat.callProg.alerting.inst.2.value' => ['9500'],
	'se.pat.callProg.alerting.inst.3.atten' => ['0'],
	'se.pat.callProg.alerting.inst.3.param' => ['500'],
	'se.pat.callProg.alerting.inst.3.type' => ['chord'],
	'se.pat.callProg.alerting.inst.3.value' => ['recWarning'],
	'se.pat.callProg.alerting.inst.4.atten' => ['0'],
	'se.pat.callProg.alerting.inst.4.param' => ['0'],
	'se.pat.callProg.alerting.inst.4.type' => ['branch'],
	'se.pat.callProg.alerting.inst.4.value' => ['-2'],
	'se.pat.callProg.alerting.inst.5.atten' => ['0'],
	'se.pat.callProg.alerting.inst.5.param' => ['0'],
	'se.pat.callProg.alerting.inst.5.type' => [''],
	'se.pat.callProg.alerting.inst.5.value' => [''],
	'se.pat.callProg.alerting.inst.6.atten' => ['0'],
	'se.pat.callProg.alerting.inst.6.param' => ['0'],
	'se.pat.callProg.alerting.inst.6.type' => [''],
	'se.pat.callProg.alerting.inst.6.value' => [''],
	'se.pat.callProg.alerting.inst.7.atten' => ['0'],
	'se.pat.callProg.alerting.inst.7.param' => ['0'],
	'se.pat.callProg.alerting.inst.7.type' => [''],
	'se.pat.callProg.alerting.inst.7.value' => [''],
	'se.pat.callProg.alerting.inst.8.atten' => ['0'],
	'se.pat.callProg.alerting.inst.8.param' => ['0'],
	'se.pat.callProg.alerting.inst.8.type' => [''],
	'se.pat.callProg.alerting.inst.8.value' => [''],
	'se.pat.callProg.alerting.name' => ['alerting'],
	'se.pat.callProg.bargeIn.inst.1.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.1.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.1.type' => ['chord'],
	'se.pat.callProg.bargeIn.inst.1.value' => ['callWaiting'],
	'se.pat.callProg.bargeIn.inst.2.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.2.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.2.type' => ['silence'],
	'se.pat.callProg.bargeIn.inst.2.value' => ['200'],
	'se.pat.callProg.bargeIn.inst.3.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.3.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.3.type' => ['chord'],
	'se.pat.callProg.bargeIn.inst.3.value' => ['callWaiting'],
	'se.pat.callProg.bargeIn.inst.4.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.4.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.4.type' => [''],
	'se.pat.callProg.bargeIn.inst.4.value' => [''],
	'se.pat.callProg.bargeIn.inst.5.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.5.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.5.type' => [''],
	'se.pat.callProg.bargeIn.inst.5.value' => [''],
	'se.pat.callProg.bargeIn.inst.6.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.6.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.6.type' => [''],
	'se.pat.callProg.bargeIn.inst.6.value' => [''],
	'se.pat.callProg.bargeIn.inst.7.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.7.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.7.type' => [''],
	'se.pat.callProg.bargeIn.inst.7.value' => [''],
	'se.pat.callProg.bargeIn.inst.8.atten' => ['0'],
	'se.pat.callProg.bargeIn.inst.8.param' => ['0'],
	'se.pat.callProg.bargeIn.inst.8.type' => [''],
	'se.pat.callProg.bargeIn.inst.8.value' => [''],
	'se.pat.callProg.bargeIn.name' => ['bargein'],
	'se.pat.callProg.busyTone.inst.1.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.1.param' => ['0'],
	'se.pat.callProg.busyTone.inst.1.type' => ['chord'],
	'se.pat.callProg.busyTone.inst.1.value' => ['busyTone'],
	'se.pat.callProg.busyTone.inst.2.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.2.param' => ['0'],
	'se.pat.callProg.busyTone.inst.2.type' => [''],
	'se.pat.callProg.busyTone.inst.2.value' => [''],
	'se.pat.callProg.busyTone.inst.3.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.3.param' => ['0'],
	'se.pat.callProg.busyTone.inst.3.type' => [''],
	'se.pat.callProg.busyTone.inst.3.value' => [''],
	'se.pat.callProg.busyTone.inst.4.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.4.param' => ['0'],
	'se.pat.callProg.busyTone.inst.4.type' => [''],
	'se.pat.callProg.busyTone.inst.4.value' => [''],
	'se.pat.callProg.busyTone.inst.5.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.5.param' => ['0'],
	'se.pat.callProg.busyTone.inst.5.type' => [''],
	'se.pat.callProg.busyTone.inst.5.value' => [''],
	'se.pat.callProg.busyTone.inst.6.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.6.param' => ['0'],
	'se.pat.callProg.busyTone.inst.6.type' => [''],
	'se.pat.callProg.busyTone.inst.6.value' => [''],
	'se.pat.callProg.busyTone.inst.7.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.7.param' => ['0'],
	'se.pat.callProg.busyTone.inst.7.type' => [''],
	'se.pat.callProg.busyTone.inst.7.value' => [''],
	'se.pat.callProg.busyTone.inst.8.atten' => ['0'],
	'se.pat.callProg.busyTone.inst.8.param' => ['0'],
	'se.pat.callProg.busyTone.inst.8.type' => [''],
	'se.pat.callProg.busyTone.inst.8.value' => [''],
	'se.pat.callProg.busyTone.name' => ['busy'],
	'se.pat.callProg.callWaiting.inst.1.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.1.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.1.type' => ['chord'],
	'se.pat.callProg.callWaiting.inst.1.value' => ['callWaiting'],
	'se.pat.callProg.callWaiting.inst.2.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.2.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.2.type' => [''],
	'se.pat.callProg.callWaiting.inst.2.value' => [''],
	'se.pat.callProg.callWaiting.inst.3.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.3.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.3.type' => [''],
	'se.pat.callProg.callWaiting.inst.3.value' => [''],
	'se.pat.callProg.callWaiting.inst.4.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.4.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.4.type' => [''],
	'se.pat.callProg.callWaiting.inst.4.value' => [''],
	'se.pat.callProg.callWaiting.inst.5.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.5.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.5.type' => [''],
	'se.pat.callProg.callWaiting.inst.5.value' => [''],
	'se.pat.callProg.callWaiting.inst.6.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.6.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.6.type' => [''],
	'se.pat.callProg.callWaiting.inst.6.value' => [''],
	'se.pat.callProg.callWaiting.inst.7.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.7.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.7.type' => [''],
	'se.pat.callProg.callWaiting.inst.7.value' => [''],
	'se.pat.callProg.callWaiting.inst.8.atten' => ['0'],
	'se.pat.callProg.callWaiting.inst.8.param' => ['0'],
	'se.pat.callProg.callWaiting.inst.8.type' => [''],
	'se.pat.callProg.callWaiting.inst.8.value' => [''],
	'se.pat.callProg.callWaiting.name' => ['call waiting'],
	'se.pat.callProg.callWaitingLong.inst.1.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.1.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.1.type' => ['chord'],
	'se.pat.callProg.callWaitingLong.inst.1.value' => ['callWaitingLong', 'callWaiting' ],
	'se.pat.callProg.callWaitingLong.inst.2.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.2.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.2.type' => ['silence'],
	'se.pat.callProg.callWaitingLong.inst.2.value' => ['9100'],
	'se.pat.callProg.callWaitingLong.inst.3.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.3.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.3.type' => ['chord'],
	'se.pat.callProg.callWaitingLong.inst.3.value' => ['callWaitingLong', 'callWaiting' ],
	'se.pat.callProg.callWaitingLong.inst.4.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.4.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.4.type' => [''],
	'se.pat.callProg.callWaitingLong.inst.4.value' => [''],
	'se.pat.callProg.callWaitingLong.inst.5.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.5.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.5.type' => [''],
	'se.pat.callProg.callWaitingLong.inst.5.value' => [''],
	'se.pat.callProg.callWaitingLong.inst.6.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.6.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.6.type' => [''],
	'se.pat.callProg.callWaitingLong.inst.6.value' => [''],
	'se.pat.callProg.callWaitingLong.inst.7.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.7.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.7.type' => [''],
	'se.pat.callProg.callWaitingLong.inst.7.value' => [''],
	'se.pat.callProg.callWaitingLong.inst.8.atten' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.8.param' => ['0'],
	'se.pat.callProg.callWaitingLong.inst.8.type' => [''],
	'se.pat.callProg.callWaitingLong.inst.8.value' => [''],
	'se.pat.callProg.callWaitingLong.name' => ['long call waiting'],
	'se.pat.callProg.confirmation.inst.1.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.1.param' => ['0'],
	'se.pat.callProg.confirmation.inst.1.type' => ['chord'],
	'se.pat.callProg.confirmation.inst.1.value' => ['stutter_3'],
	'se.pat.callProg.confirmation.inst.2.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.2.param' => ['0'],
	'se.pat.callProg.confirmation.inst.2.type' => [''],
	'se.pat.callProg.confirmation.inst.2.value' => [''],
	'se.pat.callProg.confirmation.inst.3.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.3.param' => ['0'],
	'se.pat.callProg.confirmation.inst.3.type' => [''],
	'se.pat.callProg.confirmation.inst.3.value' => [''],
	'se.pat.callProg.confirmation.inst.4.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.4.param' => ['0'],
	'se.pat.callProg.confirmation.inst.4.type' => [''],
	'se.pat.callProg.confirmation.inst.4.value' => [''],
	'se.pat.callProg.confirmation.inst.5.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.5.param' => ['0'],
	'se.pat.callProg.confirmation.inst.5.type' => [''],
	'se.pat.callProg.confirmation.inst.5.value' => [''],
	'se.pat.callProg.confirmation.inst.6.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.6.param' => ['0'],
	'se.pat.callProg.confirmation.inst.6.type' => [''],
	'se.pat.callProg.confirmation.inst.6.value' => [''],
	'se.pat.callProg.confirmation.inst.7.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.7.param' => ['0'],
	'se.pat.callProg.confirmation.inst.7.type' => [''],
	'se.pat.callProg.confirmation.inst.7.value' => [''],
	'se.pat.callProg.confirmation.inst.8.atten' => ['0'],
	'se.pat.callProg.confirmation.inst.8.param' => ['0'],
	'se.pat.callProg.confirmation.inst.8.type' => [''],
	'se.pat.callProg.confirmation.inst.8.value' => [''],
	'se.pat.callProg.confirmation.name' => ['confirmation'],
	'se.pat.callProg.dialTone.inst.1.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.1.param' => ['0'],
	'se.pat.callProg.dialTone.inst.1.type' => ['chord'],
	'se.pat.callProg.dialTone.inst.1.value' => ['dialTone'],
	'se.pat.callProg.dialTone.inst.2.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.2.param' => ['0'],
	'se.pat.callProg.dialTone.inst.2.type' => [''],
	'se.pat.callProg.dialTone.inst.2.value' => [''],
	'se.pat.callProg.dialTone.inst.3.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.3.param' => ['0'],
	'se.pat.callProg.dialTone.inst.3.type' => [''],
	'se.pat.callProg.dialTone.inst.3.value' => [''],
	'se.pat.callProg.dialTone.inst.4.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.4.param' => ['0'],
	'se.pat.callProg.dialTone.inst.4.type' => [''],
	'se.pat.callProg.dialTone.inst.4.value' => [''],
	'se.pat.callProg.dialTone.inst.5.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.5.param' => ['0'],
	'se.pat.callProg.dialTone.inst.5.type' => [''],
	'se.pat.callProg.dialTone.inst.5.value' => [''],
	'se.pat.callProg.dialTone.inst.6.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.6.param' => ['0'],
	'se.pat.callProg.dialTone.inst.6.type' => [''],
	'se.pat.callProg.dialTone.inst.6.value' => [''],
	'se.pat.callProg.dialTone.inst.7.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.7.param' => ['0'],
	'se.pat.callProg.dialTone.inst.7.type' => [''],
	'se.pat.callProg.dialTone.inst.7.value' => [''],
	'se.pat.callProg.dialTone.inst.8.atten' => ['0'],
	'se.pat.callProg.dialTone.inst.8.param' => ['0'],
	'se.pat.callProg.dialTone.inst.8.type' => [''],
	'se.pat.callProg.dialTone.inst.8.value' => [''],
	'se.pat.callProg.dialTone.name' => ['dial'],
	'se.pat.callProg.howler.inst.1.atten' => ['0'],
	'se.pat.callProg.howler.inst.1.param' => ['0'],
	'se.pat.callProg.howler.inst.1.type' => ['chord'],
	'se.pat.callProg.howler.inst.1.value' => ['howler'],
	'se.pat.callProg.howler.inst.2.atten' => ['0'],
	'se.pat.callProg.howler.inst.2.param' => ['0'],
	'se.pat.callProg.howler.inst.2.type' => [''],
	'se.pat.callProg.howler.inst.2.value' => [''],
	'se.pat.callProg.howler.inst.3.atten' => ['0'],
	'se.pat.callProg.howler.inst.3.param' => ['0'],
	'se.pat.callProg.howler.inst.3.type' => [''],
	'se.pat.callProg.howler.inst.3.value' => [''],
	'se.pat.callProg.howler.inst.4.atten' => ['0'],
	'se.pat.callProg.howler.inst.4.param' => ['0'],
	'se.pat.callProg.howler.inst.4.type' => [''],
	'se.pat.callProg.howler.inst.4.value' => [''],
	'se.pat.callProg.howler.inst.5.atten' => ['0'],
	'se.pat.callProg.howler.inst.5.param' => ['0'],
	'se.pat.callProg.howler.inst.5.type' => [''],
	'se.pat.callProg.howler.inst.5.value' => [''],
	'se.pat.callProg.howler.inst.6.atten' => ['0'],
	'se.pat.callProg.howler.inst.6.param' => ['0'],
	'se.pat.callProg.howler.inst.6.type' => [''],
	'se.pat.callProg.howler.inst.6.value' => [''],
	'se.pat.callProg.howler.inst.7.atten' => ['0'],
	'se.pat.callProg.howler.inst.7.param' => ['0'],
	'se.pat.callProg.howler.inst.7.type' => [''],
	'se.pat.callProg.howler.inst.7.value' => [''],
	'se.pat.callProg.howler.inst.8.atten' => ['0'],
	'se.pat.callProg.howler.inst.8.param' => ['0'],
	'se.pat.callProg.howler.inst.8.type' => [''],
	'se.pat.callProg.howler.inst.8.value' => [''],
	'se.pat.callProg.howler.name' => ['howler'],
	'se.pat.callProg.intercom.inst.1.atten' => ['0'],
	'se.pat.callProg.intercom.inst.1.param' => ['0'],
	'se.pat.callProg.intercom.inst.1.type' => ['chord'],
	'se.pat.callProg.intercom.inst.1.value' => ['intercom'],
	'se.pat.callProg.intercom.inst.2.atten' => ['0'],
	'se.pat.callProg.intercom.inst.2.param' => ['0'],
	'se.pat.callProg.intercom.inst.2.type' => [''],
	'se.pat.callProg.intercom.inst.2.value' => [''],
	'se.pat.callProg.intercom.inst.3.atten' => ['0'],
	'se.pat.callProg.intercom.inst.3.param' => ['0'],
	'se.pat.callProg.intercom.inst.3.type' => [''],
	'se.pat.callProg.intercom.inst.3.value' => [''],
	'se.pat.callProg.intercom.inst.4.atten' => ['0'],
	'se.pat.callProg.intercom.inst.4.param' => ['0'],
	'se.pat.callProg.intercom.inst.4.type' => [''],
	'se.pat.callProg.intercom.inst.4.value' => [''],
	'se.pat.callProg.intercom.inst.5.atten' => ['0'],
	'se.pat.callProg.intercom.inst.5.param' => ['0'],
	'se.pat.callProg.intercom.inst.5.type' => [''],
	'se.pat.callProg.intercom.inst.5.value' => [''],
	'se.pat.callProg.intercom.inst.6.atten' => ['0'],
	'se.pat.callProg.intercom.inst.6.param' => ['0'],
	'se.pat.callProg.intercom.inst.6.type' => [''],
	'se.pat.callProg.intercom.inst.6.value' => [''],
	'se.pat.callProg.intercom.inst.7.atten' => ['0'],
	'se.pat.callProg.intercom.inst.7.param' => ['0'],
	'se.pat.callProg.intercom.inst.7.type' => [''],
	'se.pat.callProg.intercom.inst.7.value' => [''],
	'se.pat.callProg.intercom.inst.8.atten' => ['0'],
	'se.pat.callProg.intercom.inst.8.param' => ['0'],
	'se.pat.callProg.intercom.inst.8.type' => [''],
	'se.pat.callProg.intercom.inst.8.value' => [''],
	'se.pat.callProg.intercom.name' => ['intercom'],
	'se.pat.callProg.msgWaiting.inst.1.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.1.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.1.type' => ['chord'],
	'se.pat.callProg.msgWaiting.inst.1.value' => ['stutterLong'],
	'se.pat.callProg.msgWaiting.inst.2.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.2.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.2.type' => ['chord'],
	'se.pat.callProg.msgWaiting.inst.2.value' => ['dialTone'],
	'se.pat.callProg.msgWaiting.inst.3.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.3.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.3.type' => [''],
	'se.pat.callProg.msgWaiting.inst.3.value' => [''],
	'se.pat.callProg.msgWaiting.inst.4.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.4.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.4.type' => [''],
	'se.pat.callProg.msgWaiting.inst.4.value' => [''],
	'se.pat.callProg.msgWaiting.inst.5.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.5.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.5.type' => [''],
	'se.pat.callProg.msgWaiting.inst.5.value' => [''],
	'se.pat.callProg.msgWaiting.inst.6.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.6.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.6.type' => [''],
	'se.pat.callProg.msgWaiting.inst.6.value' => [''],
	'se.pat.callProg.msgWaiting.inst.7.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.7.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.7.type' => [''],
	'se.pat.callProg.msgWaiting.inst.7.value' => [''],
	'se.pat.callProg.msgWaiting.inst.8.atten' => ['0'],
	'se.pat.callProg.msgWaiting.inst.8.param' => ['0'],
	'se.pat.callProg.msgWaiting.inst.8.type' => [''],
	'se.pat.callProg.msgWaiting.inst.8.value' => [''],
	'se.pat.callProg.msgWaiting.name' => ['message waiting'],
	'se.pat.callProg.precedenceCallWaiting.inst.1.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.1.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.1.type' => ['chord'],
	'se.pat.callProg.precedenceCallWaiting.inst.1.value' => ['precedenceCallWaiting'],
	'se.pat.callProg.precedenceCallWaiting.inst.2.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.2.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.2.type' => ['silence'],
	'se.pat.callProg.precedenceCallWaiting.inst.2.value' => ['9550'],
	'se.pat.callProg.precedenceCallWaiting.inst.3.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.3.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.3.type' => ['branch'],
	'se.pat.callProg.precedenceCallWaiting.inst.3.value' => ['-2'],
	'se.pat.callProg.precedenceCallWaiting.inst.4.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.4.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.4.type' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.4.value' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.5.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.5.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.5.type' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.5.value' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.6.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.6.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.6.type' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.6.value' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.7.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.7.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.7.type' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.7.value' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.8.atten' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.8.param' => ['0'],
	'se.pat.callProg.precedenceCallWaiting.inst.8.type' => [''],
	'se.pat.callProg.precedenceCallWaiting.inst.8.value' => [''],
	'se.pat.callProg.precedenceCallWaiting.name' => ['precedenceCallWaiting'],
	'se.pat.callProg.precedenceRingback.inst.1.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.1.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.1.type' => ['silence'],
	'se.pat.callProg.precedenceRingback.inst.1.value' => ['2000'],
	'se.pat.callProg.precedenceRingback.inst.2.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.2.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.2.type' => ['chord'],
	'se.pat.callProg.precedenceRingback.inst.2.value' => ['precedenceRingback'],
	'se.pat.callProg.precedenceRingback.inst.3.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.3.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.3.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.3.value' => [''],
	'se.pat.callProg.precedenceRingback.inst.4.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.4.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.4.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.4.value' => [''],
	'se.pat.callProg.precedenceRingback.inst.5.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.5.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.5.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.5.value' => [''],
	'se.pat.callProg.precedenceRingback.inst.6.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.6.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.6.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.6.value' => [''],
	'se.pat.callProg.precedenceRingback.inst.7.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.7.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.7.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.7.value' => [''],
	'se.pat.callProg.precedenceRingback.inst.8.atten' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.8.param' => ['0'],
	'se.pat.callProg.precedenceRingback.inst.8.type' => [''],
	'se.pat.callProg.precedenceRingback.inst.8.value' => [''],
	'se.pat.callProg.precedenceRingback.name' => ['precedenceRingback'],
	'se.pat.callProg.preemption.inst.1.atten' => ['0'],
	'se.pat.callProg.preemption.inst.1.param' => ['0'],
	'se.pat.callProg.preemption.inst.1.type' => ['chord'],
	'se.pat.callProg.preemption.inst.1.value' => ['preemption'],
	'se.pat.callProg.preemption.inst.2.atten' => ['0'],
	'se.pat.callProg.preemption.inst.2.param' => ['0'],
	'se.pat.callProg.preemption.inst.2.type' => [''],
	'se.pat.callProg.preemption.inst.2.value' => [''],
	'se.pat.callProg.preemption.inst.3.atten' => ['0'],
	'se.pat.callProg.preemption.inst.3.param' => ['0'],
	'se.pat.callProg.preemption.inst.3.type' => [''],
	'se.pat.callProg.preemption.inst.3.value' => [''],
	'se.pat.callProg.preemption.inst.4.atten' => ['0'],
	'se.pat.callProg.preemption.inst.4.param' => ['0'],
	'se.pat.callProg.preemption.inst.4.type' => [''],
	'se.pat.callProg.preemption.inst.4.value' => [''],
	'se.pat.callProg.preemption.inst.5.atten' => ['0'],
	'se.pat.callProg.preemption.inst.5.param' => ['0'],
	'se.pat.callProg.preemption.inst.5.type' => [''],
	'se.pat.callProg.preemption.inst.5.value' => [''],
	'se.pat.callProg.preemption.inst.6.atten' => ['0'],
	'se.pat.callProg.preemption.inst.6.param' => ['0'],
	'se.pat.callProg.preemption.inst.6.type' => [''],
	'se.pat.callProg.preemption.inst.6.value' => [''],
	'se.pat.callProg.preemption.inst.7.atten' => ['0'],
	'se.pat.callProg.preemption.inst.7.param' => ['0'],
	'se.pat.callProg.preemption.inst.7.type' => [''],
	'se.pat.callProg.preemption.inst.7.value' => [''],
	'se.pat.callProg.preemption.inst.8.atten' => ['0'],
	'se.pat.callProg.preemption.inst.8.param' => ['0'],
	'se.pat.callProg.preemption.inst.8.type' => [''],
	'se.pat.callProg.preemption.inst.8.value' => [''],
	'se.pat.callProg.preemption.name' => ['preemption'],
	'se.pat.callProg.recWarning.inst.1.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.1.param' => ['0'],
	'se.pat.callProg.recWarning.inst.1.type' => ['chord'],
	'se.pat.callProg.recWarning.inst.1.value' => ['recWarning'],
	'se.pat.callProg.recWarning.inst.2.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.2.param' => ['0'],
	'se.pat.callProg.recWarning.inst.2.type' => ['silence'],
	'se.pat.callProg.recWarning.inst.2.value' => ['14500'],
	'se.pat.callProg.recWarning.inst.3.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.3.param' => ['0'],
	'se.pat.callProg.recWarning.inst.3.type' => ['branch'],
	'se.pat.callProg.recWarning.inst.3.value' => ['-2'],
	'se.pat.callProg.recWarning.inst.4.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.4.param' => ['0'],
	'se.pat.callProg.recWarning.inst.4.type' => [''],
	'se.pat.callProg.recWarning.inst.4.value' => [''],
	'se.pat.callProg.recWarning.inst.5.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.5.param' => ['0'],
	'se.pat.callProg.recWarning.inst.5.type' => [''],
	'se.pat.callProg.recWarning.inst.5.value' => [''],
	'se.pat.callProg.recWarning.inst.6.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.6.param' => ['0'],
	'se.pat.callProg.recWarning.inst.6.type' => [''],
	'se.pat.callProg.recWarning.inst.6.value' => [''],
	'se.pat.callProg.recWarning.inst.7.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.7.param' => ['0'],
	'se.pat.callProg.recWarning.inst.7.type' => [''],
	'se.pat.callProg.recWarning.inst.7.value' => [''],
	'se.pat.callProg.recWarning.inst.8.atten' => ['0'],
	'se.pat.callProg.recWarning.inst.8.param' => ['0'],
	'se.pat.callProg.recWarning.inst.8.type' => [''],
	'se.pat.callProg.recWarning.inst.8.value' => [''],
	'se.pat.callProg.recWarning.name' => ['warning'],
	'se.pat.callProg.reorder.inst.1.atten' => ['0'],
	'se.pat.callProg.reorder.inst.1.param' => ['0'],
	'se.pat.callProg.reorder.inst.1.type' => ['chord'],
	'se.pat.callProg.reorder.inst.1.value' => ['reorder'],
	'se.pat.callProg.reorder.inst.2.atten' => ['0'],
	'se.pat.callProg.reorder.inst.2.param' => ['0'],
	'se.pat.callProg.reorder.inst.2.type' => [''],
	'se.pat.callProg.reorder.inst.2.value' => [''],
	'se.pat.callProg.reorder.inst.3.atten' => ['0'],
	'se.pat.callProg.reorder.inst.3.param' => ['0'],
	'se.pat.callProg.reorder.inst.3.type' => [''],
	'se.pat.callProg.reorder.inst.3.value' => [''],
	'se.pat.callProg.reorder.inst.4.atten' => ['0'],
	'se.pat.callProg.reorder.inst.4.param' => ['0'],
	'se.pat.callProg.reorder.inst.4.type' => [''],
	'se.pat.callProg.reorder.inst.4.value' => [''],
	'se.pat.callProg.reorder.inst.5.atten' => ['0'],
	'se.pat.callProg.reorder.inst.5.param' => ['0'],
	'se.pat.callProg.reorder.inst.5.type' => [''],
	'se.pat.callProg.reorder.inst.5.value' => [''],
	'se.pat.callProg.reorder.inst.6.atten' => ['0'],
	'se.pat.callProg.reorder.inst.6.param' => ['0'],
	'se.pat.callProg.reorder.inst.6.type' => [''],
	'se.pat.callProg.reorder.inst.6.value' => [''],
	'se.pat.callProg.reorder.inst.7.atten' => ['0'],
	'se.pat.callProg.reorder.inst.7.param' => ['0'],
	'se.pat.callProg.reorder.inst.7.type' => [''],
	'se.pat.callProg.reorder.inst.7.value' => [''],
	'se.pat.callProg.reorder.inst.8.atten' => ['0'],
	'se.pat.callProg.reorder.inst.8.param' => ['0'],
	'se.pat.callProg.reorder.inst.8.type' => [''],
	'se.pat.callProg.reorder.inst.8.value' => [''],
	'se.pat.callProg.reorder.name' => ['reorder'],
	'se.pat.callProg.ringback.inst.1.atten' => ['0'],
	'se.pat.callProg.ringback.inst.1.param' => ['0'],
	'se.pat.callProg.ringback.inst.1.type' => ['silence'],
	'se.pat.callProg.ringback.inst.1.value' => ['2000'],
	'se.pat.callProg.ringback.inst.2.atten' => ['0'],
	'se.pat.callProg.ringback.inst.2.param' => ['0'],
	'se.pat.callProg.ringback.inst.2.type' => ['chord'],
	'se.pat.callProg.ringback.inst.2.value' => ['ringback'],
	'se.pat.callProg.ringback.inst.3.atten' => ['0'],
	'se.pat.callProg.ringback.inst.3.param' => ['0'],
	'se.pat.callProg.ringback.inst.3.type' => [''],
	'se.pat.callProg.ringback.inst.3.value' => [''],
	'se.pat.callProg.ringback.inst.4.atten' => ['0'],
	'se.pat.callProg.ringback.inst.4.param' => ['0'],
	'se.pat.callProg.ringback.inst.4.type' => [''],
	'se.pat.callProg.ringback.inst.4.value' => [''],
	'se.pat.callProg.ringback.inst.5.atten' => ['0'],
	'se.pat.callProg.ringback.inst.5.param' => ['0'],
	'se.pat.callProg.ringback.inst.5.type' => [''],
	'se.pat.callProg.ringback.inst.5.value' => [''],
	'se.pat.callProg.ringback.inst.6.atten' => ['0'],
	'se.pat.callProg.ringback.inst.6.param' => ['0'],
	'se.pat.callProg.ringback.inst.6.type' => [''],
	'se.pat.callProg.ringback.inst.6.value' => [''],
	'se.pat.callProg.ringback.inst.7.atten' => ['0'],
	'se.pat.callProg.ringback.inst.7.param' => ['0'],
	'se.pat.callProg.ringback.inst.7.type' => [''],
	'se.pat.callProg.ringback.inst.7.value' => [''],
	'se.pat.callProg.ringback.inst.8.atten' => ['0'],
	'se.pat.callProg.ringback.inst.8.param' => ['0'],
	'se.pat.callProg.ringback.inst.8.type' => [''],
	'se.pat.callProg.ringback.inst.8.value' => [''],
	'se.pat.callProg.ringback.name' => ['ringback'],
	'se.pat.callProg.secondaryDialTone.inst.1.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.1.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.1.type' => ['chord'],
	'se.pat.callProg.secondaryDialTone.inst.1.value' => ['dialTone'],
	'se.pat.callProg.secondaryDialTone.inst.2.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.2.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.2.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.2.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.3.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.3.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.3.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.3.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.4.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.4.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.4.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.4.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.5.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.5.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.5.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.5.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.6.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.6.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.6.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.6.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.7.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.7.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.7.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.7.value' => [''],
	'se.pat.callProg.secondaryDialTone.inst.8.atten' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.8.param' => ['0'],
	'se.pat.callProg.secondaryDialTone.inst.8.type' => [''],
	'se.pat.callProg.secondaryDialTone.inst.8.value' => [''],
	'se.pat.callProg.secondaryDialTone.name' => ['secondary dial'],
	'se.pat.callProg.stutter.inst.1.atten' => ['0'],
	'se.pat.callProg.stutter.inst.1.param' => ['0'],
	'se.pat.callProg.stutter.inst.1.type' => ['chord'],
	'se.pat.callProg.stutter.inst.1.value' => ['stutterLong'],
	'se.pat.callProg.stutter.inst.2.atten' => ['0'],
	'se.pat.callProg.stutter.inst.2.param' => ['0'],
	'se.pat.callProg.stutter.inst.2.type' => ['chord'],
	'se.pat.callProg.stutter.inst.2.value' => ['dialTone'],
	'se.pat.callProg.stutter.inst.3.atten' => ['0'],
	'se.pat.callProg.stutter.inst.3.param' => ['0'],
	'se.pat.callProg.stutter.inst.3.type' => [''],
	'se.pat.callProg.stutter.inst.3.value' => [''],
	'se.pat.callProg.stutter.inst.4.atten' => ['0'],
	'se.pat.callProg.stutter.inst.4.param' => ['0'],
	'se.pat.callProg.stutter.inst.4.type' => [''],
	'se.pat.callProg.stutter.inst.4.value' => [''],
	'se.pat.callProg.stutter.inst.5.atten' => ['0'],
	'se.pat.callProg.stutter.inst.5.param' => ['0'],
	'se.pat.callProg.stutter.inst.5.type' => [''],
	'se.pat.callProg.stutter.inst.5.value' => [''],
	'se.pat.callProg.stutter.inst.6.atten' => ['0'],
	'se.pat.callProg.stutter.inst.6.param' => ['0'],
	'se.pat.callProg.stutter.inst.6.type' => [''],
	'se.pat.callProg.stutter.inst.6.value' => [''],
	'se.pat.callProg.stutter.inst.7.atten' => ['0'],
	'se.pat.callProg.stutter.inst.7.param' => ['0'],
	'se.pat.callProg.stutter.inst.7.type' => [''],
	'se.pat.callProg.stutter.inst.7.value' => [''],
	'se.pat.callProg.stutter.inst.8.atten' => ['0'],
	'se.pat.callProg.stutter.inst.8.param' => ['0'],
	'se.pat.callProg.stutter.inst.8.type' => [''],
	'se.pat.callProg.stutter.inst.8.value' => [''],
	'se.pat.callProg.stutter.name' => ['stutter'],
	'se.pat.misc.instantMessage.inst.1.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.1.param' => ['0'],
	'se.pat.misc.instantMessage.inst.1.type' => ['chord'],
	'se.pat.misc.instantMessage.inst.1.value' => ['cs4'],
	'se.pat.misc.instantMessage.inst.10.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.10.param' => ['0'],
	'se.pat.misc.instantMessage.inst.10.type' => [''],
	'se.pat.misc.instantMessage.inst.10.value' => [''],
	'se.pat.misc.instantMessage.inst.11.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.11.param' => ['0'],
	'se.pat.misc.instantMessage.inst.11.type' => [''],
	'se.pat.misc.instantMessage.inst.11.value' => [''],
	'se.pat.misc.instantMessage.inst.12.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.12.param' => ['0'],
	'se.pat.misc.instantMessage.inst.12.type' => [''],
	'se.pat.misc.instantMessage.inst.12.value' => [''],
	'se.pat.misc.instantMessage.inst.13.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.13.param' => ['0'],
	'se.pat.misc.instantMessage.inst.13.type' => [''],
	'se.pat.misc.instantMessage.inst.13.value' => [''],
	'se.pat.misc.instantMessage.inst.14.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.14.param' => ['0'],
	'se.pat.misc.instantMessage.inst.14.type' => [''],
	'se.pat.misc.instantMessage.inst.14.value' => [''],
	'se.pat.misc.instantMessage.inst.15.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.15.param' => ['0'],
	'se.pat.misc.instantMessage.inst.15.type' => [''],
	'se.pat.misc.instantMessage.inst.15.value' => [''],
	'se.pat.misc.instantMessage.inst.16.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.16.param' => ['0'],
	'se.pat.misc.instantMessage.inst.16.type' => [''],
	'se.pat.misc.instantMessage.inst.16.value' => [''],
	'se.pat.misc.instantMessage.inst.17.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.17.param' => ['0'],
	'se.pat.misc.instantMessage.inst.17.type' => [''],
	'se.pat.misc.instantMessage.inst.17.value' => [''],
	'se.pat.misc.instantMessage.inst.18.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.18.param' => ['0'],
	'se.pat.misc.instantMessage.inst.18.type' => [''],
	'se.pat.misc.instantMessage.inst.18.value' => [''],
	'se.pat.misc.instantMessage.inst.19.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.19.param' => ['0'],
	'se.pat.misc.instantMessage.inst.19.type' => [''],
	'se.pat.misc.instantMessage.inst.19.value' => [''],
	'se.pat.misc.instantMessage.inst.2.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.2.param' => ['0'],
	'se.pat.misc.instantMessage.inst.2.type' => ['chord'],
	'se.pat.misc.instantMessage.inst.2.value' => ['cs3'],
	'se.pat.misc.instantMessage.inst.20.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.20.param' => ['0'],
	'se.pat.misc.instantMessage.inst.20.type' => [''],
	'se.pat.misc.instantMessage.inst.20.value' => [''],
	'se.pat.misc.instantMessage.inst.21.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.21.param' => ['0'],
	'se.pat.misc.instantMessage.inst.21.type' => [''],
	'se.pat.misc.instantMessage.inst.21.value' => [''],
	'se.pat.misc.instantMessage.inst.22.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.22.param' => ['0'],
	'se.pat.misc.instantMessage.inst.22.type' => [''],
	'se.pat.misc.instantMessage.inst.22.value' => [''],
	'se.pat.misc.instantMessage.inst.23.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.23.param' => ['0'],
	'se.pat.misc.instantMessage.inst.23.type' => [''],
	'se.pat.misc.instantMessage.inst.23.value' => [''],
	'se.pat.misc.instantMessage.inst.24.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.24.param' => ['0'],
	'se.pat.misc.instantMessage.inst.24.type' => [''],
	'se.pat.misc.instantMessage.inst.24.value' => [''],
	'se.pat.misc.instantMessage.inst.25.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.25.param' => ['0'],
	'se.pat.misc.instantMessage.inst.25.type' => [''],
	'se.pat.misc.instantMessage.inst.25.value' => [''],
	'se.pat.misc.instantMessage.inst.26.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.26.param' => ['0'],
	'se.pat.misc.instantMessage.inst.26.type' => [''],
	'se.pat.misc.instantMessage.inst.26.value' => [''],
	'se.pat.misc.instantMessage.inst.27.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.27.param' => ['0'],
	'se.pat.misc.instantMessage.inst.27.type' => [''],
	'se.pat.misc.instantMessage.inst.27.value' => [''],
	'se.pat.misc.instantMessage.inst.28.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.28.param' => ['0'],
	'se.pat.misc.instantMessage.inst.28.type' => [''],
	'se.pat.misc.instantMessage.inst.28.value' => [''],
	'se.pat.misc.instantMessage.inst.29.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.29.param' => ['0'],
	'se.pat.misc.instantMessage.inst.29.type' => [''],
	'se.pat.misc.instantMessage.inst.29.value' => [''],
	'se.pat.misc.instantMessage.inst.3.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.3.param' => ['0'],
	'se.pat.misc.instantMessage.inst.3.type' => ['chord'],
	'se.pat.misc.instantMessage.inst.3.value' => ['cs4'],
	'se.pat.misc.instantMessage.inst.30.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.30.param' => ['0'],
	'se.pat.misc.instantMessage.inst.30.type' => [''],
	'se.pat.misc.instantMessage.inst.30.value' => [''],
	'se.pat.misc.instantMessage.inst.31.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.31.param' => ['0'],
	'se.pat.misc.instantMessage.inst.31.type' => [''],
	'se.pat.misc.instantMessage.inst.31.value' => [''],
	'se.pat.misc.instantMessage.inst.32.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.32.param' => ['0'],
	'se.pat.misc.instantMessage.inst.32.type' => [''],
	'se.pat.misc.instantMessage.inst.32.value' => [''],
	'se.pat.misc.instantMessage.inst.4.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.4.param' => ['0'],
	'se.pat.misc.instantMessage.inst.4.type' => [''],
	'se.pat.misc.instantMessage.inst.4.value' => [''],
	'se.pat.misc.instantMessage.inst.5.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.5.param' => ['0'],
	'se.pat.misc.instantMessage.inst.5.type' => [''],
	'se.pat.misc.instantMessage.inst.5.value' => [''],
	'se.pat.misc.instantMessage.inst.6.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.6.param' => ['0'],
	'se.pat.misc.instantMessage.inst.6.type' => [''],
	'se.pat.misc.instantMessage.inst.6.value' => [''],
	'se.pat.misc.instantMessage.inst.7.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.7.param' => ['0'],
	'se.pat.misc.instantMessage.inst.7.type' => [''],
	'se.pat.misc.instantMessage.inst.7.value' => [''],
	'se.pat.misc.instantMessage.inst.8.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.8.param' => ['0'],
	'se.pat.misc.instantMessage.inst.8.type' => [''],
	'se.pat.misc.instantMessage.inst.8.value' => [''],
	'se.pat.misc.instantMessage.inst.9.atten' => ['0'],
	'se.pat.misc.instantMessage.inst.9.param' => ['0'],
	'se.pat.misc.instantMessage.inst.9.type' => [''],
	'se.pat.misc.instantMessage.inst.9.value' => [''],
	'se.pat.misc.instantMessage.name' => ['instant message'],
	'se.pat.misc.localHoldNotification.inst.1.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.1.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.1.type' => ['chord'],
	'se.pat.misc.localHoldNotification.inst.1.value' => ['cs3'],
	'se.pat.misc.localHoldNotification.inst.10.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.10.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.10.type' => [''],
	'se.pat.misc.localHoldNotification.inst.10.value' => [''],
	'se.pat.misc.localHoldNotification.inst.11.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.11.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.11.type' => [''],
	'se.pat.misc.localHoldNotification.inst.11.value' => [''],
	'se.pat.misc.localHoldNotification.inst.12.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.12.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.12.type' => [''],
	'se.pat.misc.localHoldNotification.inst.12.value' => [''],
	'se.pat.misc.localHoldNotification.inst.13.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.13.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.13.type' => [''],
	'se.pat.misc.localHoldNotification.inst.13.value' => [''],
	'se.pat.misc.localHoldNotification.inst.14.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.14.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.14.type' => [''],
	'se.pat.misc.localHoldNotification.inst.14.value' => [''],
	'se.pat.misc.localHoldNotification.inst.15.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.15.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.15.type' => [''],
	'se.pat.misc.localHoldNotification.inst.15.value' => [''],
	'se.pat.misc.localHoldNotification.inst.16.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.16.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.16.type' => [''],
	'se.pat.misc.localHoldNotification.inst.16.value' => [''],
	'se.pat.misc.localHoldNotification.inst.17.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.17.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.17.type' => [''],
	'se.pat.misc.localHoldNotification.inst.17.value' => [''],
	'se.pat.misc.localHoldNotification.inst.18.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.18.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.18.type' => [''],
	'se.pat.misc.localHoldNotification.inst.18.value' => [''],
	'se.pat.misc.localHoldNotification.inst.19.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.19.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.19.type' => [''],
	'se.pat.misc.localHoldNotification.inst.19.value' => [''],
	'se.pat.misc.localHoldNotification.inst.2.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.2.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.2.type' => ['chord'],
	'se.pat.misc.localHoldNotification.inst.2.value' => ['cs4'],
	'se.pat.misc.localHoldNotification.inst.20.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.20.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.20.type' => [''],
	'se.pat.misc.localHoldNotification.inst.20.value' => [''],
	'se.pat.misc.localHoldNotification.inst.21.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.21.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.21.type' => [''],
	'se.pat.misc.localHoldNotification.inst.21.value' => [''],
	'se.pat.misc.localHoldNotification.inst.22.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.22.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.22.type' => [''],
	'se.pat.misc.localHoldNotification.inst.22.value' => [''],
	'se.pat.misc.localHoldNotification.inst.23.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.23.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.23.type' => [''],
	'se.pat.misc.localHoldNotification.inst.23.value' => [''],
	'se.pat.misc.localHoldNotification.inst.24.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.24.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.24.type' => [''],
	'se.pat.misc.localHoldNotification.inst.24.value' => [''],
	'se.pat.misc.localHoldNotification.inst.25.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.25.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.25.type' => [''],
	'se.pat.misc.localHoldNotification.inst.25.value' => [''],
	'se.pat.misc.localHoldNotification.inst.26.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.26.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.26.type' => [''],
	'se.pat.misc.localHoldNotification.inst.26.value' => [''],
	'se.pat.misc.localHoldNotification.inst.27.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.27.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.27.type' => [''],
	'se.pat.misc.localHoldNotification.inst.27.value' => [''],
	'se.pat.misc.localHoldNotification.inst.28.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.28.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.28.type' => [''],
	'se.pat.misc.localHoldNotification.inst.28.value' => [''],
	'se.pat.misc.localHoldNotification.inst.29.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.29.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.29.type' => [''],
	'se.pat.misc.localHoldNotification.inst.29.value' => [''],
	'se.pat.misc.localHoldNotification.inst.3.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.3.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.3.type' => ['chord'],
	'se.pat.misc.localHoldNotification.inst.3.value' => ['cs6'],
	'se.pat.misc.localHoldNotification.inst.30.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.30.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.30.type' => [''],
	'se.pat.misc.localHoldNotification.inst.30.value' => [''],
	'se.pat.misc.localHoldNotification.inst.31.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.31.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.31.type' => [''],
	'se.pat.misc.localHoldNotification.inst.31.value' => [''],
	'se.pat.misc.localHoldNotification.inst.32.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.32.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.32.type' => [''],
	'se.pat.misc.localHoldNotification.inst.32.value' => [''],
	'se.pat.misc.localHoldNotification.inst.4.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.4.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.4.type' => ['chord'],
	'se.pat.misc.localHoldNotification.inst.4.value' => ['cs4'],
	'se.pat.misc.localHoldNotification.inst.5.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.5.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.5.type' => [''],
	'se.pat.misc.localHoldNotification.inst.5.value' => [''],
	'se.pat.misc.localHoldNotification.inst.6.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.6.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.6.type' => [''],
	'se.pat.misc.localHoldNotification.inst.6.value' => [''],
	'se.pat.misc.localHoldNotification.inst.7.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.7.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.7.type' => [''],
	'se.pat.misc.localHoldNotification.inst.7.value' => [''],
	'se.pat.misc.localHoldNotification.inst.8.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.8.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.8.type' => [''],
	'se.pat.misc.localHoldNotification.inst.8.value' => [''],
	'se.pat.misc.localHoldNotification.inst.9.atten' => ['0'],
	'se.pat.misc.localHoldNotification.inst.9.param' => ['0'],
	'se.pat.misc.localHoldNotification.inst.9.type' => [''],
	'se.pat.misc.localHoldNotification.inst.9.value' => [''],
	'se.pat.misc.localHoldNotification.name' => ['local hold notification'],
	'se.pat.misc.messageWaiting.inst.1.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.1.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.1.type' => ['chord'],
	'se.pat.misc.messageWaiting.inst.1.value' => ['cs1'],
	'se.pat.misc.messageWaiting.inst.10.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.10.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.10.type' => [''],
	'se.pat.misc.messageWaiting.inst.10.value' => [''],
	'se.pat.misc.messageWaiting.inst.11.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.11.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.11.type' => [''],
	'se.pat.misc.messageWaiting.inst.11.value' => [''],
	'se.pat.misc.messageWaiting.inst.12.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.12.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.12.type' => [''],
	'se.pat.misc.messageWaiting.inst.12.value' => [''],
	'se.pat.misc.messageWaiting.inst.13.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.13.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.13.type' => [''],
	'se.pat.misc.messageWaiting.inst.13.value' => [''],
	'se.pat.misc.messageWaiting.inst.14.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.14.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.14.type' => [''],
	'se.pat.misc.messageWaiting.inst.14.value' => [''],
	'se.pat.misc.messageWaiting.inst.15.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.15.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.15.type' => [''],
	'se.pat.misc.messageWaiting.inst.15.value' => [''],
	'se.pat.misc.messageWaiting.inst.16.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.16.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.16.type' => [''],
	'se.pat.misc.messageWaiting.inst.16.value' => [''],
	'se.pat.misc.messageWaiting.inst.17.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.17.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.17.type' => [''],
	'se.pat.misc.messageWaiting.inst.17.value' => [''],
	'se.pat.misc.messageWaiting.inst.18.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.18.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.18.type' => [''],
	'se.pat.misc.messageWaiting.inst.18.value' => [''],
	'se.pat.misc.messageWaiting.inst.19.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.19.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.19.type' => [''],
	'se.pat.misc.messageWaiting.inst.19.value' => [''],
	'se.pat.misc.messageWaiting.inst.2.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.2.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.2.type' => ['chord'],
	'se.pat.misc.messageWaiting.inst.2.value' => ['cs2'],
	'se.pat.misc.messageWaiting.inst.20.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.20.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.20.type' => [''],
	'se.pat.misc.messageWaiting.inst.20.value' => [''],
	'se.pat.misc.messageWaiting.inst.21.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.21.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.21.type' => [''],
	'se.pat.misc.messageWaiting.inst.21.value' => [''],
	'se.pat.misc.messageWaiting.inst.22.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.22.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.22.type' => [''],
	'se.pat.misc.messageWaiting.inst.22.value' => [''],
	'se.pat.misc.messageWaiting.inst.23.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.23.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.23.type' => [''],
	'se.pat.misc.messageWaiting.inst.23.value' => [''],
	'se.pat.misc.messageWaiting.inst.24.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.24.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.24.type' => [''],
	'se.pat.misc.messageWaiting.inst.24.value' => [''],
	'se.pat.misc.messageWaiting.inst.25.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.25.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.25.type' => [''],
	'se.pat.misc.messageWaiting.inst.25.value' => [''],
	'se.pat.misc.messageWaiting.inst.26.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.26.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.26.type' => [''],
	'se.pat.misc.messageWaiting.inst.26.value' => [''],
	'se.pat.misc.messageWaiting.inst.27.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.27.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.27.type' => [''],
	'se.pat.misc.messageWaiting.inst.27.value' => [''],
	'se.pat.misc.messageWaiting.inst.28.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.28.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.28.type' => [''],
	'se.pat.misc.messageWaiting.inst.28.value' => [''],
	'se.pat.misc.messageWaiting.inst.29.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.29.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.29.type' => [''],
	'se.pat.misc.messageWaiting.inst.29.value' => [''],
	'se.pat.misc.messageWaiting.inst.3.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.3.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.3.type' => ['chord'],
	'se.pat.misc.messageWaiting.inst.3.value' => ['cs1'],
	'se.pat.misc.messageWaiting.inst.30.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.30.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.30.type' => [''],
	'se.pat.misc.messageWaiting.inst.30.value' => [''],
	'se.pat.misc.messageWaiting.inst.31.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.31.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.31.type' => [''],
	'se.pat.misc.messageWaiting.inst.31.value' => [''],
	'se.pat.misc.messageWaiting.inst.32.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.32.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.32.type' => [''],
	'se.pat.misc.messageWaiting.inst.32.value' => [''],
	'se.pat.misc.messageWaiting.inst.4.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.4.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.4.type' => [''],
	'se.pat.misc.messageWaiting.inst.4.value' => [''],
	'se.pat.misc.messageWaiting.inst.5.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.5.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.5.type' => [''],
	'se.pat.misc.messageWaiting.inst.5.value' => [''],
	'se.pat.misc.messageWaiting.inst.6.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.6.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.6.type' => [''],
	'se.pat.misc.messageWaiting.inst.6.value' => [''],
	'se.pat.misc.messageWaiting.inst.7.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.7.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.7.type' => [''],
	'se.pat.misc.messageWaiting.inst.7.value' => [''],
	'se.pat.misc.messageWaiting.inst.8.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.8.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.8.type' => [''],
	'se.pat.misc.messageWaiting.inst.8.value' => [''],
	'se.pat.misc.messageWaiting.inst.9.atten' => ['0'],
	'se.pat.misc.messageWaiting.inst.9.param' => ['0'],
	'se.pat.misc.messageWaiting.inst.9.type' => [''],
	'se.pat.misc.messageWaiting.inst.9.value' => [''],
	'se.pat.misc.messageWaiting.name' => ['message waiting'],
	'se.pat.misc.negativeConfirm.inst.1.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.1.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.1.type' => ['chord'],
	'se.pat.misc.negativeConfirm.inst.1.value' => ['cs7'],
	'se.pat.misc.negativeConfirm.inst.10.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.10.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.10.type' => [''],
	'se.pat.misc.negativeConfirm.inst.10.value' => [''],
	'se.pat.misc.negativeConfirm.inst.11.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.11.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.11.type' => [''],
	'se.pat.misc.negativeConfirm.inst.11.value' => [''],
	'se.pat.misc.negativeConfirm.inst.12.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.12.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.12.type' => [''],
	'se.pat.misc.negativeConfirm.inst.12.value' => [''],
	'se.pat.misc.negativeConfirm.inst.13.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.13.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.13.type' => [''],
	'se.pat.misc.negativeConfirm.inst.13.value' => [''],
	'se.pat.misc.negativeConfirm.inst.14.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.14.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.14.type' => [''],
	'se.pat.misc.negativeConfirm.inst.14.value' => [''],
	'se.pat.misc.negativeConfirm.inst.15.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.15.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.15.type' => [''],
	'se.pat.misc.negativeConfirm.inst.15.value' => [''],
	'se.pat.misc.negativeConfirm.inst.16.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.16.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.16.type' => [''],
	'se.pat.misc.negativeConfirm.inst.16.value' => [''],
	'se.pat.misc.negativeConfirm.inst.17.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.17.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.17.type' => [''],
	'se.pat.misc.negativeConfirm.inst.17.value' => [''],
	'se.pat.misc.negativeConfirm.inst.18.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.18.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.18.type' => [''],
	'se.pat.misc.negativeConfirm.inst.18.value' => [''],
	'se.pat.misc.negativeConfirm.inst.19.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.19.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.19.type' => [''],
	'se.pat.misc.negativeConfirm.inst.19.value' => [''],
	'se.pat.misc.negativeConfirm.inst.2.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.2.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.2.type' => ['silence'],
	'se.pat.misc.negativeConfirm.inst.2.value' => ['100'],
	'se.pat.misc.negativeConfirm.inst.20.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.20.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.20.type' => [''],
	'se.pat.misc.negativeConfirm.inst.20.value' => [''],
	'se.pat.misc.negativeConfirm.inst.21.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.21.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.21.type' => [''],
	'se.pat.misc.negativeConfirm.inst.21.value' => [''],
	'se.pat.misc.negativeConfirm.inst.22.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.22.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.22.type' => [''],
	'se.pat.misc.negativeConfirm.inst.22.value' => [''],
	'se.pat.misc.negativeConfirm.inst.23.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.23.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.23.type' => [''],
	'se.pat.misc.negativeConfirm.inst.23.value' => [''],
	'se.pat.misc.negativeConfirm.inst.24.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.24.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.24.type' => [''],
	'se.pat.misc.negativeConfirm.inst.24.value' => [''],
	'se.pat.misc.negativeConfirm.inst.25.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.25.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.25.type' => [''],
	'se.pat.misc.negativeConfirm.inst.25.value' => [''],
	'se.pat.misc.negativeConfirm.inst.26.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.26.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.26.type' => [''],
	'se.pat.misc.negativeConfirm.inst.26.value' => [''],
	'se.pat.misc.negativeConfirm.inst.27.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.27.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.27.type' => [''],
	'se.pat.misc.negativeConfirm.inst.27.value' => [''],
	'se.pat.misc.negativeConfirm.inst.28.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.28.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.28.type' => [''],
	'se.pat.misc.negativeConfirm.inst.28.value' => [''],
	'se.pat.misc.negativeConfirm.inst.29.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.29.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.29.type' => [''],
	'se.pat.misc.negativeConfirm.inst.29.value' => [''],
	'se.pat.misc.negativeConfirm.inst.3.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.3.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.3.type' => ['chord'],
	'se.pat.misc.negativeConfirm.inst.3.value' => ['cs6'],
	'se.pat.misc.negativeConfirm.inst.30.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.30.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.30.type' => [''],
	'se.pat.misc.negativeConfirm.inst.30.value' => [''],
	'se.pat.misc.negativeConfirm.inst.31.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.31.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.31.type' => [''],
	'se.pat.misc.negativeConfirm.inst.31.value' => [''],
	'se.pat.misc.negativeConfirm.inst.32.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.32.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.32.type' => [''],
	'se.pat.misc.negativeConfirm.inst.32.value' => [''],
	'se.pat.misc.negativeConfirm.inst.4.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.4.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.4.type' => [''],
	'se.pat.misc.negativeConfirm.inst.4.value' => [''],
	'se.pat.misc.negativeConfirm.inst.5.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.5.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.5.type' => [''],
	'se.pat.misc.negativeConfirm.inst.5.value' => [''],
	'se.pat.misc.negativeConfirm.inst.6.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.6.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.6.type' => [''],
	'se.pat.misc.negativeConfirm.inst.6.value' => [''],
	'se.pat.misc.negativeConfirm.inst.7.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.7.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.7.type' => [''],
	'se.pat.misc.negativeConfirm.inst.7.value' => [''],
	'se.pat.misc.negativeConfirm.inst.8.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.8.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.8.type' => [''],
	'se.pat.misc.negativeConfirm.inst.8.value' => [''],
	'se.pat.misc.negativeConfirm.inst.9.atten' => ['0'],
	'se.pat.misc.negativeConfirm.inst.9.param' => ['0'],
	'se.pat.misc.negativeConfirm.inst.9.type' => [''],
	'se.pat.misc.negativeConfirm.inst.9.value' => [''],
	'se.pat.misc.negativeConfirm.name' => ['negative confirmation'],
	'se.pat.misc.positiveConfirm.inst.1.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.1.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.1.type' => ['chord'],
	'se.pat.misc.positiveConfirm.inst.1.value' => ['cs7'],
	'se.pat.misc.positiveConfirm.inst.10.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.10.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.10.type' => [''],
	'se.pat.misc.positiveConfirm.inst.10.value' => [''],
	'se.pat.misc.positiveConfirm.inst.11.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.11.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.11.type' => [''],
	'se.pat.misc.positiveConfirm.inst.11.value' => [''],
	'se.pat.misc.positiveConfirm.inst.12.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.12.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.12.type' => [''],
	'se.pat.misc.positiveConfirm.inst.12.value' => [''],
	'se.pat.misc.positiveConfirm.inst.13.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.13.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.13.type' => [''],
	'se.pat.misc.positiveConfirm.inst.13.value' => [''],
	'se.pat.misc.positiveConfirm.inst.14.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.14.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.14.type' => [''],
	'se.pat.misc.positiveConfirm.inst.14.value' => [''],
	'se.pat.misc.positiveConfirm.inst.15.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.15.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.15.type' => [''],
	'se.pat.misc.positiveConfirm.inst.15.value' => [''],
	'se.pat.misc.positiveConfirm.inst.16.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.16.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.16.type' => [''],
	'se.pat.misc.positiveConfirm.inst.16.value' => [''],
	'se.pat.misc.positiveConfirm.inst.17.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.17.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.17.type' => [''],
	'se.pat.misc.positiveConfirm.inst.17.value' => [''],
	'se.pat.misc.positiveConfirm.inst.18.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.18.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.18.type' => [''],
	'se.pat.misc.positiveConfirm.inst.18.value' => [''],
	'se.pat.misc.positiveConfirm.inst.19.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.19.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.19.type' => [''],
	'se.pat.misc.positiveConfirm.inst.19.value' => [''],
	'se.pat.misc.positiveConfirm.inst.2.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.2.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.2.type' => ['chord'],
	'se.pat.misc.positiveConfirm.inst.2.value' => ['cs4'],
	'se.pat.misc.positiveConfirm.inst.20.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.20.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.20.type' => [''],
	'se.pat.misc.positiveConfirm.inst.20.value' => [''],
	'se.pat.misc.positiveConfirm.inst.21.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.21.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.21.type' => [''],
	'se.pat.misc.positiveConfirm.inst.21.value' => [''],
	'se.pat.misc.positiveConfirm.inst.22.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.22.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.22.type' => [''],
	'se.pat.misc.positiveConfirm.inst.22.value' => [''],
	'se.pat.misc.positiveConfirm.inst.23.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.23.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.23.type' => [''],
	'se.pat.misc.positiveConfirm.inst.23.value' => [''],
	'se.pat.misc.positiveConfirm.inst.24.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.24.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.24.type' => [''],
	'se.pat.misc.positiveConfirm.inst.24.value' => [''],
	'se.pat.misc.positiveConfirm.inst.25.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.25.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.25.type' => [''],
	'se.pat.misc.positiveConfirm.inst.25.value' => [''],
	'se.pat.misc.positiveConfirm.inst.26.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.26.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.26.type' => [''],
	'se.pat.misc.positiveConfirm.inst.26.value' => [''],
	'se.pat.misc.positiveConfirm.inst.27.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.27.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.27.type' => [''],
	'se.pat.misc.positiveConfirm.inst.27.value' => [''],
	'se.pat.misc.positiveConfirm.inst.28.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.28.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.28.type' => [''],
	'se.pat.misc.positiveConfirm.inst.28.value' => [''],
	'se.pat.misc.positiveConfirm.inst.29.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.29.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.29.type' => [''],
	'se.pat.misc.positiveConfirm.inst.29.value' => [''],
	'se.pat.misc.positiveConfirm.inst.3.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.3.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.3.type' => ['chord'],
	'se.pat.misc.positiveConfirm.inst.3.value' => ['cs7'],
	'se.pat.misc.positiveConfirm.inst.30.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.30.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.30.type' => [''],
	'se.pat.misc.positiveConfirm.inst.30.value' => [''],
	'se.pat.misc.positiveConfirm.inst.31.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.31.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.31.type' => [''],
	'se.pat.misc.positiveConfirm.inst.31.value' => [''],
	'se.pat.misc.positiveConfirm.inst.32.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.32.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.32.type' => [''],
	'se.pat.misc.positiveConfirm.inst.32.value' => [''],
	'se.pat.misc.positiveConfirm.inst.4.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.4.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.4.type' => [''],
	'se.pat.misc.positiveConfirm.inst.4.value' => [''],
	'se.pat.misc.positiveConfirm.inst.5.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.5.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.5.type' => [''],
	'se.pat.misc.positiveConfirm.inst.5.value' => [''],
	'se.pat.misc.positiveConfirm.inst.6.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.6.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.6.type' => [''],
	'se.pat.misc.positiveConfirm.inst.6.value' => [''],
	'se.pat.misc.positiveConfirm.inst.7.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.7.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.7.type' => [''],
	'se.pat.misc.positiveConfirm.inst.7.value' => [''],
	'se.pat.misc.positiveConfirm.inst.8.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.8.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.8.type' => [''],
	'se.pat.misc.positiveConfirm.inst.8.value' => [''],
	'se.pat.misc.positiveConfirm.inst.9.atten' => ['0'],
	'se.pat.misc.positiveConfirm.inst.9.param' => ['0'],
	'se.pat.misc.positiveConfirm.inst.9.type' => [''],
	'se.pat.misc.positiveConfirm.inst.9.value' => [''],
	'se.pat.misc.positiveConfirm.name' => ['positive confirmation'],
	'se.pat.misc.remoteHoldNotification.inst.1.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.1.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.1.type' => ['chord'],
	'se.pat.misc.remoteHoldNotification.inst.1.value' => ['cs5'],
	'se.pat.misc.remoteHoldNotification.inst.10.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.10.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.10.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.10.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.11.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.11.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.11.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.11.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.12.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.12.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.12.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.12.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.13.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.13.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.13.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.13.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.14.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.14.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.14.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.14.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.15.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.15.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.15.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.15.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.16.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.16.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.16.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.16.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.17.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.17.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.17.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.17.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.18.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.18.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.18.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.18.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.19.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.19.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.19.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.19.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.2.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.2.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.2.type' => ['chord'],
	'se.pat.misc.remoteHoldNotification.inst.2.value' => ['cs4'],
	'se.pat.misc.remoteHoldNotification.inst.20.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.20.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.20.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.20.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.21.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.21.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.21.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.21.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.22.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.22.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.22.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.22.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.23.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.23.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.23.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.23.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.24.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.24.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.24.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.24.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.25.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.25.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.25.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.25.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.26.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.26.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.26.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.26.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.27.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.27.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.27.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.27.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.28.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.28.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.28.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.28.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.29.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.29.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.29.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.29.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.3.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.3.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.3.type' => ['chord'],
	'se.pat.misc.remoteHoldNotification.inst.3.value' => ['cs1'],
	'se.pat.misc.remoteHoldNotification.inst.30.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.30.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.30.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.30.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.31.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.31.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.31.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.31.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.32.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.32.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.32.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.32.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.4.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.4.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.4.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.4.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.5.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.5.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.5.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.5.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.6.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.6.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.6.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.6.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.7.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.7.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.7.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.7.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.8.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.8.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.8.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.8.value' => [''],
	'se.pat.misc.remoteHoldNotification.inst.9.atten' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.9.param' => ['0'],
	'se.pat.misc.remoteHoldNotification.inst.9.type' => [''],
	'se.pat.misc.remoteHoldNotification.inst.9.value' => [''],
	'se.pat.misc.remoteHoldNotification.name' => ['remote hold notification'],
	'se.pat.misc.welcome.inst.1.atten' => ['0'],
	'se.pat.misc.welcome.inst.1.param' => ['0'],
	'se.pat.misc.welcome.inst.1.type' => ['sampled'],
	'se.pat.misc.welcome.inst.1.value' => ['1'],
	'se.pat.misc.welcome.inst.10.atten' => ['0'],
	'se.pat.misc.welcome.inst.10.param' => ['0'],
	'se.pat.misc.welcome.inst.10.type' => [''],
	'se.pat.misc.welcome.inst.10.value' => [''],
	'se.pat.misc.welcome.inst.11.atten' => ['0'],
	'se.pat.misc.welcome.inst.11.param' => ['0'],
	'se.pat.misc.welcome.inst.11.type' => [''],
	'se.pat.misc.welcome.inst.11.value' => [''],
	'se.pat.misc.welcome.inst.12.atten' => ['0'],
	'se.pat.misc.welcome.inst.12.param' => ['0'],
	'se.pat.misc.welcome.inst.12.type' => [''],
	'se.pat.misc.welcome.inst.12.value' => [''],
	'se.pat.misc.welcome.inst.13.atten' => ['0'],
	'se.pat.misc.welcome.inst.13.param' => ['0'],
	'se.pat.misc.welcome.inst.13.type' => [''],
	'se.pat.misc.welcome.inst.13.value' => [''],
	'se.pat.misc.welcome.inst.14.atten' => ['0'],
	'se.pat.misc.welcome.inst.14.param' => ['0'],
	'se.pat.misc.welcome.inst.14.type' => [''],
	'se.pat.misc.welcome.inst.14.value' => [''],
	'se.pat.misc.welcome.inst.15.atten' => ['0'],
	'se.pat.misc.welcome.inst.15.param' => ['0'],
	'se.pat.misc.welcome.inst.15.type' => [''],
	'se.pat.misc.welcome.inst.15.value' => [''],
	'se.pat.misc.welcome.inst.16.atten' => ['0'],
	'se.pat.misc.welcome.inst.16.param' => ['0'],
	'se.pat.misc.welcome.inst.16.type' => [''],
	'se.pat.misc.welcome.inst.16.value' => [''],
	'se.pat.misc.welcome.inst.17.atten' => ['0'],
	'se.pat.misc.welcome.inst.17.param' => ['0'],
	'se.pat.misc.welcome.inst.17.type' => [''],
	'se.pat.misc.welcome.inst.17.value' => [''],
	'se.pat.misc.welcome.inst.18.atten' => ['0'],
	'se.pat.misc.welcome.inst.18.param' => ['0'],
	'se.pat.misc.welcome.inst.18.type' => [''],
	'se.pat.misc.welcome.inst.18.value' => [''],
	'se.pat.misc.welcome.inst.19.atten' => ['0'],
	'se.pat.misc.welcome.inst.19.param' => ['0'],
	'se.pat.misc.welcome.inst.19.type' => [''],
	'se.pat.misc.welcome.inst.19.value' => [''],
	'se.pat.misc.welcome.inst.2.atten' => ['0'],
	'se.pat.misc.welcome.inst.2.param' => ['0'],
	'se.pat.misc.welcome.inst.2.type' => [''],
	'se.pat.misc.welcome.inst.2.value' => [''],
	'se.pat.misc.welcome.inst.20.atten' => ['0'],
	'se.pat.misc.welcome.inst.20.param' => ['0'],
	'se.pat.misc.welcome.inst.20.type' => [''],
	'se.pat.misc.welcome.inst.20.value' => [''],
	'se.pat.misc.welcome.inst.21.atten' => ['0'],
	'se.pat.misc.welcome.inst.21.param' => ['0'],
	'se.pat.misc.welcome.inst.21.type' => [''],
	'se.pat.misc.welcome.inst.21.value' => [''],
	'se.pat.misc.welcome.inst.22.atten' => ['0'],
	'se.pat.misc.welcome.inst.22.param' => ['0'],
	'se.pat.misc.welcome.inst.22.type' => [''],
	'se.pat.misc.welcome.inst.22.value' => [''],
	'se.pat.misc.welcome.inst.23.atten' => ['0'],
	'se.pat.misc.welcome.inst.23.param' => ['0'],
	'se.pat.misc.welcome.inst.23.type' => [''],
	'se.pat.misc.welcome.inst.23.value' => [''],
	'se.pat.misc.welcome.inst.24.atten' => ['0'],
	'se.pat.misc.welcome.inst.24.param' => ['0'],
	'se.pat.misc.welcome.inst.24.type' => [''],
	'se.pat.misc.welcome.inst.24.value' => [''],
	'se.pat.misc.welcome.inst.25.atten' => ['0'],
	'se.pat.misc.welcome.inst.25.param' => ['0'],
	'se.pat.misc.welcome.inst.25.type' => [''],
	'se.pat.misc.welcome.inst.25.value' => [''],
	'se.pat.misc.welcome.inst.26.atten' => ['0'],
	'se.pat.misc.welcome.inst.26.param' => ['0'],
	'se.pat.misc.welcome.inst.26.type' => [''],
	'se.pat.misc.welcome.inst.26.value' => [''],
	'se.pat.misc.welcome.inst.27.atten' => ['0'],
	'se.pat.misc.welcome.inst.27.param' => ['0'],
	'se.pat.misc.welcome.inst.27.type' => [''],
	'se.pat.misc.welcome.inst.27.value' => [''],
	'se.pat.misc.welcome.inst.28.atten' => ['0'],
	'se.pat.misc.welcome.inst.28.param' => ['0'],
	'se.pat.misc.welcome.inst.28.type' => [''],
	'se.pat.misc.welcome.inst.28.value' => [''],
	'se.pat.misc.welcome.inst.29.atten' => ['0'],
	'se.pat.misc.welcome.inst.29.param' => ['0'],
	'se.pat.misc.welcome.inst.29.type' => [''],
	'se.pat.misc.welcome.inst.29.value' => [''],
	'se.pat.misc.welcome.inst.3.atten' => ['0'],
	'se.pat.misc.welcome.inst.3.param' => ['0'],
	'se.pat.misc.welcome.inst.3.type' => [''],
	'se.pat.misc.welcome.inst.3.value' => [''],
	'se.pat.misc.welcome.inst.30.atten' => ['0'],
	'se.pat.misc.welcome.inst.30.param' => ['0'],
	'se.pat.misc.welcome.inst.30.type' => [''],
	'se.pat.misc.welcome.inst.30.value' => [''],
	'se.pat.misc.welcome.inst.31.atten' => ['0'],
	'se.pat.misc.welcome.inst.31.param' => ['0'],
	'se.pat.misc.welcome.inst.31.type' => [''],
	'se.pat.misc.welcome.inst.31.value' => [''],
	'se.pat.misc.welcome.inst.32.atten' => ['0'],
	'se.pat.misc.welcome.inst.32.param' => ['0'],
	'se.pat.misc.welcome.inst.32.type' => [''],
	'se.pat.misc.welcome.inst.32.value' => [''],
	'se.pat.misc.welcome.inst.4.atten' => ['0'],
	'se.pat.misc.welcome.inst.4.param' => ['0'],
	'se.pat.misc.welcome.inst.4.type' => [''],
	'se.pat.misc.welcome.inst.4.value' => [''],
	'se.pat.misc.welcome.inst.5.atten' => ['0'],
	'se.pat.misc.welcome.inst.5.param' => ['0'],
	'se.pat.misc.welcome.inst.5.type' => [''],
	'se.pat.misc.welcome.inst.5.value' => [''],
	'se.pat.misc.welcome.inst.6.atten' => ['0'],
	'se.pat.misc.welcome.inst.6.param' => ['0'],
	'se.pat.misc.welcome.inst.6.type' => [''],
	'se.pat.misc.welcome.inst.6.value' => [''],
	'se.pat.misc.welcome.inst.7.atten' => ['0'],
	'se.pat.misc.welcome.inst.7.param' => ['0'],
	'se.pat.misc.welcome.inst.7.type' => [''],
	'se.pat.misc.welcome.inst.7.value' => [''],
	'se.pat.misc.welcome.inst.8.atten' => ['0'],
	'se.pat.misc.welcome.inst.8.param' => ['0'],
	'se.pat.misc.welcome.inst.8.type' => [''],
	'se.pat.misc.welcome.inst.8.value' => [''],
	'se.pat.misc.welcome.inst.9.atten' => ['0'],
	'se.pat.misc.welcome.inst.9.param' => ['0'],
	'se.pat.misc.welcome.inst.9.type' => [''],
	'se.pat.misc.welcome.inst.9.value' => [''],
	'se.pat.misc.welcome.name' => ['welcome'],
	'se.pat.ringer.ringer1.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.1.param' => ['0'],
	'se.pat.ringer.ringer1.inst.1.type' => ['silence'],
	'se.pat.ringer.ringer1.inst.1.value' => ['0'],
	'se.pat.ringer.ringer1.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.10.param' => ['0'],
	'se.pat.ringer.ringer1.inst.10.type' => [''],
	'se.pat.ringer.ringer1.inst.10.value' => [''],
	'se.pat.ringer.ringer1.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.11.param' => ['0'],
	'se.pat.ringer.ringer1.inst.11.type' => [''],
	'se.pat.ringer.ringer1.inst.11.value' => [''],
	'se.pat.ringer.ringer1.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.12.param' => ['0'],
	'se.pat.ringer.ringer1.inst.12.type' => [''],
	'se.pat.ringer.ringer1.inst.12.value' => [''],
	'se.pat.ringer.ringer1.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.13.param' => ['0'],
	'se.pat.ringer.ringer1.inst.13.type' => [''],
	'se.pat.ringer.ringer1.inst.13.value' => [''],
	'se.pat.ringer.ringer1.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.14.param' => ['0'],
	'se.pat.ringer.ringer1.inst.14.type' => [''],
	'se.pat.ringer.ringer1.inst.14.value' => [''],
	'se.pat.ringer.ringer1.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.15.param' => ['0'],
	'se.pat.ringer.ringer1.inst.15.type' => [''],
	'se.pat.ringer.ringer1.inst.15.value' => [''],
	'se.pat.ringer.ringer1.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.16.param' => ['0'],
	'se.pat.ringer.ringer1.inst.16.type' => [''],
	'se.pat.ringer.ringer1.inst.16.value' => [''],
	'se.pat.ringer.ringer1.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.17.param' => ['0'],
	'se.pat.ringer.ringer1.inst.17.type' => [''],
	'se.pat.ringer.ringer1.inst.17.value' => [''],
	'se.pat.ringer.ringer1.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.18.param' => ['0'],
	'se.pat.ringer.ringer1.inst.18.type' => [''],
	'se.pat.ringer.ringer1.inst.18.value' => [''],
	'se.pat.ringer.ringer1.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.19.param' => ['0'],
	'se.pat.ringer.ringer1.inst.19.type' => [''],
	'se.pat.ringer.ringer1.inst.19.value' => [''],
	'se.pat.ringer.ringer1.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.2.param' => ['0'],
	'se.pat.ringer.ringer1.inst.2.type' => [''],
	'se.pat.ringer.ringer1.inst.2.value' => [''],
	'se.pat.ringer.ringer1.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.20.param' => ['0'],
	'se.pat.ringer.ringer1.inst.20.type' => [''],
	'se.pat.ringer.ringer1.inst.20.value' => [''],
	'se.pat.ringer.ringer1.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.21.param' => ['0'],
	'se.pat.ringer.ringer1.inst.21.type' => [''],
	'se.pat.ringer.ringer1.inst.21.value' => [''],
	'se.pat.ringer.ringer1.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.22.param' => ['0'],
	'se.pat.ringer.ringer1.inst.22.type' => [''],
	'se.pat.ringer.ringer1.inst.22.value' => [''],
	'se.pat.ringer.ringer1.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.23.param' => ['0'],
	'se.pat.ringer.ringer1.inst.23.type' => [''],
	'se.pat.ringer.ringer1.inst.23.value' => [''],
	'se.pat.ringer.ringer1.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.24.param' => ['0'],
	'se.pat.ringer.ringer1.inst.24.type' => [''],
	'se.pat.ringer.ringer1.inst.24.value' => [''],
	'se.pat.ringer.ringer1.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.25.param' => ['0'],
	'se.pat.ringer.ringer1.inst.25.type' => [''],
	'se.pat.ringer.ringer1.inst.25.value' => [''],
	'se.pat.ringer.ringer1.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.26.param' => ['0'],
	'se.pat.ringer.ringer1.inst.26.type' => [''],
	'se.pat.ringer.ringer1.inst.26.value' => [''],
	'se.pat.ringer.ringer1.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.27.param' => ['0'],
	'se.pat.ringer.ringer1.inst.27.type' => [''],
	'se.pat.ringer.ringer1.inst.27.value' => [''],
	'se.pat.ringer.ringer1.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.28.param' => ['0'],
	'se.pat.ringer.ringer1.inst.28.type' => [''],
	'se.pat.ringer.ringer1.inst.28.value' => [''],
	'se.pat.ringer.ringer1.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.29.param' => ['0'],
	'se.pat.ringer.ringer1.inst.29.type' => [''],
	'se.pat.ringer.ringer1.inst.29.value' => [''],
	'se.pat.ringer.ringer1.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.3.param' => ['0'],
	'se.pat.ringer.ringer1.inst.3.type' => [''],
	'se.pat.ringer.ringer1.inst.3.value' => [''],
	'se.pat.ringer.ringer1.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.30.param' => ['0'],
	'se.pat.ringer.ringer1.inst.30.type' => [''],
	'se.pat.ringer.ringer1.inst.30.value' => [''],
	'se.pat.ringer.ringer1.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.31.param' => ['0'],
	'se.pat.ringer.ringer1.inst.31.type' => [''],
	'se.pat.ringer.ringer1.inst.31.value' => [''],
	'se.pat.ringer.ringer1.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.32.param' => ['0'],
	'se.pat.ringer.ringer1.inst.32.type' => [''],
	'se.pat.ringer.ringer1.inst.32.value' => [''],
	'se.pat.ringer.ringer1.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.4.param' => ['0'],
	'se.pat.ringer.ringer1.inst.4.type' => [''],
	'se.pat.ringer.ringer1.inst.4.value' => [''],
	'se.pat.ringer.ringer1.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.5.param' => ['0'],
	'se.pat.ringer.ringer1.inst.5.type' => [''],
	'se.pat.ringer.ringer1.inst.5.value' => [''],
	'se.pat.ringer.ringer1.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.6.param' => ['0'],
	'se.pat.ringer.ringer1.inst.6.type' => [''],
	'se.pat.ringer.ringer1.inst.6.value' => [''],
	'se.pat.ringer.ringer1.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.7.param' => ['0'],
	'se.pat.ringer.ringer1.inst.7.type' => [''],
	'se.pat.ringer.ringer1.inst.7.value' => [''],
	'se.pat.ringer.ringer1.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.8.param' => ['0'],
	'se.pat.ringer.ringer1.inst.8.type' => [''],
	'se.pat.ringer.ringer1.inst.8.value' => [''],
	'se.pat.ringer.ringer1.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer1.inst.9.param' => ['0'],
	'se.pat.ringer.ringer1.inst.9.type' => [''],
	'se.pat.ringer.ringer1.inst.9.value' => [''],
	'se.pat.ringer.ringer1.name' => ['Silent Ring'],
	'se.pat.ringer.ringer10.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.1.param' => ['0'],
	'se.pat.ringer.ringer10.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.1.value' => ['E3Major'],
	'se.pat.ringer.ringer10.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.10.param' => ['0'],
	'se.pat.ringer.ringer10.inst.10.type' => ['silence'],
	'se.pat.ringer.ringer10.inst.10.value' => ['2000'],
	'se.pat.ringer.ringer10.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.11.param' => ['0'],
	'se.pat.ringer.ringer10.inst.11.type' => ['branch'],
	'se.pat.ringer.ringer10.inst.11.value' => ['-10'],
	'se.pat.ringer.ringer10.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.12.param' => ['0'],
	'se.pat.ringer.ringer10.inst.12.type' => [''],
	'se.pat.ringer.ringer10.inst.12.value' => [''],
	'se.pat.ringer.ringer10.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.13.param' => ['0'],
	'se.pat.ringer.ringer10.inst.13.type' => [''],
	'se.pat.ringer.ringer10.inst.13.value' => [''],
	'se.pat.ringer.ringer10.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.14.param' => ['0'],
	'se.pat.ringer.ringer10.inst.14.type' => [''],
	'se.pat.ringer.ringer10.inst.14.value' => [''],
	'se.pat.ringer.ringer10.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.15.param' => ['0'],
	'se.pat.ringer.ringer10.inst.15.type' => [''],
	'se.pat.ringer.ringer10.inst.15.value' => [''],
	'se.pat.ringer.ringer10.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.16.param' => ['0'],
	'se.pat.ringer.ringer10.inst.16.type' => [''],
	'se.pat.ringer.ringer10.inst.16.value' => [''],
	'se.pat.ringer.ringer10.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.17.param' => ['0'],
	'se.pat.ringer.ringer10.inst.17.type' => [''],
	'se.pat.ringer.ringer10.inst.17.value' => [''],
	'se.pat.ringer.ringer10.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.18.param' => ['0'],
	'se.pat.ringer.ringer10.inst.18.type' => [''],
	'se.pat.ringer.ringer10.inst.18.value' => [''],
	'se.pat.ringer.ringer10.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.19.param' => ['0'],
	'se.pat.ringer.ringer10.inst.19.type' => [''],
	'se.pat.ringer.ringer10.inst.19.value' => [''],
	'se.pat.ringer.ringer10.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.2.param' => ['0'],
	'se.pat.ringer.ringer10.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.2.value' => ['F3Major'],
	'se.pat.ringer.ringer10.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.20.param' => ['0'],
	'se.pat.ringer.ringer10.inst.20.type' => [''],
	'se.pat.ringer.ringer10.inst.20.value' => [''],
	'se.pat.ringer.ringer10.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.21.param' => ['0'],
	'se.pat.ringer.ringer10.inst.21.type' => [''],
	'se.pat.ringer.ringer10.inst.21.value' => [''],
	'se.pat.ringer.ringer10.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.22.param' => ['0'],
	'se.pat.ringer.ringer10.inst.22.type' => [''],
	'se.pat.ringer.ringer10.inst.22.value' => [''],
	'se.pat.ringer.ringer10.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.23.param' => ['0'],
	'se.pat.ringer.ringer10.inst.23.type' => [''],
	'se.pat.ringer.ringer10.inst.23.value' => [''],
	'se.pat.ringer.ringer10.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.24.param' => ['0'],
	'se.pat.ringer.ringer10.inst.24.type' => [''],
	'se.pat.ringer.ringer10.inst.24.value' => [''],
	'se.pat.ringer.ringer10.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.25.param' => ['0'],
	'se.pat.ringer.ringer10.inst.25.type' => [''],
	'se.pat.ringer.ringer10.inst.25.value' => [''],
	'se.pat.ringer.ringer10.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.26.param' => ['0'],
	'se.pat.ringer.ringer10.inst.26.type' => [''],
	'se.pat.ringer.ringer10.inst.26.value' => [''],
	'se.pat.ringer.ringer10.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.27.param' => ['0'],
	'se.pat.ringer.ringer10.inst.27.type' => [''],
	'se.pat.ringer.ringer10.inst.27.value' => [''],
	'se.pat.ringer.ringer10.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.28.param' => ['0'],
	'se.pat.ringer.ringer10.inst.28.type' => [''],
	'se.pat.ringer.ringer10.inst.28.value' => [''],
	'se.pat.ringer.ringer10.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.29.param' => ['0'],
	'se.pat.ringer.ringer10.inst.29.type' => [''],
	'se.pat.ringer.ringer10.inst.29.value' => [''],
	'se.pat.ringer.ringer10.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.3.param' => ['0'],
	'se.pat.ringer.ringer10.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.3.value' => ['E3Major'],
	'se.pat.ringer.ringer10.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.30.param' => ['0'],
	'se.pat.ringer.ringer10.inst.30.type' => [''],
	'se.pat.ringer.ringer10.inst.30.value' => [''],
	'se.pat.ringer.ringer10.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.31.param' => ['0'],
	'se.pat.ringer.ringer10.inst.31.type' => [''],
	'se.pat.ringer.ringer10.inst.31.value' => [''],
	'se.pat.ringer.ringer10.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.32.param' => ['0'],
	'se.pat.ringer.ringer10.inst.32.type' => [''],
	'se.pat.ringer.ringer10.inst.32.value' => [''],
	'se.pat.ringer.ringer10.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.4.param' => ['0'],
	'se.pat.ringer.ringer10.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.4.value' => ['E3Major'],
	'se.pat.ringer.ringer10.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.5.param' => ['0'],
	'se.pat.ringer.ringer10.inst.5.type' => ['silence'],
	'se.pat.ringer.ringer10.inst.5.value' => ['200'],
	'se.pat.ringer.ringer10.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.6.param' => ['0'],
	'se.pat.ringer.ringer10.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.6.value' => ['E3Major'],
	'se.pat.ringer.ringer10.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.7.param' => ['0'],
	'se.pat.ringer.ringer10.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.7.value' => ['F3Major'],
	'se.pat.ringer.ringer10.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.8.param' => ['0'],
	'se.pat.ringer.ringer10.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.8.value' => ['E3Major'],
	'se.pat.ringer.ringer10.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer10.inst.9.param' => ['0'],
	'se.pat.ringer.ringer10.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer10.inst.9.value' => ['E3Major'],
	'se.pat.ringer.ringer10.name' => ['Beeble'],
	'se.pat.ringer.ringer11.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.1.param' => ['0'],
	'se.pat.ringer.ringer11.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.1.value' => ['C3Major'],
	'se.pat.ringer.ringer11.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.10.param' => ['0'],
	'se.pat.ringer.ringer11.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.10.value' => ['E3Major'],
	'se.pat.ringer.ringer11.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.11.param' => ['0'],
	'se.pat.ringer.ringer11.inst.11.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.11.value' => ['G3Major'],
	'se.pat.ringer.ringer11.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.12.param' => ['0'],
	'se.pat.ringer.ringer11.inst.12.type' => ['silence'],
	'se.pat.ringer.ringer11.inst.12.value' => ['2700'],
	'se.pat.ringer.ringer11.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.13.param' => ['0'],
	'se.pat.ringer.ringer11.inst.13.type' => ['branch'],
	'se.pat.ringer.ringer11.inst.13.value' => ['-12'],
	'se.pat.ringer.ringer11.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.14.param' => ['0'],
	'se.pat.ringer.ringer11.inst.14.type' => [''],
	'se.pat.ringer.ringer11.inst.14.value' => [''],
	'se.pat.ringer.ringer11.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.15.param' => ['0'],
	'se.pat.ringer.ringer11.inst.15.type' => [''],
	'se.pat.ringer.ringer11.inst.15.value' => [''],
	'se.pat.ringer.ringer11.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.16.param' => ['0'],
	'se.pat.ringer.ringer11.inst.16.type' => [''],
	'se.pat.ringer.ringer11.inst.16.value' => [''],
	'se.pat.ringer.ringer11.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.17.param' => ['0'],
	'se.pat.ringer.ringer11.inst.17.type' => [''],
	'se.pat.ringer.ringer11.inst.17.value' => [''],
	'se.pat.ringer.ringer11.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.18.param' => ['0'],
	'se.pat.ringer.ringer11.inst.18.type' => [''],
	'se.pat.ringer.ringer11.inst.18.value' => [''],
	'se.pat.ringer.ringer11.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.19.param' => ['0'],
	'se.pat.ringer.ringer11.inst.19.type' => [''],
	'se.pat.ringer.ringer11.inst.19.value' => [''],
	'se.pat.ringer.ringer11.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.2.param' => ['0'],
	'se.pat.ringer.ringer11.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.2.value' => ['E3Major'],
	'se.pat.ringer.ringer11.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.20.param' => ['0'],
	'se.pat.ringer.ringer11.inst.20.type' => [''],
	'se.pat.ringer.ringer11.inst.20.value' => [''],
	'se.pat.ringer.ringer11.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.21.param' => ['0'],
	'se.pat.ringer.ringer11.inst.21.type' => [''],
	'se.pat.ringer.ringer11.inst.21.value' => [''],
	'se.pat.ringer.ringer11.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.22.param' => ['0'],
	'se.pat.ringer.ringer11.inst.22.type' => [''],
	'se.pat.ringer.ringer11.inst.22.value' => [''],
	'se.pat.ringer.ringer11.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.23.param' => ['0'],
	'se.pat.ringer.ringer11.inst.23.type' => [''],
	'se.pat.ringer.ringer11.inst.23.value' => [''],
	'se.pat.ringer.ringer11.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.24.param' => ['0'],
	'se.pat.ringer.ringer11.inst.24.type' => [''],
	'se.pat.ringer.ringer11.inst.24.value' => [''],
	'se.pat.ringer.ringer11.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.25.param' => ['0'],
	'se.pat.ringer.ringer11.inst.25.type' => [''],
	'se.pat.ringer.ringer11.inst.25.value' => [''],
	'se.pat.ringer.ringer11.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.26.param' => ['0'],
	'se.pat.ringer.ringer11.inst.26.type' => [''],
	'se.pat.ringer.ringer11.inst.26.value' => [''],
	'se.pat.ringer.ringer11.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.27.param' => ['0'],
	'se.pat.ringer.ringer11.inst.27.type' => [''],
	'se.pat.ringer.ringer11.inst.27.value' => [''],
	'se.pat.ringer.ringer11.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.28.param' => ['0'],
	'se.pat.ringer.ringer11.inst.28.type' => [''],
	'se.pat.ringer.ringer11.inst.28.value' => [''],
	'se.pat.ringer.ringer11.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.29.param' => ['0'],
	'se.pat.ringer.ringer11.inst.29.type' => [''],
	'se.pat.ringer.ringer11.inst.29.value' => [''],
	'se.pat.ringer.ringer11.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.3.param' => ['0'],
	'se.pat.ringer.ringer11.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.3.value' => ['G3Major'],
	'se.pat.ringer.ringer11.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.30.param' => ['0'],
	'se.pat.ringer.ringer11.inst.30.type' => [''],
	'se.pat.ringer.ringer11.inst.30.value' => [''],
	'se.pat.ringer.ringer11.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.31.param' => ['0'],
	'se.pat.ringer.ringer11.inst.31.type' => [''],
	'se.pat.ringer.ringer11.inst.31.value' => [''],
	'se.pat.ringer.ringer11.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.32.param' => ['0'],
	'se.pat.ringer.ringer11.inst.32.type' => [''],
	'se.pat.ringer.ringer11.inst.32.value' => [''],
	'se.pat.ringer.ringer11.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.4.param' => ['0'],
	'se.pat.ringer.ringer11.inst.4.type' => ['silence'],
	'se.pat.ringer.ringer11.inst.4.value' => ['200'],
	'se.pat.ringer.ringer11.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.5.param' => ['0'],
	'se.pat.ringer.ringer11.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.5.value' => ['C3Major'],
	'se.pat.ringer.ringer11.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.6.param' => ['0'],
	'se.pat.ringer.ringer11.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.6.value' => ['E3Major'],
	'se.pat.ringer.ringer11.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.7.param' => ['0'],
	'se.pat.ringer.ringer11.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.7.value' => ['G3Major'],
	'se.pat.ringer.ringer11.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.8.param' => ['0'],
	'se.pat.ringer.ringer11.inst.8.type' => ['silence'],
	'se.pat.ringer.ringer11.inst.8.value' => ['200'],
	'se.pat.ringer.ringer11.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer11.inst.9.param' => ['0'],
	'se.pat.ringer.ringer11.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer11.inst.9.value' => ['C3Major'],
	'se.pat.ringer.ringer11.name' => ['Triplet'],
	'se.pat.ringer.ringer12.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.1.param' => ['0'],
	'se.pat.ringer.ringer12.inst.1.type' => ['silence', 'chord' ],
	'se.pat.ringer.ringer12.inst.1.value' => ['100', 'ringback' ],
	'se.pat.ringer.ringer12.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.10.param' => ['0'],
	'se.pat.ringer.ringer12.inst.10.type' => [''],
	'se.pat.ringer.ringer12.inst.10.value' => [''],
	'se.pat.ringer.ringer12.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.11.param' => ['0'],
	'se.pat.ringer.ringer12.inst.11.type' => [''],
	'se.pat.ringer.ringer12.inst.11.value' => [''],
	'se.pat.ringer.ringer12.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.12.param' => ['0'],
	'se.pat.ringer.ringer12.inst.12.type' => [''],
	'se.pat.ringer.ringer12.inst.12.value' => [''],
	'se.pat.ringer.ringer12.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.13.param' => ['0'],
	'se.pat.ringer.ringer12.inst.13.type' => [''],
	'se.pat.ringer.ringer12.inst.13.value' => [''],
	'se.pat.ringer.ringer12.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.14.param' => ['0'],
	'se.pat.ringer.ringer12.inst.14.type' => [''],
	'se.pat.ringer.ringer12.inst.14.value' => [''],
	'se.pat.ringer.ringer12.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.15.param' => ['0'],
	'se.pat.ringer.ringer12.inst.15.type' => [''],
	'se.pat.ringer.ringer12.inst.15.value' => [''],
	'se.pat.ringer.ringer12.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.16.param' => ['0'],
	'se.pat.ringer.ringer12.inst.16.type' => [''],
	'se.pat.ringer.ringer12.inst.16.value' => [''],
	'se.pat.ringer.ringer12.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.17.param' => ['0'],
	'se.pat.ringer.ringer12.inst.17.type' => [''],
	'se.pat.ringer.ringer12.inst.17.value' => [''],
	'se.pat.ringer.ringer12.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.18.param' => ['0'],
	'se.pat.ringer.ringer12.inst.18.type' => [''],
	'se.pat.ringer.ringer12.inst.18.value' => [''],
	'se.pat.ringer.ringer12.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.19.param' => ['0'],
	'se.pat.ringer.ringer12.inst.19.type' => [''],
	'se.pat.ringer.ringer12.inst.19.value' => [''],
	'se.pat.ringer.ringer12.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.2.param' => ['0'],
	'se.pat.ringer.ringer12.inst.2.type' => ['chord', 'silence' ],
	'se.pat.ringer.ringer12.inst.2.value' => ['ringback', 200 ],
	'se.pat.ringer.ringer12.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.20.param' => ['0'],
	'se.pat.ringer.ringer12.inst.20.type' => [''],
	'se.pat.ringer.ringer12.inst.20.value' => [''],
	'se.pat.ringer.ringer12.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.21.param' => ['0'],
	'se.pat.ringer.ringer12.inst.21.type' => [''],
	'se.pat.ringer.ringer12.inst.21.value' => [''],
	'se.pat.ringer.ringer12.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.22.param' => ['0'],
	'se.pat.ringer.ringer12.inst.22.type' => [''],
	'se.pat.ringer.ringer12.inst.22.value' => [''],
	'se.pat.ringer.ringer12.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.23.param' => ['0'],
	'se.pat.ringer.ringer12.inst.23.type' => [''],
	'se.pat.ringer.ringer12.inst.23.value' => [''],
	'se.pat.ringer.ringer12.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.24.param' => ['0'],
	'se.pat.ringer.ringer12.inst.24.type' => [''],
	'se.pat.ringer.ringer12.inst.24.value' => [''],
	'se.pat.ringer.ringer12.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.25.param' => ['0'],
	'se.pat.ringer.ringer12.inst.25.type' => [''],
	'se.pat.ringer.ringer12.inst.25.value' => [''],
	'se.pat.ringer.ringer12.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.26.param' => ['0'],
	'se.pat.ringer.ringer12.inst.26.type' => [''],
	'se.pat.ringer.ringer12.inst.26.value' => [''],
	'se.pat.ringer.ringer12.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.27.param' => ['0'],
	'se.pat.ringer.ringer12.inst.27.type' => [''],
	'se.pat.ringer.ringer12.inst.27.value' => [''],
	'se.pat.ringer.ringer12.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.28.param' => ['0'],
	'se.pat.ringer.ringer12.inst.28.type' => [''],
	'se.pat.ringer.ringer12.inst.28.value' => [''],
	'se.pat.ringer.ringer12.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.29.param' => ['0'],
	'se.pat.ringer.ringer12.inst.29.type' => [''],
	'se.pat.ringer.ringer12.inst.29.value' => [''],
	'se.pat.ringer.ringer12.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.3.param' => ['0'],
	'se.pat.ringer.ringer12.inst.3.type' => ['silence', 'chord' ],
	'se.pat.ringer.ringer12.inst.3.value' => ['200', 'ringback' ],
	'se.pat.ringer.ringer12.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.30.param' => ['0'],
	'se.pat.ringer.ringer12.inst.30.type' => [''],
	'se.pat.ringer.ringer12.inst.30.value' => [''],
	'se.pat.ringer.ringer12.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.31.param' => ['0'],
	'se.pat.ringer.ringer12.inst.31.type' => [''],
	'se.pat.ringer.ringer12.inst.31.value' => [''],
	'se.pat.ringer.ringer12.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.32.param' => ['0'],
	'se.pat.ringer.ringer12.inst.32.type' => [''],
	'se.pat.ringer.ringer12.inst.32.value' => [''],
	'se.pat.ringer.ringer12.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.4.param' => ['0'],
	'se.pat.ringer.ringer12.inst.4.type' => ['chord', 'silence' ],
	'se.pat.ringer.ringer12.inst.4.value' => ['ringback', 2000 ],
	'se.pat.ringer.ringer12.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.5.param' => ['0'],
	'se.pat.ringer.ringer12.inst.5.type' => ['silence', 'branch' ],
	'se.pat.ringer.ringer12.inst.5.value' => ['2000', -4 ],
	'se.pat.ringer.ringer12.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.6.param' => ['0'],
	'se.pat.ringer.ringer12.inst.6.type' => ['branch'],
	'se.pat.ringer.ringer12.inst.6.value' => ['-5'],
	'se.pat.ringer.ringer12.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.7.param' => ['0'],
	'se.pat.ringer.ringer12.inst.7.type' => [''],
	'se.pat.ringer.ringer12.inst.7.value' => [''],
	'se.pat.ringer.ringer12.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.8.param' => ['0'],
	'se.pat.ringer.ringer12.inst.8.type' => [''],
	'se.pat.ringer.ringer12.inst.8.value' => [''],
	'se.pat.ringer.ringer12.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer12.inst.9.param' => ['0'],
	'se.pat.ringer.ringer12.inst.9.type' => [''],
	'se.pat.ringer.ringer12.inst.9.value' => [''],
	'se.pat.ringer.ringer12.name' => ['Ringback-style'],
	'se.pat.ringer.ringer13.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.1.param' => ['0'],
	'se.pat.ringer.ringer13.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.1.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.10.param' => ['0'],
	'se.pat.ringer.ringer13.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.10.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.11.param' => ['0'],
	'se.pat.ringer.ringer13.inst.11.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.11.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.12.param' => ['0'],
	'se.pat.ringer.ringer13.inst.12.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.12.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.13.param' => ['0'],
	'se.pat.ringer.ringer13.inst.13.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.13.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.14.param' => ['0'],
	'se.pat.ringer.ringer13.inst.14.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.14.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.15.param' => ['0'],
	'se.pat.ringer.ringer13.inst.15.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.15.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.16.param' => ['0'],
	'se.pat.ringer.ringer13.inst.16.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.16.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.17.param' => ['0'],
	'se.pat.ringer.ringer13.inst.17.type' => ['silence'],
	'se.pat.ringer.ringer13.inst.17.value' => ['400'],
	'se.pat.ringer.ringer13.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.18.param' => ['0'],
	'se.pat.ringer.ringer13.inst.18.type' => ['branch'],
	'se.pat.ringer.ringer13.inst.18.value' => ['-17'],
	'se.pat.ringer.ringer13.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.19.param' => ['0'],
	'se.pat.ringer.ringer13.inst.19.type' => [''],
	'se.pat.ringer.ringer13.inst.19.value' => [''],
	'se.pat.ringer.ringer13.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.2.param' => ['0'],
	'se.pat.ringer.ringer13.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.2.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.20.param' => ['0'],
	'se.pat.ringer.ringer13.inst.20.type' => [''],
	'se.pat.ringer.ringer13.inst.20.value' => [''],
	'se.pat.ringer.ringer13.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.21.param' => ['0'],
	'se.pat.ringer.ringer13.inst.21.type' => [''],
	'se.pat.ringer.ringer13.inst.21.value' => [''],
	'se.pat.ringer.ringer13.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.22.param' => ['0'],
	'se.pat.ringer.ringer13.inst.22.type' => [''],
	'se.pat.ringer.ringer13.inst.22.value' => [''],
	'se.pat.ringer.ringer13.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.23.param' => ['0'],
	'se.pat.ringer.ringer13.inst.23.type' => [''],
	'se.pat.ringer.ringer13.inst.23.value' => [''],
	'se.pat.ringer.ringer13.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.24.param' => ['0'],
	'se.pat.ringer.ringer13.inst.24.type' => [''],
	'se.pat.ringer.ringer13.inst.24.value' => [''],
	'se.pat.ringer.ringer13.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.25.param' => ['0'],
	'se.pat.ringer.ringer13.inst.25.type' => [''],
	'se.pat.ringer.ringer13.inst.25.value' => [''],
	'se.pat.ringer.ringer13.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.26.param' => ['0'],
	'se.pat.ringer.ringer13.inst.26.type' => [''],
	'se.pat.ringer.ringer13.inst.26.value' => [''],
	'se.pat.ringer.ringer13.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.27.param' => ['0'],
	'se.pat.ringer.ringer13.inst.27.type' => [''],
	'se.pat.ringer.ringer13.inst.27.value' => [''],
	'se.pat.ringer.ringer13.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.28.param' => ['0'],
	'se.pat.ringer.ringer13.inst.28.type' => [''],
	'se.pat.ringer.ringer13.inst.28.value' => [''],
	'se.pat.ringer.ringer13.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.29.param' => ['0'],
	'se.pat.ringer.ringer13.inst.29.type' => [''],
	'se.pat.ringer.ringer13.inst.29.value' => [''],
	'se.pat.ringer.ringer13.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.3.param' => ['0'],
	'se.pat.ringer.ringer13.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.3.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.30.param' => ['0'],
	'se.pat.ringer.ringer13.inst.30.type' => [''],
	'se.pat.ringer.ringer13.inst.30.value' => [''],
	'se.pat.ringer.ringer13.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.31.param' => ['0'],
	'se.pat.ringer.ringer13.inst.31.type' => [''],
	'se.pat.ringer.ringer13.inst.31.value' => [''],
	'se.pat.ringer.ringer13.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.32.param' => ['0'],
	'se.pat.ringer.ringer13.inst.32.type' => [''],
	'se.pat.ringer.ringer13.inst.32.value' => [''],
	'se.pat.ringer.ringer13.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.4.param' => ['0'],
	'se.pat.ringer.ringer13.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.4.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.5.param' => ['0'],
	'se.pat.ringer.ringer13.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.5.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.6.param' => ['0'],
	'se.pat.ringer.ringer13.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.6.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.7.param' => ['0'],
	'se.pat.ringer.ringer13.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.7.value' => ['A3Major'],
	'se.pat.ringer.ringer13.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.8.param' => ['0'],
	'se.pat.ringer.ringer13.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.8.value' => ['Db3Major'],
	'se.pat.ringer.ringer13.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer13.inst.9.param' => ['0'],
	'se.pat.ringer.ringer13.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer13.inst.9.value' => ['A3Major'],
	'se.pat.ringer.ringer13.name' => ['Low Trill Precedence'],
	'se.pat.ringer.ringer14.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.1.param' => ['0'],
	'se.pat.ringer.ringer14.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer14.inst.1.value' => ['splash'],
	'se.pat.ringer.ringer14.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.10.param' => ['0'],
	'se.pat.ringer.ringer14.inst.10.type' => [''],
	'se.pat.ringer.ringer14.inst.10.value' => [''],
	'se.pat.ringer.ringer14.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.11.param' => ['0'],
	'se.pat.ringer.ringer14.inst.11.type' => [''],
	'se.pat.ringer.ringer14.inst.11.value' => [''],
	'se.pat.ringer.ringer14.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.12.param' => ['0'],
	'se.pat.ringer.ringer14.inst.12.type' => [''],
	'se.pat.ringer.ringer14.inst.12.value' => [''],
	'se.pat.ringer.ringer14.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.13.param' => ['0'],
	'se.pat.ringer.ringer14.inst.13.type' => [''],
	'se.pat.ringer.ringer14.inst.13.value' => [''],
	'se.pat.ringer.ringer14.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.14.param' => ['0'],
	'se.pat.ringer.ringer14.inst.14.type' => [''],
	'se.pat.ringer.ringer14.inst.14.value' => [''],
	'se.pat.ringer.ringer14.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.15.param' => ['0'],
	'se.pat.ringer.ringer14.inst.15.type' => [''],
	'se.pat.ringer.ringer14.inst.15.value' => [''],
	'se.pat.ringer.ringer14.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.16.param' => ['0'],
	'se.pat.ringer.ringer14.inst.16.type' => [''],
	'se.pat.ringer.ringer14.inst.16.value' => [''],
	'se.pat.ringer.ringer14.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.17.param' => ['0'],
	'se.pat.ringer.ringer14.inst.17.type' => [''],
	'se.pat.ringer.ringer14.inst.17.value' => [''],
	'se.pat.ringer.ringer14.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.18.param' => ['0'],
	'se.pat.ringer.ringer14.inst.18.type' => [''],
	'se.pat.ringer.ringer14.inst.18.value' => [''],
	'se.pat.ringer.ringer14.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.19.param' => ['0'],
	'se.pat.ringer.ringer14.inst.19.type' => [''],
	'se.pat.ringer.ringer14.inst.19.value' => [''],
	'se.pat.ringer.ringer14.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.2.param' => ['0'],
	'se.pat.ringer.ringer14.inst.2.type' => [''],
	'se.pat.ringer.ringer14.inst.2.value' => [''],
	'se.pat.ringer.ringer14.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.20.param' => ['0'],
	'se.pat.ringer.ringer14.inst.20.type' => [''],
	'se.pat.ringer.ringer14.inst.20.value' => [''],
	'se.pat.ringer.ringer14.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.21.param' => ['0'],
	'se.pat.ringer.ringer14.inst.21.type' => [''],
	'se.pat.ringer.ringer14.inst.21.value' => [''],
	'se.pat.ringer.ringer14.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.22.param' => ['0'],
	'se.pat.ringer.ringer14.inst.22.type' => [''],
	'se.pat.ringer.ringer14.inst.22.value' => [''],
	'se.pat.ringer.ringer14.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.23.param' => ['0'],
	'se.pat.ringer.ringer14.inst.23.type' => [''],
	'se.pat.ringer.ringer14.inst.23.value' => [''],
	'se.pat.ringer.ringer14.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.24.param' => ['0'],
	'se.pat.ringer.ringer14.inst.24.type' => [''],
	'se.pat.ringer.ringer14.inst.24.value' => [''],
	'se.pat.ringer.ringer14.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.25.param' => ['0'],
	'se.pat.ringer.ringer14.inst.25.type' => [''],
	'se.pat.ringer.ringer14.inst.25.value' => [''],
	'se.pat.ringer.ringer14.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.26.param' => ['0'],
	'se.pat.ringer.ringer14.inst.26.type' => [''],
	'se.pat.ringer.ringer14.inst.26.value' => [''],
	'se.pat.ringer.ringer14.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.27.param' => ['0'],
	'se.pat.ringer.ringer14.inst.27.type' => [''],
	'se.pat.ringer.ringer14.inst.27.value' => [''],
	'se.pat.ringer.ringer14.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.28.param' => ['0'],
	'se.pat.ringer.ringer14.inst.28.type' => [''],
	'se.pat.ringer.ringer14.inst.28.value' => [''],
	'se.pat.ringer.ringer14.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.29.param' => ['0'],
	'se.pat.ringer.ringer14.inst.29.type' => [''],
	'se.pat.ringer.ringer14.inst.29.value' => [''],
	'se.pat.ringer.ringer14.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.3.param' => ['0'],
	'se.pat.ringer.ringer14.inst.3.type' => [''],
	'se.pat.ringer.ringer14.inst.3.value' => [''],
	'se.pat.ringer.ringer14.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.30.param' => ['0'],
	'se.pat.ringer.ringer14.inst.30.type' => [''],
	'se.pat.ringer.ringer14.inst.30.value' => [''],
	'se.pat.ringer.ringer14.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.31.param' => ['0'],
	'se.pat.ringer.ringer14.inst.31.type' => [''],
	'se.pat.ringer.ringer14.inst.31.value' => [''],
	'se.pat.ringer.ringer14.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.32.param' => ['0'],
	'se.pat.ringer.ringer14.inst.32.type' => [''],
	'se.pat.ringer.ringer14.inst.32.value' => [''],
	'se.pat.ringer.ringer14.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.4.param' => ['0'],
	'se.pat.ringer.ringer14.inst.4.type' => [''],
	'se.pat.ringer.ringer14.inst.4.value' => [''],
	'se.pat.ringer.ringer14.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.5.param' => ['0'],
	'se.pat.ringer.ringer14.inst.5.type' => [''],
	'se.pat.ringer.ringer14.inst.5.value' => [''],
	'se.pat.ringer.ringer14.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.6.param' => ['0'],
	'se.pat.ringer.ringer14.inst.6.type' => [''],
	'se.pat.ringer.ringer14.inst.6.value' => [''],
	'se.pat.ringer.ringer14.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.7.param' => ['0'],
	'se.pat.ringer.ringer14.inst.7.type' => [''],
	'se.pat.ringer.ringer14.inst.7.value' => [''],
	'se.pat.ringer.ringer14.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.8.param' => ['0'],
	'se.pat.ringer.ringer14.inst.8.type' => [''],
	'se.pat.ringer.ringer14.inst.8.value' => [''],
	'se.pat.ringer.ringer14.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer14.inst.9.param' => ['0'],
	'se.pat.ringer.ringer14.inst.9.type' => [''],
	'se.pat.ringer.ringer14.inst.9.value' => [''],
	'se.pat.ringer.ringer14.name' => ['Ring Splash'],
	'se.pat.ringer.ringer15.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.1.param' => ['0'],
	'se.pat.ringer.ringer15.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer15.inst.1.value' => ['2'],
	'se.pat.ringer.ringer15.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.10.param' => ['0'],
	'se.pat.ringer.ringer15.inst.10.type' => [''],
	'se.pat.ringer.ringer15.inst.10.value' => [''],
	'se.pat.ringer.ringer15.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.11.param' => ['0'],
	'se.pat.ringer.ringer15.inst.11.type' => [''],
	'se.pat.ringer.ringer15.inst.11.value' => [''],
	'se.pat.ringer.ringer15.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.12.param' => ['0'],
	'se.pat.ringer.ringer15.inst.12.type' => [''],
	'se.pat.ringer.ringer15.inst.12.value' => [''],
	'se.pat.ringer.ringer15.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.13.param' => ['0'],
	'se.pat.ringer.ringer15.inst.13.type' => [''],
	'se.pat.ringer.ringer15.inst.13.value' => [''],
	'se.pat.ringer.ringer15.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.14.param' => ['0'],
	'se.pat.ringer.ringer15.inst.14.type' => [''],
	'se.pat.ringer.ringer15.inst.14.value' => [''],
	'se.pat.ringer.ringer15.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.15.param' => ['0'],
	'se.pat.ringer.ringer15.inst.15.type' => [''],
	'se.pat.ringer.ringer15.inst.15.value' => [''],
	'se.pat.ringer.ringer15.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.16.param' => ['0'],
	'se.pat.ringer.ringer15.inst.16.type' => [''],
	'se.pat.ringer.ringer15.inst.16.value' => [''],
	'se.pat.ringer.ringer15.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.17.param' => ['0'],
	'se.pat.ringer.ringer15.inst.17.type' => [''],
	'se.pat.ringer.ringer15.inst.17.value' => [''],
	'se.pat.ringer.ringer15.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.18.param' => ['0'],
	'se.pat.ringer.ringer15.inst.18.type' => [''],
	'se.pat.ringer.ringer15.inst.18.value' => [''],
	'se.pat.ringer.ringer15.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.19.param' => ['0'],
	'se.pat.ringer.ringer15.inst.19.type' => [''],
	'se.pat.ringer.ringer15.inst.19.value' => [''],
	'se.pat.ringer.ringer15.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.2.param' => ['0'],
	'se.pat.ringer.ringer15.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer15.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer15.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.20.param' => ['0'],
	'se.pat.ringer.ringer15.inst.20.type' => [''],
	'se.pat.ringer.ringer15.inst.20.value' => [''],
	'se.pat.ringer.ringer15.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.21.param' => ['0'],
	'se.pat.ringer.ringer15.inst.21.type' => [''],
	'se.pat.ringer.ringer15.inst.21.value' => [''],
	'se.pat.ringer.ringer15.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.22.param' => ['0'],
	'se.pat.ringer.ringer15.inst.22.type' => [''],
	'se.pat.ringer.ringer15.inst.22.value' => [''],
	'se.pat.ringer.ringer15.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.23.param' => ['0'],
	'se.pat.ringer.ringer15.inst.23.type' => [''],
	'se.pat.ringer.ringer15.inst.23.value' => [''],
	'se.pat.ringer.ringer15.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.24.param' => ['0'],
	'se.pat.ringer.ringer15.inst.24.type' => [''],
	'se.pat.ringer.ringer15.inst.24.value' => [''],
	'se.pat.ringer.ringer15.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.25.param' => ['0'],
	'se.pat.ringer.ringer15.inst.25.type' => [''],
	'se.pat.ringer.ringer15.inst.25.value' => [''],
	'se.pat.ringer.ringer15.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.26.param' => ['0'],
	'se.pat.ringer.ringer15.inst.26.type' => [''],
	'se.pat.ringer.ringer15.inst.26.value' => [''],
	'se.pat.ringer.ringer15.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.27.param' => ['0'],
	'se.pat.ringer.ringer15.inst.27.type' => [''],
	'se.pat.ringer.ringer15.inst.27.value' => [''],
	'se.pat.ringer.ringer15.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.28.param' => ['0'],
	'se.pat.ringer.ringer15.inst.28.type' => [''],
	'se.pat.ringer.ringer15.inst.28.value' => [''],
	'se.pat.ringer.ringer15.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.29.param' => ['0'],
	'se.pat.ringer.ringer15.inst.29.type' => [''],
	'se.pat.ringer.ringer15.inst.29.value' => [''],
	'se.pat.ringer.ringer15.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.3.param' => ['0'],
	'se.pat.ringer.ringer15.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer15.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer15.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.30.param' => ['0'],
	'se.pat.ringer.ringer15.inst.30.type' => [''],
	'se.pat.ringer.ringer15.inst.30.value' => [''],
	'se.pat.ringer.ringer15.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.31.param' => ['0'],
	'se.pat.ringer.ringer15.inst.31.type' => [''],
	'se.pat.ringer.ringer15.inst.31.value' => [''],
	'se.pat.ringer.ringer15.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.32.param' => ['0'],
	'se.pat.ringer.ringer15.inst.32.type' => [''],
	'se.pat.ringer.ringer15.inst.32.value' => [''],
	'se.pat.ringer.ringer15.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.4.param' => ['0'],
	'se.pat.ringer.ringer15.inst.4.type' => [''],
	'se.pat.ringer.ringer15.inst.4.value' => [''],
	'se.pat.ringer.ringer15.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.5.param' => ['0'],
	'se.pat.ringer.ringer15.inst.5.type' => [''],
	'se.pat.ringer.ringer15.inst.5.value' => [''],
	'se.pat.ringer.ringer15.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.6.param' => ['0'],
	'se.pat.ringer.ringer15.inst.6.type' => [''],
	'se.pat.ringer.ringer15.inst.6.value' => [''],
	'se.pat.ringer.ringer15.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.7.param' => ['0'],
	'se.pat.ringer.ringer15.inst.7.type' => [''],
	'se.pat.ringer.ringer15.inst.7.value' => [''],
	'se.pat.ringer.ringer15.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.8.param' => ['0'],
	'se.pat.ringer.ringer15.inst.8.type' => [''],
	'se.pat.ringer.ringer15.inst.8.value' => [''],
	'se.pat.ringer.ringer15.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer15.inst.9.param' => ['0'],
	'se.pat.ringer.ringer15.inst.9.type' => [''],
	'se.pat.ringer.ringer15.inst.9.value' => [''],
	'se.pat.ringer.ringer15.name' => ['', 'Sampled 1' ],
	'se.pat.ringer.ringer16.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.1.param' => ['0'],
	'se.pat.ringer.ringer16.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer16.inst.1.value' => ['3'],
	'se.pat.ringer.ringer16.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.10.param' => ['0'],
	'se.pat.ringer.ringer16.inst.10.type' => [''],
	'se.pat.ringer.ringer16.inst.10.value' => [''],
	'se.pat.ringer.ringer16.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.11.param' => ['0'],
	'se.pat.ringer.ringer16.inst.11.type' => [''],
	'se.pat.ringer.ringer16.inst.11.value' => [''],
	'se.pat.ringer.ringer16.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.12.param' => ['0'],
	'se.pat.ringer.ringer16.inst.12.type' => [''],
	'se.pat.ringer.ringer16.inst.12.value' => [''],
	'se.pat.ringer.ringer16.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.13.param' => ['0'],
	'se.pat.ringer.ringer16.inst.13.type' => [''],
	'se.pat.ringer.ringer16.inst.13.value' => [''],
	'se.pat.ringer.ringer16.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.14.param' => ['0'],
	'se.pat.ringer.ringer16.inst.14.type' => [''],
	'se.pat.ringer.ringer16.inst.14.value' => [''],
	'se.pat.ringer.ringer16.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.15.param' => ['0'],
	'se.pat.ringer.ringer16.inst.15.type' => [''],
	'se.pat.ringer.ringer16.inst.15.value' => [''],
	'se.pat.ringer.ringer16.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.16.param' => ['0'],
	'se.pat.ringer.ringer16.inst.16.type' => [''],
	'se.pat.ringer.ringer16.inst.16.value' => [''],
	'se.pat.ringer.ringer16.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.17.param' => ['0'],
	'se.pat.ringer.ringer16.inst.17.type' => [''],
	'se.pat.ringer.ringer16.inst.17.value' => [''],
	'se.pat.ringer.ringer16.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.18.param' => ['0'],
	'se.pat.ringer.ringer16.inst.18.type' => [''],
	'se.pat.ringer.ringer16.inst.18.value' => [''],
	'se.pat.ringer.ringer16.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.19.param' => ['0'],
	'se.pat.ringer.ringer16.inst.19.type' => [''],
	'se.pat.ringer.ringer16.inst.19.value' => [''],
	'se.pat.ringer.ringer16.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.2.param' => ['0'],
	'se.pat.ringer.ringer16.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer16.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer16.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.20.param' => ['0'],
	'se.pat.ringer.ringer16.inst.20.type' => [''],
	'se.pat.ringer.ringer16.inst.20.value' => [''],
	'se.pat.ringer.ringer16.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.21.param' => ['0'],
	'se.pat.ringer.ringer16.inst.21.type' => [''],
	'se.pat.ringer.ringer16.inst.21.value' => [''],
	'se.pat.ringer.ringer16.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.22.param' => ['0'],
	'se.pat.ringer.ringer16.inst.22.type' => [''],
	'se.pat.ringer.ringer16.inst.22.value' => [''],
	'se.pat.ringer.ringer16.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.23.param' => ['0'],
	'se.pat.ringer.ringer16.inst.23.type' => [''],
	'se.pat.ringer.ringer16.inst.23.value' => [''],
	'se.pat.ringer.ringer16.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.24.param' => ['0'],
	'se.pat.ringer.ringer16.inst.24.type' => [''],
	'se.pat.ringer.ringer16.inst.24.value' => [''],
	'se.pat.ringer.ringer16.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.25.param' => ['0'],
	'se.pat.ringer.ringer16.inst.25.type' => [''],
	'se.pat.ringer.ringer16.inst.25.value' => [''],
	'se.pat.ringer.ringer16.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.26.param' => ['0'],
	'se.pat.ringer.ringer16.inst.26.type' => [''],
	'se.pat.ringer.ringer16.inst.26.value' => [''],
	'se.pat.ringer.ringer16.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.27.param' => ['0'],
	'se.pat.ringer.ringer16.inst.27.type' => [''],
	'se.pat.ringer.ringer16.inst.27.value' => [''],
	'se.pat.ringer.ringer16.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.28.param' => ['0'],
	'se.pat.ringer.ringer16.inst.28.type' => [''],
	'se.pat.ringer.ringer16.inst.28.value' => [''],
	'se.pat.ringer.ringer16.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.29.param' => ['0'],
	'se.pat.ringer.ringer16.inst.29.type' => [''],
	'se.pat.ringer.ringer16.inst.29.value' => [''],
	'se.pat.ringer.ringer16.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.3.param' => ['0'],
	'se.pat.ringer.ringer16.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer16.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer16.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.30.param' => ['0'],
	'se.pat.ringer.ringer16.inst.30.type' => [''],
	'se.pat.ringer.ringer16.inst.30.value' => [''],
	'se.pat.ringer.ringer16.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.31.param' => ['0'],
	'se.pat.ringer.ringer16.inst.31.type' => [''],
	'se.pat.ringer.ringer16.inst.31.value' => [''],
	'se.pat.ringer.ringer16.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.32.param' => ['0'],
	'se.pat.ringer.ringer16.inst.32.type' => [''],
	'se.pat.ringer.ringer16.inst.32.value' => [''],
	'se.pat.ringer.ringer16.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.4.param' => ['0'],
	'se.pat.ringer.ringer16.inst.4.type' => [''],
	'se.pat.ringer.ringer16.inst.4.value' => [''],
	'se.pat.ringer.ringer16.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.5.param' => ['0'],
	'se.pat.ringer.ringer16.inst.5.type' => [''],
	'se.pat.ringer.ringer16.inst.5.value' => [''],
	'se.pat.ringer.ringer16.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.6.param' => ['0'],
	'se.pat.ringer.ringer16.inst.6.type' => [''],
	'se.pat.ringer.ringer16.inst.6.value' => [''],
	'se.pat.ringer.ringer16.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.7.param' => ['0'],
	'se.pat.ringer.ringer16.inst.7.type' => [''],
	'se.pat.ringer.ringer16.inst.7.value' => [''],
	'se.pat.ringer.ringer16.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.8.param' => ['0'],
	'se.pat.ringer.ringer16.inst.8.type' => [''],
	'se.pat.ringer.ringer16.inst.8.value' => [''],
	'se.pat.ringer.ringer16.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer16.inst.9.param' => ['0'],
	'se.pat.ringer.ringer16.inst.9.type' => [''],
	'se.pat.ringer.ringer16.inst.9.value' => [''],
	'se.pat.ringer.ringer16.name' => ['', 'Sampled 2' ],
	'se.pat.ringer.ringer17.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.1.param' => ['0'],
	'se.pat.ringer.ringer17.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer17.inst.1.value' => ['4'],
	'se.pat.ringer.ringer17.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.10.param' => ['0'],
	'se.pat.ringer.ringer17.inst.10.type' => [''],
	'se.pat.ringer.ringer17.inst.10.value' => [''],
	'se.pat.ringer.ringer17.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.11.param' => ['0'],
	'se.pat.ringer.ringer17.inst.11.type' => [''],
	'se.pat.ringer.ringer17.inst.11.value' => [''],
	'se.pat.ringer.ringer17.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.12.param' => ['0'],
	'se.pat.ringer.ringer17.inst.12.type' => [''],
	'se.pat.ringer.ringer17.inst.12.value' => [''],
	'se.pat.ringer.ringer17.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.13.param' => ['0'],
	'se.pat.ringer.ringer17.inst.13.type' => [''],
	'se.pat.ringer.ringer17.inst.13.value' => [''],
	'se.pat.ringer.ringer17.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.14.param' => ['0'],
	'se.pat.ringer.ringer17.inst.14.type' => [''],
	'se.pat.ringer.ringer17.inst.14.value' => [''],
	'se.pat.ringer.ringer17.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.15.param' => ['0'],
	'se.pat.ringer.ringer17.inst.15.type' => [''],
	'se.pat.ringer.ringer17.inst.15.value' => [''],
	'se.pat.ringer.ringer17.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.16.param' => ['0'],
	'se.pat.ringer.ringer17.inst.16.type' => [''],
	'se.pat.ringer.ringer17.inst.16.value' => [''],
	'se.pat.ringer.ringer17.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.17.param' => ['0'],
	'se.pat.ringer.ringer17.inst.17.type' => [''],
	'se.pat.ringer.ringer17.inst.17.value' => [''],
	'se.pat.ringer.ringer17.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.18.param' => ['0'],
	'se.pat.ringer.ringer17.inst.18.type' => [''],
	'se.pat.ringer.ringer17.inst.18.value' => [''],
	'se.pat.ringer.ringer17.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.19.param' => ['0'],
	'se.pat.ringer.ringer17.inst.19.type' => [''],
	'se.pat.ringer.ringer17.inst.19.value' => [''],
	'se.pat.ringer.ringer17.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.2.param' => ['0'],
	'se.pat.ringer.ringer17.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer17.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer17.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.20.param' => ['0'],
	'se.pat.ringer.ringer17.inst.20.type' => [''],
	'se.pat.ringer.ringer17.inst.20.value' => [''],
	'se.pat.ringer.ringer17.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.21.param' => ['0'],
	'se.pat.ringer.ringer17.inst.21.type' => [''],
	'se.pat.ringer.ringer17.inst.21.value' => [''],
	'se.pat.ringer.ringer17.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.22.param' => ['0'],
	'se.pat.ringer.ringer17.inst.22.type' => [''],
	'se.pat.ringer.ringer17.inst.22.value' => [''],
	'se.pat.ringer.ringer17.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.23.param' => ['0'],
	'se.pat.ringer.ringer17.inst.23.type' => [''],
	'se.pat.ringer.ringer17.inst.23.value' => [''],
	'se.pat.ringer.ringer17.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.24.param' => ['0'],
	'se.pat.ringer.ringer17.inst.24.type' => [''],
	'se.pat.ringer.ringer17.inst.24.value' => [''],
	'se.pat.ringer.ringer17.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.25.param' => ['0'],
	'se.pat.ringer.ringer17.inst.25.type' => [''],
	'se.pat.ringer.ringer17.inst.25.value' => [''],
	'se.pat.ringer.ringer17.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.26.param' => ['0'],
	'se.pat.ringer.ringer17.inst.26.type' => [''],
	'se.pat.ringer.ringer17.inst.26.value' => [''],
	'se.pat.ringer.ringer17.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.27.param' => ['0'],
	'se.pat.ringer.ringer17.inst.27.type' => [''],
	'se.pat.ringer.ringer17.inst.27.value' => [''],
	'se.pat.ringer.ringer17.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.28.param' => ['0'],
	'se.pat.ringer.ringer17.inst.28.type' => [''],
	'se.pat.ringer.ringer17.inst.28.value' => [''],
	'se.pat.ringer.ringer17.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.29.param' => ['0'],
	'se.pat.ringer.ringer17.inst.29.type' => [''],
	'se.pat.ringer.ringer17.inst.29.value' => [''],
	'se.pat.ringer.ringer17.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.3.param' => ['0'],
	'se.pat.ringer.ringer17.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer17.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer17.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.30.param' => ['0'],
	'se.pat.ringer.ringer17.inst.30.type' => [''],
	'se.pat.ringer.ringer17.inst.30.value' => [''],
	'se.pat.ringer.ringer17.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.31.param' => ['0'],
	'se.pat.ringer.ringer17.inst.31.type' => [''],
	'se.pat.ringer.ringer17.inst.31.value' => [''],
	'se.pat.ringer.ringer17.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.32.param' => ['0'],
	'se.pat.ringer.ringer17.inst.32.type' => [''],
	'se.pat.ringer.ringer17.inst.32.value' => [''],
	'se.pat.ringer.ringer17.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.4.param' => ['0'],
	'se.pat.ringer.ringer17.inst.4.type' => [''],
	'se.pat.ringer.ringer17.inst.4.value' => [''],
	'se.pat.ringer.ringer17.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.5.param' => ['0'],
	'se.pat.ringer.ringer17.inst.5.type' => [''],
	'se.pat.ringer.ringer17.inst.5.value' => [''],
	'se.pat.ringer.ringer17.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.6.param' => ['0'],
	'se.pat.ringer.ringer17.inst.6.type' => [''],
	'se.pat.ringer.ringer17.inst.6.value' => [''],
	'se.pat.ringer.ringer17.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.7.param' => ['0'],
	'se.pat.ringer.ringer17.inst.7.type' => [''],
	'se.pat.ringer.ringer17.inst.7.value' => [''],
	'se.pat.ringer.ringer17.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.8.param' => ['0'],
	'se.pat.ringer.ringer17.inst.8.type' => [''],
	'se.pat.ringer.ringer17.inst.8.value' => [''],
	'se.pat.ringer.ringer17.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer17.inst.9.param' => ['0'],
	'se.pat.ringer.ringer17.inst.9.type' => [''],
	'se.pat.ringer.ringer17.inst.9.value' => [''],
	'se.pat.ringer.ringer17.name' => ['', 'Sampled 3' ],
	'se.pat.ringer.ringer18.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.1.param' => ['0'],
	'se.pat.ringer.ringer18.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer18.inst.1.value' => ['5'],
	'se.pat.ringer.ringer18.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.10.param' => ['0'],
	'se.pat.ringer.ringer18.inst.10.type' => [''],
	'se.pat.ringer.ringer18.inst.10.value' => [''],
	'se.pat.ringer.ringer18.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.11.param' => ['0'],
	'se.pat.ringer.ringer18.inst.11.type' => [''],
	'se.pat.ringer.ringer18.inst.11.value' => [''],
	'se.pat.ringer.ringer18.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.12.param' => ['0'],
	'se.pat.ringer.ringer18.inst.12.type' => [''],
	'se.pat.ringer.ringer18.inst.12.value' => [''],
	'se.pat.ringer.ringer18.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.13.param' => ['0'],
	'se.pat.ringer.ringer18.inst.13.type' => [''],
	'se.pat.ringer.ringer18.inst.13.value' => [''],
	'se.pat.ringer.ringer18.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.14.param' => ['0'],
	'se.pat.ringer.ringer18.inst.14.type' => [''],
	'se.pat.ringer.ringer18.inst.14.value' => [''],
	'se.pat.ringer.ringer18.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.15.param' => ['0'],
	'se.pat.ringer.ringer18.inst.15.type' => [''],
	'se.pat.ringer.ringer18.inst.15.value' => [''],
	'se.pat.ringer.ringer18.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.16.param' => ['0'],
	'se.pat.ringer.ringer18.inst.16.type' => [''],
	'se.pat.ringer.ringer18.inst.16.value' => [''],
	'se.pat.ringer.ringer18.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.17.param' => ['0'],
	'se.pat.ringer.ringer18.inst.17.type' => [''],
	'se.pat.ringer.ringer18.inst.17.value' => [''],
	'se.pat.ringer.ringer18.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.18.param' => ['0'],
	'se.pat.ringer.ringer18.inst.18.type' => [''],
	'se.pat.ringer.ringer18.inst.18.value' => [''],
	'se.pat.ringer.ringer18.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.19.param' => ['0'],
	'se.pat.ringer.ringer18.inst.19.type' => [''],
	'se.pat.ringer.ringer18.inst.19.value' => [''],
	'se.pat.ringer.ringer18.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.2.param' => ['0'],
	'se.pat.ringer.ringer18.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer18.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer18.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.20.param' => ['0'],
	'se.pat.ringer.ringer18.inst.20.type' => [''],
	'se.pat.ringer.ringer18.inst.20.value' => [''],
	'se.pat.ringer.ringer18.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.21.param' => ['0'],
	'se.pat.ringer.ringer18.inst.21.type' => [''],
	'se.pat.ringer.ringer18.inst.21.value' => [''],
	'se.pat.ringer.ringer18.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.22.param' => ['0'],
	'se.pat.ringer.ringer18.inst.22.type' => [''],
	'se.pat.ringer.ringer18.inst.22.value' => [''],
	'se.pat.ringer.ringer18.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.23.param' => ['0'],
	'se.pat.ringer.ringer18.inst.23.type' => [''],
	'se.pat.ringer.ringer18.inst.23.value' => [''],
	'se.pat.ringer.ringer18.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.24.param' => ['0'],
	'se.pat.ringer.ringer18.inst.24.type' => [''],
	'se.pat.ringer.ringer18.inst.24.value' => [''],
	'se.pat.ringer.ringer18.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.25.param' => ['0'],
	'se.pat.ringer.ringer18.inst.25.type' => [''],
	'se.pat.ringer.ringer18.inst.25.value' => [''],
	'se.pat.ringer.ringer18.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.26.param' => ['0'],
	'se.pat.ringer.ringer18.inst.26.type' => [''],
	'se.pat.ringer.ringer18.inst.26.value' => [''],
	'se.pat.ringer.ringer18.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.27.param' => ['0'],
	'se.pat.ringer.ringer18.inst.27.type' => [''],
	'se.pat.ringer.ringer18.inst.27.value' => [''],
	'se.pat.ringer.ringer18.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.28.param' => ['0'],
	'se.pat.ringer.ringer18.inst.28.type' => [''],
	'se.pat.ringer.ringer18.inst.28.value' => [''],
	'se.pat.ringer.ringer18.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.29.param' => ['0'],
	'se.pat.ringer.ringer18.inst.29.type' => [''],
	'se.pat.ringer.ringer18.inst.29.value' => [''],
	'se.pat.ringer.ringer18.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.3.param' => ['0'],
	'se.pat.ringer.ringer18.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer18.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer18.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.30.param' => ['0'],
	'se.pat.ringer.ringer18.inst.30.type' => [''],
	'se.pat.ringer.ringer18.inst.30.value' => [''],
	'se.pat.ringer.ringer18.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.31.param' => ['0'],
	'se.pat.ringer.ringer18.inst.31.type' => [''],
	'se.pat.ringer.ringer18.inst.31.value' => [''],
	'se.pat.ringer.ringer18.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.32.param' => ['0'],
	'se.pat.ringer.ringer18.inst.32.type' => [''],
	'se.pat.ringer.ringer18.inst.32.value' => [''],
	'se.pat.ringer.ringer18.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.4.param' => ['0'],
	'se.pat.ringer.ringer18.inst.4.type' => [''],
	'se.pat.ringer.ringer18.inst.4.value' => [''],
	'se.pat.ringer.ringer18.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.5.param' => ['0'],
	'se.pat.ringer.ringer18.inst.5.type' => [''],
	'se.pat.ringer.ringer18.inst.5.value' => [''],
	'se.pat.ringer.ringer18.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.6.param' => ['0'],
	'se.pat.ringer.ringer18.inst.6.type' => [''],
	'se.pat.ringer.ringer18.inst.6.value' => [''],
	'se.pat.ringer.ringer18.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.7.param' => ['0'],
	'se.pat.ringer.ringer18.inst.7.type' => [''],
	'se.pat.ringer.ringer18.inst.7.value' => [''],
	'se.pat.ringer.ringer18.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.8.param' => ['0'],
	'se.pat.ringer.ringer18.inst.8.type' => [''],
	'se.pat.ringer.ringer18.inst.8.value' => [''],
	'se.pat.ringer.ringer18.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer18.inst.9.param' => ['0'],
	'se.pat.ringer.ringer18.inst.9.type' => [''],
	'se.pat.ringer.ringer18.inst.9.value' => [''],
	'se.pat.ringer.ringer18.name' => ['', 'Sampled 4' ],
	'se.pat.ringer.ringer19.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.1.param' => ['0'],
	'se.pat.ringer.ringer19.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer19.inst.1.value' => ['6'],
	'se.pat.ringer.ringer19.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.10.param' => ['0'],
	'se.pat.ringer.ringer19.inst.10.type' => [''],
	'se.pat.ringer.ringer19.inst.10.value' => [''],
	'se.pat.ringer.ringer19.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.11.param' => ['0'],
	'se.pat.ringer.ringer19.inst.11.type' => [''],
	'se.pat.ringer.ringer19.inst.11.value' => [''],
	'se.pat.ringer.ringer19.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.12.param' => ['0'],
	'se.pat.ringer.ringer19.inst.12.type' => [''],
	'se.pat.ringer.ringer19.inst.12.value' => [''],
	'se.pat.ringer.ringer19.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.13.param' => ['0'],
	'se.pat.ringer.ringer19.inst.13.type' => [''],
	'se.pat.ringer.ringer19.inst.13.value' => [''],
	'se.pat.ringer.ringer19.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.14.param' => ['0'],
	'se.pat.ringer.ringer19.inst.14.type' => [''],
	'se.pat.ringer.ringer19.inst.14.value' => [''],
	'se.pat.ringer.ringer19.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.15.param' => ['0'],
	'se.pat.ringer.ringer19.inst.15.type' => [''],
	'se.pat.ringer.ringer19.inst.15.value' => [''],
	'se.pat.ringer.ringer19.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.16.param' => ['0'],
	'se.pat.ringer.ringer19.inst.16.type' => [''],
	'se.pat.ringer.ringer19.inst.16.value' => [''],
	'se.pat.ringer.ringer19.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.17.param' => ['0'],
	'se.pat.ringer.ringer19.inst.17.type' => [''],
	'se.pat.ringer.ringer19.inst.17.value' => [''],
	'se.pat.ringer.ringer19.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.18.param' => ['0'],
	'se.pat.ringer.ringer19.inst.18.type' => [''],
	'se.pat.ringer.ringer19.inst.18.value' => [''],
	'se.pat.ringer.ringer19.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.19.param' => ['0'],
	'se.pat.ringer.ringer19.inst.19.type' => [''],
	'se.pat.ringer.ringer19.inst.19.value' => [''],
	'se.pat.ringer.ringer19.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.2.param' => ['0'],
	'se.pat.ringer.ringer19.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer19.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer19.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.20.param' => ['0'],
	'se.pat.ringer.ringer19.inst.20.type' => [''],
	'se.pat.ringer.ringer19.inst.20.value' => [''],
	'se.pat.ringer.ringer19.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.21.param' => ['0'],
	'se.pat.ringer.ringer19.inst.21.type' => [''],
	'se.pat.ringer.ringer19.inst.21.value' => [''],
	'se.pat.ringer.ringer19.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.22.param' => ['0'],
	'se.pat.ringer.ringer19.inst.22.type' => [''],
	'se.pat.ringer.ringer19.inst.22.value' => [''],
	'se.pat.ringer.ringer19.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.23.param' => ['0'],
	'se.pat.ringer.ringer19.inst.23.type' => [''],
	'se.pat.ringer.ringer19.inst.23.value' => [''],
	'se.pat.ringer.ringer19.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.24.param' => ['0'],
	'se.pat.ringer.ringer19.inst.24.type' => [''],
	'se.pat.ringer.ringer19.inst.24.value' => [''],
	'se.pat.ringer.ringer19.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.25.param' => ['0'],
	'se.pat.ringer.ringer19.inst.25.type' => [''],
	'se.pat.ringer.ringer19.inst.25.value' => [''],
	'se.pat.ringer.ringer19.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.26.param' => ['0'],
	'se.pat.ringer.ringer19.inst.26.type' => [''],
	'se.pat.ringer.ringer19.inst.26.value' => [''],
	'se.pat.ringer.ringer19.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.27.param' => ['0'],
	'se.pat.ringer.ringer19.inst.27.type' => [''],
	'se.pat.ringer.ringer19.inst.27.value' => [''],
	'se.pat.ringer.ringer19.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.28.param' => ['0'],
	'se.pat.ringer.ringer19.inst.28.type' => [''],
	'se.pat.ringer.ringer19.inst.28.value' => [''],
	'se.pat.ringer.ringer19.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.29.param' => ['0'],
	'se.pat.ringer.ringer19.inst.29.type' => [''],
	'se.pat.ringer.ringer19.inst.29.value' => [''],
	'se.pat.ringer.ringer19.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.3.param' => ['0'],
	'se.pat.ringer.ringer19.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer19.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer19.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.30.param' => ['0'],
	'se.pat.ringer.ringer19.inst.30.type' => [''],
	'se.pat.ringer.ringer19.inst.30.value' => [''],
	'se.pat.ringer.ringer19.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.31.param' => ['0'],
	'se.pat.ringer.ringer19.inst.31.type' => [''],
	'se.pat.ringer.ringer19.inst.31.value' => [''],
	'se.pat.ringer.ringer19.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.32.param' => ['0'],
	'se.pat.ringer.ringer19.inst.32.type' => [''],
	'se.pat.ringer.ringer19.inst.32.value' => [''],
	'se.pat.ringer.ringer19.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.4.param' => ['0'],
	'se.pat.ringer.ringer19.inst.4.type' => [''],
	'se.pat.ringer.ringer19.inst.4.value' => [''],
	'se.pat.ringer.ringer19.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.5.param' => ['0'],
	'se.pat.ringer.ringer19.inst.5.type' => [''],
	'se.pat.ringer.ringer19.inst.5.value' => [''],
	'se.pat.ringer.ringer19.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.6.param' => ['0'],
	'se.pat.ringer.ringer19.inst.6.type' => [''],
	'se.pat.ringer.ringer19.inst.6.value' => [''],
	'se.pat.ringer.ringer19.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.7.param' => ['0'],
	'se.pat.ringer.ringer19.inst.7.type' => [''],
	'se.pat.ringer.ringer19.inst.7.value' => [''],
	'se.pat.ringer.ringer19.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.8.param' => ['0'],
	'se.pat.ringer.ringer19.inst.8.type' => [''],
	'se.pat.ringer.ringer19.inst.8.value' => [''],
	'se.pat.ringer.ringer19.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer19.inst.9.param' => ['0'],
	'se.pat.ringer.ringer19.inst.9.type' => [''],
	'se.pat.ringer.ringer19.inst.9.value' => [''],
	'se.pat.ringer.ringer19.name' => ['', 'Sampled 5' ],
	'se.pat.ringer.ringer2.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.1.param' => ['0'],
	'se.pat.ringer.ringer2.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.1.value' => ['A3Major'],
	'se.pat.ringer.ringer2.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.10.param' => ['0'],
	'se.pat.ringer.ringer2.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.10.value' => ['Db3Major'],
	'se.pat.ringer.ringer2.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.11.param' => ['0'],
	'se.pat.ringer.ringer2.inst.11.type' => ['silence'],
	'se.pat.ringer.ringer2.inst.11.value' => ['3000'],
	'se.pat.ringer.ringer2.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.12.param' => ['0'],
	'se.pat.ringer.ringer2.inst.12.type' => ['branch'],
	'se.pat.ringer.ringer2.inst.12.value' => ['-11'],
	'se.pat.ringer.ringer2.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.13.param' => ['0'],
	'se.pat.ringer.ringer2.inst.13.type' => [''],
	'se.pat.ringer.ringer2.inst.13.value' => [''],
	'se.pat.ringer.ringer2.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.14.param' => ['0'],
	'se.pat.ringer.ringer2.inst.14.type' => [''],
	'se.pat.ringer.ringer2.inst.14.value' => [''],
	'se.pat.ringer.ringer2.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.15.param' => ['0'],
	'se.pat.ringer.ringer2.inst.15.type' => [''],
	'se.pat.ringer.ringer2.inst.15.value' => [''],
	'se.pat.ringer.ringer2.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.16.param' => ['0'],
	'se.pat.ringer.ringer2.inst.16.type' => [''],
	'se.pat.ringer.ringer2.inst.16.value' => [''],
	'se.pat.ringer.ringer2.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.17.param' => ['0'],
	'se.pat.ringer.ringer2.inst.17.type' => [''],
	'se.pat.ringer.ringer2.inst.17.value' => [''],
	'se.pat.ringer.ringer2.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.18.param' => ['0'],
	'se.pat.ringer.ringer2.inst.18.type' => [''],
	'se.pat.ringer.ringer2.inst.18.value' => [''],
	'se.pat.ringer.ringer2.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.19.param' => ['0'],
	'se.pat.ringer.ringer2.inst.19.type' => [''],
	'se.pat.ringer.ringer2.inst.19.value' => [''],
	'se.pat.ringer.ringer2.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.2.param' => ['0'],
	'se.pat.ringer.ringer2.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.2.value' => ['Db3Major'],
	'se.pat.ringer.ringer2.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.20.param' => ['0'],
	'se.pat.ringer.ringer2.inst.20.type' => [''],
	'se.pat.ringer.ringer2.inst.20.value' => [''],
	'se.pat.ringer.ringer2.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.21.param' => ['0'],
	'se.pat.ringer.ringer2.inst.21.type' => [''],
	'se.pat.ringer.ringer2.inst.21.value' => [''],
	'se.pat.ringer.ringer2.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.22.param' => ['0'],
	'se.pat.ringer.ringer2.inst.22.type' => [''],
	'se.pat.ringer.ringer2.inst.22.value' => [''],
	'se.pat.ringer.ringer2.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.23.param' => ['0'],
	'se.pat.ringer.ringer2.inst.23.type' => [''],
	'se.pat.ringer.ringer2.inst.23.value' => [''],
	'se.pat.ringer.ringer2.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.24.param' => ['0'],
	'se.pat.ringer.ringer2.inst.24.type' => [''],
	'se.pat.ringer.ringer2.inst.24.value' => [''],
	'se.pat.ringer.ringer2.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.25.param' => ['0'],
	'se.pat.ringer.ringer2.inst.25.type' => [''],
	'se.pat.ringer.ringer2.inst.25.value' => [''],
	'se.pat.ringer.ringer2.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.26.param' => ['0'],
	'se.pat.ringer.ringer2.inst.26.type' => [''],
	'se.pat.ringer.ringer2.inst.26.value' => [''],
	'se.pat.ringer.ringer2.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.27.param' => ['0'],
	'se.pat.ringer.ringer2.inst.27.type' => [''],
	'se.pat.ringer.ringer2.inst.27.value' => [''],
	'se.pat.ringer.ringer2.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.28.param' => ['0'],
	'se.pat.ringer.ringer2.inst.28.type' => [''],
	'se.pat.ringer.ringer2.inst.28.value' => [''],
	'se.pat.ringer.ringer2.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.29.param' => ['0'],
	'se.pat.ringer.ringer2.inst.29.type' => [''],
	'se.pat.ringer.ringer2.inst.29.value' => [''],
	'se.pat.ringer.ringer2.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.3.param' => ['0'],
	'se.pat.ringer.ringer2.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.3.value' => ['A3Major'],
	'se.pat.ringer.ringer2.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.30.param' => ['0'],
	'se.pat.ringer.ringer2.inst.30.type' => [''],
	'se.pat.ringer.ringer2.inst.30.value' => [''],
	'se.pat.ringer.ringer2.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.31.param' => ['0'],
	'se.pat.ringer.ringer2.inst.31.type' => [''],
	'se.pat.ringer.ringer2.inst.31.value' => [''],
	'se.pat.ringer.ringer2.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.32.param' => ['0'],
	'se.pat.ringer.ringer2.inst.32.type' => [''],
	'se.pat.ringer.ringer2.inst.32.value' => [''],
	'se.pat.ringer.ringer2.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.4.param' => ['0'],
	'se.pat.ringer.ringer2.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.4.value' => ['Db3Major'],
	'se.pat.ringer.ringer2.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.5.param' => ['0'],
	'se.pat.ringer.ringer2.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.5.value' => ['A3Major'],
	'se.pat.ringer.ringer2.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.6.param' => ['0'],
	'se.pat.ringer.ringer2.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.6.value' => ['Db3Major'],
	'se.pat.ringer.ringer2.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.7.param' => ['0'],
	'se.pat.ringer.ringer2.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.7.value' => ['A3Major'],
	'se.pat.ringer.ringer2.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.8.param' => ['0'],
	'se.pat.ringer.ringer2.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.8.value' => ['Db3Major'],
	'se.pat.ringer.ringer2.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer2.inst.9.param' => ['0'],
	'se.pat.ringer.ringer2.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer2.inst.9.value' => ['A3Major'],
	'se.pat.ringer.ringer2.name' => ['Low Trill'],
	'se.pat.ringer.ringer20.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.1.param' => ['0'],
	'se.pat.ringer.ringer20.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer20.inst.1.value' => ['7'],
	'se.pat.ringer.ringer20.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.10.param' => ['0'],
	'se.pat.ringer.ringer20.inst.10.type' => [''],
	'se.pat.ringer.ringer20.inst.10.value' => [''],
	'se.pat.ringer.ringer20.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.11.param' => ['0'],
	'se.pat.ringer.ringer20.inst.11.type' => [''],
	'se.pat.ringer.ringer20.inst.11.value' => [''],
	'se.pat.ringer.ringer20.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.12.param' => ['0'],
	'se.pat.ringer.ringer20.inst.12.type' => [''],
	'se.pat.ringer.ringer20.inst.12.value' => [''],
	'se.pat.ringer.ringer20.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.13.param' => ['0'],
	'se.pat.ringer.ringer20.inst.13.type' => [''],
	'se.pat.ringer.ringer20.inst.13.value' => [''],
	'se.pat.ringer.ringer20.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.14.param' => ['0'],
	'se.pat.ringer.ringer20.inst.14.type' => [''],
	'se.pat.ringer.ringer20.inst.14.value' => [''],
	'se.pat.ringer.ringer20.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.15.param' => ['0'],
	'se.pat.ringer.ringer20.inst.15.type' => [''],
	'se.pat.ringer.ringer20.inst.15.value' => [''],
	'se.pat.ringer.ringer20.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.16.param' => ['0'],
	'se.pat.ringer.ringer20.inst.16.type' => [''],
	'se.pat.ringer.ringer20.inst.16.value' => [''],
	'se.pat.ringer.ringer20.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.17.param' => ['0'],
	'se.pat.ringer.ringer20.inst.17.type' => [''],
	'se.pat.ringer.ringer20.inst.17.value' => [''],
	'se.pat.ringer.ringer20.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.18.param' => ['0'],
	'se.pat.ringer.ringer20.inst.18.type' => [''],
	'se.pat.ringer.ringer20.inst.18.value' => [''],
	'se.pat.ringer.ringer20.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.19.param' => ['0'],
	'se.pat.ringer.ringer20.inst.19.type' => [''],
	'se.pat.ringer.ringer20.inst.19.value' => [''],
	'se.pat.ringer.ringer20.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.2.param' => ['0'],
	'se.pat.ringer.ringer20.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer20.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer20.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.20.param' => ['0'],
	'se.pat.ringer.ringer20.inst.20.type' => [''],
	'se.pat.ringer.ringer20.inst.20.value' => [''],
	'se.pat.ringer.ringer20.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.21.param' => ['0'],
	'se.pat.ringer.ringer20.inst.21.type' => [''],
	'se.pat.ringer.ringer20.inst.21.value' => [''],
	'se.pat.ringer.ringer20.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.22.param' => ['0'],
	'se.pat.ringer.ringer20.inst.22.type' => [''],
	'se.pat.ringer.ringer20.inst.22.value' => [''],
	'se.pat.ringer.ringer20.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.23.param' => ['0'],
	'se.pat.ringer.ringer20.inst.23.type' => [''],
	'se.pat.ringer.ringer20.inst.23.value' => [''],
	'se.pat.ringer.ringer20.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.24.param' => ['0'],
	'se.pat.ringer.ringer20.inst.24.type' => [''],
	'se.pat.ringer.ringer20.inst.24.value' => [''],
	'se.pat.ringer.ringer20.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.25.param' => ['0'],
	'se.pat.ringer.ringer20.inst.25.type' => [''],
	'se.pat.ringer.ringer20.inst.25.value' => [''],
	'se.pat.ringer.ringer20.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.26.param' => ['0'],
	'se.pat.ringer.ringer20.inst.26.type' => [''],
	'se.pat.ringer.ringer20.inst.26.value' => [''],
	'se.pat.ringer.ringer20.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.27.param' => ['0'],
	'se.pat.ringer.ringer20.inst.27.type' => [''],
	'se.pat.ringer.ringer20.inst.27.value' => [''],
	'se.pat.ringer.ringer20.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.28.param' => ['0'],
	'se.pat.ringer.ringer20.inst.28.type' => [''],
	'se.pat.ringer.ringer20.inst.28.value' => [''],
	'se.pat.ringer.ringer20.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.29.param' => ['0'],
	'se.pat.ringer.ringer20.inst.29.type' => [''],
	'se.pat.ringer.ringer20.inst.29.value' => [''],
	'se.pat.ringer.ringer20.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.3.param' => ['0'],
	'se.pat.ringer.ringer20.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer20.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer20.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.30.param' => ['0'],
	'se.pat.ringer.ringer20.inst.30.type' => [''],
	'se.pat.ringer.ringer20.inst.30.value' => [''],
	'se.pat.ringer.ringer20.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.31.param' => ['0'],
	'se.pat.ringer.ringer20.inst.31.type' => [''],
	'se.pat.ringer.ringer20.inst.31.value' => [''],
	'se.pat.ringer.ringer20.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.32.param' => ['0'],
	'se.pat.ringer.ringer20.inst.32.type' => [''],
	'se.pat.ringer.ringer20.inst.32.value' => [''],
	'se.pat.ringer.ringer20.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.4.param' => ['0'],
	'se.pat.ringer.ringer20.inst.4.type' => [''],
	'se.pat.ringer.ringer20.inst.4.value' => [''],
	'se.pat.ringer.ringer20.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.5.param' => ['0'],
	'se.pat.ringer.ringer20.inst.5.type' => [''],
	'se.pat.ringer.ringer20.inst.5.value' => [''],
	'se.pat.ringer.ringer20.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.6.param' => ['0'],
	'se.pat.ringer.ringer20.inst.6.type' => [''],
	'se.pat.ringer.ringer20.inst.6.value' => [''],
	'se.pat.ringer.ringer20.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.7.param' => ['0'],
	'se.pat.ringer.ringer20.inst.7.type' => [''],
	'se.pat.ringer.ringer20.inst.7.value' => [''],
	'se.pat.ringer.ringer20.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.8.param' => ['0'],
	'se.pat.ringer.ringer20.inst.8.type' => [''],
	'se.pat.ringer.ringer20.inst.8.value' => [''],
	'se.pat.ringer.ringer20.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer20.inst.9.param' => ['0'],
	'se.pat.ringer.ringer20.inst.9.type' => [''],
	'se.pat.ringer.ringer20.inst.9.value' => [''],
	'se.pat.ringer.ringer20.name' => ['', 'Sampled 6' ],
	'se.pat.ringer.ringer21.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.1.param' => ['0'],
	'se.pat.ringer.ringer21.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer21.inst.1.value' => ['8'],
	'se.pat.ringer.ringer21.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.10.param' => ['0'],
	'se.pat.ringer.ringer21.inst.10.type' => [''],
	'se.pat.ringer.ringer21.inst.10.value' => [''],
	'se.pat.ringer.ringer21.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.11.param' => ['0'],
	'se.pat.ringer.ringer21.inst.11.type' => [''],
	'se.pat.ringer.ringer21.inst.11.value' => [''],
	'se.pat.ringer.ringer21.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.12.param' => ['0'],
	'se.pat.ringer.ringer21.inst.12.type' => [''],
	'se.pat.ringer.ringer21.inst.12.value' => [''],
	'se.pat.ringer.ringer21.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.13.param' => ['0'],
	'se.pat.ringer.ringer21.inst.13.type' => [''],
	'se.pat.ringer.ringer21.inst.13.value' => [''],
	'se.pat.ringer.ringer21.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.14.param' => ['0'],
	'se.pat.ringer.ringer21.inst.14.type' => [''],
	'se.pat.ringer.ringer21.inst.14.value' => [''],
	'se.pat.ringer.ringer21.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.15.param' => ['0'],
	'se.pat.ringer.ringer21.inst.15.type' => [''],
	'se.pat.ringer.ringer21.inst.15.value' => [''],
	'se.pat.ringer.ringer21.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.16.param' => ['0'],
	'se.pat.ringer.ringer21.inst.16.type' => [''],
	'se.pat.ringer.ringer21.inst.16.value' => [''],
	'se.pat.ringer.ringer21.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.17.param' => ['0'],
	'se.pat.ringer.ringer21.inst.17.type' => [''],
	'se.pat.ringer.ringer21.inst.17.value' => [''],
	'se.pat.ringer.ringer21.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.18.param' => ['0'],
	'se.pat.ringer.ringer21.inst.18.type' => [''],
	'se.pat.ringer.ringer21.inst.18.value' => [''],
	'se.pat.ringer.ringer21.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.19.param' => ['0'],
	'se.pat.ringer.ringer21.inst.19.type' => [''],
	'se.pat.ringer.ringer21.inst.19.value' => [''],
	'se.pat.ringer.ringer21.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.2.param' => ['0'],
	'se.pat.ringer.ringer21.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer21.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer21.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.20.param' => ['0'],
	'se.pat.ringer.ringer21.inst.20.type' => [''],
	'se.pat.ringer.ringer21.inst.20.value' => [''],
	'se.pat.ringer.ringer21.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.21.param' => ['0'],
	'se.pat.ringer.ringer21.inst.21.type' => [''],
	'se.pat.ringer.ringer21.inst.21.value' => [''],
	'se.pat.ringer.ringer21.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.22.param' => ['0'],
	'se.pat.ringer.ringer21.inst.22.type' => [''],
	'se.pat.ringer.ringer21.inst.22.value' => [''],
	'se.pat.ringer.ringer21.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.23.param' => ['0'],
	'se.pat.ringer.ringer21.inst.23.type' => [''],
	'se.pat.ringer.ringer21.inst.23.value' => [''],
	'se.pat.ringer.ringer21.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.24.param' => ['0'],
	'se.pat.ringer.ringer21.inst.24.type' => [''],
	'se.pat.ringer.ringer21.inst.24.value' => [''],
	'se.pat.ringer.ringer21.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.25.param' => ['0'],
	'se.pat.ringer.ringer21.inst.25.type' => [''],
	'se.pat.ringer.ringer21.inst.25.value' => [''],
	'se.pat.ringer.ringer21.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.26.param' => ['0'],
	'se.pat.ringer.ringer21.inst.26.type' => [''],
	'se.pat.ringer.ringer21.inst.26.value' => [''],
	'se.pat.ringer.ringer21.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.27.param' => ['0'],
	'se.pat.ringer.ringer21.inst.27.type' => [''],
	'se.pat.ringer.ringer21.inst.27.value' => [''],
	'se.pat.ringer.ringer21.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.28.param' => ['0'],
	'se.pat.ringer.ringer21.inst.28.type' => [''],
	'se.pat.ringer.ringer21.inst.28.value' => [''],
	'se.pat.ringer.ringer21.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.29.param' => ['0'],
	'se.pat.ringer.ringer21.inst.29.type' => [''],
	'se.pat.ringer.ringer21.inst.29.value' => [''],
	'se.pat.ringer.ringer21.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.3.param' => ['0'],
	'se.pat.ringer.ringer21.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer21.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer21.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.30.param' => ['0'],
	'se.pat.ringer.ringer21.inst.30.type' => [''],
	'se.pat.ringer.ringer21.inst.30.value' => [''],
	'se.pat.ringer.ringer21.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.31.param' => ['0'],
	'se.pat.ringer.ringer21.inst.31.type' => [''],
	'se.pat.ringer.ringer21.inst.31.value' => [''],
	'se.pat.ringer.ringer21.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.32.param' => ['0'],
	'se.pat.ringer.ringer21.inst.32.type' => [''],
	'se.pat.ringer.ringer21.inst.32.value' => [''],
	'se.pat.ringer.ringer21.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.4.param' => ['0'],
	'se.pat.ringer.ringer21.inst.4.type' => [''],
	'se.pat.ringer.ringer21.inst.4.value' => [''],
	'se.pat.ringer.ringer21.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.5.param' => ['0'],
	'se.pat.ringer.ringer21.inst.5.type' => [''],
	'se.pat.ringer.ringer21.inst.5.value' => [''],
	'se.pat.ringer.ringer21.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.6.param' => ['0'],
	'se.pat.ringer.ringer21.inst.6.type' => [''],
	'se.pat.ringer.ringer21.inst.6.value' => [''],
	'se.pat.ringer.ringer21.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.7.param' => ['0'],
	'se.pat.ringer.ringer21.inst.7.type' => [''],
	'se.pat.ringer.ringer21.inst.7.value' => [''],
	'se.pat.ringer.ringer21.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.8.param' => ['0'],
	'se.pat.ringer.ringer21.inst.8.type' => [''],
	'se.pat.ringer.ringer21.inst.8.value' => [''],
	'se.pat.ringer.ringer21.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer21.inst.9.param' => ['0'],
	'se.pat.ringer.ringer21.inst.9.type' => [''],
	'se.pat.ringer.ringer21.inst.9.value' => [''],
	'se.pat.ringer.ringer21.name' => ['', 'Sampled 7' ],
	'se.pat.ringer.ringer22.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.1.param' => ['0'],
	'se.pat.ringer.ringer22.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer22.inst.1.value' => ['9'],
	'se.pat.ringer.ringer22.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.10.param' => ['0'],
	'se.pat.ringer.ringer22.inst.10.type' => [''],
	'se.pat.ringer.ringer22.inst.10.value' => [''],
	'se.pat.ringer.ringer22.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.11.param' => ['0'],
	'se.pat.ringer.ringer22.inst.11.type' => [''],
	'se.pat.ringer.ringer22.inst.11.value' => [''],
	'se.pat.ringer.ringer22.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.12.param' => ['0'],
	'se.pat.ringer.ringer22.inst.12.type' => [''],
	'se.pat.ringer.ringer22.inst.12.value' => [''],
	'se.pat.ringer.ringer22.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.13.param' => ['0'],
	'se.pat.ringer.ringer22.inst.13.type' => [''],
	'se.pat.ringer.ringer22.inst.13.value' => [''],
	'se.pat.ringer.ringer22.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.14.param' => ['0'],
	'se.pat.ringer.ringer22.inst.14.type' => [''],
	'se.pat.ringer.ringer22.inst.14.value' => [''],
	'se.pat.ringer.ringer22.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.15.param' => ['0'],
	'se.pat.ringer.ringer22.inst.15.type' => [''],
	'se.pat.ringer.ringer22.inst.15.value' => [''],
	'se.pat.ringer.ringer22.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.16.param' => ['0'],
	'se.pat.ringer.ringer22.inst.16.type' => [''],
	'se.pat.ringer.ringer22.inst.16.value' => [''],
	'se.pat.ringer.ringer22.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.17.param' => ['0'],
	'se.pat.ringer.ringer22.inst.17.type' => [''],
	'se.pat.ringer.ringer22.inst.17.value' => [''],
	'se.pat.ringer.ringer22.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.18.param' => ['0'],
	'se.pat.ringer.ringer22.inst.18.type' => [''],
	'se.pat.ringer.ringer22.inst.18.value' => [''],
	'se.pat.ringer.ringer22.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.19.param' => ['0'],
	'se.pat.ringer.ringer22.inst.19.type' => [''],
	'se.pat.ringer.ringer22.inst.19.value' => [''],
	'se.pat.ringer.ringer22.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.2.param' => ['0'],
	'se.pat.ringer.ringer22.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer22.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer22.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.20.param' => ['0'],
	'se.pat.ringer.ringer22.inst.20.type' => [''],
	'se.pat.ringer.ringer22.inst.20.value' => [''],
	'se.pat.ringer.ringer22.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.21.param' => ['0'],
	'se.pat.ringer.ringer22.inst.21.type' => [''],
	'se.pat.ringer.ringer22.inst.21.value' => [''],
	'se.pat.ringer.ringer22.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.22.param' => ['0'],
	'se.pat.ringer.ringer22.inst.22.type' => [''],
	'se.pat.ringer.ringer22.inst.22.value' => [''],
	'se.pat.ringer.ringer22.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.23.param' => ['0'],
	'se.pat.ringer.ringer22.inst.23.type' => [''],
	'se.pat.ringer.ringer22.inst.23.value' => [''],
	'se.pat.ringer.ringer22.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.24.param' => ['0'],
	'se.pat.ringer.ringer22.inst.24.type' => [''],
	'se.pat.ringer.ringer22.inst.24.value' => [''],
	'se.pat.ringer.ringer22.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.25.param' => ['0'],
	'se.pat.ringer.ringer22.inst.25.type' => [''],
	'se.pat.ringer.ringer22.inst.25.value' => [''],
	'se.pat.ringer.ringer22.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.26.param' => ['0'],
	'se.pat.ringer.ringer22.inst.26.type' => [''],
	'se.pat.ringer.ringer22.inst.26.value' => [''],
	'se.pat.ringer.ringer22.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.27.param' => ['0'],
	'se.pat.ringer.ringer22.inst.27.type' => [''],
	'se.pat.ringer.ringer22.inst.27.value' => [''],
	'se.pat.ringer.ringer22.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.28.param' => ['0'],
	'se.pat.ringer.ringer22.inst.28.type' => [''],
	'se.pat.ringer.ringer22.inst.28.value' => [''],
	'se.pat.ringer.ringer22.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.29.param' => ['0'],
	'se.pat.ringer.ringer22.inst.29.type' => [''],
	'se.pat.ringer.ringer22.inst.29.value' => [''],
	'se.pat.ringer.ringer22.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.3.param' => ['0'],
	'se.pat.ringer.ringer22.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer22.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer22.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.30.param' => ['0'],
	'se.pat.ringer.ringer22.inst.30.type' => [''],
	'se.pat.ringer.ringer22.inst.30.value' => [''],
	'se.pat.ringer.ringer22.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.31.param' => ['0'],
	'se.pat.ringer.ringer22.inst.31.type' => [''],
	'se.pat.ringer.ringer22.inst.31.value' => [''],
	'se.pat.ringer.ringer22.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.32.param' => ['0'],
	'se.pat.ringer.ringer22.inst.32.type' => [''],
	'se.pat.ringer.ringer22.inst.32.value' => [''],
	'se.pat.ringer.ringer22.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.4.param' => ['0'],
	'se.pat.ringer.ringer22.inst.4.type' => [''],
	'se.pat.ringer.ringer22.inst.4.value' => [''],
	'se.pat.ringer.ringer22.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.5.param' => ['0'],
	'se.pat.ringer.ringer22.inst.5.type' => [''],
	'se.pat.ringer.ringer22.inst.5.value' => [''],
	'se.pat.ringer.ringer22.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.6.param' => ['0'],
	'se.pat.ringer.ringer22.inst.6.type' => [''],
	'se.pat.ringer.ringer22.inst.6.value' => [''],
	'se.pat.ringer.ringer22.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.7.param' => ['0'],
	'se.pat.ringer.ringer22.inst.7.type' => [''],
	'se.pat.ringer.ringer22.inst.7.value' => [''],
	'se.pat.ringer.ringer22.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.8.param' => ['0'],
	'se.pat.ringer.ringer22.inst.8.type' => [''],
	'se.pat.ringer.ringer22.inst.8.value' => [''],
	'se.pat.ringer.ringer22.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer22.inst.9.param' => ['0'],
	'se.pat.ringer.ringer22.inst.9.type' => [''],
	'se.pat.ringer.ringer22.inst.9.value' => [''],
	'se.pat.ringer.ringer22.name' => ['', 'Sampled 8' ],
	'se.pat.ringer.ringer23.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.1.param' => ['0'],
	'se.pat.ringer.ringer23.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer23.inst.1.value' => ['10'],
	'se.pat.ringer.ringer23.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.10.param' => ['0'],
	'se.pat.ringer.ringer23.inst.10.type' => [''],
	'se.pat.ringer.ringer23.inst.10.value' => [''],
	'se.pat.ringer.ringer23.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.11.param' => ['0'],
	'se.pat.ringer.ringer23.inst.11.type' => [''],
	'se.pat.ringer.ringer23.inst.11.value' => [''],
	'se.pat.ringer.ringer23.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.12.param' => ['0'],
	'se.pat.ringer.ringer23.inst.12.type' => [''],
	'se.pat.ringer.ringer23.inst.12.value' => [''],
	'se.pat.ringer.ringer23.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.13.param' => ['0'],
	'se.pat.ringer.ringer23.inst.13.type' => [''],
	'se.pat.ringer.ringer23.inst.13.value' => [''],
	'se.pat.ringer.ringer23.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.14.param' => ['0'],
	'se.pat.ringer.ringer23.inst.14.type' => [''],
	'se.pat.ringer.ringer23.inst.14.value' => [''],
	'se.pat.ringer.ringer23.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.15.param' => ['0'],
	'se.pat.ringer.ringer23.inst.15.type' => [''],
	'se.pat.ringer.ringer23.inst.15.value' => [''],
	'se.pat.ringer.ringer23.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.16.param' => ['0'],
	'se.pat.ringer.ringer23.inst.16.type' => [''],
	'se.pat.ringer.ringer23.inst.16.value' => [''],
	'se.pat.ringer.ringer23.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.17.param' => ['0'],
	'se.pat.ringer.ringer23.inst.17.type' => [''],
	'se.pat.ringer.ringer23.inst.17.value' => [''],
	'se.pat.ringer.ringer23.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.18.param' => ['0'],
	'se.pat.ringer.ringer23.inst.18.type' => [''],
	'se.pat.ringer.ringer23.inst.18.value' => [''],
	'se.pat.ringer.ringer23.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.19.param' => ['0'],
	'se.pat.ringer.ringer23.inst.19.type' => [''],
	'se.pat.ringer.ringer23.inst.19.value' => [''],
	'se.pat.ringer.ringer23.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.2.param' => ['0'],
	'se.pat.ringer.ringer23.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer23.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer23.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.20.param' => ['0'],
	'se.pat.ringer.ringer23.inst.20.type' => [''],
	'se.pat.ringer.ringer23.inst.20.value' => [''],
	'se.pat.ringer.ringer23.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.21.param' => ['0'],
	'se.pat.ringer.ringer23.inst.21.type' => [''],
	'se.pat.ringer.ringer23.inst.21.value' => [''],
	'se.pat.ringer.ringer23.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.22.param' => ['0'],
	'se.pat.ringer.ringer23.inst.22.type' => [''],
	'se.pat.ringer.ringer23.inst.22.value' => [''],
	'se.pat.ringer.ringer23.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.23.param' => ['0'],
	'se.pat.ringer.ringer23.inst.23.type' => [''],
	'se.pat.ringer.ringer23.inst.23.value' => [''],
	'se.pat.ringer.ringer23.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.24.param' => ['0'],
	'se.pat.ringer.ringer23.inst.24.type' => [''],
	'se.pat.ringer.ringer23.inst.24.value' => [''],
	'se.pat.ringer.ringer23.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.25.param' => ['0'],
	'se.pat.ringer.ringer23.inst.25.type' => [''],
	'se.pat.ringer.ringer23.inst.25.value' => [''],
	'se.pat.ringer.ringer23.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.26.param' => ['0'],
	'se.pat.ringer.ringer23.inst.26.type' => [''],
	'se.pat.ringer.ringer23.inst.26.value' => [''],
	'se.pat.ringer.ringer23.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.27.param' => ['0'],
	'se.pat.ringer.ringer23.inst.27.type' => [''],
	'se.pat.ringer.ringer23.inst.27.value' => [''],
	'se.pat.ringer.ringer23.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.28.param' => ['0'],
	'se.pat.ringer.ringer23.inst.28.type' => [''],
	'se.pat.ringer.ringer23.inst.28.value' => [''],
	'se.pat.ringer.ringer23.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.29.param' => ['0'],
	'se.pat.ringer.ringer23.inst.29.type' => [''],
	'se.pat.ringer.ringer23.inst.29.value' => [''],
	'se.pat.ringer.ringer23.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.3.param' => ['0'],
	'se.pat.ringer.ringer23.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer23.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer23.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.30.param' => ['0'],
	'se.pat.ringer.ringer23.inst.30.type' => [''],
	'se.pat.ringer.ringer23.inst.30.value' => [''],
	'se.pat.ringer.ringer23.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.31.param' => ['0'],
	'se.pat.ringer.ringer23.inst.31.type' => [''],
	'se.pat.ringer.ringer23.inst.31.value' => [''],
	'se.pat.ringer.ringer23.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.32.param' => ['0'],
	'se.pat.ringer.ringer23.inst.32.type' => [''],
	'se.pat.ringer.ringer23.inst.32.value' => [''],
	'se.pat.ringer.ringer23.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.4.param' => ['0'],
	'se.pat.ringer.ringer23.inst.4.type' => [''],
	'se.pat.ringer.ringer23.inst.4.value' => [''],
	'se.pat.ringer.ringer23.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.5.param' => ['0'],
	'se.pat.ringer.ringer23.inst.5.type' => [''],
	'se.pat.ringer.ringer23.inst.5.value' => [''],
	'se.pat.ringer.ringer23.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.6.param' => ['0'],
	'se.pat.ringer.ringer23.inst.6.type' => [''],
	'se.pat.ringer.ringer23.inst.6.value' => [''],
	'se.pat.ringer.ringer23.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.7.param' => ['0'],
	'se.pat.ringer.ringer23.inst.7.type' => [''],
	'se.pat.ringer.ringer23.inst.7.value' => [''],
	'se.pat.ringer.ringer23.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.8.param' => ['0'],
	'se.pat.ringer.ringer23.inst.8.type' => [''],
	'se.pat.ringer.ringer23.inst.8.value' => [''],
	'se.pat.ringer.ringer23.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer23.inst.9.param' => ['0'],
	'se.pat.ringer.ringer23.inst.9.type' => [''],
	'se.pat.ringer.ringer23.inst.9.value' => [''],
	'se.pat.ringer.ringer23.name' => ['', 'Sampled 9' ],
	'se.pat.ringer.ringer24.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.1.param' => ['0'],
	'se.pat.ringer.ringer24.inst.1.type' => ['sampled'],
	'se.pat.ringer.ringer24.inst.1.value' => ['11'],
	'se.pat.ringer.ringer24.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.10.param' => ['0'],
	'se.pat.ringer.ringer24.inst.10.type' => [''],
	'se.pat.ringer.ringer24.inst.10.value' => [''],
	'se.pat.ringer.ringer24.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.11.param' => ['0'],
	'se.pat.ringer.ringer24.inst.11.type' => [''],
	'se.pat.ringer.ringer24.inst.11.value' => [''],
	'se.pat.ringer.ringer24.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.12.param' => ['0'],
	'se.pat.ringer.ringer24.inst.12.type' => [''],
	'se.pat.ringer.ringer24.inst.12.value' => [''],
	'se.pat.ringer.ringer24.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.13.param' => ['0'],
	'se.pat.ringer.ringer24.inst.13.type' => [''],
	'se.pat.ringer.ringer24.inst.13.value' => [''],
	'se.pat.ringer.ringer24.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.14.param' => ['0'],
	'se.pat.ringer.ringer24.inst.14.type' => [''],
	'se.pat.ringer.ringer24.inst.14.value' => [''],
	'se.pat.ringer.ringer24.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.15.param' => ['0'],
	'se.pat.ringer.ringer24.inst.15.type' => [''],
	'se.pat.ringer.ringer24.inst.15.value' => [''],
	'se.pat.ringer.ringer24.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.16.param' => ['0'],
	'se.pat.ringer.ringer24.inst.16.type' => [''],
	'se.pat.ringer.ringer24.inst.16.value' => [''],
	'se.pat.ringer.ringer24.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.17.param' => ['0'],
	'se.pat.ringer.ringer24.inst.17.type' => [''],
	'se.pat.ringer.ringer24.inst.17.value' => [''],
	'se.pat.ringer.ringer24.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.18.param' => ['0'],
	'se.pat.ringer.ringer24.inst.18.type' => [''],
	'se.pat.ringer.ringer24.inst.18.value' => [''],
	'se.pat.ringer.ringer24.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.19.param' => ['0'],
	'se.pat.ringer.ringer24.inst.19.type' => [''],
	'se.pat.ringer.ringer24.inst.19.value' => [''],
	'se.pat.ringer.ringer24.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.2.param' => ['0'],
	'se.pat.ringer.ringer24.inst.2.type' => ['silence'],
	'se.pat.ringer.ringer24.inst.2.value' => ['3000'],
	'se.pat.ringer.ringer24.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.20.param' => ['0'],
	'se.pat.ringer.ringer24.inst.20.type' => [''],
	'se.pat.ringer.ringer24.inst.20.value' => [''],
	'se.pat.ringer.ringer24.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.21.param' => ['0'],
	'se.pat.ringer.ringer24.inst.21.type' => [''],
	'se.pat.ringer.ringer24.inst.21.value' => [''],
	'se.pat.ringer.ringer24.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.22.param' => ['0'],
	'se.pat.ringer.ringer24.inst.22.type' => [''],
	'se.pat.ringer.ringer24.inst.22.value' => [''],
	'se.pat.ringer.ringer24.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.23.param' => ['0'],
	'se.pat.ringer.ringer24.inst.23.type' => [''],
	'se.pat.ringer.ringer24.inst.23.value' => [''],
	'se.pat.ringer.ringer24.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.24.param' => ['0'],
	'se.pat.ringer.ringer24.inst.24.type' => [''],
	'se.pat.ringer.ringer24.inst.24.value' => [''],
	'se.pat.ringer.ringer24.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.25.param' => ['0'],
	'se.pat.ringer.ringer24.inst.25.type' => [''],
	'se.pat.ringer.ringer24.inst.25.value' => [''],
	'se.pat.ringer.ringer24.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.26.param' => ['0'],
	'se.pat.ringer.ringer24.inst.26.type' => [''],
	'se.pat.ringer.ringer24.inst.26.value' => [''],
	'se.pat.ringer.ringer24.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.27.param' => ['0'],
	'se.pat.ringer.ringer24.inst.27.type' => [''],
	'se.pat.ringer.ringer24.inst.27.value' => [''],
	'se.pat.ringer.ringer24.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.28.param' => ['0'],
	'se.pat.ringer.ringer24.inst.28.type' => [''],
	'se.pat.ringer.ringer24.inst.28.value' => [''],
	'se.pat.ringer.ringer24.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.29.param' => ['0'],
	'se.pat.ringer.ringer24.inst.29.type' => [''],
	'se.pat.ringer.ringer24.inst.29.value' => [''],
	'se.pat.ringer.ringer24.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.3.param' => ['0'],
	'se.pat.ringer.ringer24.inst.3.type' => ['branch'],
	'se.pat.ringer.ringer24.inst.3.value' => ['-2'],
	'se.pat.ringer.ringer24.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.30.param' => ['0'],
	'se.pat.ringer.ringer24.inst.30.type' => [''],
	'se.pat.ringer.ringer24.inst.30.value' => [''],
	'se.pat.ringer.ringer24.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.31.param' => ['0'],
	'se.pat.ringer.ringer24.inst.31.type' => [''],
	'se.pat.ringer.ringer24.inst.31.value' => [''],
	'se.pat.ringer.ringer24.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.32.param' => ['0'],
	'se.pat.ringer.ringer24.inst.32.type' => [''],
	'se.pat.ringer.ringer24.inst.32.value' => [''],
	'se.pat.ringer.ringer24.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.4.param' => ['0'],
	'se.pat.ringer.ringer24.inst.4.type' => [''],
	'se.pat.ringer.ringer24.inst.4.value' => [''],
	'se.pat.ringer.ringer24.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.5.param' => ['0'],
	'se.pat.ringer.ringer24.inst.5.type' => [''],
	'se.pat.ringer.ringer24.inst.5.value' => [''],
	'se.pat.ringer.ringer24.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.6.param' => ['0'],
	'se.pat.ringer.ringer24.inst.6.type' => [''],
	'se.pat.ringer.ringer24.inst.6.value' => [''],
	'se.pat.ringer.ringer24.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.7.param' => ['0'],
	'se.pat.ringer.ringer24.inst.7.type' => [''],
	'se.pat.ringer.ringer24.inst.7.value' => [''],
	'se.pat.ringer.ringer24.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.8.param' => ['0'],
	'se.pat.ringer.ringer24.inst.8.type' => [''],
	'se.pat.ringer.ringer24.inst.8.value' => [''],
	'se.pat.ringer.ringer24.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer24.inst.9.param' => ['0'],
	'se.pat.ringer.ringer24.inst.9.type' => [''],
	'se.pat.ringer.ringer24.inst.9.value' => [''],
	'se.pat.ringer.ringer24.name' => ['', 'Sampled 10' ],
	'se.pat.ringer.ringer3.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.1.param' => ['0'],
	'se.pat.ringer.ringer3.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.1.value' => ['A3Major'],
	'se.pat.ringer.ringer3.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.10.param' => ['0'],
	'se.pat.ringer.ringer3.inst.10.type' => ['silence'],
	'se.pat.ringer.ringer3.inst.10.value' => ['2000'],
	'se.pat.ringer.ringer3.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.11.param' => ['0'],
	'se.pat.ringer.ringer3.inst.11.type' => ['branch'],
	'se.pat.ringer.ringer3.inst.11.value' => ['-10'],
	'se.pat.ringer.ringer3.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.12.param' => ['0'],
	'se.pat.ringer.ringer3.inst.12.type' => [''],
	'se.pat.ringer.ringer3.inst.12.value' => [''],
	'se.pat.ringer.ringer3.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.13.param' => ['0'],
	'se.pat.ringer.ringer3.inst.13.type' => [''],
	'se.pat.ringer.ringer3.inst.13.value' => [''],
	'se.pat.ringer.ringer3.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.14.param' => ['0'],
	'se.pat.ringer.ringer3.inst.14.type' => [''],
	'se.pat.ringer.ringer3.inst.14.value' => [''],
	'se.pat.ringer.ringer3.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.15.param' => ['0'],
	'se.pat.ringer.ringer3.inst.15.type' => [''],
	'se.pat.ringer.ringer3.inst.15.value' => [''],
	'se.pat.ringer.ringer3.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.16.param' => ['0'],
	'se.pat.ringer.ringer3.inst.16.type' => [''],
	'se.pat.ringer.ringer3.inst.16.value' => [''],
	'se.pat.ringer.ringer3.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.17.param' => ['0'],
	'se.pat.ringer.ringer3.inst.17.type' => [''],
	'se.pat.ringer.ringer3.inst.17.value' => [''],
	'se.pat.ringer.ringer3.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.18.param' => ['0'],
	'se.pat.ringer.ringer3.inst.18.type' => [''],
	'se.pat.ringer.ringer3.inst.18.value' => [''],
	'se.pat.ringer.ringer3.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.19.param' => ['0'],
	'se.pat.ringer.ringer3.inst.19.type' => [''],
	'se.pat.ringer.ringer3.inst.19.value' => [''],
	'se.pat.ringer.ringer3.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.2.param' => ['0'],
	'se.pat.ringer.ringer3.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.2.value' => ['Db3Major'],
	'se.pat.ringer.ringer3.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.20.param' => ['0'],
	'se.pat.ringer.ringer3.inst.20.type' => [''],
	'se.pat.ringer.ringer3.inst.20.value' => [''],
	'se.pat.ringer.ringer3.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.21.param' => ['0'],
	'se.pat.ringer.ringer3.inst.21.type' => [''],
	'se.pat.ringer.ringer3.inst.21.value' => [''],
	'se.pat.ringer.ringer3.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.22.param' => ['0'],
	'se.pat.ringer.ringer3.inst.22.type' => [''],
	'se.pat.ringer.ringer3.inst.22.value' => [''],
	'se.pat.ringer.ringer3.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.23.param' => ['0'],
	'se.pat.ringer.ringer3.inst.23.type' => [''],
	'se.pat.ringer.ringer3.inst.23.value' => [''],
	'se.pat.ringer.ringer3.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.24.param' => ['0'],
	'se.pat.ringer.ringer3.inst.24.type' => [''],
	'se.pat.ringer.ringer3.inst.24.value' => [''],
	'se.pat.ringer.ringer3.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.25.param' => ['0'],
	'se.pat.ringer.ringer3.inst.25.type' => [''],
	'se.pat.ringer.ringer3.inst.25.value' => [''],
	'se.pat.ringer.ringer3.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.26.param' => ['0'],
	'se.pat.ringer.ringer3.inst.26.type' => [''],
	'se.pat.ringer.ringer3.inst.26.value' => [''],
	'se.pat.ringer.ringer3.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.27.param' => ['0'],
	'se.pat.ringer.ringer3.inst.27.type' => [''],
	'se.pat.ringer.ringer3.inst.27.value' => [''],
	'se.pat.ringer.ringer3.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.28.param' => ['0'],
	'se.pat.ringer.ringer3.inst.28.type' => [''],
	'se.pat.ringer.ringer3.inst.28.value' => [''],
	'se.pat.ringer.ringer3.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.29.param' => ['0'],
	'se.pat.ringer.ringer3.inst.29.type' => [''],
	'se.pat.ringer.ringer3.inst.29.value' => [''],
	'se.pat.ringer.ringer3.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.3.param' => ['0'],
	'se.pat.ringer.ringer3.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.3.value' => ['A3Major'],
	'se.pat.ringer.ringer3.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.30.param' => ['0'],
	'se.pat.ringer.ringer3.inst.30.type' => [''],
	'se.pat.ringer.ringer3.inst.30.value' => [''],
	'se.pat.ringer.ringer3.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.31.param' => ['0'],
	'se.pat.ringer.ringer3.inst.31.type' => [''],
	'se.pat.ringer.ringer3.inst.31.value' => [''],
	'se.pat.ringer.ringer3.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.32.param' => ['0'],
	'se.pat.ringer.ringer3.inst.32.type' => [''],
	'se.pat.ringer.ringer3.inst.32.value' => [''],
	'se.pat.ringer.ringer3.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.4.param' => ['0'],
	'se.pat.ringer.ringer3.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.4.value' => ['Db3Major'],
	'se.pat.ringer.ringer3.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.5.param' => ['0'],
	'se.pat.ringer.ringer3.inst.5.type' => ['silence'],
	'se.pat.ringer.ringer3.inst.5.value' => ['200'],
	'se.pat.ringer.ringer3.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.6.param' => ['0'],
	'se.pat.ringer.ringer3.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.6.value' => ['A3Major'],
	'se.pat.ringer.ringer3.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.7.param' => ['0'],
	'se.pat.ringer.ringer3.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.7.value' => ['Db3Major'],
	'se.pat.ringer.ringer3.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.8.param' => ['0'],
	'se.pat.ringer.ringer3.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.8.value' => ['A3Major'],
	'se.pat.ringer.ringer3.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer3.inst.9.param' => ['0'],
	'se.pat.ringer.ringer3.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer3.inst.9.value' => ['Db3Major'],
	'se.pat.ringer.ringer3.name' => ['Low Double Trill'],
	'se.pat.ringer.ringer4.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.1.param' => ['0'],
	'se.pat.ringer.ringer4.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.1.value' => ['C3Major'],
	'se.pat.ringer.ringer4.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.10.param' => ['0'],
	'se.pat.ringer.ringer4.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.10.value' => ['E3Major'],
	'se.pat.ringer.ringer4.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.11.param' => ['0'],
	'se.pat.ringer.ringer4.inst.11.type' => ['silence'],
	'se.pat.ringer.ringer4.inst.11.value' => ['3000'],
	'se.pat.ringer.ringer4.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.12.param' => ['0'],
	'se.pat.ringer.ringer4.inst.12.type' => ['branch'],
	'se.pat.ringer.ringer4.inst.12.value' => ['-11'],
	'se.pat.ringer.ringer4.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.13.param' => ['0'],
	'se.pat.ringer.ringer4.inst.13.type' => [''],
	'se.pat.ringer.ringer4.inst.13.value' => [''],
	'se.pat.ringer.ringer4.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.14.param' => ['0'],
	'se.pat.ringer.ringer4.inst.14.type' => [''],
	'se.pat.ringer.ringer4.inst.14.value' => [''],
	'se.pat.ringer.ringer4.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.15.param' => ['0'],
	'se.pat.ringer.ringer4.inst.15.type' => [''],
	'se.pat.ringer.ringer4.inst.15.value' => [''],
	'se.pat.ringer.ringer4.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.16.param' => ['0'],
	'se.pat.ringer.ringer4.inst.16.type' => [''],
	'se.pat.ringer.ringer4.inst.16.value' => [''],
	'se.pat.ringer.ringer4.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.17.param' => ['0'],
	'se.pat.ringer.ringer4.inst.17.type' => [''],
	'se.pat.ringer.ringer4.inst.17.value' => [''],
	'se.pat.ringer.ringer4.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.18.param' => ['0'],
	'se.pat.ringer.ringer4.inst.18.type' => [''],
	'se.pat.ringer.ringer4.inst.18.value' => [''],
	'se.pat.ringer.ringer4.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.19.param' => ['0'],
	'se.pat.ringer.ringer4.inst.19.type' => [''],
	'se.pat.ringer.ringer4.inst.19.value' => [''],
	'se.pat.ringer.ringer4.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.2.param' => ['0'],
	'se.pat.ringer.ringer4.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.2.value' => ['E3Major'],
	'se.pat.ringer.ringer4.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.20.param' => ['0'],
	'se.pat.ringer.ringer4.inst.20.type' => [''],
	'se.pat.ringer.ringer4.inst.20.value' => [''],
	'se.pat.ringer.ringer4.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.21.param' => ['0'],
	'se.pat.ringer.ringer4.inst.21.type' => [''],
	'se.pat.ringer.ringer4.inst.21.value' => [''],
	'se.pat.ringer.ringer4.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.22.param' => ['0'],
	'se.pat.ringer.ringer4.inst.22.type' => [''],
	'se.pat.ringer.ringer4.inst.22.value' => [''],
	'se.pat.ringer.ringer4.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.23.param' => ['0'],
	'se.pat.ringer.ringer4.inst.23.type' => [''],
	'se.pat.ringer.ringer4.inst.23.value' => [''],
	'se.pat.ringer.ringer4.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.24.param' => ['0'],
	'se.pat.ringer.ringer4.inst.24.type' => [''],
	'se.pat.ringer.ringer4.inst.24.value' => [''],
	'se.pat.ringer.ringer4.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.25.param' => ['0'],
	'se.pat.ringer.ringer4.inst.25.type' => [''],
	'se.pat.ringer.ringer4.inst.25.value' => [''],
	'se.pat.ringer.ringer4.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.26.param' => ['0'],
	'se.pat.ringer.ringer4.inst.26.type' => [''],
	'se.pat.ringer.ringer4.inst.26.value' => [''],
	'se.pat.ringer.ringer4.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.27.param' => ['0'],
	'se.pat.ringer.ringer4.inst.27.type' => [''],
	'se.pat.ringer.ringer4.inst.27.value' => [''],
	'se.pat.ringer.ringer4.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.28.param' => ['0'],
	'se.pat.ringer.ringer4.inst.28.type' => [''],
	'se.pat.ringer.ringer4.inst.28.value' => [''],
	'se.pat.ringer.ringer4.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.29.param' => ['0'],
	'se.pat.ringer.ringer4.inst.29.type' => [''],
	'se.pat.ringer.ringer4.inst.29.value' => [''],
	'se.pat.ringer.ringer4.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.3.param' => ['0'],
	'se.pat.ringer.ringer4.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.3.value' => ['C3Major'],
	'se.pat.ringer.ringer4.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.30.param' => ['0'],
	'se.pat.ringer.ringer4.inst.30.type' => [''],
	'se.pat.ringer.ringer4.inst.30.value' => [''],
	'se.pat.ringer.ringer4.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.31.param' => ['0'],
	'se.pat.ringer.ringer4.inst.31.type' => [''],
	'se.pat.ringer.ringer4.inst.31.value' => [''],
	'se.pat.ringer.ringer4.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.32.param' => ['0'],
	'se.pat.ringer.ringer4.inst.32.type' => [''],
	'se.pat.ringer.ringer4.inst.32.value' => [''],
	'se.pat.ringer.ringer4.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.4.param' => ['0'],
	'se.pat.ringer.ringer4.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.4.value' => ['E3Major'],
	'se.pat.ringer.ringer4.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.5.param' => ['0'],
	'se.pat.ringer.ringer4.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.5.value' => ['C3Major'],
	'se.pat.ringer.ringer4.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.6.param' => ['0'],
	'se.pat.ringer.ringer4.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.6.value' => ['E3Major'],
	'se.pat.ringer.ringer4.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.7.param' => ['0'],
	'se.pat.ringer.ringer4.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.7.value' => ['C3Major'],
	'se.pat.ringer.ringer4.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.8.param' => ['0'],
	'se.pat.ringer.ringer4.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.8.value' => ['E3Major'],
	'se.pat.ringer.ringer4.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer4.inst.9.param' => ['0'],
	'se.pat.ringer.ringer4.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer4.inst.9.value' => ['C3Major'],
	'se.pat.ringer.ringer4.name' => ['Medium Trill'],
	'se.pat.ringer.ringer5.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.1.param' => ['0'],
	'se.pat.ringer.ringer5.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.1.value' => ['C3Major'],
	'se.pat.ringer.ringer5.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.10.param' => ['0'],
	'se.pat.ringer.ringer5.inst.10.type' => ['silence'],
	'se.pat.ringer.ringer5.inst.10.value' => ['2000'],
	'se.pat.ringer.ringer5.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.11.param' => ['0'],
	'se.pat.ringer.ringer5.inst.11.type' => ['branch'],
	'se.pat.ringer.ringer5.inst.11.value' => ['-10'],
	'se.pat.ringer.ringer5.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.12.param' => ['0'],
	'se.pat.ringer.ringer5.inst.12.type' => [''],
	'se.pat.ringer.ringer5.inst.12.value' => [''],
	'se.pat.ringer.ringer5.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.13.param' => ['0'],
	'se.pat.ringer.ringer5.inst.13.type' => [''],
	'se.pat.ringer.ringer5.inst.13.value' => [''],
	'se.pat.ringer.ringer5.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.14.param' => ['0'],
	'se.pat.ringer.ringer5.inst.14.type' => [''],
	'se.pat.ringer.ringer5.inst.14.value' => [''],
	'se.pat.ringer.ringer5.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.15.param' => ['0'],
	'se.pat.ringer.ringer5.inst.15.type' => [''],
	'se.pat.ringer.ringer5.inst.15.value' => [''],
	'se.pat.ringer.ringer5.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.16.param' => ['0'],
	'se.pat.ringer.ringer5.inst.16.type' => [''],
	'se.pat.ringer.ringer5.inst.16.value' => [''],
	'se.pat.ringer.ringer5.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.17.param' => ['0'],
	'se.pat.ringer.ringer5.inst.17.type' => [''],
	'se.pat.ringer.ringer5.inst.17.value' => [''],
	'se.pat.ringer.ringer5.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.18.param' => ['0'],
	'se.pat.ringer.ringer5.inst.18.type' => [''],
	'se.pat.ringer.ringer5.inst.18.value' => [''],
	'se.pat.ringer.ringer5.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.19.param' => ['0'],
	'se.pat.ringer.ringer5.inst.19.type' => [''],
	'se.pat.ringer.ringer5.inst.19.value' => [''],
	'se.pat.ringer.ringer5.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.2.param' => ['0'],
	'se.pat.ringer.ringer5.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.2.value' => ['E3Major'],
	'se.pat.ringer.ringer5.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.20.param' => ['0'],
	'se.pat.ringer.ringer5.inst.20.type' => [''],
	'se.pat.ringer.ringer5.inst.20.value' => [''],
	'se.pat.ringer.ringer5.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.21.param' => ['0'],
	'se.pat.ringer.ringer5.inst.21.type' => [''],
	'se.pat.ringer.ringer5.inst.21.value' => [''],
	'se.pat.ringer.ringer5.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.22.param' => ['0'],
	'se.pat.ringer.ringer5.inst.22.type' => [''],
	'se.pat.ringer.ringer5.inst.22.value' => [''],
	'se.pat.ringer.ringer5.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.23.param' => ['0'],
	'se.pat.ringer.ringer5.inst.23.type' => [''],
	'se.pat.ringer.ringer5.inst.23.value' => [''],
	'se.pat.ringer.ringer5.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.24.param' => ['0'],
	'se.pat.ringer.ringer5.inst.24.type' => [''],
	'se.pat.ringer.ringer5.inst.24.value' => [''],
	'se.pat.ringer.ringer5.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.25.param' => ['0'],
	'se.pat.ringer.ringer5.inst.25.type' => [''],
	'se.pat.ringer.ringer5.inst.25.value' => [''],
	'se.pat.ringer.ringer5.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.26.param' => ['0'],
	'se.pat.ringer.ringer5.inst.26.type' => [''],
	'se.pat.ringer.ringer5.inst.26.value' => [''],
	'se.pat.ringer.ringer5.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.27.param' => ['0'],
	'se.pat.ringer.ringer5.inst.27.type' => [''],
	'se.pat.ringer.ringer5.inst.27.value' => [''],
	'se.pat.ringer.ringer5.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.28.param' => ['0'],
	'se.pat.ringer.ringer5.inst.28.type' => [''],
	'se.pat.ringer.ringer5.inst.28.value' => [''],
	'se.pat.ringer.ringer5.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.29.param' => ['0'],
	'se.pat.ringer.ringer5.inst.29.type' => [''],
	'se.pat.ringer.ringer5.inst.29.value' => [''],
	'se.pat.ringer.ringer5.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.3.param' => ['0'],
	'se.pat.ringer.ringer5.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.3.value' => ['C3Major'],
	'se.pat.ringer.ringer5.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.30.param' => ['0'],
	'se.pat.ringer.ringer5.inst.30.type' => [''],
	'se.pat.ringer.ringer5.inst.30.value' => [''],
	'se.pat.ringer.ringer5.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.31.param' => ['0'],
	'se.pat.ringer.ringer5.inst.31.type' => [''],
	'se.pat.ringer.ringer5.inst.31.value' => [''],
	'se.pat.ringer.ringer5.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.32.param' => ['0'],
	'se.pat.ringer.ringer5.inst.32.type' => [''],
	'se.pat.ringer.ringer5.inst.32.value' => [''],
	'se.pat.ringer.ringer5.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.4.param' => ['0'],
	'se.pat.ringer.ringer5.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.4.value' => ['E3Major'],
	'se.pat.ringer.ringer5.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.5.param' => ['0'],
	'se.pat.ringer.ringer5.inst.5.type' => ['silence'],
	'se.pat.ringer.ringer5.inst.5.value' => ['200'],
	'se.pat.ringer.ringer5.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.6.param' => ['0'],
	'se.pat.ringer.ringer5.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.6.value' => ['C3Major'],
	'se.pat.ringer.ringer5.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.7.param' => ['0'],
	'se.pat.ringer.ringer5.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.7.value' => ['E3Major'],
	'se.pat.ringer.ringer5.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.8.param' => ['0'],
	'se.pat.ringer.ringer5.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.8.value' => ['C3Major'],
	'se.pat.ringer.ringer5.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer5.inst.9.param' => ['0'],
	'se.pat.ringer.ringer5.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer5.inst.9.value' => ['E3Major'],
	'se.pat.ringer.ringer5.name' => ['Medium Double Trill'],
	'se.pat.ringer.ringer6.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.1.param' => ['0'],
	'se.pat.ringer.ringer6.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.1.value' => ['originalLow'],
	'se.pat.ringer.ringer6.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.10.param' => ['0'],
	'se.pat.ringer.ringer6.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.10.value' => ['originalHigh'],
	'se.pat.ringer.ringer6.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.11.param' => ['0'],
	'se.pat.ringer.ringer6.inst.11.type' => ['silence'],
	'se.pat.ringer.ringer6.inst.11.value' => ['3000'],
	'se.pat.ringer.ringer6.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.12.param' => ['0'],
	'se.pat.ringer.ringer6.inst.12.type' => ['branch'],
	'se.pat.ringer.ringer6.inst.12.value' => ['-11'],
	'se.pat.ringer.ringer6.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.13.param' => ['0'],
	'se.pat.ringer.ringer6.inst.13.type' => [''],
	'se.pat.ringer.ringer6.inst.13.value' => [''],
	'se.pat.ringer.ringer6.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.14.param' => ['0'],
	'se.pat.ringer.ringer6.inst.14.type' => [''],
	'se.pat.ringer.ringer6.inst.14.value' => [''],
	'se.pat.ringer.ringer6.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.15.param' => ['0'],
	'se.pat.ringer.ringer6.inst.15.type' => [''],
	'se.pat.ringer.ringer6.inst.15.value' => [''],
	'se.pat.ringer.ringer6.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.16.param' => ['0'],
	'se.pat.ringer.ringer6.inst.16.type' => [''],
	'se.pat.ringer.ringer6.inst.16.value' => [''],
	'se.pat.ringer.ringer6.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.17.param' => ['0'],
	'se.pat.ringer.ringer6.inst.17.type' => [''],
	'se.pat.ringer.ringer6.inst.17.value' => [''],
	'se.pat.ringer.ringer6.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.18.param' => ['0'],
	'se.pat.ringer.ringer6.inst.18.type' => [''],
	'se.pat.ringer.ringer6.inst.18.value' => [''],
	'se.pat.ringer.ringer6.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.19.param' => ['0'],
	'se.pat.ringer.ringer6.inst.19.type' => [''],
	'se.pat.ringer.ringer6.inst.19.value' => [''],
	'se.pat.ringer.ringer6.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.2.param' => ['0'],
	'se.pat.ringer.ringer6.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.2.value' => ['originalHigh'],
	'se.pat.ringer.ringer6.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.20.param' => ['0'],
	'se.pat.ringer.ringer6.inst.20.type' => [''],
	'se.pat.ringer.ringer6.inst.20.value' => [''],
	'se.pat.ringer.ringer6.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.21.param' => ['0'],
	'se.pat.ringer.ringer6.inst.21.type' => [''],
	'se.pat.ringer.ringer6.inst.21.value' => [''],
	'se.pat.ringer.ringer6.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.22.param' => ['0'],
	'se.pat.ringer.ringer6.inst.22.type' => [''],
	'se.pat.ringer.ringer6.inst.22.value' => [''],
	'se.pat.ringer.ringer6.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.23.param' => ['0'],
	'se.pat.ringer.ringer6.inst.23.type' => [''],
	'se.pat.ringer.ringer6.inst.23.value' => [''],
	'se.pat.ringer.ringer6.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.24.param' => ['0'],
	'se.pat.ringer.ringer6.inst.24.type' => [''],
	'se.pat.ringer.ringer6.inst.24.value' => [''],
	'se.pat.ringer.ringer6.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.25.param' => ['0'],
	'se.pat.ringer.ringer6.inst.25.type' => [''],
	'se.pat.ringer.ringer6.inst.25.value' => [''],
	'se.pat.ringer.ringer6.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.26.param' => ['0'],
	'se.pat.ringer.ringer6.inst.26.type' => [''],
	'se.pat.ringer.ringer6.inst.26.value' => [''],
	'se.pat.ringer.ringer6.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.27.param' => ['0'],
	'se.pat.ringer.ringer6.inst.27.type' => [''],
	'se.pat.ringer.ringer6.inst.27.value' => [''],
	'se.pat.ringer.ringer6.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.28.param' => ['0'],
	'se.pat.ringer.ringer6.inst.28.type' => [''],
	'se.pat.ringer.ringer6.inst.28.value' => [''],
	'se.pat.ringer.ringer6.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.29.param' => ['0'],
	'se.pat.ringer.ringer6.inst.29.type' => [''],
	'se.pat.ringer.ringer6.inst.29.value' => [''],
	'se.pat.ringer.ringer6.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.3.param' => ['0'],
	'se.pat.ringer.ringer6.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.3.value' => ['originalLow'],
	'se.pat.ringer.ringer6.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.30.param' => ['0'],
	'se.pat.ringer.ringer6.inst.30.type' => [''],
	'se.pat.ringer.ringer6.inst.30.value' => [''],
	'se.pat.ringer.ringer6.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.31.param' => ['0'],
	'se.pat.ringer.ringer6.inst.31.type' => [''],
	'se.pat.ringer.ringer6.inst.31.value' => [''],
	'se.pat.ringer.ringer6.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.32.param' => ['0'],
	'se.pat.ringer.ringer6.inst.32.type' => [''],
	'se.pat.ringer.ringer6.inst.32.value' => [''],
	'se.pat.ringer.ringer6.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.4.param' => ['0'],
	'se.pat.ringer.ringer6.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.4.value' => ['originalHigh'],
	'se.pat.ringer.ringer6.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.5.param' => ['0'],
	'se.pat.ringer.ringer6.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.5.value' => ['originalLow'],
	'se.pat.ringer.ringer6.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.6.param' => ['0'],
	'se.pat.ringer.ringer6.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.6.value' => ['originalHigh'],
	'se.pat.ringer.ringer6.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.7.param' => ['0'],
	'se.pat.ringer.ringer6.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.7.value' => ['originalLow'],
	'se.pat.ringer.ringer6.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.8.param' => ['0'],
	'se.pat.ringer.ringer6.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.8.value' => ['originalHigh'],
	'se.pat.ringer.ringer6.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer6.inst.9.param' => ['0'],
	'se.pat.ringer.ringer6.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer6.inst.9.value' => ['originalLow'],
	'se.pat.ringer.ringer6.name' => ['High Trill'],
	'se.pat.ringer.ringer7.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.1.param' => ['0'],
	'se.pat.ringer.ringer7.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.1.value' => ['originalLow'],
	'se.pat.ringer.ringer7.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.10.param' => ['0'],
	'se.pat.ringer.ringer7.inst.10.type' => ['silence'],
	'se.pat.ringer.ringer7.inst.10.value' => ['2000'],
	'se.pat.ringer.ringer7.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.11.param' => ['0'],
	'se.pat.ringer.ringer7.inst.11.type' => ['branch'],
	'se.pat.ringer.ringer7.inst.11.value' => ['-10'],
	'se.pat.ringer.ringer7.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.12.param' => ['0'],
	'se.pat.ringer.ringer7.inst.12.type' => [''],
	'se.pat.ringer.ringer7.inst.12.value' => [''],
	'se.pat.ringer.ringer7.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.13.param' => ['0'],
	'se.pat.ringer.ringer7.inst.13.type' => [''],
	'se.pat.ringer.ringer7.inst.13.value' => [''],
	'se.pat.ringer.ringer7.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.14.param' => ['0'],
	'se.pat.ringer.ringer7.inst.14.type' => [''],
	'se.pat.ringer.ringer7.inst.14.value' => [''],
	'se.pat.ringer.ringer7.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.15.param' => ['0'],
	'se.pat.ringer.ringer7.inst.15.type' => [''],
	'se.pat.ringer.ringer7.inst.15.value' => [''],
	'se.pat.ringer.ringer7.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.16.param' => ['0'],
	'se.pat.ringer.ringer7.inst.16.type' => [''],
	'se.pat.ringer.ringer7.inst.16.value' => [''],
	'se.pat.ringer.ringer7.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.17.param' => ['0'],
	'se.pat.ringer.ringer7.inst.17.type' => [''],
	'se.pat.ringer.ringer7.inst.17.value' => [''],
	'se.pat.ringer.ringer7.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.18.param' => ['0'],
	'se.pat.ringer.ringer7.inst.18.type' => [''],
	'se.pat.ringer.ringer7.inst.18.value' => [''],
	'se.pat.ringer.ringer7.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.19.param' => ['0'],
	'se.pat.ringer.ringer7.inst.19.type' => [''],
	'se.pat.ringer.ringer7.inst.19.value' => [''],
	'se.pat.ringer.ringer7.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.2.param' => ['0'],
	'se.pat.ringer.ringer7.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.2.value' => ['originalHigh'],
	'se.pat.ringer.ringer7.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.20.param' => ['0'],
	'se.pat.ringer.ringer7.inst.20.type' => [''],
	'se.pat.ringer.ringer7.inst.20.value' => [''],
	'se.pat.ringer.ringer7.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.21.param' => ['0'],
	'se.pat.ringer.ringer7.inst.21.type' => [''],
	'se.pat.ringer.ringer7.inst.21.value' => [''],
	'se.pat.ringer.ringer7.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.22.param' => ['0'],
	'se.pat.ringer.ringer7.inst.22.type' => [''],
	'se.pat.ringer.ringer7.inst.22.value' => [''],
	'se.pat.ringer.ringer7.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.23.param' => ['0'],
	'se.pat.ringer.ringer7.inst.23.type' => [''],
	'se.pat.ringer.ringer7.inst.23.value' => [''],
	'se.pat.ringer.ringer7.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.24.param' => ['0'],
	'se.pat.ringer.ringer7.inst.24.type' => [''],
	'se.pat.ringer.ringer7.inst.24.value' => [''],
	'se.pat.ringer.ringer7.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.25.param' => ['0'],
	'se.pat.ringer.ringer7.inst.25.type' => [''],
	'se.pat.ringer.ringer7.inst.25.value' => [''],
	'se.pat.ringer.ringer7.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.26.param' => ['0'],
	'se.pat.ringer.ringer7.inst.26.type' => [''],
	'se.pat.ringer.ringer7.inst.26.value' => [''],
	'se.pat.ringer.ringer7.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.27.param' => ['0'],
	'se.pat.ringer.ringer7.inst.27.type' => [''],
	'se.pat.ringer.ringer7.inst.27.value' => [''],
	'se.pat.ringer.ringer7.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.28.param' => ['0'],
	'se.pat.ringer.ringer7.inst.28.type' => [''],
	'se.pat.ringer.ringer7.inst.28.value' => [''],
	'se.pat.ringer.ringer7.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.29.param' => ['0'],
	'se.pat.ringer.ringer7.inst.29.type' => [''],
	'se.pat.ringer.ringer7.inst.29.value' => [''],
	'se.pat.ringer.ringer7.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.3.param' => ['0'],
	'se.pat.ringer.ringer7.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.3.value' => ['originalLow'],
	'se.pat.ringer.ringer7.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.30.param' => ['0'],
	'se.pat.ringer.ringer7.inst.30.type' => [''],
	'se.pat.ringer.ringer7.inst.30.value' => [''],
	'se.pat.ringer.ringer7.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.31.param' => ['0'],
	'se.pat.ringer.ringer7.inst.31.type' => [''],
	'se.pat.ringer.ringer7.inst.31.value' => [''],
	'se.pat.ringer.ringer7.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.32.param' => ['0'],
	'se.pat.ringer.ringer7.inst.32.type' => [''],
	'se.pat.ringer.ringer7.inst.32.value' => [''],
	'se.pat.ringer.ringer7.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.4.param' => ['0'],
	'se.pat.ringer.ringer7.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.4.value' => ['originalHigh'],
	'se.pat.ringer.ringer7.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.5.param' => ['0'],
	'se.pat.ringer.ringer7.inst.5.type' => ['silence'],
	'se.pat.ringer.ringer7.inst.5.value' => ['200'],
	'se.pat.ringer.ringer7.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.6.param' => ['0'],
	'se.pat.ringer.ringer7.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.6.value' => ['originalLow'],
	'se.pat.ringer.ringer7.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.7.param' => ['0'],
	'se.pat.ringer.ringer7.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.7.value' => ['originalHigh'],
	'se.pat.ringer.ringer7.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.8.param' => ['0'],
	'se.pat.ringer.ringer7.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.8.value' => ['originalLow'],
	'se.pat.ringer.ringer7.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer7.inst.9.param' => ['0'],
	'se.pat.ringer.ringer7.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer7.inst.9.value' => ['originalHigh'],
	'se.pat.ringer.ringer7.name' => ['High Double Trill'],
	'se.pat.ringer.ringer8.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.1.param' => ['0'],
	'se.pat.ringer.ringer8.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.1.value' => ['Gb3Major'],
	'se.pat.ringer.ringer8.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.10.param' => ['0'],
	'se.pat.ringer.ringer8.inst.10.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.10.value' => ['A4Major'],
	'se.pat.ringer.ringer8.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.11.param' => ['0'],
	'se.pat.ringer.ringer8.inst.11.type' => ['silence'],
	'se.pat.ringer.ringer8.inst.11.value' => ['3000'],
	'se.pat.ringer.ringer8.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.12.param' => ['0'],
	'se.pat.ringer.ringer8.inst.12.type' => ['branch'],
	'se.pat.ringer.ringer8.inst.12.value' => ['-11'],
	'se.pat.ringer.ringer8.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.13.param' => ['0'],
	'se.pat.ringer.ringer8.inst.13.type' => [''],
	'se.pat.ringer.ringer8.inst.13.value' => [''],
	'se.pat.ringer.ringer8.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.14.param' => ['0'],
	'se.pat.ringer.ringer8.inst.14.type' => [''],
	'se.pat.ringer.ringer8.inst.14.value' => [''],
	'se.pat.ringer.ringer8.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.15.param' => ['0'],
	'se.pat.ringer.ringer8.inst.15.type' => [''],
	'se.pat.ringer.ringer8.inst.15.value' => [''],
	'se.pat.ringer.ringer8.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.16.param' => ['0'],
	'se.pat.ringer.ringer8.inst.16.type' => [''],
	'se.pat.ringer.ringer8.inst.16.value' => [''],
	'se.pat.ringer.ringer8.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.17.param' => ['0'],
	'se.pat.ringer.ringer8.inst.17.type' => [''],
	'se.pat.ringer.ringer8.inst.17.value' => [''],
	'se.pat.ringer.ringer8.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.18.param' => ['0'],
	'se.pat.ringer.ringer8.inst.18.type' => [''],
	'se.pat.ringer.ringer8.inst.18.value' => [''],
	'se.pat.ringer.ringer8.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.19.param' => ['0'],
	'se.pat.ringer.ringer8.inst.19.type' => [''],
	'se.pat.ringer.ringer8.inst.19.value' => [''],
	'se.pat.ringer.ringer8.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.2.param' => ['0'],
	'se.pat.ringer.ringer8.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.2.value' => ['A4Major'],
	'se.pat.ringer.ringer8.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.20.param' => ['0'],
	'se.pat.ringer.ringer8.inst.20.type' => [''],
	'se.pat.ringer.ringer8.inst.20.value' => [''],
	'se.pat.ringer.ringer8.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.21.param' => ['0'],
	'se.pat.ringer.ringer8.inst.21.type' => [''],
	'se.pat.ringer.ringer8.inst.21.value' => [''],
	'se.pat.ringer.ringer8.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.22.param' => ['0'],
	'se.pat.ringer.ringer8.inst.22.type' => [''],
	'se.pat.ringer.ringer8.inst.22.value' => [''],
	'se.pat.ringer.ringer8.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.23.param' => ['0'],
	'se.pat.ringer.ringer8.inst.23.type' => [''],
	'se.pat.ringer.ringer8.inst.23.value' => [''],
	'se.pat.ringer.ringer8.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.24.param' => ['0'],
	'se.pat.ringer.ringer8.inst.24.type' => [''],
	'se.pat.ringer.ringer8.inst.24.value' => [''],
	'se.pat.ringer.ringer8.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.25.param' => ['0'],
	'se.pat.ringer.ringer8.inst.25.type' => [''],
	'se.pat.ringer.ringer8.inst.25.value' => [''],
	'se.pat.ringer.ringer8.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.26.param' => ['0'],
	'se.pat.ringer.ringer8.inst.26.type' => [''],
	'se.pat.ringer.ringer8.inst.26.value' => [''],
	'se.pat.ringer.ringer8.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.27.param' => ['0'],
	'se.pat.ringer.ringer8.inst.27.type' => [''],
	'se.pat.ringer.ringer8.inst.27.value' => [''],
	'se.pat.ringer.ringer8.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.28.param' => ['0'],
	'se.pat.ringer.ringer8.inst.28.type' => [''],
	'se.pat.ringer.ringer8.inst.28.value' => [''],
	'se.pat.ringer.ringer8.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.29.param' => ['0'],
	'se.pat.ringer.ringer8.inst.29.type' => [''],
	'se.pat.ringer.ringer8.inst.29.value' => [''],
	'se.pat.ringer.ringer8.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.3.param' => ['0'],
	'se.pat.ringer.ringer8.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.3.value' => ['Gb3Major'],
	'se.pat.ringer.ringer8.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.30.param' => ['0'],
	'se.pat.ringer.ringer8.inst.30.type' => [''],
	'se.pat.ringer.ringer8.inst.30.value' => [''],
	'se.pat.ringer.ringer8.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.31.param' => ['0'],
	'se.pat.ringer.ringer8.inst.31.type' => [''],
	'se.pat.ringer.ringer8.inst.31.value' => [''],
	'se.pat.ringer.ringer8.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.32.param' => ['0'],
	'se.pat.ringer.ringer8.inst.32.type' => [''],
	'se.pat.ringer.ringer8.inst.32.value' => [''],
	'se.pat.ringer.ringer8.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.4.param' => ['0'],
	'se.pat.ringer.ringer8.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.4.value' => ['A4Major'],
	'se.pat.ringer.ringer8.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.5.param' => ['0'],
	'se.pat.ringer.ringer8.inst.5.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.5.value' => ['Gb3Major'],
	'se.pat.ringer.ringer8.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.6.param' => ['0'],
	'se.pat.ringer.ringer8.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.6.value' => ['A4Major'],
	'se.pat.ringer.ringer8.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.7.param' => ['0'],
	'se.pat.ringer.ringer8.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.7.value' => ['Gb3Major'],
	'se.pat.ringer.ringer8.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.8.param' => ['0'],
	'se.pat.ringer.ringer8.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.8.value' => ['A4Major'],
	'se.pat.ringer.ringer8.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer8.inst.9.param' => ['0'],
	'se.pat.ringer.ringer8.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer8.inst.9.value' => ['Gb3Major'],
	'se.pat.ringer.ringer8.name' => ['Highest Trill'],
	'se.pat.ringer.ringer9.inst.1.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.1.param' => ['0'],
	'se.pat.ringer.ringer9.inst.1.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.1.value' => ['Gb3Major'],
	'se.pat.ringer.ringer9.inst.10.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.10.param' => ['0'],
	'se.pat.ringer.ringer9.inst.10.type' => ['silence'],
	'se.pat.ringer.ringer9.inst.10.value' => ['2000'],
	'se.pat.ringer.ringer9.inst.11.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.11.param' => ['0'],
	'se.pat.ringer.ringer9.inst.11.type' => ['branch'],
	'se.pat.ringer.ringer9.inst.11.value' => ['-10'],
	'se.pat.ringer.ringer9.inst.12.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.12.param' => ['0'],
	'se.pat.ringer.ringer9.inst.12.type' => [''],
	'se.pat.ringer.ringer9.inst.12.value' => [''],
	'se.pat.ringer.ringer9.inst.13.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.13.param' => ['0'],
	'se.pat.ringer.ringer9.inst.13.type' => [''],
	'se.pat.ringer.ringer9.inst.13.value' => [''],
	'se.pat.ringer.ringer9.inst.14.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.14.param' => ['0'],
	'se.pat.ringer.ringer9.inst.14.type' => [''],
	'se.pat.ringer.ringer9.inst.14.value' => [''],
	'se.pat.ringer.ringer9.inst.15.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.15.param' => ['0'],
	'se.pat.ringer.ringer9.inst.15.type' => [''],
	'se.pat.ringer.ringer9.inst.15.value' => [''],
	'se.pat.ringer.ringer9.inst.16.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.16.param' => ['0'],
	'se.pat.ringer.ringer9.inst.16.type' => [''],
	'se.pat.ringer.ringer9.inst.16.value' => [''],
	'se.pat.ringer.ringer9.inst.17.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.17.param' => ['0'],
	'se.pat.ringer.ringer9.inst.17.type' => [''],
	'se.pat.ringer.ringer9.inst.17.value' => [''],
	'se.pat.ringer.ringer9.inst.18.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.18.param' => ['0'],
	'se.pat.ringer.ringer9.inst.18.type' => [''],
	'se.pat.ringer.ringer9.inst.18.value' => [''],
	'se.pat.ringer.ringer9.inst.19.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.19.param' => ['0'],
	'se.pat.ringer.ringer9.inst.19.type' => [''],
	'se.pat.ringer.ringer9.inst.19.value' => [''],
	'se.pat.ringer.ringer9.inst.2.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.2.param' => ['0'],
	'se.pat.ringer.ringer9.inst.2.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.2.value' => ['A4Major'],
	'se.pat.ringer.ringer9.inst.20.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.20.param' => ['0'],
	'se.pat.ringer.ringer9.inst.20.type' => [''],
	'se.pat.ringer.ringer9.inst.20.value' => [''],
	'se.pat.ringer.ringer9.inst.21.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.21.param' => ['0'],
	'se.pat.ringer.ringer9.inst.21.type' => [''],
	'se.pat.ringer.ringer9.inst.21.value' => [''],
	'se.pat.ringer.ringer9.inst.22.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.22.param' => ['0'],
	'se.pat.ringer.ringer9.inst.22.type' => [''],
	'se.pat.ringer.ringer9.inst.22.value' => [''],
	'se.pat.ringer.ringer9.inst.23.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.23.param' => ['0'],
	'se.pat.ringer.ringer9.inst.23.type' => [''],
	'se.pat.ringer.ringer9.inst.23.value' => [''],
	'se.pat.ringer.ringer9.inst.24.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.24.param' => ['0'],
	'se.pat.ringer.ringer9.inst.24.type' => [''],
	'se.pat.ringer.ringer9.inst.24.value' => [''],
	'se.pat.ringer.ringer9.inst.25.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.25.param' => ['0'],
	'se.pat.ringer.ringer9.inst.25.type' => [''],
	'se.pat.ringer.ringer9.inst.25.value' => [''],
	'se.pat.ringer.ringer9.inst.26.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.26.param' => ['0'],
	'se.pat.ringer.ringer9.inst.26.type' => [''],
	'se.pat.ringer.ringer9.inst.26.value' => [''],
	'se.pat.ringer.ringer9.inst.27.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.27.param' => ['0'],
	'se.pat.ringer.ringer9.inst.27.type' => [''],
	'se.pat.ringer.ringer9.inst.27.value' => [''],
	'se.pat.ringer.ringer9.inst.28.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.28.param' => ['0'],
	'se.pat.ringer.ringer9.inst.28.type' => [''],
	'se.pat.ringer.ringer9.inst.28.value' => [''],
	'se.pat.ringer.ringer9.inst.29.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.29.param' => ['0'],
	'se.pat.ringer.ringer9.inst.29.type' => [''],
	'se.pat.ringer.ringer9.inst.29.value' => [''],
	'se.pat.ringer.ringer9.inst.3.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.3.param' => ['0'],
	'se.pat.ringer.ringer9.inst.3.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.3.value' => ['Gb3Major'],
	'se.pat.ringer.ringer9.inst.30.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.30.param' => ['0'],
	'se.pat.ringer.ringer9.inst.30.type' => [''],
	'se.pat.ringer.ringer9.inst.30.value' => [''],
	'se.pat.ringer.ringer9.inst.31.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.31.param' => ['0'],
	'se.pat.ringer.ringer9.inst.31.type' => [''],
	'se.pat.ringer.ringer9.inst.31.value' => [''],
	'se.pat.ringer.ringer9.inst.32.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.32.param' => ['0'],
	'se.pat.ringer.ringer9.inst.32.type' => [''],
	'se.pat.ringer.ringer9.inst.32.value' => [''],
	'se.pat.ringer.ringer9.inst.4.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.4.param' => ['0'],
	'se.pat.ringer.ringer9.inst.4.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.4.value' => ['A4Major'],
	'se.pat.ringer.ringer9.inst.5.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.5.param' => ['0'],
	'se.pat.ringer.ringer9.inst.5.type' => ['silence'],
	'se.pat.ringer.ringer9.inst.5.value' => ['200'],
	'se.pat.ringer.ringer9.inst.6.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.6.param' => ['0'],
	'se.pat.ringer.ringer9.inst.6.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.6.value' => ['Gb3Major'],
	'se.pat.ringer.ringer9.inst.7.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.7.param' => ['0'],
	'se.pat.ringer.ringer9.inst.7.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.7.value' => ['A4Major'],
	'se.pat.ringer.ringer9.inst.8.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.8.param' => ['0'],
	'se.pat.ringer.ringer9.inst.8.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.8.value' => ['Gb3Major'],
	'se.pat.ringer.ringer9.inst.9.atten' => ['0'],
	'se.pat.ringer.ringer9.inst.9.param' => ['0'],
	'se.pat.ringer.ringer9.inst.9.type' => ['chord'],
	'se.pat.ringer.ringer9.inst.9.value' => ['A4Major'],
	'se.pat.ringer.ringer9.name' => ['Highest Double Trill'],
	'se.rt.autoAnswer.callWait' => ['callWaiting'],
	'se.rt.autoAnswer.mod' => ['1'],
	'se.rt.autoAnswer.name' => ['Auto Answer'],
	'se.rt.autoAnswer.ringer' => ['ringer2'],
	'se.rt.autoAnswer.timeout' => ['2000'],
	'se.rt.autoAnswer.type' => ['answer'],
	'se.rt.custom1.callWait' => ['callWaitingLong'],
	'se.rt.custom1.mod' => ['1'],
	'se.rt.custom1.name' => ['Custom 1'],
	'se.rt.custom1.ringer' => ['ringer5'],
	'se.rt.custom1.timeout' => ['2000'],
	'se.rt.custom1.type' => ['ring'],
	'se.rt.custom10.callWait' => ['callWaiting'],
	'se.rt.custom10.mod' => ['1'],
	'se.rt.custom10.name' => ['Custom 10'],
	'se.rt.custom10.ringer' => ['ringer2'],
	'se.rt.custom10.timeout' => ['2000'],
	'se.rt.custom10.type' => ['ring'],
	'se.rt.custom11.callWait' => ['callWaiting'],
	'se.rt.custom11.mod' => ['1'],
	'se.rt.custom11.name' => ['Custom 11'],
	'se.rt.custom11.ringer' => ['ringer2'],
	'se.rt.custom11.timeout' => ['2000'],
	'se.rt.custom11.type' => ['ring'],
	'se.rt.custom12.callWait' => ['callWaiting'],
	'se.rt.custom12.mod' => ['1'],
	'se.rt.custom12.name' => ['Custom 12'],
	'se.rt.custom12.ringer' => ['ringer2'],
	'se.rt.custom12.timeout' => ['2000'],
	'se.rt.custom12.type' => ['ring'],
	'se.rt.custom13.callWait' => ['callWaiting'],
	'se.rt.custom13.mod' => ['1'],
	'se.rt.custom13.name' => ['Custom 13'],
	'se.rt.custom13.ringer' => ['ringer2'],
	'se.rt.custom13.timeout' => ['2000'],
	'se.rt.custom13.type' => ['ring'],
	'se.rt.custom14.callWait' => ['callWaiting'],
	'se.rt.custom14.mod' => ['1'],
	'se.rt.custom14.name' => ['Custom 14'],
	'se.rt.custom14.ringer' => ['ringer2'],
	'se.rt.custom14.timeout' => ['2000'],
	'se.rt.custom14.type' => ['ring'],
	'se.rt.custom15.callWait' => ['callWaiting'],
	'se.rt.custom15.mod' => ['1'],
	'se.rt.custom15.name' => ['Custom 15'],
	'se.rt.custom15.ringer' => ['ringer2'],
	'se.rt.custom15.timeout' => ['2000'],
	'se.rt.custom15.type' => ['ring'],
	'se.rt.custom16.callWait' => ['callWaiting'],
	'se.rt.custom16.mod' => ['1'],
	'se.rt.custom16.name' => ['Custom 16'],
	'se.rt.custom16.ringer' => ['ringer2'],
	'se.rt.custom16.timeout' => ['2000'],
	'se.rt.custom16.type' => ['ring'],
	'se.rt.custom17.callWait' => ['callWaiting'],
	'se.rt.custom17.mod' => ['1'],
	'se.rt.custom17.name' => ['Custom 17'],
	'se.rt.custom17.ringer' => ['ringer2'],
	'se.rt.custom17.timeout' => ['2000'],
	'se.rt.custom17.type' => ['ring'],
	'se.rt.custom2.callWait' => ['callWaitingLong'],
	'se.rt.custom2.mod' => ['1'],
	'se.rt.custom2.name' => ['Custom 2'],
	'se.rt.custom2.ringer' => ['ringer7'],
	'se.rt.custom2.timeout' => ['2000'],
	'se.rt.custom2.type' => ['ring'],
	'se.rt.custom3.callWait' => ['callWaitingLong'],
	'se.rt.custom3.mod' => ['1'],
	'se.rt.custom3.name' => ['Custom 3'],
	'se.rt.custom3.ringer' => ['ringer9'],
	'se.rt.custom3.timeout' => ['2000'],
	'se.rt.custom3.type' => ['ring'],
	'se.rt.custom4.callWait' => ['callWaitingLong'],
	'se.rt.custom4.mod' => ['1'],
	'se.rt.custom4.name' => ['Custom 4'],
	'se.rt.custom4.ringer' => ['ringer11'],
	'se.rt.custom4.timeout' => ['2000'],
	'se.rt.custom4.type' => ['ring'],
	'se.rt.custom5.callWait' => ['callWaiting'],
	'se.rt.custom5.mod' => ['1'],
	'se.rt.custom5.name' => ['Custom 5'],
	'se.rt.custom5.ringer' => ['ringer2'],
	'se.rt.custom5.timeout' => ['2000'],
	'se.rt.custom5.type' => ['ring'],
	'se.rt.custom6.callWait' => ['callWaiting'],
	'se.rt.custom6.mod' => ['1'],
	'se.rt.custom6.name' => ['Custom 6'],
	'se.rt.custom6.ringer' => ['ringer2'],
	'se.rt.custom6.timeout' => ['2000'],
	'se.rt.custom6.type' => ['ring'],
	'se.rt.custom7.callWait' => ['callWaiting'],
	'se.rt.custom7.mod' => ['1'],
	'se.rt.custom7.name' => ['Custom 7'],
	'se.rt.custom7.ringer' => ['ringer2'],
	'se.rt.custom7.timeout' => ['2000'],
	'se.rt.custom7.type' => ['ring'],
	'se.rt.custom8.callWait' => ['callWaiting'],
	'se.rt.custom8.mod' => ['1'],
	'se.rt.custom8.name' => ['Custom 8'],
	'se.rt.custom8.ringer' => ['ringer2'],
	'se.rt.custom8.timeout' => ['2000'],
	'se.rt.custom8.type' => ['ring'],
	'se.rt.custom9.callWait' => ['callWaiting'],
	'se.rt.custom9.mod' => ['1'],
	'se.rt.custom9.name' => ['Custom 9'],
	'se.rt.custom9.ringer' => ['ringer2'],
	'se.rt.custom9.timeout' => ['2000'],
	'se.rt.custom9.type' => ['ring'],
	'se.rt.default.callWait' => ['callWaiting'],
	'se.rt.default.mod' => ['1'],
	'se.rt.default.name' => ['Default'],
	'se.rt.default.ringer' => ['ringer2'],
	'se.rt.default.timeout' => ['2000'],
	'se.rt.default.type' => ['ring'],
	'se.rt.emergency.callWait' => ['callWaiting'],
	'se.rt.emergency.mod' => ['1'],
	'se.rt.emergency.name' => ['Emergency'],
	'se.rt.emergency.ringer' => ['ringer2'],
	'se.rt.emergency.timeout' => ['2000'],
	'se.rt.emergency.type' => ['ring'],
	'se.rt.enabled' => ['1'],
	'se.rt.external.callWait' => ['callWaiting'],
	'se.rt.external.mod' => ['1'],
	'se.rt.external.name' => ['External'],
	'se.rt.external.ringer' => ['ringer2'],
	'se.rt.external.timeout' => ['2000'],
	'se.rt.external.type' => ['ring'],
	'se.rt.internal.callWait' => ['callWaiting'],
	'se.rt.internal.mod' => ['1'],
	'se.rt.internal.name' => ['Internal'],
	'se.rt.internal.ringer' => ['ringer2'],
	'se.rt.internal.timeout' => ['2000'],
	'se.rt.internal.type' => ['ring'],
	'se.rt.modification.enabled' => ['1'],
	'se.rt.precedence.callWait' => ['precedenceCallWaiting'],
	'se.rt.precedence.mod' => ['1'],
	'se.rt.precedence.name' => ['Precedence'],
	'se.rt.precedence.ringer' => ['ringer13'],
	'se.rt.precedence.timeout' => ['2000'],
	'se.rt.precedence.type' => ['ring'],
	'se.rt.ringAutoAnswer.callWait' => ['callWaiting'],
	'se.rt.ringAutoAnswer.mod' => ['1'],
	'se.rt.ringAutoAnswer.name' => ['Ring Answer'],
	'se.rt.ringAutoAnswer.ringer' => ['ringer2'],
	'se.rt.ringAutoAnswer.timeout' => ['2000'],
	'se.rt.ringAutoAnswer.type' => ['ring-answer'],
	'se.rt.splash.callWait' => ['callWaiting'],
	'se.rt.splash.mod' => ['1'],
	'se.rt.splash.name' => ['Splash'],
	'se.rt.splash.ringer' => ['ringer14'],
	'se.rt.splash.timeout' => ['2000'],
	'se.rt.splash.type' => ['ring'],
	'se.rt.visual.callWait' => ['callWaiting'],
	'se.rt.visual.mod' => ['0'],
	'se.rt.visual.name' => ['Visual'],
	'se.rt.visual.ringer' => ['ringer1'],
	'se.rt.visual.timeout' => ['2000'],
	'se.rt.visual.type' => ['visual'],
	'se.stutterOnVoiceMail' => ['1'],
	'sec.H235.mediaEncryption.enabled' => ['1'],
	'sec.H235.mediaEncryption.offer' => ['0'],
	'sec.H235.mediaEncryption.require' => ['0'],
	'sec.TLS.LDAP.cipherList' => ['NoCipher'],
	'sec.TLS.SIP.cipherList' => ['NoCipher'],
	'sec.TLS.browser.cipherList' => ['NoCipher'],
	'sec.TLS.cipherList' => ['ALL:!DH:!LOW:!EXP:!MD5:@STRENGTH'],
	'sec.TLS.customDeviceCert.enable' => ['0'],
	'sec.TLS.prov.cipherList' => ['NoCipher'],
	'sec.TLS.syslog.cipherList' => ['NoCipher'],
	'sec.TLS.xmpp.cipherList' => ['NoCipher'],
	'sec.dot1x.eapollogoff.enabled' => ['0'],
	'sec.dot1x.eapollogoff.lanlinkreset' => ['0'],
	'sec.encryption.upload.config' => ['0'],
	'sec.encryption.upload.dir' => ['0'],
	'sec.encryption.upload.overrides' => ['0'],
	'sec.pwd.length.admin' => ['1'],
	'sec.pwd.length.user' => ['2'],
	'sec.srtp.answerWithNewKey' => ['1'],
	'sec.srtp.enable' => ['1'],
	'sec.srtp.key.lifetime' => [''],
	'sec.srtp.mki.enabled' => ['0'],
	'sec.srtp.offer' => ['0'],
	'sec.srtp.offer.HMAC_SHA1_32' => ['0'],
	'sec.srtp.offer.HMAC_SHA1_80' => ['1'],
	'sec.srtp.require' => ['0'],
	'sec.srtp.requireMatchingTag' => ['1'],
	'sec.srtp.rx.1.crypto' => [''],
	'sec.srtp.rx.2.crypto' => [''],
	'sec.srtp.rx.3.crypto' => [''],
	'sec.srtp.rx.4.crypto' => [''],
	'sec.srtp.rx.5.crypto' => [''],
	'sec.srtp.sessionParams.noAuth.offer' => ['0'],
	'sec.srtp.sessionParams.noAuth.require' => ['0'],
	'sec.srtp.sessionParams.noEncrypRTCP.offer' => ['0'],
	'sec.srtp.sessionParams.noEncrypRTCP.require' => ['0'],
	'sec.srtp.sessionParams.noEncrypRTP.offer' => ['0'],
	'sec.srtp.sessionParams.noEncrypRTP.require' => ['0'],
	'sec.srtp.tx.crypto' => [''],
	'sec.tagSerialNo' => ['0'],
	'softkey.1.action' => [''],
	'softkey.1.enable' => ['0'],
	'softkey.1.label' => [''],
	'softkey.1.precede' => ['0'],
	'softkey.1.use.active' => ['0'],
	'softkey.1.use.alerting' => ['0'],
	'softkey.1.use.dialtone' => ['0'],
	'softkey.1.use.hold' => ['0'],
	'softkey.1.use.idle' => ['0'],
	'softkey.1.use.proceeding' => ['0'],
	'softkey.1.use.setup' => ['0'],
	'softkey.10.action' => [''],
	'softkey.10.enable' => ['0'],
	'softkey.10.label' => [''],
	'softkey.10.precede' => ['0'],
	'softkey.10.use.active' => ['0'],
	'softkey.10.use.alerting' => ['0'],
	'softkey.10.use.dialtone' => ['0'],
	'softkey.10.use.hold' => ['0'],
	'softkey.10.use.idle' => ['0'],
	'softkey.10.use.proceeding' => ['0'],
	'softkey.10.use.setup' => ['0'],
	'softkey.11.action' => [''],
	'softkey.11.enable' => ['0'],
	'softkey.11.label' => [''],
	'softkey.11.precede' => ['0'],
	'softkey.11.use.active' => ['0'],
	'softkey.11.use.alerting' => ['0'],
	'softkey.11.use.dialtone' => ['0'],
	'softkey.11.use.hold' => ['0'],
	'softkey.11.use.idle' => ['0'],
	'softkey.11.use.proceeding' => ['0'],
	'softkey.11.use.setup' => ['0'],
	'softkey.12.action' => [''],
	'softkey.12.enable' => ['0'],
	'softkey.12.label' => [''],
	'softkey.12.precede' => ['0'],
	'softkey.12.use.active' => ['0'],
	'softkey.12.use.alerting' => ['0'],
	'softkey.12.use.dialtone' => ['0'],
	'softkey.12.use.hold' => ['0'],
	'softkey.12.use.idle' => ['0'],
	'softkey.12.use.proceeding' => ['0'],
	'softkey.12.use.setup' => ['0'],
	'softkey.13.action' => [''],
	'softkey.13.enable' => ['0'],
	'softkey.13.label' => [''],
	'softkey.13.precede' => ['0'],
	'softkey.13.use.active' => ['0'],
	'softkey.13.use.alerting' => ['0'],
	'softkey.13.use.dialtone' => ['0'],
	'softkey.13.use.hold' => ['0'],
	'softkey.13.use.idle' => ['0'],
	'softkey.13.use.proceeding' => ['0'],
	'softkey.13.use.setup' => ['0'],
	'softkey.2.action' => [''],
	'softkey.2.enable' => ['0'],
	'softkey.2.label' => [''],
	'softkey.2.precede' => ['0'],
	'softkey.2.use.active' => ['0'],
	'softkey.2.use.alerting' => ['0'],
	'softkey.2.use.dialtone' => ['0'],
	'softkey.2.use.hold' => ['0'],
	'softkey.2.use.idle' => ['0'],
	'softkey.2.use.proceeding' => ['0'],
	'softkey.2.use.setup' => ['0'],
	'softkey.3.action' => [''],
	'softkey.3.enable' => ['0'],
	'softkey.3.label' => [''],
	'softkey.3.precede' => ['0'],
	'softkey.3.use.active' => ['0'],
	'softkey.3.use.alerting' => ['0'],
	'softkey.3.use.dialtone' => ['0'],
	'softkey.3.use.hold' => ['0'],
	'softkey.3.use.idle' => ['0'],
	'softkey.3.use.proceeding' => ['0'],
	'softkey.3.use.setup' => ['0'],
	'softkey.4.action' => [''],
	'softkey.4.enable' => ['0'],
	'softkey.4.label' => [''],
	'softkey.4.precede' => ['0'],
	'softkey.4.use.active' => ['0'],
	'softkey.4.use.alerting' => ['0'],
	'softkey.4.use.dialtone' => ['0'],
	'softkey.4.use.hold' => ['0'],
	'softkey.4.use.idle' => ['0'],
	'softkey.4.use.proceeding' => ['0'],
	'softkey.4.use.setup' => ['0'],
	'softkey.5.action' => [''],
	'softkey.5.enable' => ['0'],
	'softkey.5.label' => [''],
	'softkey.5.precede' => ['0'],
	'softkey.5.use.active' => ['0'],
	'softkey.5.use.alerting' => ['0'],
	'softkey.5.use.dialtone' => ['0'],
	'softkey.5.use.hold' => ['0'],
	'softkey.5.use.idle' => ['0'],
	'softkey.5.use.proceeding' => ['0'],
	'softkey.5.use.setup' => ['0'],
	'softkey.6.action' => [''],
	'softkey.6.enable' => ['0'],
	'softkey.6.label' => [''],
	'softkey.6.precede' => ['0'],
	'softkey.6.use.active' => ['0'],
	'softkey.6.use.alerting' => ['0'],
	'softkey.6.use.dialtone' => ['0'],
	'softkey.6.use.hold' => ['0'],
	'softkey.6.use.idle' => ['0'],
	'softkey.6.use.proceeding' => ['0'],
	'softkey.6.use.setup' => ['0'],
	'softkey.7.action' => [''],
	'softkey.7.enable' => ['0'],
	'softkey.7.label' => [''],
	'softkey.7.precede' => ['0'],
	'softkey.7.use.active' => ['0'],
	'softkey.7.use.alerting' => ['0'],
	'softkey.7.use.dialtone' => ['0'],
	'softkey.7.use.hold' => ['0'],
	'softkey.7.use.idle' => ['0'],
	'softkey.7.use.proceeding' => ['0'],
	'softkey.7.use.setup' => ['0'],
	'softkey.8.action' => [''],
	'softkey.8.enable' => ['0'],
	'softkey.8.label' => [''],
	'softkey.8.precede' => ['0'],
	'softkey.8.use.active' => ['0'],
	'softkey.8.use.alerting' => ['0'],
	'softkey.8.use.dialtone' => ['0'],
	'softkey.8.use.hold' => ['0'],
	'softkey.8.use.idle' => ['0'],
	'softkey.8.use.proceeding' => ['0'],
	'softkey.8.use.setup' => ['0'],
	'softkey.9.action' => [''],
	'softkey.9.enable' => ['0'],
	'softkey.9.label' => [''],
	'softkey.9.precede' => ['0'],
	'softkey.9.use.active' => ['0'],
	'softkey.9.use.alerting' => ['0'],
	'softkey.9.use.dialtone' => ['0'],
	'softkey.9.use.hold' => ['0'],
	'softkey.9.use.idle' => ['0'],
	'softkey.9.use.proceeding' => ['0'],
	'softkey.9.use.setup' => ['0'],
	'softkey.feature.basicCallManagement.redundant' => ['1'],
	'softkey.feature.buddies' => ['1'],
	'softkey.feature.callers' => ['0'],
	'softkey.feature.callers.SPIP231' => ['1'],
	'softkey.feature.callers.SPIP235T' => ['1'],
	'softkey.feature.callers.SPIP320' => ['1'],
	'softkey.feature.callers.SPIP321' => ['1'],
	'softkey.feature.callers.SPIP330' => ['1'],
	'softkey.feature.callers.SPIP331' => ['1'],
	'softkey.feature.callers.SPIP335' => ['1'],
	'softkey.feature.directories' => ['0'],
	'softkey.feature.directories.SPIP231' => ['1'],
	'softkey.feature.directories.SPIP235T' => ['1'],
	'softkey.feature.directories.SPIP320' => ['1'],
	'softkey.feature.directories.SPIP321' => ['1'],
	'softkey.feature.directories.SPIP330' => ['1'],
	'softkey.feature.directories.SPIP331' => ['1'],
	'softkey.feature.directories.SPIP335' => ['1'],
	'softkey.feature.directories.SSIP7000' => ['1'],
	'softkey.feature.endcall' => ['1'],
	'softkey.feature.forward' => ['1'],
	'softkey.feature.join' => ['1'],
	'softkey.feature.mystatus' => ['1'],
	'softkey.feature.newcall' => ['1'],
	'softkey.feature.split' => ['1'],
	'standalone' => ['yes'],
	'tcpIpApp.dns.altServer' => [''],
	'tcpIpApp.dns.domain' => [''],
	'tcpIpApp.dns.server' => [''],
	'tcpIpApp.keepalive.tcp.idleTransmitInterval' => ['30'],
	'tcpIpApp.keepalive.tcp.noResponseTransmitInterval' => ['20'],
	'tcpIpApp.keepalive.tcp.sip.tls.enable' => ['0'],
	'tcpIpApp.pmt.enabled' => ['0'],
	'tcpIpApp.port.rtp.filterByIp' => ['1'],
	'tcpIpApp.port.rtp.filterByPort' => ['0'],
	'tcpIpApp.port.rtp.forceSend' => ['0'],
	'tcpIpApp.port.rtp.mediaPortRangeStart' => ['2222'],
	'tcpIpApp.sntp.address' => [''],
	'tcpIpApp.sntp.address.overrideDHCP' => ['0'],
	'tcpIpApp.sntp.daylightSavings.enable' => ['1'],
	'tcpIpApp.sntp.daylightSavings.fixedDayEnable' => ['0'],
	'tcpIpApp.sntp.daylightSavings.start.date' => ['8'],
	'tcpIpApp.sntp.daylightSavings.start.dayOfWeek' => ['1'],
	'tcpIpApp.sntp.daylightSavings.start.dayOfWeek.lastInMonth' => ['0'],
	'tcpIpApp.sntp.daylightSavings.start.month' => ['3'],
	'tcpIpApp.sntp.daylightSavings.start.time' => ['2'],
	'tcpIpApp.sntp.daylightSavings.stop.date' => ['1'],
	'tcpIpApp.sntp.daylightSavings.stop.dayOfWeek' => ['1'],
	'tcpIpApp.sntp.daylightSavings.stop.dayOfWeek.lastInMonth' => ['0'],
	'tcpIpApp.sntp.daylightSavings.stop.month' => ['11'],
	'tcpIpApp.sntp.daylightSavings.stop.time' => ['2'],
	'tcpIpApp.sntp.gmtOffset' => ['0'],
	'tcpIpApp.sntp.gmtOffset.overrideDHCP' => ['0'],
	'tcpIpApp.sntp.resyncPeriod' => ['86400'],
	'tone.chord.callProg.busyTone.freq.1' => ['480'],
	'tone.chord.callProg.busyTone.freq.2' => ['620'],
	'tone.chord.callProg.busyTone.freq.3' => ['0'],
	'tone.chord.callProg.busyTone.freq.4' => ['0'],
	'tone.chord.callProg.busyTone.freq.5' => ['0'],
	'tone.chord.callProg.busyTone.freq.6' => ['0'],
	'tone.chord.callProg.busyTone.level.1' => ['-30'],
	'tone.chord.callProg.busyTone.level.2' => ['-30'],
	'tone.chord.callProg.busyTone.level.3' => ['0'],
	'tone.chord.callProg.busyTone.level.4' => ['0'],
	'tone.chord.callProg.busyTone.level.5' => ['0'],
	'tone.chord.callProg.busyTone.level.6' => ['0'],
	'tone.chord.callProg.busyTone.offDur' => ['500'],
	'tone.chord.callProg.busyTone.onDur' => ['500'],
	'tone.chord.callProg.busyTone.repeat' => ['0'],
	'tone.chord.callProg.callWaiting.freq.1' => ['440'],
	'tone.chord.callProg.callWaiting.freq.2' => ['0'],
	'tone.chord.callProg.callWaiting.freq.3' => ['0'],
	'tone.chord.callProg.callWaiting.freq.4' => ['0'],
	'tone.chord.callProg.callWaiting.freq.5' => ['0'],
	'tone.chord.callProg.callWaiting.freq.6' => ['0'],
	'tone.chord.callProg.callWaiting.level.1' => ['-19'],
	'tone.chord.callProg.callWaiting.level.2' => ['0'],
	'tone.chord.callProg.callWaiting.level.3' => ['0'],
	'tone.chord.callProg.callWaiting.level.4' => ['0'],
	'tone.chord.callProg.callWaiting.level.5' => ['0'],
	'tone.chord.callProg.callWaiting.level.6' => ['0'],
	'tone.chord.callProg.callWaiting.offDur' => ['10000', 10000 ],
	'tone.chord.callProg.callWaiting.onDur' => ['300'],
	'tone.chord.callProg.callWaiting.repeat' => ['2'],
	'tone.chord.callProg.callWaitingLong.freq.1' => ['440'],
	'tone.chord.callProg.callWaitingLong.freq.2' => ['0'],
	'tone.chord.callProg.callWaitingLong.freq.3' => ['0'],
	'tone.chord.callProg.callWaitingLong.freq.4' => ['0'],
	'tone.chord.callProg.callWaitingLong.freq.5' => ['0'],
	'tone.chord.callProg.callWaitingLong.freq.6' => ['0'],
	'tone.chord.callProg.callWaitingLong.level.1' => ['-19'],
	'tone.chord.callProg.callWaitingLong.level.2' => ['0'],
	'tone.chord.callProg.callWaitingLong.level.3' => ['0'],
	'tone.chord.callProg.callWaitingLong.level.4' => ['0'],
	'tone.chord.callProg.callWaitingLong.level.5' => ['0'],
	'tone.chord.callProg.callWaitingLong.level.6' => ['0'],
	'tone.chord.callProg.callWaitingLong.offDur' => ['150'],
	'tone.chord.callProg.callWaitingLong.onDur' => ['300'],
	'tone.chord.callProg.callWaitingLong.repeat' => ['2'],
	'tone.chord.callProg.dialTone.freq.1' => ['350'],
	'tone.chord.callProg.dialTone.freq.2' => ['440'],
	'tone.chord.callProg.dialTone.freq.3' => ['0'],
	'tone.chord.callProg.dialTone.freq.4' => ['0'],
	'tone.chord.callProg.dialTone.freq.5' => ['0'],
	'tone.chord.callProg.dialTone.freq.6' => ['0'],
	'tone.chord.callProg.dialTone.level.1' => ['-19'],
	'tone.chord.callProg.dialTone.level.2' => ['-19'],
	'tone.chord.callProg.dialTone.level.3' => ['0'],
	'tone.chord.callProg.dialTone.level.4' => ['0'],
	'tone.chord.callProg.dialTone.level.5' => ['0'],
	'tone.chord.callProg.dialTone.level.6' => ['0'],
	'tone.chord.callProg.dialTone.offDur' => ['0'],
	'tone.chord.callProg.dialTone.onDur' => ['0'],
	'tone.chord.callProg.dialTone.repeat' => ['0'],
	'tone.chord.callProg.howler.freq.1' => ['900'],
	'tone.chord.callProg.howler.freq.2' => ['1100'],
	'tone.chord.callProg.howler.freq.3' => ['1300'],
	'tone.chord.callProg.howler.freq.4' => ['1500'],
	'tone.chord.callProg.howler.freq.5' => ['0'],
	'tone.chord.callProg.howler.freq.6' => ['0'],
	'tone.chord.callProg.howler.level.1' => ['-12'],
	'tone.chord.callProg.howler.level.2' => ['-12'],
	'tone.chord.callProg.howler.level.3' => ['-12'],
	'tone.chord.callProg.howler.level.4' => ['-12'],
	'tone.chord.callProg.howler.level.5' => ['0'],
	'tone.chord.callProg.howler.level.6' => ['0'],
	'tone.chord.callProg.howler.offDur' => ['100'],
	'tone.chord.callProg.howler.onDur' => ['100'],
	'tone.chord.callProg.howler.repeat' => ['0'],
	'tone.chord.callProg.intercom.freq.1' => ['550'],
	'tone.chord.callProg.intercom.freq.2' => ['0'],
	'tone.chord.callProg.intercom.freq.3' => ['0'],
	'tone.chord.callProg.intercom.freq.4' => ['0'],
	'tone.chord.callProg.intercom.freq.5' => ['0'],
	'tone.chord.callProg.intercom.freq.6' => ['0'],
	'tone.chord.callProg.intercom.level.1' => ['-19'],
	'tone.chord.callProg.intercom.level.2' => ['0'],
	'tone.chord.callProg.intercom.level.3' => ['0'],
	'tone.chord.callProg.intercom.level.4' => ['0'],
	'tone.chord.callProg.intercom.level.5' => ['0'],
	'tone.chord.callProg.intercom.level.6' => ['0'],
	'tone.chord.callProg.intercom.offDur' => ['0'],
	'tone.chord.callProg.intercom.onDur' => ['500'],
	'tone.chord.callProg.intercom.repeat' => ['1'],
	'tone.chord.callProg.precedenceCallWaiting.freq.1' => ['440'],
	'tone.chord.callProg.precedenceCallWaiting.freq.2' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.freq.3' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.freq.4' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.freq.5' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.freq.6' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.level.1' => ['-19'],
	'tone.chord.callProg.precedenceCallWaiting.level.2' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.level.3' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.level.4' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.level.5' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.level.6' => ['0'],
	'tone.chord.callProg.precedenceCallWaiting.offDur' => ['50'],
	'tone.chord.callProg.precedenceCallWaiting.onDur' => ['100'],
	'tone.chord.callProg.precedenceCallWaiting.repeat' => ['3'],
	'tone.chord.callProg.precedenceRingback.freq.1' => ['440'],
	'tone.chord.callProg.precedenceRingback.freq.2' => ['480'],
	'tone.chord.callProg.precedenceRingback.freq.3' => ['0'],
	'tone.chord.callProg.precedenceRingback.freq.4' => ['0'],
	'tone.chord.callProg.precedenceRingback.freq.5' => ['0'],
	'tone.chord.callProg.precedenceRingback.freq.6' => ['0'],
	'tone.chord.callProg.precedenceRingback.level.1' => ['-25'],
	'tone.chord.callProg.precedenceRingback.level.2' => ['-25'],
	'tone.chord.callProg.precedenceRingback.level.3' => ['0'],
	'tone.chord.callProg.precedenceRingback.level.4' => ['0'],
	'tone.chord.callProg.precedenceRingback.level.5' => ['0'],
	'tone.chord.callProg.precedenceRingback.level.6' => ['0'],
	'tone.chord.callProg.precedenceRingback.offDur' => ['360'],
	'tone.chord.callProg.precedenceRingback.onDur' => ['1640'],
	'tone.chord.callProg.precedenceRingback.repeat' => ['0'],
	'tone.chord.callProg.preemption.freq.1' => ['440'],
	'tone.chord.callProg.preemption.freq.2' => ['620'],
	'tone.chord.callProg.preemption.freq.3' => ['0'],
	'tone.chord.callProg.preemption.freq.4' => ['0'],
	'tone.chord.callProg.preemption.freq.5' => ['0'],
	'tone.chord.callProg.preemption.freq.6' => ['0'],
	'tone.chord.callProg.preemption.level.1' => ['-19'],
	'tone.chord.callProg.preemption.level.2' => ['-19'],
	'tone.chord.callProg.preemption.level.3' => ['0'],
	'tone.chord.callProg.preemption.level.4' => ['0'],
	'tone.chord.callProg.preemption.level.5' => ['0'],
	'tone.chord.callProg.preemption.level.6' => ['0'],
	'tone.chord.callProg.preemption.offDur' => ['0'],
	'tone.chord.callProg.preemption.onDur' => ['0'],
	'tone.chord.callProg.preemption.repeat' => ['0'],
	'tone.chord.callProg.recWarning.freq.1' => ['1400'],
	'tone.chord.callProg.recWarning.freq.2' => ['0'],
	'tone.chord.callProg.recWarning.freq.3' => ['0'],
	'tone.chord.callProg.recWarning.freq.4' => ['0'],
	'tone.chord.callProg.recWarning.freq.5' => ['0'],
	'tone.chord.callProg.recWarning.freq.6' => ['0'],
	'tone.chord.callProg.recWarning.level.1' => ['-25'],
	'tone.chord.callProg.recWarning.level.2' => ['0'],
	'tone.chord.callProg.recWarning.level.3' => ['0'],
	'tone.chord.callProg.recWarning.level.4' => ['0'],
	'tone.chord.callProg.recWarning.level.5' => ['0'],
	'tone.chord.callProg.recWarning.level.6' => ['0'],
	'tone.chord.callProg.recWarning.offDur' => ['0'],
	'tone.chord.callProg.recWarning.onDur' => ['500'],
	'tone.chord.callProg.recWarning.repeat' => ['1'],
	'tone.chord.callProg.reorder.freq.1' => ['480'],
	'tone.chord.callProg.reorder.freq.2' => ['620'],
	'tone.chord.callProg.reorder.freq.3' => ['0'],
	'tone.chord.callProg.reorder.freq.4' => ['0'],
	'tone.chord.callProg.reorder.freq.5' => ['0'],
	'tone.chord.callProg.reorder.freq.6' => ['0'],
	'tone.chord.callProg.reorder.level.1' => ['-30'],
	'tone.chord.callProg.reorder.level.2' => ['-30'],
	'tone.chord.callProg.reorder.level.3' => ['-30'],
	'tone.chord.callProg.reorder.level.4' => ['-30'],
	'tone.chord.callProg.reorder.level.5' => ['-30'],
	'tone.chord.callProg.reorder.level.6' => ['-30'],
	'tone.chord.callProg.reorder.offDur' => ['250'],
	'tone.chord.callProg.reorder.onDur' => ['250'],
	'tone.chord.callProg.reorder.repeat' => ['0'],
	'tone.chord.callProg.ringback.freq.1' => ['440'],
	'tone.chord.callProg.ringback.freq.2' => ['480'],
	'tone.chord.callProg.ringback.freq.3' => ['0'],
	'tone.chord.callProg.ringback.freq.4' => ['0'],
	'tone.chord.callProg.ringback.freq.5' => ['0'],
	'tone.chord.callProg.ringback.freq.6' => ['0'],
	'tone.chord.callProg.ringback.level.1' => ['-25'],
	'tone.chord.callProg.ringback.level.2' => ['-25'],
	'tone.chord.callProg.ringback.level.3' => ['0'],
	'tone.chord.callProg.ringback.level.4' => ['0'],
	'tone.chord.callProg.ringback.level.5' => ['0'],
	'tone.chord.callProg.ringback.level.6' => ['0'],
	'tone.chord.callProg.ringback.offDur' => ['4000'],
	'tone.chord.callProg.ringback.onDur' => ['2000'],
	'tone.chord.callProg.ringback.repeat' => ['0'],
	'tone.chord.callProg.spare1.freq.1' => ['0'],
	'tone.chord.callProg.spare1.freq.2' => ['0'],
	'tone.chord.callProg.spare1.freq.3' => ['0'],
	'tone.chord.callProg.spare1.freq.4' => ['0'],
	'tone.chord.callProg.spare1.freq.5' => ['0'],
	'tone.chord.callProg.spare1.freq.6' => ['0'],
	'tone.chord.callProg.spare1.level.1' => ['0'],
	'tone.chord.callProg.spare1.level.2' => ['0'],
	'tone.chord.callProg.spare1.level.3' => ['0'],
	'tone.chord.callProg.spare1.level.4' => ['0'],
	'tone.chord.callProg.spare1.level.5' => ['0'],
	'tone.chord.callProg.spare1.level.6' => ['0'],
	'tone.chord.callProg.spare1.offDur' => ['0'],
	'tone.chord.callProg.spare1.onDur' => ['100'],
	'tone.chord.callProg.spare1.repeat' => ['1'],
	'tone.chord.callProg.spare2.freq.1' => ['0'],
	'tone.chord.callProg.spare2.freq.2' => ['0'],
	'tone.chord.callProg.spare2.freq.3' => ['0'],
	'tone.chord.callProg.spare2.freq.4' => ['0'],
	'tone.chord.callProg.spare2.freq.5' => ['0'],
	'tone.chord.callProg.spare2.freq.6' => ['0'],
	'tone.chord.callProg.spare2.level.1' => ['0'],
	'tone.chord.callProg.spare2.level.2' => ['0'],
	'tone.chord.callProg.spare2.level.3' => ['0'],
	'tone.chord.callProg.spare2.level.4' => ['0'],
	'tone.chord.callProg.spare2.level.5' => ['0'],
	'tone.chord.callProg.spare2.level.6' => ['0'],
	'tone.chord.callProg.spare2.offDur' => ['0'],
	'tone.chord.callProg.spare2.onDur' => ['100'],
	'tone.chord.callProg.spare2.repeat' => ['1'],
	'tone.chord.callProg.spare3.freq.1' => ['0'],
	'tone.chord.callProg.spare3.freq.2' => ['0'],
	'tone.chord.callProg.spare3.freq.3' => ['0'],
	'tone.chord.callProg.spare3.freq.4' => ['0'],
	'tone.chord.callProg.spare3.freq.5' => ['0'],
	'tone.chord.callProg.spare3.freq.6' => ['0'],
	'tone.chord.callProg.spare3.level.1' => ['0'],
	'tone.chord.callProg.spare3.level.2' => ['0'],
	'tone.chord.callProg.spare3.level.3' => ['0'],
	'tone.chord.callProg.spare3.level.4' => ['0'],
	'tone.chord.callProg.spare3.level.5' => ['0'],
	'tone.chord.callProg.spare3.level.6' => ['0'],
	'tone.chord.callProg.spare3.offDur' => ['0'],
	'tone.chord.callProg.spare3.onDur' => ['100'],
	'tone.chord.callProg.spare3.repeat' => ['1'],
	'tone.chord.callProg.spare4.freq.1' => ['0'],
	'tone.chord.callProg.spare4.freq.2' => ['0'],
	'tone.chord.callProg.spare4.freq.3' => ['0'],
	'tone.chord.callProg.spare4.freq.4' => ['0'],
	'tone.chord.callProg.spare4.freq.5' => ['0'],
	'tone.chord.callProg.spare4.freq.6' => ['0'],
	'tone.chord.callProg.spare4.level.1' => ['0'],
	'tone.chord.callProg.spare4.level.2' => ['0'],
	'tone.chord.callProg.spare4.level.3' => ['0'],
	'tone.chord.callProg.spare4.level.4' => ['0'],
	'tone.chord.callProg.spare4.level.5' => ['0'],
	'tone.chord.callProg.spare4.level.6' => ['0'],
	'tone.chord.callProg.spare4.offDur' => ['0'],
	'tone.chord.callProg.spare4.onDur' => ['100'],
	'tone.chord.callProg.spare4.repeat' => ['1'],
	'tone.chord.callProg.spare5.freq.1' => ['0'],
	'tone.chord.callProg.spare5.freq.2' => ['0'],
	'tone.chord.callProg.spare5.freq.3' => ['0'],
	'tone.chord.callProg.spare5.freq.4' => ['0'],
	'tone.chord.callProg.spare5.freq.5' => ['0'],
	'tone.chord.callProg.spare5.freq.6' => ['0'],
	'tone.chord.callProg.spare5.level.1' => ['0'],
	'tone.chord.callProg.spare5.level.2' => ['0'],
	'tone.chord.callProg.spare5.level.3' => ['0'],
	'tone.chord.callProg.spare5.level.4' => ['0'],
	'tone.chord.callProg.spare5.level.5' => ['0'],
	'tone.chord.callProg.spare5.level.6' => ['0'],
	'tone.chord.callProg.spare5.offDur' => ['0'],
	'tone.chord.callProg.spare5.onDur' => ['100'],
	'tone.chord.callProg.spare5.repeat' => ['1'],
	'tone.chord.callProg.spare6.freq.1' => ['0'],
	'tone.chord.callProg.spare6.freq.2' => ['0'],
	'tone.chord.callProg.spare6.freq.3' => ['0'],
	'tone.chord.callProg.spare6.freq.4' => ['0'],
	'tone.chord.callProg.spare6.freq.5' => ['0'],
	'tone.chord.callProg.spare6.freq.6' => ['0'],
	'tone.chord.callProg.spare6.level.1' => ['0'],
	'tone.chord.callProg.spare6.level.2' => ['0'],
	'tone.chord.callProg.spare6.level.3' => ['0'],
	'tone.chord.callProg.spare6.level.4' => ['0'],
	'tone.chord.callProg.spare6.level.5' => ['0'],
	'tone.chord.callProg.spare6.level.6' => ['0'],
	'tone.chord.callProg.spare6.offDur' => ['0'],
	'tone.chord.callProg.spare6.onDur' => ['100'],
	'tone.chord.callProg.spare6.repeat' => ['1'],
	'tone.chord.callProg.stutterLong.freq.1' => ['350'],
	'tone.chord.callProg.stutterLong.freq.2' => ['440'],
	'tone.chord.callProg.stutterLong.freq.3' => ['0'],
	'tone.chord.callProg.stutterLong.freq.4' => ['0'],
	'tone.chord.callProg.stutterLong.freq.5' => ['0'],
	'tone.chord.callProg.stutterLong.freq.6' => ['0'],
	'tone.chord.callProg.stutterLong.level.1' => ['-19'],
	'tone.chord.callProg.stutterLong.level.2' => ['-19'],
	'tone.chord.callProg.stutterLong.level.3' => ['0'],
	'tone.chord.callProg.stutterLong.level.4' => ['0'],
	'tone.chord.callProg.stutterLong.level.5' => ['0'],
	'tone.chord.callProg.stutterLong.level.6' => ['0'],
	'tone.chord.callProg.stutterLong.offDur' => ['100'],
	'tone.chord.callProg.stutterLong.onDur' => ['100'],
	'tone.chord.callProg.stutterLong.repeat' => ['6'],
	'tone.chord.callProg.stutter_3.freq.1' => ['350'],
	'tone.chord.callProg.stutter_3.freq.2' => ['440'],
	'tone.chord.callProg.stutter_3.freq.3' => ['0'],
	'tone.chord.callProg.stutter_3.freq.4' => ['0'],
	'tone.chord.callProg.stutter_3.freq.5' => ['0'],
	'tone.chord.callProg.stutter_3.freq.6' => ['0'],
	'tone.chord.callProg.stutter_3.level.1' => ['-19'],
	'tone.chord.callProg.stutter_3.level.2' => ['-19'],
	'tone.chord.callProg.stutter_3.level.3' => ['0'],
	'tone.chord.callProg.stutter_3.level.4' => ['0'],
	'tone.chord.callProg.stutter_3.level.5' => ['0'],
	'tone.chord.callProg.stutter_3.level.6' => ['0'],
	'tone.chord.callProg.stutter_3.offDur' => ['100'],
	'tone.chord.callProg.stutter_3.onDur' => ['100'],
	'tone.chord.callProg.stutter_3.repeat' => ['3'],
	'tone.chord.misc.cs1.freq.1' => ['440'],
	'tone.chord.misc.cs1.freq.2' => ['554'],
	'tone.chord.misc.cs1.freq.3' => ['659'],
	'tone.chord.misc.cs1.freq.4' => ['0'],
	'tone.chord.misc.cs1.freq.5' => ['0'],
	'tone.chord.misc.cs1.freq.6' => ['0'],
	'tone.chord.misc.cs1.level.1' => ['-10'],
	'tone.chord.misc.cs1.level.2' => ['-10'],
	'tone.chord.misc.cs1.level.3' => ['-10'],
	'tone.chord.misc.cs1.level.4' => ['0'],
	'tone.chord.misc.cs1.level.5' => ['0'],
	'tone.chord.misc.cs1.level.6' => ['0'],
	'tone.chord.misc.cs1.offDur' => ['0'],
	'tone.chord.misc.cs1.onDur' => ['100'],
	'tone.chord.misc.cs1.repeat' => ['1'],
	'tone.chord.misc.cs10.freq.1' => ['1046'],
	'tone.chord.misc.cs10.freq.2' => ['0'],
	'tone.chord.misc.cs10.freq.3' => ['0'],
	'tone.chord.misc.cs10.freq.4' => ['0'],
	'tone.chord.misc.cs10.freq.5' => ['0'],
	'tone.chord.misc.cs10.freq.6' => ['0'],
	'tone.chord.misc.cs10.level.1' => ['-10'],
	'tone.chord.misc.cs10.level.2' => ['0'],
	'tone.chord.misc.cs10.level.3' => ['0'],
	'tone.chord.misc.cs10.level.4' => ['0'],
	'tone.chord.misc.cs10.level.5' => ['0'],
	'tone.chord.misc.cs10.level.6' => ['0'],
	'tone.chord.misc.cs10.offDur' => ['0'],
	'tone.chord.misc.cs10.onDur' => ['100'],
	'tone.chord.misc.cs10.repeat' => ['1'],
	'tone.chord.misc.cs11.freq.1' => ['1244'],
	'tone.chord.misc.cs11.freq.2' => ['0'],
	'tone.chord.misc.cs11.freq.3' => ['0'],
	'tone.chord.misc.cs11.freq.4' => ['0'],
	'tone.chord.misc.cs11.freq.5' => ['0'],
	'tone.chord.misc.cs11.freq.6' => ['0'],
	'tone.chord.misc.cs11.level.1' => ['-10'],
	'tone.chord.misc.cs11.level.2' => ['0'],
	'tone.chord.misc.cs11.level.3' => ['0'],
	'tone.chord.misc.cs11.level.4' => ['0'],
	'tone.chord.misc.cs11.level.5' => ['0'],
	'tone.chord.misc.cs11.level.6' => ['0'],
	'tone.chord.misc.cs11.offDur' => ['0'],
	'tone.chord.misc.cs11.onDur' => ['100'],
	'tone.chord.misc.cs11.repeat' => ['1'],
	'tone.chord.misc.cs2.freq.1' => ['493'],
	'tone.chord.misc.cs2.freq.2' => ['622'],
	'tone.chord.misc.cs2.freq.3' => ['740'],
	'tone.chord.misc.cs2.freq.4' => ['0'],
	'tone.chord.misc.cs2.freq.5' => ['0'],
	'tone.chord.misc.cs2.freq.6' => ['0'],
	'tone.chord.misc.cs2.level.1' => ['-10'],
	'tone.chord.misc.cs2.level.2' => ['-10'],
	'tone.chord.misc.cs2.level.3' => ['-10'],
	'tone.chord.misc.cs2.level.4' => ['0'],
	'tone.chord.misc.cs2.level.5' => ['0'],
	'tone.chord.misc.cs2.level.6' => ['0'],
	'tone.chord.misc.cs2.offDur' => ['0'],
	'tone.chord.misc.cs2.onDur' => ['100'],
	'tone.chord.misc.cs2.repeat' => ['1'],
	'tone.chord.misc.cs3.freq.1' => ['523'],
	'tone.chord.misc.cs3.freq.2' => ['659'],
	'tone.chord.misc.cs3.freq.3' => ['784'],
	'tone.chord.misc.cs3.freq.4' => ['0'],
	'tone.chord.misc.cs3.freq.5' => ['0'],
	'tone.chord.misc.cs3.freq.6' => ['0'],
	'tone.chord.misc.cs3.level.1' => ['-10'],
	'tone.chord.misc.cs3.level.2' => ['-10'],
	'tone.chord.misc.cs3.level.3' => ['-10'],
	'tone.chord.misc.cs3.level.4' => ['0'],
	'tone.chord.misc.cs3.level.5' => ['0'],
	'tone.chord.misc.cs3.level.6' => ['0'],
	'tone.chord.misc.cs3.offDur' => ['0'],
	'tone.chord.misc.cs3.onDur' => ['100'],
	'tone.chord.misc.cs3.repeat' => ['1'],
	'tone.chord.misc.cs4.freq.1' => ['659'],
	'tone.chord.misc.cs4.freq.2' => ['831'],
	'tone.chord.misc.cs4.freq.3' => ['988'],
	'tone.chord.misc.cs4.freq.4' => ['0'],
	'tone.chord.misc.cs4.freq.5' => ['0'],
	'tone.chord.misc.cs4.freq.6' => ['0'],
	'tone.chord.misc.cs4.level.1' => ['-10'],
	'tone.chord.misc.cs4.level.2' => ['-10'],
	'tone.chord.misc.cs4.level.3' => ['-10'],
	'tone.chord.misc.cs4.level.4' => ['0'],
	'tone.chord.misc.cs4.level.5' => ['0'],
	'tone.chord.misc.cs4.level.6' => ['0'],
	'tone.chord.misc.cs4.offDur' => ['0'],
	'tone.chord.misc.cs4.onDur' => ['100'],
	'tone.chord.misc.cs4.repeat' => ['1'],
	'tone.chord.misc.cs5.freq.1' => ['880'],
	'tone.chord.misc.cs5.freq.2' => ['1108'],
	'tone.chord.misc.cs5.freq.3' => ['1318'],
	'tone.chord.misc.cs5.freq.4' => ['0'],
	'tone.chord.misc.cs5.freq.5' => ['0'],
	'tone.chord.misc.cs5.freq.6' => ['0'],
	'tone.chord.misc.cs5.level.1' => ['-10'],
	'tone.chord.misc.cs5.level.2' => ['-10'],
	'tone.chord.misc.cs5.level.3' => ['-10'],
	'tone.chord.misc.cs5.level.4' => ['0'],
	'tone.chord.misc.cs5.level.5' => ['0'],
	'tone.chord.misc.cs5.level.6' => ['0'],
	'tone.chord.misc.cs5.offDur' => ['0'],
	'tone.chord.misc.cs5.onDur' => ['100'],
	'tone.chord.misc.cs5.repeat' => ['1'],
	'tone.chord.misc.cs6.freq.1' => ['622'],
	'tone.chord.misc.cs6.freq.2' => ['783'],
	'tone.chord.misc.cs6.freq.3' => ['932'],
	'tone.chord.misc.cs6.freq.4' => ['0'],
	'tone.chord.misc.cs6.freq.5' => ['0'],
	'tone.chord.misc.cs6.freq.6' => ['0'],
	'tone.chord.misc.cs6.level.1' => ['-10'],
	'tone.chord.misc.cs6.level.2' => ['-10'],
	'tone.chord.misc.cs6.level.3' => ['-10'],
	'tone.chord.misc.cs6.level.4' => ['0'],
	'tone.chord.misc.cs6.level.5' => ['0'],
	'tone.chord.misc.cs6.level.6' => ['0'],
	'tone.chord.misc.cs6.offDur' => ['0'],
	'tone.chord.misc.cs6.onDur' => ['100'],
	'tone.chord.misc.cs6.repeat' => ['1'],
	'tone.chord.misc.cs7.freq.1' => ['784'],
	'tone.chord.misc.cs7.freq.2' => ['988'],
	'tone.chord.misc.cs7.freq.3' => ['1174'],
	'tone.chord.misc.cs7.freq.4' => ['0'],
	'tone.chord.misc.cs7.freq.5' => ['0'],
	'tone.chord.misc.cs7.freq.6' => ['0'],
	'tone.chord.misc.cs7.level.1' => ['-10'],
	'tone.chord.misc.cs7.level.2' => ['-10'],
	'tone.chord.misc.cs7.level.3' => ['-10'],
	'tone.chord.misc.cs7.level.4' => ['0'],
	'tone.chord.misc.cs7.level.5' => ['0'],
	'tone.chord.misc.cs7.level.6' => ['0'],
	'tone.chord.misc.cs7.offDur' => ['0'],
	'tone.chord.misc.cs7.onDur' => ['100'],
	'tone.chord.misc.cs7.repeat' => ['1'],
	'tone.chord.misc.cs8.freq.1' => ['494'],
	'tone.chord.misc.cs8.freq.2' => ['0'],
	'tone.chord.misc.cs8.freq.3' => ['0'],
	'tone.chord.misc.cs8.freq.4' => ['0'],
	'tone.chord.misc.cs8.freq.5' => ['0'],
	'tone.chord.misc.cs8.freq.6' => ['0'],
	'tone.chord.misc.cs8.level.1' => ['-10'],
	'tone.chord.misc.cs8.level.2' => ['0'],
	'tone.chord.misc.cs8.level.3' => ['0'],
	'tone.chord.misc.cs8.level.4' => ['0'],
	'tone.chord.misc.cs8.level.5' => ['0'],
	'tone.chord.misc.cs8.level.6' => ['0'],
	'tone.chord.misc.cs8.offDur' => ['0'],
	'tone.chord.misc.cs8.onDur' => ['100'],
	'tone.chord.misc.cs8.repeat' => ['1'],
	'tone.chord.misc.cs9.freq.1' => ['740'],
	'tone.chord.misc.cs9.freq.2' => ['0'],
	'tone.chord.misc.cs9.freq.3' => ['0'],
	'tone.chord.misc.cs9.freq.4' => ['0'],
	'tone.chord.misc.cs9.freq.5' => ['0'],
	'tone.chord.misc.cs9.freq.6' => ['0'],
	'tone.chord.misc.cs9.level.1' => ['-10'],
	'tone.chord.misc.cs9.level.2' => ['0'],
	'tone.chord.misc.cs9.level.3' => ['0'],
	'tone.chord.misc.cs9.level.4' => ['0'],
	'tone.chord.misc.cs9.level.5' => ['0'],
	'tone.chord.misc.cs9.level.6' => ['0'],
	'tone.chord.misc.cs9.offDur' => ['0'],
	'tone.chord.misc.cs9.onDur' => ['100'],
	'tone.chord.misc.cs9.repeat' => ['1'],
	'tone.chord.misc.spare1.freq.1' => ['0'],
	'tone.chord.misc.spare1.freq.2' => ['0'],
	'tone.chord.misc.spare1.freq.3' => ['0'],
	'tone.chord.misc.spare1.freq.4' => ['0'],
	'tone.chord.misc.spare1.freq.5' => ['0'],
	'tone.chord.misc.spare1.freq.6' => ['0'],
	'tone.chord.misc.spare1.level.1' => ['0'],
	'tone.chord.misc.spare1.level.2' => ['0'],
	'tone.chord.misc.spare1.level.3' => ['0'],
	'tone.chord.misc.spare1.level.4' => ['0'],
	'tone.chord.misc.spare1.level.5' => ['0'],
	'tone.chord.misc.spare1.level.6' => ['0'],
	'tone.chord.misc.spare1.offDur' => ['0'],
	'tone.chord.misc.spare1.onDur' => ['100'],
	'tone.chord.misc.spare1.repeat' => ['1'],
	'tone.chord.misc.spare2.freq.1' => ['0'],
	'tone.chord.misc.spare2.freq.2' => ['0'],
	'tone.chord.misc.spare2.freq.3' => ['0'],
	'tone.chord.misc.spare2.freq.4' => ['0'],
	'tone.chord.misc.spare2.freq.5' => ['0'],
	'tone.chord.misc.spare2.freq.6' => ['0'],
	'tone.chord.misc.spare2.level.1' => ['0'],
	'tone.chord.misc.spare2.level.2' => ['0'],
	'tone.chord.misc.spare2.level.3' => ['0'],
	'tone.chord.misc.spare2.level.4' => ['0'],
	'tone.chord.misc.spare2.level.5' => ['0'],
	'tone.chord.misc.spare2.level.6' => ['0'],
	'tone.chord.misc.spare2.offDur' => ['0'],
	'tone.chord.misc.spare2.onDur' => ['100'],
	'tone.chord.misc.spare2.repeat' => ['1'],
	'tone.chord.misc.spare3.freq.1' => ['0'],
	'tone.chord.misc.spare3.freq.2' => ['0'],
	'tone.chord.misc.spare3.freq.3' => ['0'],
	'tone.chord.misc.spare3.freq.4' => ['0'],
	'tone.chord.misc.spare3.freq.5' => ['0'],
	'tone.chord.misc.spare3.freq.6' => ['0'],
	'tone.chord.misc.spare3.level.1' => ['0'],
	'tone.chord.misc.spare3.level.2' => ['0'],
	'tone.chord.misc.spare3.level.3' => ['0'],
	'tone.chord.misc.spare3.level.4' => ['0'],
	'tone.chord.misc.spare3.level.5' => ['0'],
	'tone.chord.misc.spare3.level.6' => ['0'],
	'tone.chord.misc.spare3.offDur' => ['0'],
	'tone.chord.misc.spare3.onDur' => ['100'],
	'tone.chord.misc.spare3.repeat' => ['1'],
	'tone.chord.misc.spare4.freq.1' => ['0'],
	'tone.chord.misc.spare4.freq.2' => ['0'],
	'tone.chord.misc.spare4.freq.3' => ['0'],
	'tone.chord.misc.spare4.freq.4' => ['0'],
	'tone.chord.misc.spare4.freq.5' => ['0'],
	'tone.chord.misc.spare4.freq.6' => ['0'],
	'tone.chord.misc.spare4.level.1' => ['0'],
	'tone.chord.misc.spare4.level.2' => ['0'],
	'tone.chord.misc.spare4.level.3' => ['0'],
	'tone.chord.misc.spare4.level.4' => ['0'],
	'tone.chord.misc.spare4.level.5' => ['0'],
	'tone.chord.misc.spare4.level.6' => ['0'],
	'tone.chord.misc.spare4.offDur' => ['0'],
	'tone.chord.misc.spare4.onDur' => ['100'],
	'tone.chord.misc.spare4.repeat' => ['1'],
	'tone.chord.misc.spare5.freq.1' => ['0'],
	'tone.chord.misc.spare5.freq.2' => ['0'],
	'tone.chord.misc.spare5.freq.3' => ['0'],
	'tone.chord.misc.spare5.freq.4' => ['0'],
	'tone.chord.misc.spare5.freq.5' => ['0'],
	'tone.chord.misc.spare5.freq.6' => ['0'],
	'tone.chord.misc.spare5.level.1' => ['0'],
	'tone.chord.misc.spare5.level.2' => ['0'],
	'tone.chord.misc.spare5.level.3' => ['0'],
	'tone.chord.misc.spare5.level.4' => ['0'],
	'tone.chord.misc.spare5.level.5' => ['0'],
	'tone.chord.misc.spare5.level.6' => ['0'],
	'tone.chord.misc.spare5.offDur' => ['0'],
	'tone.chord.misc.spare5.onDur' => ['100'],
	'tone.chord.misc.spare5.repeat' => ['1'],
	'tone.chord.misc.spare6.freq.1' => ['0'],
	'tone.chord.misc.spare6.freq.2' => ['0'],
	'tone.chord.misc.spare6.freq.3' => ['0'],
	'tone.chord.misc.spare6.freq.4' => ['0'],
	'tone.chord.misc.spare6.freq.5' => ['0'],
	'tone.chord.misc.spare6.freq.6' => ['0'],
	'tone.chord.misc.spare6.level.1' => ['0'],
	'tone.chord.misc.spare6.level.2' => ['0'],
	'tone.chord.misc.spare6.level.3' => ['0'],
	'tone.chord.misc.spare6.level.4' => ['0'],
	'tone.chord.misc.spare6.level.5' => ['0'],
	'tone.chord.misc.spare6.level.6' => ['0'],
	'tone.chord.misc.spare6.offDur' => ['0'],
	'tone.chord.misc.spare6.onDur' => ['100'],
	'tone.chord.misc.spare6.repeat' => ['1'],
	'tone.chord.misc.spare7.freq.1' => ['0'],
	'tone.chord.misc.spare7.freq.2' => ['0'],
	'tone.chord.misc.spare7.freq.3' => ['0'],
	'tone.chord.misc.spare7.freq.4' => ['0'],
	'tone.chord.misc.spare7.freq.5' => ['0'],
	'tone.chord.misc.spare7.freq.6' => ['0'],
	'tone.chord.misc.spare7.level.1' => ['0'],
	'tone.chord.misc.spare7.level.2' => ['0'],
	'tone.chord.misc.spare7.level.3' => ['0'],
	'tone.chord.misc.spare7.level.4' => ['0'],
	'tone.chord.misc.spare7.level.5' => ['0'],
	'tone.chord.misc.spare7.level.6' => ['0'],
	'tone.chord.misc.spare7.offDur' => ['0'],
	'tone.chord.misc.spare7.onDur' => ['100'],
	'tone.chord.misc.spare7.repeat' => ['1'],
	'tone.chord.misc.spare8.freq.1' => ['0'],
	'tone.chord.misc.spare8.freq.2' => ['0'],
	'tone.chord.misc.spare8.freq.3' => ['0'],
	'tone.chord.misc.spare8.freq.4' => ['0'],
	'tone.chord.misc.spare8.freq.5' => ['0'],
	'tone.chord.misc.spare8.freq.6' => ['0'],
	'tone.chord.misc.spare8.level.1' => ['0'],
	'tone.chord.misc.spare8.level.2' => ['0'],
	'tone.chord.misc.spare8.level.3' => ['0'],
	'tone.chord.misc.spare8.level.4' => ['0'],
	'tone.chord.misc.spare8.level.5' => ['0'],
	'tone.chord.misc.spare8.level.6' => ['0'],
	'tone.chord.misc.spare8.offDur' => ['0'],
	'tone.chord.misc.spare8.onDur' => ['100'],
	'tone.chord.misc.spare8.repeat' => ['1'],
	'tone.chord.misc.spare9.freq.1' => ['0'],
	'tone.chord.misc.spare9.freq.2' => ['0'],
	'tone.chord.misc.spare9.freq.3' => ['0'],
	'tone.chord.misc.spare9.freq.4' => ['0'],
	'tone.chord.misc.spare9.freq.5' => ['0'],
	'tone.chord.misc.spare9.freq.6' => ['0'],
	'tone.chord.misc.spare9.level.1' => ['0'],
	'tone.chord.misc.spare9.level.2' => ['0'],
	'tone.chord.misc.spare9.level.3' => ['0'],
	'tone.chord.misc.spare9.level.4' => ['0'],
	'tone.chord.misc.spare9.level.5' => ['0'],
	'tone.chord.misc.spare9.level.6' => ['0'],
	'tone.chord.misc.spare9.offDur' => ['0'],
	'tone.chord.misc.spare9.onDur' => ['100'],
	'tone.chord.misc.spare9.repeat' => ['1'],
	'tone.chord.ringer.A3.freq.1' => ['440'],
	'tone.chord.ringer.A3.freq.2' => ['0'],
	'tone.chord.ringer.A3.freq.3' => ['0'],
	'tone.chord.ringer.A3.freq.4' => ['0'],
	'tone.chord.ringer.A3.freq.5' => ['0'],
	'tone.chord.ringer.A3.freq.6' => ['0'],
	'tone.chord.ringer.A3.level.1' => ['-10'],
	'tone.chord.ringer.A3.level.2' => ['0'],
	'tone.chord.ringer.A3.level.3' => ['0'],
	'tone.chord.ringer.A3.level.4' => ['0'],
	'tone.chord.ringer.A3.level.5' => ['0'],
	'tone.chord.ringer.A3.level.6' => ['0'],
	'tone.chord.ringer.A3.offDur' => ['0'],
	'tone.chord.ringer.A3.onDur' => ['100'],
	'tone.chord.ringer.A3.repeat' => ['1'],
	'tone.chord.ringer.A3Major.freq.1' => ['440'],
	'tone.chord.ringer.A3Major.freq.2' => ['554'],
	'tone.chord.ringer.A3Major.freq.3' => ['659'],
	'tone.chord.ringer.A3Major.freq.4' => ['880'],
	'tone.chord.ringer.A3Major.freq.5' => ['0'],
	'tone.chord.ringer.A3Major.freq.6' => ['0'],
	'tone.chord.ringer.A3Major.level.1' => ['-10'],
	'tone.chord.ringer.A3Major.level.2' => ['-10'],
	'tone.chord.ringer.A3Major.level.3' => ['-10'],
	'tone.chord.ringer.A3Major.level.4' => ['-19'],
	'tone.chord.ringer.A3Major.level.5' => ['0'],
	'tone.chord.ringer.A3Major.level.6' => ['0'],
	'tone.chord.ringer.A3Major.offDur' => ['0'],
	'tone.chord.ringer.A3Major.onDur' => ['100'],
	'tone.chord.ringer.A3Major.repeat' => ['1'],
	'tone.chord.ringer.A4.freq.1' => ['880'],
	'tone.chord.ringer.A4.freq.2' => ['0'],
	'tone.chord.ringer.A4.freq.3' => ['0'],
	'tone.chord.ringer.A4.freq.4' => ['0'],
	'tone.chord.ringer.A4.freq.5' => ['0'],
	'tone.chord.ringer.A4.freq.6' => ['0'],
	'tone.chord.ringer.A4.level.1' => ['-10'],
	'tone.chord.ringer.A4.level.2' => ['0'],
	'tone.chord.ringer.A4.level.3' => ['0'],
	'tone.chord.ringer.A4.level.4' => ['0'],
	'tone.chord.ringer.A4.level.5' => ['0'],
	'tone.chord.ringer.A4.level.6' => ['0'],
	'tone.chord.ringer.A4.offDur' => ['0'],
	'tone.chord.ringer.A4.onDur' => ['100'],
	'tone.chord.ringer.A4.repeat' => ['1'],
	'tone.chord.ringer.A4Major.freq.1' => ['880'],
	'tone.chord.ringer.A4Major.freq.2' => ['1108'],
	'tone.chord.ringer.A4Major.freq.3' => ['1318'],
	'tone.chord.ringer.A4Major.freq.4' => ['1760'],
	'tone.chord.ringer.A4Major.freq.5' => ['0'],
	'tone.chord.ringer.A4Major.freq.6' => ['0'],
	'tone.chord.ringer.A4Major.level.1' => ['-10'],
	'tone.chord.ringer.A4Major.level.2' => ['-10'],
	'tone.chord.ringer.A4Major.level.3' => ['-10'],
	'tone.chord.ringer.A4Major.level.4' => ['-19'],
	'tone.chord.ringer.A4Major.level.5' => ['0'],
	'tone.chord.ringer.A4Major.level.6' => ['0'],
	'tone.chord.ringer.A4Major.offDur' => ['0'],
	'tone.chord.ringer.A4Major.onDur' => ['100'],
	'tone.chord.ringer.A4Major.repeat' => ['1'],
	'tone.chord.ringer.Ab2.freq.1' => ['415'],
	'tone.chord.ringer.Ab2.freq.2' => ['0'],
	'tone.chord.ringer.Ab2.freq.3' => ['0'],
	'tone.chord.ringer.Ab2.freq.4' => ['0'],
	'tone.chord.ringer.Ab2.freq.5' => ['0'],
	'tone.chord.ringer.Ab2.freq.6' => ['0'],
	'tone.chord.ringer.Ab2.level.1' => ['-10'],
	'tone.chord.ringer.Ab2.level.2' => ['0'],
	'tone.chord.ringer.Ab2.level.3' => ['0'],
	'tone.chord.ringer.Ab2.level.4' => ['0'],
	'tone.chord.ringer.Ab2.level.5' => ['0'],
	'tone.chord.ringer.Ab2.level.6' => ['0'],
	'tone.chord.ringer.Ab2.offDur' => ['0'],
	'tone.chord.ringer.Ab2.onDur' => ['100'],
	'tone.chord.ringer.Ab2.repeat' => ['1'],
	'tone.chord.ringer.Ab3.freq.1' => ['830'],
	'tone.chord.ringer.Ab3.freq.2' => ['0'],
	'tone.chord.ringer.Ab3.freq.3' => ['0'],
	'tone.chord.ringer.Ab3.freq.4' => ['0'],
	'tone.chord.ringer.Ab3.freq.5' => ['0'],
	'tone.chord.ringer.Ab3.freq.6' => ['0'],
	'tone.chord.ringer.Ab3.level.1' => ['-10'],
	'tone.chord.ringer.Ab3.level.2' => ['0'],
	'tone.chord.ringer.Ab3.level.3' => ['0'],
	'tone.chord.ringer.Ab3.level.4' => ['0'],
	'tone.chord.ringer.Ab3.level.5' => ['0'],
	'tone.chord.ringer.Ab3.level.6' => ['0'],
	'tone.chord.ringer.Ab3.offDur' => ['0'],
	'tone.chord.ringer.Ab3.onDur' => ['100'],
	'tone.chord.ringer.Ab3.repeat' => ['1'],
	'tone.chord.ringer.Ab3Major.freq.1' => ['831'],
	'tone.chord.ringer.Ab3Major.freq.2' => ['1046'],
	'tone.chord.ringer.Ab3Major.freq.3' => ['1244'],
	'tone.chord.ringer.Ab3Major.freq.4' => ['1661'],
	'tone.chord.ringer.Ab3Major.freq.5' => ['0'],
	'tone.chord.ringer.Ab3Major.freq.6' => ['0'],
	'tone.chord.ringer.Ab3Major.level.1' => ['-10'],
	'tone.chord.ringer.Ab3Major.level.2' => ['-10'],
	'tone.chord.ringer.Ab3Major.level.3' => ['-10'],
	'tone.chord.ringer.Ab3Major.level.4' => ['-19'],
	'tone.chord.ringer.Ab3Major.level.5' => ['0'],
	'tone.chord.ringer.Ab3Major.level.6' => ['0'],
	'tone.chord.ringer.Ab3Major.offDur' => ['0'],
	'tone.chord.ringer.Ab3Major.onDur' => ['100'],
	'tone.chord.ringer.Ab3Major.repeat' => ['1'],
	'tone.chord.ringer.B3.freq.1' => ['494'],
	'tone.chord.ringer.B3.freq.2' => ['0'],
	'tone.chord.ringer.B3.freq.3' => ['0'],
	'tone.chord.ringer.B3.freq.4' => ['0'],
	'tone.chord.ringer.B3.freq.5' => ['0'],
	'tone.chord.ringer.B3.freq.6' => ['0'],
	'tone.chord.ringer.B3.level.1' => ['-10'],
	'tone.chord.ringer.B3.level.2' => ['0'],
	'tone.chord.ringer.B3.level.3' => ['0'],
	'tone.chord.ringer.B3.level.4' => ['0'],
	'tone.chord.ringer.B3.level.5' => ['0'],
	'tone.chord.ringer.B3.level.6' => ['0'],
	'tone.chord.ringer.B3.offDur' => ['0'],
	'tone.chord.ringer.B3.onDur' => ['100'],
	'tone.chord.ringer.B3.repeat' => ['1'],
	'tone.chord.ringer.B3Major.freq.1' => ['493'],
	'tone.chord.ringer.B3Major.freq.2' => ['622'],
	'tone.chord.ringer.B3Major.freq.3' => ['740'],
	'tone.chord.ringer.B3Major.freq.4' => ['988'],
	'tone.chord.ringer.B3Major.freq.5' => ['0'],
	'tone.chord.ringer.B3Major.freq.6' => ['0'],
	'tone.chord.ringer.B3Major.level.1' => ['-10'],
	'tone.chord.ringer.B3Major.level.2' => ['-10'],
	'tone.chord.ringer.B3Major.level.3' => ['-10'],
	'tone.chord.ringer.B3Major.level.4' => ['-19'],
	'tone.chord.ringer.B3Major.level.5' => ['0'],
	'tone.chord.ringer.B3Major.level.6' => ['0'],
	'tone.chord.ringer.B3Major.offDur' => ['0'],
	'tone.chord.ringer.B3Major.onDur' => ['100'],
	'tone.chord.ringer.B3Major.repeat' => ['1'],
	'tone.chord.ringer.B4.freq.1' => ['988'],
	'tone.chord.ringer.B4.freq.2' => ['0'],
	'tone.chord.ringer.B4.freq.3' => ['0'],
	'tone.chord.ringer.B4.freq.4' => ['0'],
	'tone.chord.ringer.B4.freq.5' => ['0'],
	'tone.chord.ringer.B4.freq.6' => ['0'],
	'tone.chord.ringer.B4.level.1' => ['-10'],
	'tone.chord.ringer.B4.level.2' => ['0'],
	'tone.chord.ringer.B4.level.3' => ['0'],
	'tone.chord.ringer.B4.level.4' => ['0'],
	'tone.chord.ringer.B4.level.5' => ['0'],
	'tone.chord.ringer.B4.level.6' => ['0'],
	'tone.chord.ringer.B4.offDur' => ['0'],
	'tone.chord.ringer.B4.onDur' => ['100'],
	'tone.chord.ringer.B4.repeat' => ['1'],
	'tone.chord.ringer.Bb3.freq.1' => ['466'],
	'tone.chord.ringer.Bb3.freq.2' => ['0'],
	'tone.chord.ringer.Bb3.freq.3' => ['0'],
	'tone.chord.ringer.Bb3.freq.4' => ['0'],
	'tone.chord.ringer.Bb3.freq.5' => ['0'],
	'tone.chord.ringer.Bb3.freq.6' => ['0'],
	'tone.chord.ringer.Bb3.level.1' => ['-10'],
	'tone.chord.ringer.Bb3.level.2' => ['0'],
	'tone.chord.ringer.Bb3.level.3' => ['0'],
	'tone.chord.ringer.Bb3.level.4' => ['0'],
	'tone.chord.ringer.Bb3.level.5' => ['0'],
	'tone.chord.ringer.Bb3.level.6' => ['0'],
	'tone.chord.ringer.Bb3.offDur' => ['0'],
	'tone.chord.ringer.Bb3.onDur' => ['100'],
	'tone.chord.ringer.Bb3.repeat' => ['1'],
	'tone.chord.ringer.Bb3Major.freq.1' => ['466'],
	'tone.chord.ringer.Bb3Major.freq.2' => ['587'],
	'tone.chord.ringer.Bb3Major.freq.3' => ['698'],
	'tone.chord.ringer.Bb3Major.freq.4' => ['932'],
	'tone.chord.ringer.Bb3Major.freq.5' => ['0'],
	'tone.chord.ringer.Bb3Major.freq.6' => ['0'],
	'tone.chord.ringer.Bb3Major.level.1' => ['-10'],
	'tone.chord.ringer.Bb3Major.level.2' => ['-10'],
	'tone.chord.ringer.Bb3Major.level.3' => ['-10'],
	'tone.chord.ringer.Bb3Major.level.4' => ['-19'],
	'tone.chord.ringer.Bb3Major.level.5' => ['0'],
	'tone.chord.ringer.Bb3Major.level.6' => ['0'],
	'tone.chord.ringer.Bb3Major.offDur' => ['0'],
	'tone.chord.ringer.Bb3Major.onDur' => ['100'],
	'tone.chord.ringer.Bb3Major.repeat' => ['1'],
	'tone.chord.ringer.Bb4.freq.1' => ['932'],
	'tone.chord.ringer.Bb4.freq.2' => ['0'],
	'tone.chord.ringer.Bb4.freq.3' => ['0'],
	'tone.chord.ringer.Bb4.freq.4' => ['0'],
	'tone.chord.ringer.Bb4.freq.5' => ['0'],
	'tone.chord.ringer.Bb4.freq.6' => ['0'],
	'tone.chord.ringer.Bb4.level.1' => ['-10'],
	'tone.chord.ringer.Bb4.level.2' => ['0'],
	'tone.chord.ringer.Bb4.level.3' => ['0'],
	'tone.chord.ringer.Bb4.level.4' => ['0'],
	'tone.chord.ringer.Bb4.level.5' => ['0'],
	'tone.chord.ringer.Bb4.level.6' => ['0'],
	'tone.chord.ringer.Bb4.offDur' => ['0'],
	'tone.chord.ringer.Bb4.onDur' => ['100'],
	'tone.chord.ringer.Bb4.repeat' => ['1'],
	'tone.chord.ringer.C3.freq.1' => ['523'],
	'tone.chord.ringer.C3.freq.2' => ['0'],
	'tone.chord.ringer.C3.freq.3' => ['0'],
	'tone.chord.ringer.C3.freq.4' => ['0'],
	'tone.chord.ringer.C3.freq.5' => ['0'],
	'tone.chord.ringer.C3.freq.6' => ['0'],
	'tone.chord.ringer.C3.level.1' => ['-10'],
	'tone.chord.ringer.C3.level.2' => ['0'],
	'tone.chord.ringer.C3.level.3' => ['0'],
	'tone.chord.ringer.C3.level.4' => ['0'],
	'tone.chord.ringer.C3.level.5' => ['0'],
	'tone.chord.ringer.C3.level.6' => ['0'],
	'tone.chord.ringer.C3.offDur' => ['0'],
	'tone.chord.ringer.C3.onDur' => ['100'],
	'tone.chord.ringer.C3.repeat' => ['1'],
	'tone.chord.ringer.C3Major.freq.1' => ['523'],
	'tone.chord.ringer.C3Major.freq.2' => ['659'],
	'tone.chord.ringer.C3Major.freq.3' => ['784'],
	'tone.chord.ringer.C3Major.freq.4' => ['1046'],
	'tone.chord.ringer.C3Major.freq.5' => ['0'],
	'tone.chord.ringer.C3Major.freq.6' => ['0'],
	'tone.chord.ringer.C3Major.level.1' => ['-10'],
	'tone.chord.ringer.C3Major.level.2' => ['-10'],
	'tone.chord.ringer.C3Major.level.3' => ['-10'],
	'tone.chord.ringer.C3Major.level.4' => ['-19'],
	'tone.chord.ringer.C3Major.level.5' => ['0'],
	'tone.chord.ringer.C3Major.level.6' => ['0'],
	'tone.chord.ringer.C3Major.offDur' => ['0'],
	'tone.chord.ringer.C3Major.onDur' => ['100'],
	'tone.chord.ringer.C3Major.repeat' => ['1'],
	'tone.chord.ringer.C4.freq.1' => ['1046'],
	'tone.chord.ringer.C4.freq.2' => ['0'],
	'tone.chord.ringer.C4.freq.3' => ['0'],
	'tone.chord.ringer.C4.freq.4' => ['0'],
	'tone.chord.ringer.C4.freq.5' => ['0'],
	'tone.chord.ringer.C4.freq.6' => ['0'],
	'tone.chord.ringer.C4.level.1' => ['-10'],
	'tone.chord.ringer.C4.level.2' => ['0'],
	'tone.chord.ringer.C4.level.3' => ['0'],
	'tone.chord.ringer.C4.level.4' => ['0'],
	'tone.chord.ringer.C4.level.5' => ['0'],
	'tone.chord.ringer.C4.level.6' => ['0'],
	'tone.chord.ringer.C4.offDur' => ['0'],
	'tone.chord.ringer.C4.onDur' => ['100'],
	'tone.chord.ringer.C4.repeat' => ['1'],
	'tone.chord.ringer.D3.freq.1' => ['587'],
	'tone.chord.ringer.D3.freq.2' => ['0'],
	'tone.chord.ringer.D3.freq.3' => ['0'],
	'tone.chord.ringer.D3.freq.4' => ['0'],
	'tone.chord.ringer.D3.freq.5' => ['0'],
	'tone.chord.ringer.D3.freq.6' => ['0'],
	'tone.chord.ringer.D3.level.1' => ['-10'],
	'tone.chord.ringer.D3.level.2' => ['0'],
	'tone.chord.ringer.D3.level.3' => ['0'],
	'tone.chord.ringer.D3.level.4' => ['0'],
	'tone.chord.ringer.D3.level.5' => ['0'],
	'tone.chord.ringer.D3.level.6' => ['0'],
	'tone.chord.ringer.D3.offDur' => ['0'],
	'tone.chord.ringer.D3.onDur' => ['100'],
	'tone.chord.ringer.D3.repeat' => ['1'],
	'tone.chord.ringer.D3Major.freq.1' => ['587'],
	'tone.chord.ringer.D3Major.freq.2' => ['740'],
	'tone.chord.ringer.D3Major.freq.3' => ['880'],
	'tone.chord.ringer.D3Major.freq.4' => ['1175'],
	'tone.chord.ringer.D3Major.freq.5' => ['0'],
	'tone.chord.ringer.D3Major.freq.6' => ['0'],
	'tone.chord.ringer.D3Major.level.1' => ['-10'],
	'tone.chord.ringer.D3Major.level.2' => ['-10'],
	'tone.chord.ringer.D3Major.level.3' => ['-10'],
	'tone.chord.ringer.D3Major.level.4' => ['-19'],
	'tone.chord.ringer.D3Major.level.5' => ['0'],
	'tone.chord.ringer.D3Major.level.6' => ['0'],
	'tone.chord.ringer.D3Major.offDur' => ['0'],
	'tone.chord.ringer.D3Major.onDur' => ['100'],
	'tone.chord.ringer.D3Major.repeat' => ['1'],
	'tone.chord.ringer.D4.freq.1' => ['1175'],
	'tone.chord.ringer.D4.freq.2' => ['0'],
	'tone.chord.ringer.D4.freq.3' => ['0'],
	'tone.chord.ringer.D4.freq.4' => ['0'],
	'tone.chord.ringer.D4.freq.5' => ['0'],
	'tone.chord.ringer.D4.freq.6' => ['0'],
	'tone.chord.ringer.D4.level.1' => ['-10'],
	'tone.chord.ringer.D4.level.2' => ['0'],
	'tone.chord.ringer.D4.level.3' => ['0'],
	'tone.chord.ringer.D4.level.4' => ['0'],
	'tone.chord.ringer.D4.level.5' => ['0'],
	'tone.chord.ringer.D4.level.6' => ['0'],
	'tone.chord.ringer.D4.offDur' => ['0'],
	'tone.chord.ringer.D4.onDur' => ['100'],
	'tone.chord.ringer.D4.repeat' => ['1'],
	'tone.chord.ringer.Db3.freq.1' => ['554'],
	'tone.chord.ringer.Db3.freq.2' => ['0'],
	'tone.chord.ringer.Db3.freq.3' => ['0'],
	'tone.chord.ringer.Db3.freq.4' => ['0'],
	'tone.chord.ringer.Db3.freq.5' => ['0'],
	'tone.chord.ringer.Db3.freq.6' => ['0'],
	'tone.chord.ringer.Db3.level.1' => ['-10'],
	'tone.chord.ringer.Db3.level.2' => ['0'],
	'tone.chord.ringer.Db3.level.3' => ['0'],
	'tone.chord.ringer.Db3.level.4' => ['0'],
	'tone.chord.ringer.Db3.level.5' => ['0'],
	'tone.chord.ringer.Db3.level.6' => ['0'],
	'tone.chord.ringer.Db3.offDur' => ['0'],
	'tone.chord.ringer.Db3.onDur' => ['100'],
	'tone.chord.ringer.Db3.repeat' => ['1'],
	'tone.chord.ringer.Db3Major.freq.1' => ['554'],
	'tone.chord.ringer.Db3Major.freq.2' => ['698'],
	'tone.chord.ringer.Db3Major.freq.3' => ['830'],
	'tone.chord.ringer.Db3Major.freq.4' => ['1109'],
	'tone.chord.ringer.Db3Major.freq.5' => ['0'],
	'tone.chord.ringer.Db3Major.freq.6' => ['0'],
	'tone.chord.ringer.Db3Major.level.1' => ['-10'],
	'tone.chord.ringer.Db3Major.level.2' => ['-10'],
	'tone.chord.ringer.Db3Major.level.3' => ['-10'],
	'tone.chord.ringer.Db3Major.level.4' => ['-19'],
	'tone.chord.ringer.Db3Major.level.5' => ['0'],
	'tone.chord.ringer.Db3Major.level.6' => ['0'],
	'tone.chord.ringer.Db3Major.offDur' => ['0'],
	'tone.chord.ringer.Db3Major.onDur' => ['100'],
	'tone.chord.ringer.Db3Major.repeat' => ['1'],
	'tone.chord.ringer.Db4.freq.1' => ['1109'],
	'tone.chord.ringer.Db4.freq.2' => ['0'],
	'tone.chord.ringer.Db4.freq.3' => ['0'],
	'tone.chord.ringer.Db4.freq.4' => ['0'],
	'tone.chord.ringer.Db4.freq.5' => ['0'],
	'tone.chord.ringer.Db4.freq.6' => ['0'],
	'tone.chord.ringer.Db4.level.1' => ['-10'],
	'tone.chord.ringer.Db4.level.2' => ['0'],
	'tone.chord.ringer.Db4.level.3' => ['0'],
	'tone.chord.ringer.Db4.level.4' => ['0'],
	'tone.chord.ringer.Db4.level.5' => ['0'],
	'tone.chord.ringer.Db4.level.6' => ['0'],
	'tone.chord.ringer.Db4.offDur' => ['0'],
	'tone.chord.ringer.Db4.onDur' => ['100'],
	'tone.chord.ringer.Db4.repeat' => ['1'],
	'tone.chord.ringer.E3.freq.1' => ['659'],
	'tone.chord.ringer.E3.freq.2' => ['0'],
	'tone.chord.ringer.E3.freq.3' => ['0'],
	'tone.chord.ringer.E3.freq.4' => ['0'],
	'tone.chord.ringer.E3.freq.5' => ['0'],
	'tone.chord.ringer.E3.freq.6' => ['0'],
	'tone.chord.ringer.E3.level.1' => ['-10'],
	'tone.chord.ringer.E3.level.2' => ['0'],
	'tone.chord.ringer.E3.level.3' => ['0'],
	'tone.chord.ringer.E3.level.4' => ['0'],
	'tone.chord.ringer.E3.level.5' => ['0'],
	'tone.chord.ringer.E3.level.6' => ['0'],
	'tone.chord.ringer.E3.offDur' => ['0'],
	'tone.chord.ringer.E3.onDur' => ['100'],
	'tone.chord.ringer.E3.repeat' => ['1'],
	'tone.chord.ringer.E3Major.freq.1' => ['659'],
	'tone.chord.ringer.E3Major.freq.2' => ['831'],
	'tone.chord.ringer.E3Major.freq.3' => ['988'],
	'tone.chord.ringer.E3Major.freq.4' => ['1318'],
	'tone.chord.ringer.E3Major.freq.5' => ['0'],
	'tone.chord.ringer.E3Major.freq.6' => ['0'],
	'tone.chord.ringer.E3Major.level.1' => ['-10'],
	'tone.chord.ringer.E3Major.level.2' => ['-10'],
	'tone.chord.ringer.E3Major.level.3' => ['-10'],
	'tone.chord.ringer.E3Major.level.4' => ['-19'],
	'tone.chord.ringer.E3Major.level.5' => ['0'],
	'tone.chord.ringer.E3Major.level.6' => ['0'],
	'tone.chord.ringer.E3Major.offDur' => ['0'],
	'tone.chord.ringer.E3Major.onDur' => ['100'],
	'tone.chord.ringer.E3Major.repeat' => ['1'],
	'tone.chord.ringer.E4.freq.1' => ['1318'],
	'tone.chord.ringer.E4.freq.2' => ['0'],
	'tone.chord.ringer.E4.freq.3' => ['0'],
	'tone.chord.ringer.E4.freq.4' => ['0'],
	'tone.chord.ringer.E4.freq.5' => ['0'],
	'tone.chord.ringer.E4.freq.6' => ['0'],
	'tone.chord.ringer.E4.level.1' => ['-10'],
	'tone.chord.ringer.E4.level.2' => ['0'],
	'tone.chord.ringer.E4.level.3' => ['0'],
	'tone.chord.ringer.E4.level.4' => ['0'],
	'tone.chord.ringer.E4.level.5' => ['0'],
	'tone.chord.ringer.E4.level.6' => ['0'],
	'tone.chord.ringer.E4.offDur' => ['0'],
	'tone.chord.ringer.E4.onDur' => ['100'],
	'tone.chord.ringer.E4.repeat' => ['1'],
	'tone.chord.ringer.Eb3.freq.1' => ['622'],
	'tone.chord.ringer.Eb3.freq.2' => ['0'],
	'tone.chord.ringer.Eb3.freq.3' => ['0'],
	'tone.chord.ringer.Eb3.freq.4' => ['0'],
	'tone.chord.ringer.Eb3.freq.5' => ['0'],
	'tone.chord.ringer.Eb3.freq.6' => ['0'],
	'tone.chord.ringer.Eb3.level.1' => ['-10'],
	'tone.chord.ringer.Eb3.level.2' => ['0'],
	'tone.chord.ringer.Eb3.level.3' => ['0'],
	'tone.chord.ringer.Eb3.level.4' => ['0'],
	'tone.chord.ringer.Eb3.level.5' => ['0'],
	'tone.chord.ringer.Eb3.level.6' => ['0'],
	'tone.chord.ringer.Eb3.offDur' => ['0'],
	'tone.chord.ringer.Eb3.onDur' => ['100'],
	'tone.chord.ringer.Eb3.repeat' => ['1'],
	'tone.chord.ringer.Eb3Major.freq.1' => ['622'],
	'tone.chord.ringer.Eb3Major.freq.2' => ['783'],
	'tone.chord.ringer.Eb3Major.freq.3' => ['932'],
	'tone.chord.ringer.Eb3Major.freq.4' => ['1244'],
	'tone.chord.ringer.Eb3Major.freq.5' => ['0'],
	'tone.chord.ringer.Eb3Major.freq.6' => ['0'],
	'tone.chord.ringer.Eb3Major.level.1' => ['-10'],
	'tone.chord.ringer.Eb3Major.level.2' => ['-10'],
	'tone.chord.ringer.Eb3Major.level.3' => ['-10'],
	'tone.chord.ringer.Eb3Major.level.4' => ['-16'],
	'tone.chord.ringer.Eb3Major.level.5' => ['0'],
	'tone.chord.ringer.Eb3Major.level.6' => ['0'],
	'tone.chord.ringer.Eb3Major.offDur' => ['0'],
	'tone.chord.ringer.Eb3Major.onDur' => ['100'],
	'tone.chord.ringer.Eb3Major.repeat' => ['1'],
	'tone.chord.ringer.Eb4.freq.1' => ['1244'],
	'tone.chord.ringer.Eb4.freq.2' => ['0'],
	'tone.chord.ringer.Eb4.freq.3' => ['0'],
	'tone.chord.ringer.Eb4.freq.4' => ['0'],
	'tone.chord.ringer.Eb4.freq.5' => ['0'],
	'tone.chord.ringer.Eb4.freq.6' => ['0'],
	'tone.chord.ringer.Eb4.level.1' => ['-10'],
	'tone.chord.ringer.Eb4.level.2' => ['0'],
	'tone.chord.ringer.Eb4.level.3' => ['0'],
	'tone.chord.ringer.Eb4.level.4' => ['0'],
	'tone.chord.ringer.Eb4.level.5' => ['0'],
	'tone.chord.ringer.Eb4.level.6' => ['0'],
	'tone.chord.ringer.Eb4.offDur' => ['0'],
	'tone.chord.ringer.Eb4.onDur' => ['100'],
	'tone.chord.ringer.Eb4.repeat' => ['1'],
	'tone.chord.ringer.F2.freq.1' => ['349'],
	'tone.chord.ringer.F2.freq.2' => ['0'],
	'tone.chord.ringer.F2.freq.3' => ['0'],
	'tone.chord.ringer.F2.freq.4' => ['0'],
	'tone.chord.ringer.F2.freq.5' => ['0'],
	'tone.chord.ringer.F2.freq.6' => ['0'],
	'tone.chord.ringer.F2.level.1' => ['-10'],
	'tone.chord.ringer.F2.level.2' => ['0'],
	'tone.chord.ringer.F2.level.3' => ['0'],
	'tone.chord.ringer.F2.level.4' => ['0'],
	'tone.chord.ringer.F2.level.5' => ['0'],
	'tone.chord.ringer.F2.level.6' => ['0'],
	'tone.chord.ringer.F2.offDur' => ['0'],
	'tone.chord.ringer.F2.onDur' => ['100'],
	'tone.chord.ringer.F2.repeat' => ['1'],
	'tone.chord.ringer.F3.freq.1' => ['698'],
	'tone.chord.ringer.F3.freq.2' => ['0'],
	'tone.chord.ringer.F3.freq.3' => ['0'],
	'tone.chord.ringer.F3.freq.4' => ['0'],
	'tone.chord.ringer.F3.freq.5' => ['0'],
	'tone.chord.ringer.F3.freq.6' => ['0'],
	'tone.chord.ringer.F3.level.1' => ['-10'],
	'tone.chord.ringer.F3.level.2' => ['0'],
	'tone.chord.ringer.F3.level.3' => ['0'],
	'tone.chord.ringer.F3.level.4' => ['0'],
	'tone.chord.ringer.F3.level.5' => ['0'],
	'tone.chord.ringer.F3.level.6' => ['0'],
	'tone.chord.ringer.F3.offDur' => ['0'],
	'tone.chord.ringer.F3.onDur' => ['100'],
	'tone.chord.ringer.F3.repeat' => ['1'],
	'tone.chord.ringer.F3Major.freq.1' => ['698'],
	'tone.chord.ringer.F3Major.freq.2' => ['880'],
	'tone.chord.ringer.F3Major.freq.3' => ['1046'],
	'tone.chord.ringer.F3Major.freq.4' => ['1397'],
	'tone.chord.ringer.F3Major.freq.5' => ['0'],
	'tone.chord.ringer.F3Major.freq.6' => ['0'],
	'tone.chord.ringer.F3Major.level.1' => ['-10'],
	'tone.chord.ringer.F3Major.level.2' => ['-10'],
	'tone.chord.ringer.F3Major.level.3' => ['-10'],
	'tone.chord.ringer.F3Major.level.4' => ['-19'],
	'tone.chord.ringer.F3Major.level.5' => ['0'],
	'tone.chord.ringer.F3Major.level.6' => ['0'],
	'tone.chord.ringer.F3Major.offDur' => ['0'],
	'tone.chord.ringer.F3Major.onDur' => ['100'],
	'tone.chord.ringer.F3Major.repeat' => ['1'],
	'tone.chord.ringer.F4.freq.1' => ['1397'],
	'tone.chord.ringer.F4.freq.2' => ['0'],
	'tone.chord.ringer.F4.freq.3' => ['0'],
	'tone.chord.ringer.F4.freq.4' => ['0'],
	'tone.chord.ringer.F4.freq.5' => ['0'],
	'tone.chord.ringer.F4.freq.6' => ['0'],
	'tone.chord.ringer.F4.level.1' => ['-10'],
	'tone.chord.ringer.F4.level.2' => ['0'],
	'tone.chord.ringer.F4.level.3' => ['0'],
	'tone.chord.ringer.F4.level.4' => ['0'],
	'tone.chord.ringer.F4.level.5' => ['0'],
	'tone.chord.ringer.F4.level.6' => ['0'],
	'tone.chord.ringer.F4.offDur' => ['0'],
	'tone.chord.ringer.F4.onDur' => ['100'],
	'tone.chord.ringer.F4.repeat' => ['1'],
	'tone.chord.ringer.G2.freq.1' => ['392'],
	'tone.chord.ringer.G2.freq.2' => ['0'],
	'tone.chord.ringer.G2.freq.3' => ['0'],
	'tone.chord.ringer.G2.freq.4' => ['0'],
	'tone.chord.ringer.G2.freq.5' => ['0'],
	'tone.chord.ringer.G2.freq.6' => ['0'],
	'tone.chord.ringer.G2.level.1' => ['-10'],
	'tone.chord.ringer.G2.level.2' => ['0'],
	'tone.chord.ringer.G2.level.3' => ['0'],
	'tone.chord.ringer.G2.level.4' => ['0'],
	'tone.chord.ringer.G2.level.5' => ['0'],
	'tone.chord.ringer.G2.level.6' => ['0'],
	'tone.chord.ringer.G2.offDur' => ['0'],
	'tone.chord.ringer.G2.onDur' => ['100'],
	'tone.chord.ringer.G2.repeat' => ['1'],
	'tone.chord.ringer.G3.freq.1' => ['784'],
	'tone.chord.ringer.G3.freq.2' => ['0'],
	'tone.chord.ringer.G3.freq.3' => ['0'],
	'tone.chord.ringer.G3.freq.4' => ['0'],
	'tone.chord.ringer.G3.freq.5' => ['0'],
	'tone.chord.ringer.G3.freq.6' => ['0'],
	'tone.chord.ringer.G3.level.1' => ['-10'],
	'tone.chord.ringer.G3.level.2' => ['0'],
	'tone.chord.ringer.G3.level.3' => ['0'],
	'tone.chord.ringer.G3.level.4' => ['0'],
	'tone.chord.ringer.G3.level.5' => ['0'],
	'tone.chord.ringer.G3.level.6' => ['0'],
	'tone.chord.ringer.G3.offDur' => ['0'],
	'tone.chord.ringer.G3.onDur' => ['100'],
	'tone.chord.ringer.G3.repeat' => ['1'],
	'tone.chord.ringer.G3Major.freq.1' => ['784'],
	'tone.chord.ringer.G3Major.freq.2' => ['988'],
	'tone.chord.ringer.G3Major.freq.3' => ['1174'],
	'tone.chord.ringer.G3Major.freq.4' => ['1568'],
	'tone.chord.ringer.G3Major.freq.5' => ['0'],
	'tone.chord.ringer.G3Major.freq.6' => ['0'],
	'tone.chord.ringer.G3Major.level.1' => ['-10'],
	'tone.chord.ringer.G3Major.level.2' => ['-10'],
	'tone.chord.ringer.G3Major.level.3' => ['-10'],
	'tone.chord.ringer.G3Major.level.4' => ['-16'],
	'tone.chord.ringer.G3Major.level.5' => ['0'],
	'tone.chord.ringer.G3Major.level.6' => ['0'],
	'tone.chord.ringer.G3Major.offDur' => ['0'],
	'tone.chord.ringer.G3Major.onDur' => ['100'],
	'tone.chord.ringer.G3Major.repeat' => ['1'],
	'tone.chord.ringer.Gb2.freq.1' => ['370'],
	'tone.chord.ringer.Gb2.freq.2' => ['0'],
	'tone.chord.ringer.Gb2.freq.3' => ['0'],
	'tone.chord.ringer.Gb2.freq.4' => ['0'],
	'tone.chord.ringer.Gb2.freq.5' => ['0'],
	'tone.chord.ringer.Gb2.freq.6' => ['0'],
	'tone.chord.ringer.Gb2.level.1' => ['-10'],
	'tone.chord.ringer.Gb2.level.2' => ['0'],
	'tone.chord.ringer.Gb2.level.3' => ['0'],
	'tone.chord.ringer.Gb2.level.4' => ['0'],
	'tone.chord.ringer.Gb2.level.5' => ['0'],
	'tone.chord.ringer.Gb2.level.6' => ['0'],
	'tone.chord.ringer.Gb2.offDur' => ['0'],
	'tone.chord.ringer.Gb2.onDur' => ['100'],
	'tone.chord.ringer.Gb2.repeat' => ['1'],
	'tone.chord.ringer.Gb3.freq.1' => ['740'],
	'tone.chord.ringer.Gb3.freq.2' => ['0'],
	'tone.chord.ringer.Gb3.freq.3' => ['0'],
	'tone.chord.ringer.Gb3.freq.4' => ['0'],
	'tone.chord.ringer.Gb3.freq.5' => ['0'],
	'tone.chord.ringer.Gb3.freq.6' => ['0'],
	'tone.chord.ringer.Gb3.level.1' => ['-10'],
	'tone.chord.ringer.Gb3.level.2' => ['0'],
	'tone.chord.ringer.Gb3.level.3' => ['0'],
	'tone.chord.ringer.Gb3.level.4' => ['0'],
	'tone.chord.ringer.Gb3.level.5' => ['0'],
	'tone.chord.ringer.Gb3.level.6' => ['0'],
	'tone.chord.ringer.Gb3.offDur' => ['0'],
	'tone.chord.ringer.Gb3.onDur' => ['100'],
	'tone.chord.ringer.Gb3.repeat' => ['1'],
	'tone.chord.ringer.Gb3Major.freq.1' => ['740'],
	'tone.chord.ringer.Gb3Major.freq.2' => ['932'],
	'tone.chord.ringer.Gb3Major.freq.3' => ['1108'],
	'tone.chord.ringer.Gb3Major.freq.4' => ['1480'],
	'tone.chord.ringer.Gb3Major.freq.5' => ['0'],
	'tone.chord.ringer.Gb3Major.freq.6' => ['0'],
	'tone.chord.ringer.Gb3Major.level.1' => ['-10'],
	'tone.chord.ringer.Gb3Major.level.2' => ['-10'],
	'tone.chord.ringer.Gb3Major.level.3' => ['-10'],
	'tone.chord.ringer.Gb3Major.level.4' => ['-19'],
	'tone.chord.ringer.Gb3Major.level.5' => ['0'],
	'tone.chord.ringer.Gb3Major.level.6' => ['0'],
	'tone.chord.ringer.Gb3Major.offDur' => ['0'],
	'tone.chord.ringer.Gb3Major.onDur' => ['100'],
	'tone.chord.ringer.Gb3Major.repeat' => ['1'],
	'tone.chord.ringer.originalHigh.freq.1' => ['784'],
	'tone.chord.ringer.originalHigh.freq.2' => ['1176'],
	'tone.chord.ringer.originalHigh.freq.3' => ['1568'],
	'tone.chord.ringer.originalHigh.freq.4' => ['0'],
	'tone.chord.ringer.originalHigh.freq.5' => ['0'],
	'tone.chord.ringer.originalHigh.freq.6' => ['0'],
	'tone.chord.ringer.originalHigh.level.1' => ['-10'],
	'tone.chord.ringer.originalHigh.level.2' => ['-16'],
	'tone.chord.ringer.originalHigh.level.3' => ['-19'],
	'tone.chord.ringer.originalHigh.level.4' => ['-45'],
	'tone.chord.ringer.originalHigh.level.5' => ['0'],
	'tone.chord.ringer.originalHigh.level.6' => ['0'],
	'tone.chord.ringer.originalHigh.offDur' => ['0'],
	'tone.chord.ringer.originalHigh.onDur' => ['100'],
	'tone.chord.ringer.originalHigh.repeat' => ['1'],
	'tone.chord.ringer.originalLow.freq.1' => ['622'],
	'tone.chord.ringer.originalLow.freq.2' => ['933'],
	'tone.chord.ringer.originalLow.freq.3' => ['1244'],
	'tone.chord.ringer.originalLow.freq.4' => ['0'],
	'tone.chord.ringer.originalLow.freq.5' => ['0'],
	'tone.chord.ringer.originalLow.freq.6' => ['0'],
	'tone.chord.ringer.originalLow.level.1' => ['-10'],
	'tone.chord.ringer.originalLow.level.2' => ['-16'],
	'tone.chord.ringer.originalLow.level.3' => ['-19'],
	'tone.chord.ringer.originalLow.level.4' => ['-45'],
	'tone.chord.ringer.originalLow.level.5' => ['0'],
	'tone.chord.ringer.originalLow.level.6' => ['0'],
	'tone.chord.ringer.originalLow.offDur' => ['0'],
	'tone.chord.ringer.originalLow.onDur' => ['100'],
	'tone.chord.ringer.originalLow.repeat' => ['1'],
	'tone.chord.ringer.ringback.freq.1' => ['440'],
	'tone.chord.ringer.ringback.freq.2' => ['480'],
	'tone.chord.ringer.ringback.freq.3' => ['0'],
	'tone.chord.ringer.ringback.freq.4' => ['0'],
	'tone.chord.ringer.ringback.freq.5' => ['0'],
	'tone.chord.ringer.ringback.freq.6' => ['0'],
	'tone.chord.ringer.ringback.level.1' => ['-10'],
	'tone.chord.ringer.ringback.level.2' => ['-10'],
	'tone.chord.ringer.ringback.level.3' => ['0'],
	'tone.chord.ringer.ringback.level.4' => ['0'],
	'tone.chord.ringer.ringback.level.5' => ['0'],
	'tone.chord.ringer.ringback.level.6' => ['0'],
	'tone.chord.ringer.ringback.offDur' => ['0'],
	'tone.chord.ringer.ringback.onDur' => ['400'],
	'tone.chord.ringer.ringback.repeat' => ['1'],
	'tone.chord.ringer.spare1.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare1.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare1.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare1.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare1.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare1.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare1.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare1.offDur' => ['0'],
	'tone.chord.ringer.spare1.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare1.repeat' => ['1'],
	'tone.chord.ringer.spare10.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare10.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare10.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare10.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare10.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare10.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare10.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare10.offDur' => ['0'],
	'tone.chord.ringer.spare10.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare10.repeat' => ['1'],
	'tone.chord.ringer.spare11.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare11.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare11.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare11.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare11.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare11.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare11.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare11.offDur' => ['0'],
	'tone.chord.ringer.spare11.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare11.repeat' => ['1'],
	'tone.chord.ringer.spare12.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare12.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare12.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare12.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare12.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare12.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare12.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare12.offDur' => ['0'],
	'tone.chord.ringer.spare12.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare12.repeat' => ['1'],
	'tone.chord.ringer.spare13.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare13.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare13.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare13.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare13.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare13.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare13.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare13.offDur' => ['0'],
	'tone.chord.ringer.spare13.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare13.repeat' => ['1'],
	'tone.chord.ringer.spare14.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare14.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare14.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare14.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare14.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare14.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare14.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare14.offDur' => ['0'],
	'tone.chord.ringer.spare14.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare14.repeat' => ['1'],
	'tone.chord.ringer.spare15.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare15.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare15.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare15.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare15.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare15.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare15.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare15.offDur' => ['0'],
	'tone.chord.ringer.spare15.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare15.repeat' => ['1'],
	'tone.chord.ringer.spare16.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare16.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare16.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare16.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare16.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare16.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare16.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare16.offDur' => ['0'],
	'tone.chord.ringer.spare16.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare16.repeat' => ['1'],
	'tone.chord.ringer.spare17.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare17.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare17.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare17.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare17.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare17.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare17.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare17.offDur' => ['0'],
	'tone.chord.ringer.spare17.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare17.repeat' => ['1'],
	'tone.chord.ringer.spare18.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare18.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare18.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare18.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare18.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare18.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare18.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare18.offDur' => ['0'],
	'tone.chord.ringer.spare18.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare18.repeat' => ['1'],
	'tone.chord.ringer.spare19.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare19.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare19.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare19.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare19.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare19.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare19.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare19.offDur' => ['0'],
	'tone.chord.ringer.spare19.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare19.repeat' => ['1'],
	'tone.chord.ringer.spare2.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare2.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare2.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare2.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare2.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare2.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare2.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare2.offDur' => ['0'],
	'tone.chord.ringer.spare2.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare2.repeat' => ['1'],
	'tone.chord.ringer.spare3.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare3.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare3.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare3.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare3.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare3.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare3.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare3.offDur' => ['0'],
	'tone.chord.ringer.spare3.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare3.repeat' => ['1'],
	'tone.chord.ringer.spare4.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare4.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare4.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare4.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare4.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare4.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare4.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare4.offDur' => ['0'],
	'tone.chord.ringer.spare4.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare4.repeat' => ['1'],
	'tone.chord.ringer.spare5.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare5.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare5.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare5.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare5.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare5.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare5.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare5.offDur' => ['0'],
	'tone.chord.ringer.spare5.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare5.repeat' => ['1'],
	'tone.chord.ringer.spare6.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare6.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare6.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare6.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare6.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare6.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare6.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare6.offDur' => ['0'],
	'tone.chord.ringer.spare6.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare6.repeat' => ['1'],
	'tone.chord.ringer.spare7.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare7.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare7.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare7.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare7.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare7.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare7.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare7.offDur' => ['0'],
	'tone.chord.ringer.spare7.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare7.repeat' => ['1'],
	'tone.chord.ringer.spare8.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare8.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare8.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare8.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare8.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare8.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare8.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare8.offDur' => ['0'],
	'tone.chord.ringer.spare8.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare8.repeat' => ['1'],
	'tone.chord.ringer.spare9.freq.1' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.freq.2' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.freq.3' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.freq.4' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.freq.5' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.freq.6' => ['0', 440, 480, 1000 ],
	'tone.chord.ringer.spare9.level.1' => ['0', -10 ],
	'tone.chord.ringer.spare9.level.2' => ['0', -10 ],
	'tone.chord.ringer.spare9.level.3' => ['0', -10 ],
	'tone.chord.ringer.spare9.level.4' => ['0', -10 ],
	'tone.chord.ringer.spare9.level.5' => ['0', -10 ],
	'tone.chord.ringer.spare9.level.6' => ['0', -10 ],
	'tone.chord.ringer.spare9.offDur' => ['0'],
	'tone.chord.ringer.spare9.onDur' => ['100', 400 ],
	'tone.chord.ringer.spare9.repeat' => ['1'],
	'tone.chord.ringer.splash.freq.1' => ['440'],
	'tone.chord.ringer.splash.freq.2' => ['480'],
	'tone.chord.ringer.splash.freq.3' => ['0'],
	'tone.chord.ringer.splash.freq.4' => ['0'],
	'tone.chord.ringer.splash.freq.5' => ['0'],
	'tone.chord.ringer.splash.freq.6' => ['0'],
	'tone.chord.ringer.splash.level.1' => ['-10'],
	'tone.chord.ringer.splash.level.2' => ['-10'],
	'tone.chord.ringer.splash.level.3' => ['0'],
	'tone.chord.ringer.splash.level.4' => ['0'],
	'tone.chord.ringer.splash.level.5' => ['0'],
	'tone.chord.ringer.splash.level.6' => ['0'],
	'tone.chord.ringer.splash.offDur' => ['0'],
	'tone.chord.ringer.splash.onDur' => ['500'],
	'tone.chord.ringer.splash.repeat' => ['1'],
	'tone.dtmf.chassis.masking' => ['0'],
	'tone.dtmf.level' => ['-15'],
	'tone.dtmf.offTime' => ['50'],
	'tone.dtmf.onTime' => ['50'],
	'tone.dtmf.rfc2833Control' => ['1'],
	'tone.dtmf.rfc2833Payload' => ['127', 127 ],
	'tone.dtmf.viaRtp' => ['1'],
	'tr69.enabled' => ['0'],
	'up.25mm' => ['0'],
	'up.2P5mmJack.mode' => ['0'],
	'up.accessibilityFeatures' => ['0'],
	'up.analogHeadsetOption' => ['0'],
	'up.audioMode' => ['0'],
	'up.audioSetup.auxInput' => ['2'],
	'up.audioSetup.auxOutput' => ['2'],
	'up.backlight.idleIntensity' => ['1'],
	'up.backlight.onIntensity' => ['3'],
	'up.callTypeOrderVoice' => ['0'],
	'up.callTypePromptPref' => ['1'],
	'up.enableCallTypePrompt' => ['1'],
	'up.handsfreeMode' => ['1'],
	'up.headsetMode' => ['0'],
	'up.idleBrowser.enabled' => ['0', '' ],
	'up.idleTimeout' => ['40'],
	'up.lineKeyCallTerminate' => ['0'],
	'up.lineKeyCallTerminate.SPIP231' => ['1'],
	'up.lineKeyCallTerminate.SPIP235T' => ['1'],
	'up.localClockEnabled' => ['1'],
	'up.manualProtocolRouting' => ['1'],
	'up.manualProtocolRouting.softKeys' => ['1'],
	'up.mwiVisible' => ['0'],
	'up.numberFirstCID' => ['0'],
	'up.offHookAction.none' => ['0'],
	'up.onHookDialingEnabled' => ['1'],
	'up.oneTouchVoiceMail' => ['0'],
	'up.pictureFrame.folder' => [''],
	'up.pictureFrame.timePerImage' => ['5'],
	'up.prioritizeBackgroundMenuItem.enabled' => ['1'],
	'up.screenCapture.enabled' => ['0'],
	'up.screenSaver.enabled' => ['0'],
	'up.screenSaver.waitTime' => ['15'],
	'up.toneControl.bass' => ['0'],
	'up.toneControl.treble' => ['0'],
	'up.useDirectoryNames' => ['0'],
	'up.welcomeSoundEnabled' => ['1'],
	'up.welcomeSoundOnWarmBootEnabled' => ['0'],
	'usb.recordBufSize.1' => ['48'],
	'usb.recordBufSize.1.SPIP650' => ['16'],
	'usb.recordBufSize.1.SPIP670' => ['16'],
	'usb.recordBufSize.2' => ['48'],
	'usb.recordBufSize.2.SPIP650' => ['25'],
	'usb.recordBufSize.2.SPIP670' => ['25'],
	'usb.recordBufSize.3' => ['48'],
	'usb.recordBufSize.3.SPIP650' => ['40'],
	'usb.recordBufSize.3.SPIP670' => ['40'],
	'usb.set1.acceptUnknownDrives' => ['1'],
	'usb.set1.device.1.code' => ['3'],
	'usb.set1.device.1.product' => ['0'],
	'usb.set1.device.1.vendor' => ['0'],
	'usb.set1.device.10.code' => ['3'],
	'usb.set1.device.10.product' => ['0'],
	'usb.set1.device.10.vendor' => ['0'],
	'usb.set1.device.100.code' => ['3'],
	'usb.set1.device.100.product' => ['0'],
	'usb.set1.device.100.vendor' => ['0'],
	'usb.set1.device.11.code' => ['3'],
	'usb.set1.device.11.product' => ['0'],
	'usb.set1.device.11.vendor' => ['0'],
	'usb.set1.device.12.code' => ['3'],
	'usb.set1.device.12.product' => ['0'],
	'usb.set1.device.12.vendor' => ['0'],
	'usb.set1.device.13.code' => ['3'],
	'usb.set1.device.13.product' => ['0'],
	'usb.set1.device.13.vendor' => ['0'],
	'usb.set1.device.14.code' => ['3'],
	'usb.set1.device.14.product' => ['0'],
	'usb.set1.device.14.vendor' => ['0'],
	'usb.set1.device.15.code' => ['3'],
	'usb.set1.device.15.product' => ['0'],
	'usb.set1.device.15.vendor' => ['0'],
	'usb.set1.device.16.code' => ['3'],
	'usb.set1.device.16.product' => ['0'],
	'usb.set1.device.16.vendor' => ['0'],
	'usb.set1.device.17.code' => ['3'],
	'usb.set1.device.17.product' => ['0'],
	'usb.set1.device.17.vendor' => ['0'],
	'usb.set1.device.18.code' => ['3'],
	'usb.set1.device.18.product' => ['0'],
	'usb.set1.device.18.vendor' => ['0'],
	'usb.set1.device.19.code' => ['3'],
	'usb.set1.device.19.product' => ['0'],
	'usb.set1.device.19.vendor' => ['0'],
	'usb.set1.device.2.code' => ['3'],
	'usb.set1.device.2.product' => ['0'],
	'usb.set1.device.2.vendor' => ['0'],
	'usb.set1.device.20.code' => ['3'],
	'usb.set1.device.20.product' => ['0'],
	'usb.set1.device.20.vendor' => ['0'],
	'usb.set1.device.21.code' => ['3'],
	'usb.set1.device.21.product' => ['0'],
	'usb.set1.device.21.vendor' => ['0'],
	'usb.set1.device.22.code' => ['3'],
	'usb.set1.device.22.product' => ['0'],
	'usb.set1.device.22.vendor' => ['0'],
	'usb.set1.device.23.code' => ['3'],
	'usb.set1.device.23.product' => ['0'],
	'usb.set1.device.23.vendor' => ['0'],
	'usb.set1.device.24.code' => ['3'],
	'usb.set1.device.24.product' => ['0'],
	'usb.set1.device.24.vendor' => ['0'],
	'usb.set1.device.25.code' => ['3'],
	'usb.set1.device.25.product' => ['0'],
	'usb.set1.device.25.vendor' => ['0'],
	'usb.set1.device.26.code' => ['3'],
	'usb.set1.device.26.product' => ['0'],
	'usb.set1.device.26.vendor' => ['0'],
	'usb.set1.device.27.code' => ['3'],
	'usb.set1.device.27.product' => ['0'],
	'usb.set1.device.27.vendor' => ['0'],
	'usb.set1.device.28.code' => ['3'],
	'usb.set1.device.28.product' => ['0'],
	'usb.set1.device.28.vendor' => ['0'],
	'usb.set1.device.29.code' => ['3'],
	'usb.set1.device.29.product' => ['0'],
	'usb.set1.device.29.vendor' => ['0'],
	'usb.set1.device.3.code' => ['3'],
	'usb.set1.device.3.product' => ['0'],
	'usb.set1.device.3.vendor' => ['0'],
	'usb.set1.device.30.code' => ['3'],
	'usb.set1.device.30.product' => ['0'],
	'usb.set1.device.30.vendor' => ['0'],
	'usb.set1.device.31.code' => ['3'],
	'usb.set1.device.31.product' => ['0'],
	'usb.set1.device.31.vendor' => ['0'],
	'usb.set1.device.32.code' => ['3'],
	'usb.set1.device.32.product' => ['0'],
	'usb.set1.device.32.vendor' => ['0'],
	'usb.set1.device.33.code' => ['3'],
	'usb.set1.device.33.product' => ['0'],
	'usb.set1.device.33.vendor' => ['0'],
	'usb.set1.device.34.code' => ['3'],
	'usb.set1.device.34.product' => ['0'],
	'usb.set1.device.34.vendor' => ['0'],
	'usb.set1.device.35.code' => ['3'],
	'usb.set1.device.35.product' => ['0'],
	'usb.set1.device.35.vendor' => ['0'],
	'usb.set1.device.36.code' => ['3'],
	'usb.set1.device.36.product' => ['0'],
	'usb.set1.device.36.vendor' => ['0'],
	'usb.set1.device.37.code' => ['3'],
	'usb.set1.device.37.product' => ['0'],
	'usb.set1.device.37.vendor' => ['0'],
	'usb.set1.device.38.code' => ['3'],
	'usb.set1.device.38.product' => ['0'],
	'usb.set1.device.38.vendor' => ['0'],
	'usb.set1.device.39.code' => ['3'],
	'usb.set1.device.39.product' => ['0'],
	'usb.set1.device.39.vendor' => ['0'],
	'usb.set1.device.4.code' => ['3'],
	'usb.set1.device.4.product' => ['0'],
	'usb.set1.device.4.vendor' => ['0'],
	'usb.set1.device.40.code' => ['3'],
	'usb.set1.device.40.product' => ['0'],
	'usb.set1.device.40.vendor' => ['0'],
	'usb.set1.device.41.code' => ['3'],
	'usb.set1.device.41.product' => ['0'],
	'usb.set1.device.41.vendor' => ['0'],
	'usb.set1.device.42.code' => ['3'],
	'usb.set1.device.42.product' => ['0'],
	'usb.set1.device.42.vendor' => ['0'],
	'usb.set1.device.43.code' => ['3'],
	'usb.set1.device.43.product' => ['0'],
	'usb.set1.device.43.vendor' => ['0'],
	'usb.set1.device.44.code' => ['3'],
	'usb.set1.device.44.product' => ['0'],
	'usb.set1.device.44.vendor' => ['0'],
	'usb.set1.device.45.code' => ['3'],
	'usb.set1.device.45.product' => ['0'],
	'usb.set1.device.45.vendor' => ['0'],
	'usb.set1.device.46.code' => ['3'],
	'usb.set1.device.46.product' => ['0'],
	'usb.set1.device.46.vendor' => ['0'],
	'usb.set1.device.47.code' => ['3'],
	'usb.set1.device.47.product' => ['0'],
	'usb.set1.device.47.vendor' => ['0'],
	'usb.set1.device.48.code' => ['3'],
	'usb.set1.device.48.product' => ['0'],
	'usb.set1.device.48.vendor' => ['0'],
	'usb.set1.device.49.code' => ['3'],
	'usb.set1.device.49.product' => ['0'],
	'usb.set1.device.49.vendor' => ['0'],
	'usb.set1.device.5.code' => ['3'],
	'usb.set1.device.5.product' => ['0'],
	'usb.set1.device.5.vendor' => ['0'],
	'usb.set1.device.50.code' => ['3'],
	'usb.set1.device.50.product' => ['0'],
	'usb.set1.device.50.vendor' => ['0'],
	'usb.set1.device.51.code' => ['3'],
	'usb.set1.device.51.product' => ['0'],
	'usb.set1.device.51.vendor' => ['0'],
	'usb.set1.device.52.code' => ['3'],
	'usb.set1.device.52.product' => ['0'],
	'usb.set1.device.52.vendor' => ['0'],
	'usb.set1.device.53.code' => ['3'],
	'usb.set1.device.53.product' => ['0'],
	'usb.set1.device.53.vendor' => ['0'],
	'usb.set1.device.54.code' => ['3'],
	'usb.set1.device.54.product' => ['0'],
	'usb.set1.device.54.vendor' => ['0'],
	'usb.set1.device.55.code' => ['3'],
	'usb.set1.device.55.product' => ['0'],
	'usb.set1.device.55.vendor' => ['0'],
	'usb.set1.device.56.code' => ['3'],
	'usb.set1.device.56.product' => ['0'],
	'usb.set1.device.56.vendor' => ['0'],
	'usb.set1.device.57.code' => ['3'],
	'usb.set1.device.57.product' => ['0'],
	'usb.set1.device.57.vendor' => ['0'],
	'usb.set1.device.58.code' => ['3'],
	'usb.set1.device.58.product' => ['0'],
	'usb.set1.device.58.vendor' => ['0'],
	'usb.set1.device.59.code' => ['3'],
	'usb.set1.device.59.product' => ['0'],
	'usb.set1.device.59.vendor' => ['0'],
	'usb.set1.device.6.code' => ['3'],
	'usb.set1.device.6.product' => ['0'],
	'usb.set1.device.6.vendor' => ['0'],
	'usb.set1.device.60.code' => ['3'],
	'usb.set1.device.60.product' => ['0'],
	'usb.set1.device.60.vendor' => ['0'],
	'usb.set1.device.61.code' => ['3'],
	'usb.set1.device.61.product' => ['0'],
	'usb.set1.device.61.vendor' => ['0'],
	'usb.set1.device.62.code' => ['3'],
	'usb.set1.device.62.product' => ['0'],
	'usb.set1.device.62.vendor' => ['0'],
	'usb.set1.device.63.code' => ['3'],
	'usb.set1.device.63.product' => ['0'],
	'usb.set1.device.63.vendor' => ['0'],
	'usb.set1.device.64.code' => ['3'],
	'usb.set1.device.64.product' => ['0'],
	'usb.set1.device.64.vendor' => ['0'],
	'usb.set1.device.65.code' => ['3'],
	'usb.set1.device.65.product' => ['0'],
	'usb.set1.device.65.vendor' => ['0'],
	'usb.set1.device.66.code' => ['3'],
	'usb.set1.device.66.product' => ['0'],
	'usb.set1.device.66.vendor' => ['0'],
	'usb.set1.device.67.code' => ['3'],
	'usb.set1.device.67.product' => ['0'],
	'usb.set1.device.67.vendor' => ['0'],
	'usb.set1.device.68.code' => ['3'],
	'usb.set1.device.68.product' => ['0'],
	'usb.set1.device.68.vendor' => ['0'],
	'usb.set1.device.69.code' => ['3'],
	'usb.set1.device.69.product' => ['0'],
	'usb.set1.device.69.vendor' => ['0'],
	'usb.set1.device.7.code' => ['3'],
	'usb.set1.device.7.product' => ['0'],
	'usb.set1.device.7.vendor' => ['0'],
	'usb.set1.device.70.code' => ['3'],
	'usb.set1.device.70.product' => ['0'],
	'usb.set1.device.70.vendor' => ['0'],
	'usb.set1.device.71.code' => ['3'],
	'usb.set1.device.71.product' => ['0'],
	'usb.set1.device.71.vendor' => ['0'],
	'usb.set1.device.72.code' => ['3'],
	'usb.set1.device.72.product' => ['0'],
	'usb.set1.device.72.vendor' => ['0'],
	'usb.set1.device.73.code' => ['3'],
	'usb.set1.device.73.product' => ['0'],
	'usb.set1.device.73.vendor' => ['0'],
	'usb.set1.device.74.code' => ['3'],
	'usb.set1.device.74.product' => ['0'],
	'usb.set1.device.74.vendor' => ['0'],
	'usb.set1.device.75.code' => ['3'],
	'usb.set1.device.75.product' => ['0'],
	'usb.set1.device.75.vendor' => ['0'],
	'usb.set1.device.76.code' => ['3'],
	'usb.set1.device.76.product' => ['0'],
	'usb.set1.device.76.vendor' => ['0'],
	'usb.set1.device.77.code' => ['3'],
	'usb.set1.device.77.product' => ['0'],
	'usb.set1.device.77.vendor' => ['0'],
	'usb.set1.device.78.code' => ['3'],
	'usb.set1.device.78.product' => ['0'],
	'usb.set1.device.78.vendor' => ['0'],
	'usb.set1.device.79.code' => ['3'],
	'usb.set1.device.79.product' => ['0'],
	'usb.set1.device.79.vendor' => ['0'],
	'usb.set1.device.8.code' => ['3'],
	'usb.set1.device.8.product' => ['0'],
	'usb.set1.device.8.vendor' => ['0'],
	'usb.set1.device.80.code' => ['3'],
	'usb.set1.device.80.product' => ['0'],
	'usb.set1.device.80.vendor' => ['0'],
	'usb.set1.device.81.code' => ['3'],
	'usb.set1.device.81.product' => ['0'],
	'usb.set1.device.81.vendor' => ['0'],
	'usb.set1.device.82.code' => ['3'],
	'usb.set1.device.82.product' => ['0'],
	'usb.set1.device.82.vendor' => ['0'],
	'usb.set1.device.83.code' => ['3'],
	'usb.set1.device.83.product' => ['0'],
	'usb.set1.device.83.vendor' => ['0'],
	'usb.set1.device.84.code' => ['3'],
	'usb.set1.device.84.product' => ['0'],
	'usb.set1.device.84.vendor' => ['0'],
	'usb.set1.device.85.code' => ['3'],
	'usb.set1.device.85.product' => ['0'],
	'usb.set1.device.85.vendor' => ['0'],
	'usb.set1.device.86.code' => ['3'],
	'usb.set1.device.86.product' => ['0'],
	'usb.set1.device.86.vendor' => ['0'],
	'usb.set1.device.87.code' => ['3'],
	'usb.set1.device.87.product' => ['0'],
	'usb.set1.device.87.vendor' => ['0'],
	'usb.set1.device.88.code' => ['3'],
	'usb.set1.device.88.product' => ['0'],
	'usb.set1.device.88.vendor' => ['0'],
	'usb.set1.device.89.code' => ['3'],
	'usb.set1.device.89.product' => ['0'],
	'usb.set1.device.89.vendor' => ['0'],
	'usb.set1.device.9.code' => ['3'],
	'usb.set1.device.9.product' => ['0'],
	'usb.set1.device.9.vendor' => ['0'],
	'usb.set1.device.90.code' => ['3'],
	'usb.set1.device.90.product' => ['0'],
	'usb.set1.device.90.vendor' => ['0'],
	'usb.set1.device.91.code' => ['3'],
	'usb.set1.device.91.product' => ['0'],
	'usb.set1.device.91.vendor' => ['0'],
	'usb.set1.device.92.code' => ['3'],
	'usb.set1.device.92.product' => ['0'],
	'usb.set1.device.92.vendor' => ['0'],
	'usb.set1.device.93.code' => ['3'],
	'usb.set1.device.93.product' => ['0'],
	'usb.set1.device.93.vendor' => ['0'],
	'usb.set1.device.94.code' => ['3'],
	'usb.set1.device.94.product' => ['0'],
	'usb.set1.device.94.vendor' => ['0'],
	'usb.set1.device.95.code' => ['3'],
	'usb.set1.device.95.product' => ['0'],
	'usb.set1.device.95.vendor' => ['0'],
	'usb.set1.device.96.code' => ['3'],
	'usb.set1.device.96.product' => ['0'],
	'usb.set1.device.96.vendor' => ['0'],
	'usb.set1.device.97.code' => ['3'],
	'usb.set1.device.97.product' => ['0'],
	'usb.set1.device.97.vendor' => ['0'],
	'usb.set1.device.98.code' => ['3'],
	'usb.set1.device.98.product' => ['0'],
	'usb.set1.device.98.vendor' => ['0'],
	'usb.set1.device.99.code' => ['3'],
	'usb.set1.device.99.product' => ['0'],
	'usb.set1.device.99.vendor' => ['0'],
	'usb.set1.rejectAllDrivesLargerThan2GB' => ['0'],
	'usb.set1.useInternalDriveLists' => ['1'],
	'usb.set1.verifyAllowedDrives' => ['0'],
	'usb.set1.verifyUnknownDrives' => ['2'],
	'version' => ['1.0'],
	'video.autoFullScreen' => ['0'],
	'video.autoStartVideoTx' => ['1', '' ],
	'video.callRate' => ['512', 448 ],
	'video.camera.brightness' => ['3'],
	'video.camera.contrast' => ['0'],
	'video.camera.flickerAvoidance' => ['0'],
	'video.camera.frameRate' => ['25'],
	'video.camera.saturation' => ['3'],
	'video.camera.sharpness' => ['3'],
	'video.codecPref.H261' => ['4'],
	'video.codecPref.H263' => ['3'],
	'video.codecPref.H2631998' => ['2'],
	'video.codecPref.H264' => ['1'],
	'video.enable' => ['1', '' ],
	'video.forceRtcpVideoCodecControl' => ['0'],
	'video.localCameraView.fullScreen.enabled' => ['1'],
	'video.localCameraView.fullScreen.mode' => [''],
	'video.maxCallRate' => ['768', '' ],
	'video.pipResolutionX' => ['352'],
	'video.pipResolutionY' => ['288'],
	'video.profile.H261.CifMpi' => ['1'],
	'video.profile.H261.QcifMpi' => ['1'],
	'video.profile.H261.annexD' => ['1'],
	'video.profile.H261.jitterBufferMax' => ['2000'],
	'video.profile.H261.jitterBufferMin' => ['150'],
	'video.profile.H261.jitterBufferShrink' => ['70'],
	'video.profile.H261.payloadType' => ['31'],
	'video.profile.H263.CifMpi' => ['1'],
	'video.profile.H263.QcifMpi' => ['1'],
	'video.profile.H263.SqcifMpi' => ['1'],
	'video.profile.H263.jitterBufferMax' => ['2000'],
	'video.profile.H263.jitterBufferMin' => ['150'],
	'video.profile.H263.jitterBufferShrink' => ['70'],
	'video.profile.H263.payloadType' => ['34'],
	'video.profile.H2631998.CifMpi' => ['1'],
	'video.profile.H2631998.QcifMpi' => ['1'],
	'video.profile.H2631998.SqcifMpi' => ['1'],
	'video.profile.H2631998.annexF' => ['0'],
	'video.profile.H2631998.annexI' => ['0'],
	'video.profile.H2631998.annexJ' => ['0'],
	'video.profile.H2631998.annexK' => ['1'],
	'video.profile.H2631998.annexN' => ['1'],
	'video.profile.H2631998.annexT' => ['0'],
	'video.profile.H2631998.jitterBufferMax' => ['2000'],
	'video.profile.H2631998.jitterBufferMin' => ['150'],
	'video.profile.H2631998.jitterBufferShrink' => ['70'],
	'video.profile.H2631998.payloadType' => ['96'],
	'video.profile.H264.jitterBufferMax' => ['2000'],
	'video.profile.H264.jitterBufferMin' => ['150'],
	'video.profile.H264.jitterBufferShrink' => ['70'],
	'video.profile.H264.maxCpb' => ['2000'],
	'video.profile.H264.maxDpb' => ['891'],
	'video.profile.H264.maxFs' => ['396'],
	'video.profile.H264.maxMbps' => ['11880'],
	'video.profile.H264.maxRcmdNaluSize' => ['1400'],
	'video.profile.H264.packetizationMode' => ['0'],
	'video.profile.H264.payloadType' => ['109'],
	'video.profile.H264.profileLevel' => ['1.3'],
	'video.profile.H264.redundantPicCap' => ['0'],
	'video.profile.H264.spropParameterSets' => [''],
	'video.quality' => [''],
	'video.screenMode' => ['normal', '' ],
	'video.screenModeFS' => ['normal', '' ],
	'voIpProt.H323.autoGateKeeperDiscovery' => ['1'],
	'voIpProt.H323.blockFacilityOnStartH245' => ['0'],
	'voIpProt.H323.dtmfViaSignaling.H245alphanumericMode' => ['1'],
	'voIpProt.H323.dtmfViaSignaling.H245signalMode' => ['1'],
	'voIpProt.H323.dtmfViaSignaling.enabled' => ['1'],
	'voIpProt.H323.enable' => ['0'],
	'voIpProt.H323.local.RAS.port' => ['1719'],
	'voIpProt.H323.local.port' => ['1720'],
	'voIpProt.SDP.answer.useLocalPreferences' => ['0'],
	'voIpProt.SDP.early.answerOrOffer' => ['0'],
	'voIpProt.SDP.offer.iLBC.13_33kbps.includeMode' => ['1'],
	'voIpProt.SDP.useLegacyPayloadTypeNegotiation' => ['0'],
	'voIpProt.SIP.CID.sourcePreference' => [''],
	'voIpProt.SIP.WM50' => ['0'],
	'voIpProt.SIP.acceptMissingVideoFmtp' => ['1'],
	'voIpProt.SIP.acd.signalingMethod' => ['0'],
	'voIpProt.SIP.alertInfo.1.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.1.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.1.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.1.value' => [''],
	'voIpProt.SIP.alertInfo.10.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.10.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.10.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.10.value' => [''],
	'voIpProt.SIP.alertInfo.11.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.11.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.11.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.11.value' => [''],
	'voIpProt.SIP.alertInfo.12.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.12.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.12.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.12.value' => [''],
	'voIpProt.SIP.alertInfo.13.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.13.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.13.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.13.value' => [''],
	'voIpProt.SIP.alertInfo.14.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.14.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.14.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.14.value' => [''],
	'voIpProt.SIP.alertInfo.15.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.15.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.15.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.15.value' => [''],
	'voIpProt.SIP.alertInfo.16.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.16.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.16.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.16.value' => [''],
	'voIpProt.SIP.alertInfo.17.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.17.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.17.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.17.value' => [''],
	'voIpProt.SIP.alertInfo.18.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.18.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.18.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.18.value' => [''],
	'voIpProt.SIP.alertInfo.19.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.19.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.19.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.19.value' => [''],
	'voIpProt.SIP.alertInfo.2.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.2.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.2.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.2.value' => [''],
	'voIpProt.SIP.alertInfo.20.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.20.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.20.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.20.value' => [''],
	'voIpProt.SIP.alertInfo.21.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.21.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.21.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.21.value' => [''],
	'voIpProt.SIP.alertInfo.22.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.22.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.22.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.22.value' => [''],
	'voIpProt.SIP.alertInfo.3.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.3.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.3.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.3.value' => [''],
	'voIpProt.SIP.alertInfo.4.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.4.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.4.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.4.value' => [''],
	'voIpProt.SIP.alertInfo.5.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.5.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.5.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.5.value' => [''],
	'voIpProt.SIP.alertInfo.6.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.6.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.6.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.6.value' => [''],
	'voIpProt.SIP.alertInfo.7.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.7.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.7.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.7.value' => [''],
	'voIpProt.SIP.alertInfo.8.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.8.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.8.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.8.value' => [''],
	'voIpProt.SIP.alertInfo.9.callWaiting' => ['0'],
	'voIpProt.SIP.alertInfo.9.class' => ['default', '' ],
	'voIpProt.SIP.alertInfo.9.ringer' => ['0'],
	'voIpProt.SIP.alertInfo.9.value' => [''],
	'voIpProt.SIP.allowTransferOnProceeding' => ['1'],
	'voIpProt.SIP.assuredService.defaultPriority' => ['1'],
	'voIpProt.SIP.assuredService.enable' => ['0'],
	'voIpProt.SIP.assuredService.namespace' => ['UCRdsn'],
	'voIpProt.SIP.assuredService.namespace.custom.name' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.1' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.10' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.2' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.3' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.4' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.5' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.6' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.7' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.8' => [''],
	'voIpProt.SIP.assuredService.namespace.custom.priority.9' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.1' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.2' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.3' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.4' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.5' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdrsn.6' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdsn.1' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdsn.2' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdsn.3' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdsn.4' => [''],
	'voIpProt.SIP.assuredService.namespace.label.UCRdsn.5' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.1' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.10' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.2' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.3' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.4' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.5' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.6' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.7' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.8' => [''],
	'voIpProt.SIP.assuredService.namespace.label.custom.9' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.1' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.2' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.3' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.4' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.5' => [''],
	'voIpProt.SIP.assuredService.namespace.label.drsn.6' => [''],
	'voIpProt.SIP.assuredService.namespace.label.dsn.1' => [''],
	'voIpProt.SIP.assuredService.namespace.label.dsn.2' => [''],
	'voIpProt.SIP.assuredService.namespace.label.dsn.3' => [''],
	'voIpProt.SIP.assuredService.namespace.label.dsn.4' => [''],
	'voIpProt.SIP.assuredService.namespace.label.dsn.5' => [''],
	'voIpProt.SIP.assuredService.precedenceThreshold' => ['2'],
	'voIpProt.SIP.assuredService.preemptionAutoTerminationDelay.local' => ['0'],
	'voIpProt.SIP.assuredService.preemptionAutoTerminationDelay.remote' => ['3'],
	'voIpProt.SIP.assuredService.serverControlled' => ['1'],
	'voIpProt.SIP.authOptimizedInFailover' => ['0'],
	'voIpProt.SIP.compliance.RFC3261.validate.contentLanguage' => ['1'],
	'voIpProt.SIP.compliance.RFC3261.validate.contentLength' => ['1'],
	'voIpProt.SIP.compliance.RFC3261.validate.uriScheme' => ['1'],
	'voIpProt.SIP.conference.address' => [''],
	'voIpProt.SIP.connectionReuse.useAlias' => ['0'],
	'voIpProt.SIP.csta' => ['0'],
	'voIpProt.SIP.delayForIFrame' => ['400'],
	'voIpProt.SIP.dialog.usePvalue' => ['0'],
	'voIpProt.SIP.dialog.useSDP' => ['0'],
	'voIpProt.SIP.dtmfViaSignaling.rfc2976' => ['0'],
	'voIpProt.SIP.enable' => ['1'],
	'voIpProt.SIP.header.diversion.enable' => ['0'],
	'voIpProt.SIP.header.diversion.list.useFirst' => ['1'],
	'voIpProt.SIP.header.warning.codes.accept' => [''],
	'voIpProt.SIP.header.warning.enable' => ['0'],
	'voIpProt.SIP.keepalive.sessionTimers' => ['0'],
	'voIpProt.SIP.lcs' => ['0'],
	'voIpProt.SIP.lineSeize.retries' => ['10'],
	'voIpProt.SIP.local.port' => ['0', 5060 ],
	'voIpProt.SIP.musicOnHold.connectTimeout' => ['4'],
	'voIpProt.SIP.musicOnHold.uri' => [''],
	'voIpProt.SIP.outboundProxy.address' => [''],
	'voIpProt.SIP.outboundProxy.failOver.failBack.mode' => ['newRequests', '' ],
	'voIpProt.SIP.outboundProxy.failOver.failBack.timeout' => ['3600'],
	'voIpProt.SIP.outboundProxy.failOver.failRegistrationOn' => ['1'],
	'voIpProt.SIP.outboundProxy.failOver.reRegisterOn' => ['0'],
	'voIpProt.SIP.outboundProxy.port' => ['0', 5060 ],
	'voIpProt.SIP.outboundProxy.transport' => ['DNSnaptr'],
	'voIpProt.SIP.pingInterval' => ['0'],
	'voIpProt.SIP.presence.nortelShortMode' => ['0'],
	'voIpProt.SIP.requestURI.E164.addGlobalPrefix' => ['0'],
	'voIpProt.SIP.requestValidation.1.method' => [''],
	'voIpProt.SIP.requestValidation.1.request' => [''],
	'voIpProt.SIP.requestValidation.1.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.1.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.10.method' => [''],
	'voIpProt.SIP.requestValidation.10.request' => [''],
	'voIpProt.SIP.requestValidation.10.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.10.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.11.method' => [''],
	'voIpProt.SIP.requestValidation.11.request' => [''],
	'voIpProt.SIP.requestValidation.11.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.11.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.12.method' => [''],
	'voIpProt.SIP.requestValidation.12.request' => [''],
	'voIpProt.SIP.requestValidation.12.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.12.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.13.method' => [''],
	'voIpProt.SIP.requestValidation.13.request' => [''],
	'voIpProt.SIP.requestValidation.13.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.13.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.14.method' => [''],
	'voIpProt.SIP.requestValidation.14.request' => [''],
	'voIpProt.SIP.requestValidation.14.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.14.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.15.method' => [''],
	'voIpProt.SIP.requestValidation.15.request' => [''],
	'voIpProt.SIP.requestValidation.15.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.15.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.16.method' => [''],
	'voIpProt.SIP.requestValidation.16.request' => [''],
	'voIpProt.SIP.requestValidation.16.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.16.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.17.method' => [''],
	'voIpProt.SIP.requestValidation.17.request' => [''],
	'voIpProt.SIP.requestValidation.17.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.17.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.18.method' => [''],
	'voIpProt.SIP.requestValidation.18.request' => [''],
	'voIpProt.SIP.requestValidation.18.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.18.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.19.method' => [''],
	'voIpProt.SIP.requestValidation.19.request' => [''],
	'voIpProt.SIP.requestValidation.19.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.19.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.2.method' => [''],
	'voIpProt.SIP.requestValidation.2.request' => [''],
	'voIpProt.SIP.requestValidation.2.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.2.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.20.method' => [''],
	'voIpProt.SIP.requestValidation.20.request' => [''],
	'voIpProt.SIP.requestValidation.20.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.20.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.3.method' => [''],
	'voIpProt.SIP.requestValidation.3.request' => [''],
	'voIpProt.SIP.requestValidation.3.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.3.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.4.method' => [''],
	'voIpProt.SIP.requestValidation.4.request' => [''],
	'voIpProt.SIP.requestValidation.4.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.4.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.5.method' => [''],
	'voIpProt.SIP.requestValidation.5.request' => [''],
	'voIpProt.SIP.requestValidation.5.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.5.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.6.method' => [''],
	'voIpProt.SIP.requestValidation.6.request' => [''],
	'voIpProt.SIP.requestValidation.6.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.6.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.7.method' => [''],
	'voIpProt.SIP.requestValidation.7.request' => [''],
	'voIpProt.SIP.requestValidation.7.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.7.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.8.method' => [''],
	'voIpProt.SIP.requestValidation.8.request' => [''],
	'voIpProt.SIP.requestValidation.8.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.8.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.9.method' => [''],
	'voIpProt.SIP.requestValidation.9.request' => [''],
	'voIpProt.SIP.requestValidation.9.request.1.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.10.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.11.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.12.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.13.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.14.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.15.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.16.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.17.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.18.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.19.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.2.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.20.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.3.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.4.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.5.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.6.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.7.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.8.event' => [''],
	'voIpProt.SIP.requestValidation.9.request.9.event' => [''],
	'voIpProt.SIP.requestValidation.digest.realm' => ['PolycomSPIP'],
	'voIpProt.SIP.sendCompactHdrs' => ['0'],
	'voIpProt.SIP.serverFeatureControl.cf' => ['0'],
	'voIpProt.SIP.serverFeatureControl.dnd' => ['0'],
	'voIpProt.SIP.serverFeatureControl.localProcessing.cf' => ['1'],
	'voIpProt.SIP.serverFeatureControl.localProcessing.dnd' => ['1'],
	'voIpProt.SIP.specialEvent.checkSync.alwaysReboot' => ['0'],
	'voIpProt.SIP.specialEvent.lineSeize.nonStandard' => ['1'],
	'voIpProt.SIP.strictLineSeize' => ['0'],
	'voIpProt.SIP.strictReplacesHeader' => ['1'],
	'voIpProt.SIP.strictUserValidation' => ['0'],
	'voIpProt.SIP.tcpFastFailover' => ['0'],
	'voIpProt.SIP.turnOffNonSecureTransport' => ['0'],
	'voIpProt.SIP.use486forReject' => ['0'],
	'voIpProt.SIP.useCompleteUriForRetrieve' => ['1'],
	'voIpProt.SIP.useContactInReferTo' => ['0'],
	'voIpProt.SIP.useRFC2543hold' => ['0'],
	'voIpProt.SIP.useSendonlyHold' => ['1'],
	'voIpProt.local.name' => [''],
	'voIpProt.server.1.address' => [''],
	'voIpProt.server.1.expires' => ['3600'],
	'voIpProt.server.1.expires.lineSeize' => ['30'],
	'voIpProt.server.1.expires.overlap' => ['60'],
	'voIpProt.server.1.failOver.failBack.mode' => ['newRequests', ''],
	'voIpProt.server.1.failOver.failBack.timeout' => ['3600'],
	'voIpProt.server.1.failOver.failRegistrationOn' => ['1'],
	'voIpProt.server.1.failOver.reRegisterOn' => ['0'],
	'voIpProt.server.1.lcs' => ['0'],
	'voIpProt.server.1.port' => ['0', 5060],
	'voIpProt.server.1.register' => ['1'],
	'voIpProt.server.1.retryMaxCount' => ['3'],
	'voIpProt.server.1.retryTimeOut' => ['0'],
	'voIpProt.server.1.transport' => ['DNSnaptr'],
	'voIpProt.server.2.address' => [''],
	'voIpProt.server.2.expires' => ['3600'],
	'voIpProt.server.2.expires.lineSeize' => ['30'],
	'voIpProt.server.2.expires.overlap' => ['60'],
	'voIpProt.server.2.failOver.failBack.mode' => ['newRequests', ''],
	'voIpProt.server.2.failOver.failBack.timeout' => ['3600'],
	'voIpProt.server.2.failOver.failRegistrationOn' => ['1'],
	'voIpProt.server.2.failOver.reRegisterOn' => ['0'],
	'voIpProt.server.2.lcs' => ['0'],
	'voIpProt.server.2.port' => ['0', 5060],
	'voIpProt.server.2.register' => ['1'],
	'voIpProt.server.2.retryMaxCount' => ['3'],
	'voIpProt.server.2.retryTimeOut' => ['0'],
	'voIpProt.server.2.transport' => ['DNSnaptr'],
	'voIpProt.server.3.address' => [''],
	'voIpProt.server.3.expires' => ['3600'],
	'voIpProt.server.3.expires.lineSeize' => ['30'],
	'voIpProt.server.3.expires.overlap' => ['60'],
	'voIpProt.server.3.failOver.failBack.mode' => ['newRequests', ''],
	'voIpProt.server.3.failOver.failBack.timeout' => ['3600'],
	'voIpProt.server.3.failOver.failRegistrationOn' => ['1'],
	'voIpProt.server.3.failOver.reRegisterOn' => ['0'],
	'voIpProt.server.3.lcs' => ['0'],
	'voIpProt.server.3.port' => ['0', 5060],
	'voIpProt.server.3.register' => ['1'],
	'voIpProt.server.3.retryMaxCount' => ['3'],
	'voIpProt.server.3.retryTimeOut' => ['0'],
	'voIpProt.server.3.transport' => ['DNSnaptr'],
	'voIpProt.server.4.address' => [''],
	'voIpProt.server.4.expires' => ['3600'],
	'voIpProt.server.4.expires.lineSeize' => ['30'],
	'voIpProt.server.4.expires.overlap' => ['60'],
	'voIpProt.server.4.failOver.failBack.mode' => ['newRequests', ''],
	'voIpProt.server.4.failOver.failBack.timeout' => ['3600'],
	'voIpProt.server.4.failOver.failRegistrationOn' => ['1'],
	'voIpProt.server.4.failOver.reRegisterOn' => ['0'],
	'voIpProt.server.4.lcs' => ['0'],
	'voIpProt.server.4.port' => ['0', 5060],
	'voIpProt.server.4.register' => ['1'],
	'voIpProt.server.4.retryMaxCount' => ['3'],
	'voIpProt.server.4.retryTimeOut' => ['0'],
	'voIpProt.server.4.transport' => ['DNSnaptr'],
	'voIpProt.server.H323.1.address' => [''],
	'voIpProt.server.H323.1.expires' => ['3600'],
	'voIpProt.server.H323.1.port' => ['1719'],
	'voIpProt.server.H323.1.register' => ['1'],
	'voIpProt.server.H323.2.address' => [''],
	'voIpProt.server.H323.2.expires' => ['3600'],
	'voIpProt.server.H323.2.port' => ['1719'],
	'voIpProt.server.H323.2.register' => ['1'],
	'voIpProt.server.H323.3.address' => [''],
	'voIpProt.server.H323.3.expires' => ['3600'],
	'voIpProt.server.H323.3.port' => ['1719'],
	'voIpProt.server.H323.3.register' => ['1'],
	'voIpProt.server.H323.4.address' => [''],
	'voIpProt.server.H323.4.expires' => ['3600'],
	'voIpProt.server.H323.4.port' => ['1719'],
	'voIpProt.server.H323.4.register' => ['1'],
	'voIpProt.server.dhcp.available' => ['0'],
	'voIpProt.server.dhcp.option' => ['128'],
	'voIpProt.server.dhcp.type' => ['0'],
	'voice.aec.hd.enable' => ['0'],
	'voice.aec.hd.erlTab_0_300' => ['-24'],
	'voice.aec.hd.erlTab_1500_3500' => ['-24'],
	'voice.aec.hd.erlTab_300_600' => ['-24'],
	'voice.aec.hd.erlTab_3500_7000' => ['-24'],
	'voice.aec.hd.erlTab_600_1500' => ['-24'],
	'voice.aec.hd.highFreqCutOff' => ['7000'],
	'voice.aec.hd.lowFreqCutOff' => ['100'],
	'voice.aec.hf.enable' => ['1'],
	'voice.aec.hf.erlTab_0_300' => ['-6'],
	'voice.aec.hf.erlTab_1500_3500' => ['-6'],
	'voice.aec.hf.erlTab_300_600' => ['-6'],
	'voice.aec.hf.erlTab_3500_7000' => ['-6'],
	'voice.aec.hf.erlTab_600_1500' => ['-6'],
	'voice.aec.hf.highFreqCutOff' => ['7000'],
	'voice.aec.hf.lowFreqCutOff' => ['100'],
	'voice.aec.hs.enable' => ['1'],
	'voice.aec.hs.erlTab_0_300' => ['-24'],
	'voice.aec.hs.erlTab_1500_3500' => ['-24'],
	'voice.aec.hs.erlTab_300_600' => ['-24'],
	'voice.aec.hs.erlTab_3500_7000' => ['-24'],
	'voice.aec.hs.erlTab_600_1500' => ['-24'],
	'voice.aec.hs.highFreqCutOff' => ['7000'],
	'voice.aec.hs.lowFreqCutOff' => ['100'],
	'voice.aes.hd.duplexBalance' => ['0'],
	'voice.aes.hd.enable' => ['0'],
	'voice.aes.hf.duplexBalance.1' => ['9'],
	'voice.aes.hf.duplexBalance.2' => ['8'],
	'voice.aes.hf.duplexBalance.3' => ['7'],
	'voice.aes.hf.duplexBalance.4' => ['6'],
	'voice.aes.hf.duplexBalance.5' => ['5'],
	'voice.aes.hf.duplexBalance.6' => ['4'],
	'voice.aes.hf.duplexBalance.7' => ['3'],
	'voice.aes.hf.duplexBalance.8' => ['2'],
	'voice.aes.hf.duplexBalance.9' => ['1'],
	'voice.aes.hf.duplexBalance.IP_5000.1' => ['10'],
	'voice.aes.hf.duplexBalance.IP_5000.2' => ['9'],
	'voice.aes.hf.duplexBalance.IP_5000.3' => ['8'],
	'voice.aes.hf.duplexBalance.IP_5000.4' => ['7'],
	'voice.aes.hf.duplexBalance.IP_5000.5' => ['6'],
	'voice.aes.hf.duplexBalance.IP_5000.6' => ['5'],
	'voice.aes.hf.duplexBalance.IP_5000.7' => ['4'],
	'voice.aes.hf.duplexBalance.IP_5000.8' => ['3'],
	'voice.aes.hf.duplexBalance.IP_5000.9' => ['2'],
	'voice.aes.hf.duplexBalance.IP_6000.1' => ['10'],
	'voice.aes.hf.duplexBalance.IP_6000.2' => ['9'],
	'voice.aes.hf.duplexBalance.IP_6000.3' => ['8'],
	'voice.aes.hf.duplexBalance.IP_6000.4' => ['7'],
	'voice.aes.hf.duplexBalance.IP_6000.5' => ['6'],
	'voice.aes.hf.duplexBalance.IP_6000.6' => ['5'],
	'voice.aes.hf.duplexBalance.IP_6000.7' => ['4'],
	'voice.aes.hf.duplexBalance.IP_6000.8' => ['3'],
	'voice.aes.hf.duplexBalance.IP_6000.9' => ['2'],
	'voice.aes.hf.duplexBalance.IP_7000.1' => ['7'],
	'voice.aes.hf.duplexBalance.IP_7000.2' => ['7'],
	'voice.aes.hf.duplexBalance.IP_7000.3' => ['6'],
	'voice.aes.hf.duplexBalance.IP_7000.4' => ['6'],
	'voice.aes.hf.duplexBalance.IP_7000.5' => ['5'],
	'voice.aes.hf.duplexBalance.IP_7000.6' => ['4'],
	'voice.aes.hf.duplexBalance.IP_7000.7' => ['4'],
	'voice.aes.hf.duplexBalance.IP_7000.8' => ['3'],
	'voice.aes.hf.duplexBalance.IP_7000.9' => ['2'],
	'voice.aes.hf.enable' => ['1'],
	'voice.aes.hs.duplexBalance' => ['7'],
	'voice.aes.hs.enable' => ['1'],
	'voice.agc.hd.enable' => ['0'],
	'voice.agc.hf.enable' => ['0'],
	'voice.agc.hs.enable' => ['0'],
	'voice.audioProfile.G711A.jitterBufferMax' => ['160'],
	'voice.audioProfile.G711A.jitterBufferMin' => ['40'],
	'voice.audioProfile.G711A.jitterBufferShrink' => ['500'],
	'voice.audioProfile.G711A.payloadSize' => ['20'],
	'voice.audioProfile.G711A.payloadType' => ['8'],
	'voice.audioProfile.G711Mu.jitterBufferMax' => ['160'],
	'voice.audioProfile.G711Mu.jitterBufferMin' => ['40'],
	'voice.audioProfile.G711Mu.jitterBufferShrink' => ['500'],
	'voice.audioProfile.G711Mu.payloadSize' => ['20'],
	'voice.audioProfile.G711Mu.payloadType' => ['0'],
	'voice.audioProfile.G719.32kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G719.32kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G719.32kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G719.32kbps.payloadSize' => ['20'],
	'voice.audioProfile.G719.32kbps.payloadType' => ['107'],
	'voice.audioProfile.G719.48kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G719.48kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G719.48kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G719.48kbps.payloadSize' => ['20'],
	'voice.audioProfile.G719.48kbps.payloadType' => ['108'],
	'voice.audioProfile.G719.64kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G719.64kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G719.64kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G719.64kbps.payloadSize' => ['20'],
	'voice.audioProfile.G719.64kbps.payloadType' => ['109'],
	'voice.audioProfile.G722.jitterBufferMax' => ['200'],
	'voice.audioProfile.G722.jitterBufferMin' => ['40'],
	'voice.audioProfile.G722.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G722.payloadSize' => ['20'],
	'voice.audioProfile.G722.payloadType' => ['9'],
	'voice.audioProfile.G7221.16kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221.16kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221.16kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221.16kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221.16kbps.payloadType' => ['103'],
	'voice.audioProfile.G7221.24kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221.24kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221.24kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221.24kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221.24kbps.payloadType' => ['101'],
	'voice.audioProfile.G7221.32kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221.32kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221.32kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221.32kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221.32kbps.payloadType' => ['102'],
	'voice.audioProfile.G7221C.24kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221C.24kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221C.24kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221C.24kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221C.24kbps.payloadType' => ['113'],
	'voice.audioProfile.G7221C.32kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221C.32kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221C.32kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221C.32kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221C.32kbps.payloadType' => ['114'],
	'voice.audioProfile.G7221C.48kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.G7221C.48kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.G7221C.48kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.G7221C.48kbps.payloadSize' => ['20'],
	'voice.audioProfile.G7221C.48kbps.payloadType' => ['115'],
	'voice.audioProfile.G729AB.jitterBufferMax' => ['160'],
	'voice.audioProfile.G729AB.jitterBufferMin' => ['40'],
	'voice.audioProfile.G729AB.jitterBufferShrink' => ['500'],
	'voice.audioProfile.G729AB.payloadSize' => ['20'],
	'voice.audioProfile.G729AB.payloadType' => ['18'],
	'voice.audioProfile.Lin16.16ksps.jitterBufferMax' => ['100'],
	'voice.audioProfile.Lin16.16ksps.jitterBufferMin' => ['20'],
	'voice.audioProfile.Lin16.16ksps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.Lin16.16ksps.payloadSize' => ['10'],
	'voice.audioProfile.Lin16.16ksps.payloadType' => ['117'],
	'voice.audioProfile.Lin16.32ksps.jitterBufferMax' => ['100'],
	'voice.audioProfile.Lin16.32ksps.jitterBufferMin' => ['20'],
	'voice.audioProfile.Lin16.32ksps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.Lin16.32ksps.payloadSize' => ['10'],
	'voice.audioProfile.Lin16.32ksps.payloadType' => ['118'],
	'voice.audioProfile.Lin16.44_1ksps.jitterBufferMax' => ['100'],
	'voice.audioProfile.Lin16.44_1ksps.jitterBufferMin' => ['20'],
	'voice.audioProfile.Lin16.44_1ksps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.Lin16.44_1ksps.payloadSize' => ['10'],
	'voice.audioProfile.Lin16.44_1ksps.payloadType' => ['120'],
	'voice.audioProfile.Lin16.48ksps.jitterBufferMax' => ['100'],
	'voice.audioProfile.Lin16.48ksps.jitterBufferMin' => ['20'],
	'voice.audioProfile.Lin16.48ksps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.Lin16.48ksps.payloadSize' => ['10'],
	'voice.audioProfile.Lin16.48ksps.payloadType' => ['119'],
	'voice.audioProfile.Lin16.8ksps.jitterBufferMax' => ['100'],
	'voice.audioProfile.Lin16.8ksps.jitterBufferMin' => ['20'],
	'voice.audioProfile.Lin16.8ksps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.Lin16.8ksps.payloadSize' => ['10'],
	'voice.audioProfile.Lin16.8ksps.payloadType' => ['116'],
	'voice.audioProfile.Siren14.24kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren14.24kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren14.24kbps.jitterBufferShrink' => ['1500', 150 ],
	'voice.audioProfile.Siren14.24kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren14.24kbps.payloadType' => ['97'],
	'voice.audioProfile.Siren14.32kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren14.32kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren14.32kbps.jitterBufferShrink' => ['1500', 150 ],
	'voice.audioProfile.Siren14.32kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren14.32kbps.payloadType' => ['98'],
	'voice.audioProfile.Siren14.48kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren14.48kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren14.48kbps.jitterBufferShrink' => ['1500', 150 ],
	'voice.audioProfile.Siren14.48kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren14.48kbps.payloadType' => ['99'],
	'voice.audioProfile.Siren22.32kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren22.32kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren22.32kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.Siren22.32kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren22.32kbps.payloadType' => ['104', 125 ],
	'voice.audioProfile.Siren22.48kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren22.48kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren22.48kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.Siren22.48kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren22.48kbps.payloadType' => ['105', 126 ],
	'voice.audioProfile.Siren22.64kbps.jitterBufferMax' => ['200'],
	'voice.audioProfile.Siren22.64kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.Siren22.64kbps.jitterBufferShrink' => ['1500'],
	'voice.audioProfile.Siren22.64kbps.payloadSize' => ['20'],
	'voice.audioProfile.Siren22.64kbps.payloadType' => ['106', 127 ],
	'voice.audioProfile.iLBC.13_33kbps.jitterBufferMax' => ['160'],
	'voice.audioProfile.iLBC.13_33kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.iLBC.13_33kbps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.iLBC.13_33kbps.payloadSize' => ['30'],
	'voice.audioProfile.iLBC.13_33kbps.payloadType' => ['110'],
	'voice.audioProfile.iLBC.15_2kbps.jitterBufferMax' => ['160'],
	'voice.audioProfile.iLBC.15_2kbps.jitterBufferMin' => ['40'],
	'voice.audioProfile.iLBC.15_2kbps.jitterBufferShrink' => ['500'],
	'voice.audioProfile.iLBC.15_2kbps.payloadSize' => ['20'],
	'voice.audioProfile.iLBC.15_2kbps.payloadType' => ['110'],
	'voice.codecPref.G711_A' => ['7'],
	'voice.codecPref.G711_Mu' => ['6'],
	'voice.codecPref.G719.32kbps' => ['0'],
	'voice.codecPref.G719.48kbps' => ['0'],
	'voice.codecPref.G719.64kbps' => ['0'],
	'voice.codecPref.G722' => ['4'],
	'voice.codecPref.G7221.16kbps' => ['0'],
	'voice.codecPref.G7221.24kbps' => ['0'],
	'voice.codecPref.G7221.32kbps' => ['5'],
	'voice.codecPref.G7221_C.24kbps' => ['0'],
	'voice.codecPref.G7221_C.32kbps' => ['0'],
	'voice.codecPref.G7221_C.48kbps' => ['2'],
	'voice.codecPref.G729_AB' => ['8'],
	'voice.codecPref.Lin16.16ksps' => ['0'],
	'voice.codecPref.Lin16.32ksps' => ['0'],
	'voice.codecPref.Lin16.44_1ksps' => ['0'],
	'voice.codecPref.Lin16.48ksps' => ['0'],
	'voice.codecPref.Lin16.8ksps' => ['0'],
	'voice.codecPref.Siren14.24kbps' => ['0'],
	'voice.codecPref.Siren14.32kbps' => ['0'],
	'voice.codecPref.Siren14.48kbps' => ['3'],
	'voice.codecPref.Siren22.32kbps' => ['0'],
	'voice.codecPref.Siren22.48kbps' => ['0'],
	'voice.codecPref.Siren22.64kbps' => ['1'],
	'voice.codecPref.iLBC.13_33kbps' => ['0', '' ],
	'voice.codecPref.iLBC.15_2kbps' => ['0', '' ],
	'voice.gain.rx.analog.chassis.IP_330' => ['0'],
	'voice.gain.rx.analog.chassis.IP_450' => ['0'],
	'voice.gain.rx.analog.chassis.IP_5000' => ['0'],
	'voice.gain.rx.analog.chassis.IP_6000' => ['0'],
	'voice.gain.rx.analog.chassis.IP_650' => ['0'],
	'voice.gain.rx.analog.chassis.IP_7000' => ['0'],
	'voice.gain.rx.analog.chassis.VVX_1500' => ['-3'],
	'voice.gain.rx.analog.handset' => ['0'],
	'voice.gain.rx.analog.handset.VVX_1500' => ['-2'],
	'voice.gain.rx.analog.handset.sidetone' => ['-20'],
	'voice.gain.rx.analog.handset.sidetone.VVX_1500' => ['-15'],
	'voice.gain.rx.analog.headset' => ['0'],
	'voice.gain.rx.analog.headset.VVX_1500' => ['-2'],
	'voice.gain.rx.analog.headset.sidetone' => ['-24'],
	'voice.gain.rx.analog.headset.sidetone.VVX_1500' => ['-31'],
	'voice.gain.rx.analog.ringer.IP_330' => ['0'],
	'voice.gain.rx.analog.ringer.IP_450' => ['0'],
	'voice.gain.rx.analog.ringer.IP_5000' => ['0'],
	'voice.gain.rx.analog.ringer.IP_6000' => ['0'],
	'voice.gain.rx.analog.ringer.IP_650' => ['0'],
	'voice.gain.rx.analog.ringer.IP_7000' => ['0'],
	'voice.gain.rx.analog.ringer.VVX_1500' => ['0'],
	'voice.gain.rx.digital.chassis.IP_330' => ['5'],
	'voice.gain.rx.digital.chassis.IP_450' => ['5'],
	'voice.gain.rx.digital.chassis.IP_5000' => ['11'],
	'voice.gain.rx.digital.chassis.IP_6000' => ['5'],
	'voice.gain.rx.digital.chassis.IP_650' => ['5'],
	'voice.gain.rx.digital.chassis.IP_7000' => ['5'],
	'voice.gain.rx.digital.chassis.VVX_1500' => ['0'],
	'voice.gain.rx.digital.handset' => ['-15'],
	'voice.gain.rx.digital.handset.VVX_1500' => ['-15'],
	'voice.gain.rx.digital.headset' => ['-21'],
	'voice.gain.rx.digital.headset.VVX_1500' => ['-21'],
	'voice.gain.rx.digital.ringer' => ['-21'],
	'voice.gain.rx.digital.ringer.IP_330' => ['-12'],
	'voice.gain.rx.digital.ringer.IP_450' => ['-12'],
	'voice.gain.rx.digital.ringer.IP_5000' => ['-12'],
	'voice.gain.rx.digital.ringer.IP_6000' => ['-21'],
	'voice.gain.rx.digital.ringer.IP_650' => ['-12'],
	'voice.gain.rx.digital.ringer.IP_7000' => ['-21'],
	'voice.gain.rx.digital.ringer.VVX_1500' => ['-21'],
	'voice.gain.tx.analog.chassis.IP_330' => ['36'],
	'voice.gain.tx.analog.chassis.IP_450' => ['36'],
	'voice.gain.tx.analog.chassis.IP_5000' => ['0'],
	'voice.gain.tx.analog.chassis.IP_6000' => ['0'],
	'voice.gain.tx.analog.chassis.IP_650' => ['36'],
	'voice.gain.tx.analog.chassis.IP_7000' => ['0'],
	'voice.gain.tx.analog.chassis.VVX_1500' => ['-25'],
	'voice.gain.tx.analog.handset' => ['6'],
	'voice.gain.tx.analog.handset.VVX_1500' => ['-48'],
	'voice.gain.tx.analog.headset' => ['3'],
	'voice.gain.tx.analog.headset.VVX_1500' => ['-47'],
	'voice.gain.tx.digital.chassis.IP_330' => ['12'],
	'voice.gain.tx.digital.chassis.IP_450' => ['12'],
	'voice.gain.tx.digital.chassis.IP_5000' => ['15'],
	'voice.gain.tx.digital.chassis.IP_6000' => ['6'],
	'voice.gain.tx.digital.chassis.IP_650' => ['12'],
	'voice.gain.tx.digital.chassis.IP_7000' => ['6'],
	'voice.gain.tx.digital.chassis.VVX_1500' => ['3'],
	'voice.gain.tx.digital.handset' => ['0'],
	'voice.gain.tx.digital.handset.IP_330' => ['10'],
	'voice.gain.tx.digital.handset.IP_450' => ['6'],
	'voice.gain.tx.digital.handset.IP_650' => ['6'],
	'voice.gain.tx.digital.handset.VVX_1500' => ['12'],
	'voice.gain.tx.digital.headset' => ['0'],
	'voice.gain.tx.digital.headset.IP_330' => ['10'],
	'voice.gain.tx.digital.headset.IP_450' => ['6'],
	'voice.gain.tx.digital.headset.IP_650' => ['6'],
	'voice.gain.tx.digital.headset.VVX_1500' => ['12'],
	'voice.handset.rxag.adjust.IP_330' => ['1'],
	'voice.handset.rxag.adjust.IP_450' => ['1'],
	'voice.handset.rxag.adjust.IP_650' => ['1'],
	'voice.handset.sidetone.adjust.IP_330' => ['3'],
	'voice.handset.sidetone.adjust.IP_450' => ['0'],
	'voice.handset.sidetone.adjust.IP_650' => ['0'],
	'voice.handset.txag.adjust.IP_330' => ['18'],
	'voice.handset.txag.adjust.IP_450' => ['18'],
	'voice.handset.txag.adjust.IP_650' => ['18'],
	'voice.handset.wideband' => ['0'],
	'voice.headset.rxag.adjust.IP_330' => ['4'],
	'voice.headset.rxag.adjust.IP_450' => ['4'],
	'voice.headset.rxag.adjust.IP_650' => ['1'],
	'voice.headset.sidetone.adjust.IP_330' => ['-3'],
	'voice.headset.sidetone.adjust.IP_450' => ['-3'],
	'voice.headset.sidetone.adjust.IP_650' => ['-3'],
	'voice.headset.txag.adjust.IP_330' => ['21'],
	'voice.headset.txag.adjust.IP_450' => ['21'],
	'voice.headset.txag.adjust.IP_650' => ['21'],
	'voice.lineAgc.hd.enable' => ['0'],
	'voice.lineAgc.hf.enable' => ['1'],
	'voice.lineAgc.hs.enable' => ['0'],
	'voice.ns.hd.enable' => ['0'],
	'voice.ns.hd.signalAttn' => ['0'],
	'voice.ns.hd.silenceAttn' => ['0'],
	'voice.ns.hf.IP_5000.enable' => ['1'],
	'voice.ns.hf.IP_5000.signalAttn' => ['-6'],
	'voice.ns.hf.IP_5000.silenceAttn' => ['-9'],
	'voice.ns.hf.IP_6000.enable' => ['1'],
	'voice.ns.hf.IP_6000.signalAttn' => ['-6'],
	'voice.ns.hf.IP_6000.silenceAttn' => ['-9'],
	'voice.ns.hf.IP_7000.enable' => ['1'],
	'voice.ns.hf.IP_7000.signalAttn' => ['-6'],
	'voice.ns.hf.IP_7000.silenceAttn' => ['-9'],
	'voice.ns.hf.enable' => ['1'],
	'voice.ns.hf.signalAttn' => ['-6'],
	'voice.ns.hf.silenceAttn' => ['-9'],
	'voice.ns.hs.enable' => ['1'],
	'voice.ns.hs.signalAttn' => ['-6'],
	'voice.ns.hs.silenceAttn' => ['-9'],
	'voice.qualityMonitoring.collector.alert.delay.threshold.critical' => ['0'],
	'voice.qualityMonitoring.collector.alert.delay.threshold.warning' => ['0'],
	'voice.qualityMonitoring.collector.alert.moslq.threshold.critical' => ['0'],
	'voice.qualityMonitoring.collector.alert.moslq.threshold.warning' => ['0'],
	'voice.qualityMonitoring.collector.enable.periodic' => ['0'],
	'voice.qualityMonitoring.collector.enable.session' => ['0'],
	'voice.qualityMonitoring.collector.enable.triggeredPeriodic' => ['0'],
	'voice.qualityMonitoring.collector.period' => ['20'],
	'voice.qualityMonitoring.collector.server.1.address' => [''],
	'voice.qualityMonitoring.collector.server.1.port' => ['5060'],
	'voice.qualityMonitoring.rtcpxr.enable' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.1' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.10' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.11' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.12' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.13' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.14' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.15' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.16' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.17' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.18' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.19' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.2' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.20' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.21' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.22' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.23' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.24' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.25' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.26' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.27' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.28' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.29' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.3' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.30' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.31' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.32' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.33' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.34' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.35' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.36' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.37' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.38' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.39' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.4' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.40' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.41' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.42' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.43' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.44' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.45' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.46' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.47' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.48' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.49' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.5' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.50' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.51' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.52' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.53' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.54' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.55' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.56' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.57' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.58' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.59' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.6' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.60' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.61' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.62' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.63' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.64' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.7' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.8' => ['0'],
	'voice.rxEq.hf.postFilter.1.coef.9' => ['0'],
	'voice.rxEq.hf.postFilter.1.shift' => ['0'],
	'voice.rxEq.hf.postFilter.1.size' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.1' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.10' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.11' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.12' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.13' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.14' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.15' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.16' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.17' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.18' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.19' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.2' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.20' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.21' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.22' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.23' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.24' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.25' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.26' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.27' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.28' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.29' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.3' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.30' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.31' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.32' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.33' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.34' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.35' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.36' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.37' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.38' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.39' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.4' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.40' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.41' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.42' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.43' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.44' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.45' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.46' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.47' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.48' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.49' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.5' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.50' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.51' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.52' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.53' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.54' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.55' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.56' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.57' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.58' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.59' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.6' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.60' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.61' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.62' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.63' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.64' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.7' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.8' => ['0'],
	'voice.rxEq.hf.postFilter.2.coef.9' => ['0'],
	'voice.rxEq.hf.postFilter.2.shift' => ['0'],
	'voice.rxEq.hf.postFilter.2.size' => ['0'],
	'voice.rxEq.hf.postFilter.enable' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.1' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.10' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.11' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.12' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.13' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.14' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.15' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.16' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.17' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.18' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.19' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.2' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.20' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.21' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.22' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.23' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.24' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.25' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.26' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.27' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.28' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.29' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.3' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.30' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.31' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.32' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.33' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.34' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.35' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.36' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.37' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.38' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.39' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.4' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.40' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.41' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.42' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.43' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.44' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.45' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.46' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.47' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.48' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.49' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.5' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.50' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.51' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.52' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.53' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.54' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.55' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.56' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.57' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.58' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.59' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.6' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.60' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.61' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.62' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.63' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.64' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.7' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.8' => ['0'],
	'voice.rxEq.hf.preFilter.1.coef.9' => ['0'],
	'voice.rxEq.hf.preFilter.1.shift' => ['0'],
	'voice.rxEq.hf.preFilter.1.size' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.1' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.10' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.11' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.12' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.13' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.14' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.15' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.16' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.17' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.18' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.19' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.2' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.20' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.21' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.22' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.23' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.24' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.25' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.26' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.27' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.28' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.29' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.3' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.30' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.31' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.32' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.33' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.34' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.35' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.36' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.37' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.38' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.39' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.4' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.40' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.41' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.42' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.43' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.44' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.45' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.46' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.47' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.48' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.49' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.5' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.50' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.51' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.52' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.53' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.54' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.55' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.56' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.57' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.58' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.59' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.6' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.60' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.61' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.62' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.63' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.64' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.7' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.8' => ['0'],
	'voice.rxEq.hf.preFilter.2.coef.9' => ['0'],
	'voice.rxEq.hf.preFilter.2.shift' => ['0'],
	'voice.rxEq.hf.preFilter.2.size' => ['0'],
	'voice.rxEq.hf.preFilter.enable' => ['1'],
	'voice.rxEq.hs.postFilter.1.coef.1' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.10' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.11' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.12' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.13' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.14' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.15' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.16' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.17' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.18' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.19' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.2' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.20' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.21' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.22' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.23' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.24' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.25' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.26' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.27' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.28' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.29' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.3' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.30' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.31' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.32' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.33' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.34' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.35' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.36' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.37' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.38' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.39' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.4' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.40' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.41' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.42' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.43' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.44' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.45' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.46' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.47' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.48' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.49' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.5' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.50' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.51' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.52' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.53' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.54' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.55' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.56' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.57' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.58' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.59' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.6' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.60' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.61' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.62' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.63' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.64' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.7' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.8' => ['0'],
	'voice.rxEq.hs.postFilter.1.coef.9' => ['0'],
	'voice.rxEq.hs.postFilter.1.shift' => ['0'],
	'voice.rxEq.hs.postFilter.1.size' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.1' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.10' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.11' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.12' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.13' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.14' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.15' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.16' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.17' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.18' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.19' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.2' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.20' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.21' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.22' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.23' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.24' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.25' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.26' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.27' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.28' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.29' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.3' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.30' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.31' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.32' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.33' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.34' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.35' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.36' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.37' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.38' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.39' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.4' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.40' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.41' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.42' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.43' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.44' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.45' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.46' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.47' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.48' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.49' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.5' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.50' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.51' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.52' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.53' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.54' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.55' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.56' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.57' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.58' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.59' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.6' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.60' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.61' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.62' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.63' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.64' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.7' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.8' => ['0'],
	'voice.rxEq.hs.postFilter.2.coef.9' => ['0'],
	'voice.rxEq.hs.postFilter.2.shift' => ['0'],
	'voice.rxEq.hs.postFilter.2.size' => ['0'],
	'voice.rxEq.hs.postFilter.enable' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.1' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.10' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.11' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.12' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.13' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.14' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.15' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.16' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.17' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.18' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.19' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.2' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.20' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.21' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.22' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.23' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.24' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.25' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.26' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.27' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.28' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.29' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.3' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.30' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.31' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.32' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.33' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.34' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.35' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.36' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.37' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.38' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.39' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.4' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.40' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.41' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.42' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.43' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.44' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.45' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.46' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.47' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.48' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.49' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.5' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.50' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.51' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.52' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.53' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.54' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.55' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.56' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.57' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.58' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.59' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.6' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.60' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.61' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.62' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.63' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.64' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.7' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.8' => ['0'],
	'voice.rxEq.hs.preFilter.1.coef.9' => ['0'],
	'voice.rxEq.hs.preFilter.1.shift' => ['0'],
	'voice.rxEq.hs.preFilter.1.size' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.1' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.10' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.11' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.12' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.13' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.14' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.15' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.16' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.17' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.18' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.19' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.2' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.20' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.21' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.22' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.23' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.24' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.25' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.26' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.27' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.28' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.29' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.3' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.30' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.31' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.32' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.33' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.34' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.35' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.36' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.37' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.38' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.39' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.4' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.40' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.41' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.42' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.43' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.44' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.45' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.46' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.47' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.48' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.49' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.5' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.50' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.51' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.52' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.53' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.54' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.55' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.56' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.57' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.58' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.59' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.6' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.60' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.61' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.62' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.63' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.64' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.7' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.8' => ['0'],
	'voice.rxEq.hs.preFilter.2.coef.9' => ['0'],
	'voice.rxEq.hs.preFilter.2.shift' => ['0'],
	'voice.rxEq.hs.preFilter.2.size' => ['0'],
	'voice.rxEq.hs.preFilter.enable' => ['1'],
	'voice.rxQos.avgJitter' => ['20'],
	'voice.rxQos.maxJitter' => ['160'],
	'voice.txEq.hf.postFilter.1.coef.1' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.10' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.11' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.12' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.13' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.14' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.15' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.16' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.17' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.18' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.19' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.2' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.20' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.21' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.22' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.23' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.24' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.25' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.26' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.27' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.28' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.29' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.3' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.30' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.31' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.32' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.33' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.34' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.35' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.36' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.37' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.38' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.39' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.4' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.40' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.41' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.42' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.43' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.44' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.45' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.46' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.47' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.48' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.49' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.5' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.50' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.51' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.52' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.53' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.54' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.55' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.56' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.57' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.58' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.59' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.6' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.60' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.61' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.62' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.63' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.64' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.7' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.8' => ['0'],
	'voice.txEq.hf.postFilter.1.coef.9' => ['0'],
	'voice.txEq.hf.postFilter.1.shift' => ['0'],
	'voice.txEq.hf.postFilter.1.size' => ['0'],
	'voice.txEq.hf.postFilter.enable' => ['1'],
	'voice.txEq.hf.preFilter.1.coef.1' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.10' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.11' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.12' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.13' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.14' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.15' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.16' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.17' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.18' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.19' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.2' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.20' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.21' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.22' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.23' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.24' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.25' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.26' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.27' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.28' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.29' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.3' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.30' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.31' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.32' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.33' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.34' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.35' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.36' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.37' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.38' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.39' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.4' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.40' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.41' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.42' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.43' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.44' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.45' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.46' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.47' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.48' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.49' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.5' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.50' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.51' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.52' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.53' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.54' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.55' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.56' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.57' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.58' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.59' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.6' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.60' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.61' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.62' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.63' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.64' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.7' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.8' => ['0'],
	'voice.txEq.hf.preFilter.1.coef.9' => ['0'],
	'voice.txEq.hf.preFilter.1.shift' => ['0'],
	'voice.txEq.hf.preFilter.1.size' => ['0'],
	'voice.txEq.hf.preFilter.enable' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.1' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.10' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.11' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.12' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.13' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.14' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.15' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.16' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.17' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.18' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.19' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.2' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.20' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.21' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.22' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.23' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.24' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.25' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.26' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.27' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.28' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.29' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.3' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.30' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.31' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.32' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.33' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.34' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.35' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.36' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.37' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.38' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.39' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.4' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.40' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.41' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.42' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.43' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.44' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.45' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.46' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.47' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.48' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.49' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.5' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.50' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.51' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.52' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.53' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.54' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.55' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.56' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.57' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.58' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.59' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.6' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.60' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.61' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.62' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.63' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.64' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.7' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.8' => ['0'],
	'voice.txEq.hs.postFilter.1.coef.9' => ['0'],
	'voice.txEq.hs.postFilter.1.shift' => ['0'],
	'voice.txEq.hs.postFilter.1.size' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.1' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.10' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.11' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.12' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.13' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.14' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.15' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.16' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.17' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.18' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.19' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.2' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.20' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.21' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.22' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.23' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.24' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.25' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.26' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.27' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.28' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.29' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.3' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.30' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.31' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.32' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.33' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.34' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.35' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.36' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.37' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.38' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.39' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.4' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.40' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.41' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.42' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.43' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.44' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.45' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.46' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.47' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.48' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.49' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.5' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.50' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.51' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.52' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.53' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.54' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.55' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.56' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.57' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.58' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.59' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.6' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.60' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.61' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.62' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.63' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.64' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.7' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.8' => ['0'],
	'voice.txEq.hs.postFilter.2.coef.9' => ['0'],
	'voice.txEq.hs.postFilter.2.shift' => ['0'],
	'voice.txEq.hs.postFilter.2.size' => ['0'],
	'voice.txEq.hs.postFilter.enable' => ['1'],
	'voice.txEq.hs.preFilter.1.coef.1' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.10' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.11' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.12' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.13' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.14' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.15' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.16' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.17' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.18' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.19' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.2' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.20' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.21' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.22' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.23' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.24' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.25' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.26' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.27' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.28' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.29' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.3' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.30' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.31' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.32' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.33' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.34' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.35' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.36' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.37' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.38' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.39' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.4' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.40' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.41' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.42' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.43' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.44' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.45' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.46' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.47' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.48' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.49' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.5' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.50' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.51' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.52' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.53' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.54' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.55' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.56' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.57' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.58' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.59' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.6' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.60' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.61' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.62' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.63' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.64' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.7' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.8' => ['0'],
	'voice.txEq.hs.preFilter.1.coef.9' => ['0'],
	'voice.txEq.hs.preFilter.1.shift' => ['0'],
	'voice.txEq.hs.preFilter.1.size' => ['0'],
	'voice.txEq.hs.preFilter.enable' => ['0'],
	'voice.txPacketDelay' => [''],
	'voice.txPacketFilter' => ['0'],
	'voice.vad.signalAnnexB' => ['1'],
	'voice.vadEnable' => ['0'],
	'voice.vadThresh' => ['15'],
	'voice.volume.persist.handset' => ['0'],
	'voice.volume.persist.handsfree' => ['1'],
	'voice.volume.persist.headset' => ['0'],
	'xmpp.1.allowIM' => ['1'],
	'xmpp.1.auth.domain' => [''],
	'xmpp.1.auth.password' => [''],
	'xmpp.1.auth.useLoginCredentials' => ['0'],
	'xmpp.1.dialMethod' => ['sip'],
	'xmpp.1.dirCorp.name' => [''],
	'xmpp.1.enable' => ['0'],
	'xmpp.1.jid' => [''],
	'xmpp.1.mode' => ['normal'],
	'xmpp.1.privacy' => ['0'],
	'xmpp.1.regMap' => ['1'],
	'xmpp.1.roster.invite.accept' => ['automatic'],
	'xmpp.1.roster.invite.addMethod' => ['h350Person'],
	'xmpp.1.roster.subscription.symetric' => ['1'],
	'xmpp.1.server' => [''],
	'xmpp.1.verifyCert' => ['1'],
	'voice.codecPref.iLBC.13_33kbps.SPIP320' => ['0'],
	'voice.codecPref.iLBC.13_33kbps.SPIP321' => ['0'],
	'voice.codecPref.iLBC.13_33kbps.SPIP330' => ['0'],
	'voice.codecPref.iLBC.13_33kbps.SPIP331' => ['0'],
	'voice.codecPref.iLBC.15_2kbps.SPIP320' => ['0'],
	'voice.codecPref.iLBC.15_2kbps.SPIP321' => ['0'],
	'voice.codecPref.iLBC.15_2kbps.SPIP330' => ['0'],
	'voice.codecPref.iLBC.15_2kbps.SPIP331' => ['0'],
};

}



1;
